/* Generated by Cython 0.29.26 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "lark_cython.lark_cython",
        "sources": [
            "lark_cython\\lark_cython.pyx"
        ]
    },
    "module_name": "lark_cython.lark_cython"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_26"
#define CYTHON_HEX_VERSION 0x001D1AF0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL (PY_VERSION_HEX < 0x030B00A1)
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *call_result=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject* co=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(0))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto cleanup_code_too;
        if (!(empty = PyTuple_New(0))) goto cleanup_code_too; // unfortunately __pyx_empty_tuple isn't available here
        if (!(call_result = PyObject_Call(replace, empty, kwds))) goto cleanup_code_too;
        Py_XDECREF((PyObject*)co);
        co = (PyCodeObject*)call_result;
        call_result = NULL;
        if (0) {
            cleanup_code_too:
            Py_XDECREF((PyObject*)co);
            co = NULL;
        }
        end:
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(call_result);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return co;
    }
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if defined(PyUnicode_IS_READY)
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #else
  #define __Pyx_PyUnicode_READY(op)       (0)
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #endif
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__lark_cython__lark_cython
#define __PYX_HAVE_API__lark_cython__lark_cython
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "lark_cython\\lark_cython.pyx",
  "stringsource",
};

/*--- Type declarations ---*/
struct __pyx_obj_11lark_cython_11lark_cython_Token;
struct __pyx_obj_11lark_cython_11lark_cython_LexerState;
struct __pyx_obj_11lark_cython_11lark_cython_LineCounter;
struct __pyx_obj_11lark_cython_11lark_cython_Scanner;
struct __pyx_obj_11lark_cython_11lark_cython_Lexer;
struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer;
struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer;
struct __pyx_obj_11lark_cython_11lark_cython_LexerThread;
struct __pyx_obj_11lark_cython_11lark_cython_ParseConf;
struct __pyx_obj_11lark_cython_11lark_cython_ParserState;
struct __pyx_obj_11lark_cython_11lark_cython__Parser;
struct __pyx_obj_11lark_cython_11lark_cython_Meta;
struct __pyx_obj_11lark_cython_11lark_cython_Tree;
struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild;
struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions;
struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter;
struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR;
struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders;
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback;
struct __pyx_opt_args_11lark_cython_11lark_cython_5Token_update;
struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token;

/* "lark_cython/lark_cython.pyx":36
 *         self.end_pos = end_pos
 * 
 *     cdef update(self, type_: Optional[str]=None, value: Optional[Any]=None):             # <<<<<<<<<<<<<<
 *         return Token.new_borrow_pos(
 *             type_ if type_ is not None else self.type,
 */
struct __pyx_opt_args_11lark_cython_11lark_cython_5Token_update {
  int __pyx_n;
  PyObject *type_;
  PyObject *value;
};

/* "lark_cython/lark_cython.pyx":436
 *         return copy(self)
 * 
 *     cdef feed_token(self, Token token, bint is_end=False):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list state_stack = self.state_stack
 */
struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token {
  int __pyx_n;
  int is_end;
};

/* "lark_cython/lark_cython.pyx":16
 * 
 * @cython.freelist(10240)
 * cdef class Token:             # <<<<<<<<<<<<<<
 *     cdef public str type
 *     cdef public int start_pos
 */
struct __pyx_obj_11lark_cython_11lark_cython_Token {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_Token *__pyx_vtab;
  PyObject *type;
  int start_pos;
  PyObject *value;
  int line;
  int column;
  PyObject *end_line;
  PyObject *end_column;
  PyObject *end_pos;
};


/* "lark_cython/lark_cython.pyx":65
 *         return hash(self.value)
 * 
 * cdef class LexerState:             # <<<<<<<<<<<<<<
 *     __slots__ = 'text', 'line_ctr', 'last_token'
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_LexerState {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerState *__pyx_vtab;
  PyObject *text;
  struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *line_ctr;
  PyObject *last_token;
};


/* "lark_cython/lark_cython.pyx":86
 *         return type(self)(self.text, copy(self.line_ctr), self.last_token)
 * 
 * cdef class LineCounter:             # <<<<<<<<<<<<<<
 *     __slots__ = 'char_pos', 'line', 'column', 'line_start_pos', 'newline_char'
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_LineCounter {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_LineCounter *__pyx_vtab;
  PyObject *newline_char;
  int char_pos;
  int line;
  int column;
  int line_start_pos;
};


/* "lark_cython/lark_cython.pyx":125
 * 
 * 
 * cdef class Scanner:             # <<<<<<<<<<<<<<
 *     cdef public terminals
 *     cdef public int g_regex_flags
 */
struct __pyx_obj_11lark_cython_11lark_cython_Scanner {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_Scanner *__pyx_vtab;
  PyObject *terminals;
  int g_regex_flags;
  PyObject *re_;
  PyObject *use_bytes;
  PyObject *match_whole;
  PyObject *allowed_types;
  PyObject *_mres;
};


/* "lark_cython/lark_cython.pyx":171
 * 
 * 
 * cdef class Lexer:             # <<<<<<<<<<<<<<
 *     """Lexer interface
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_Lexer {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer *__pyx_vtab;
};


/* "lark_cython/lark_cython.pyx":187
 *         return LexerThread(self, text)
 * 
 * cdef class BasicLexer(Lexer):             # <<<<<<<<<<<<<<
 * 
 *     cdef list terminals #: Collection[TerminalDef]
 */
struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer {
  struct __pyx_obj_11lark_cython_11lark_cython_Lexer __pyx_base;
  PyObject *terminals;
  PyObject *ignore_types;
  PyObject *newline_types;
  PyObject *user_callbacks;
  PyObject *callback;
  PyObject *re;
  int g_regex_flags;
  int use_bytes;
  PyObject *terminals_by_name;
  struct __pyx_obj_11lark_cython_11lark_cython_Scanner *_scanner;
};


/* "lark_cython/lark_cython.pyx":301
 *         raise EOFError(self)
 * 
 * cdef class ContextualLexer(Lexer):             # <<<<<<<<<<<<<<
 * 
 *     cdef dict lexers #: Dict[str, BasicLexer]
 */
struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer {
  struct __pyx_obj_11lark_cython_11lark_cython_Lexer __pyx_base;
  PyObject *lexers;
  struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *root_lexer;
};


/* "lark_cython/lark_cython.pyx":353
 * 
 * 
 * cdef class LexerThread:             # <<<<<<<<<<<<<<
 *     """A thread that ties a lexer instance and a lexer state, to be used by the parser"""
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_LexerThread {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerThread *__pyx_vtab;
  struct __pyx_obj_11lark_cython_11lark_cython_Lexer *lexer;
  PyObject *state;
};


/* "lark_cython/lark_cython.pyx":383
 * 
 * 
 * cdef class ParseConf:             # <<<<<<<<<<<<<<
 *     __slots__ = 'parse_table', 'callbacks', 'start', 'start_state', 'end_state', 'states'
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_ParseConf {
  PyObject_HEAD
  PyObject *parse_table;
  int start_state;
  int end_state;
  PyObject *states;
  PyObject *callbacks;
  PyObject *start;
};


/* "lark_cython/lark_cython.pyx":402
 * 
 * 
 * cdef class ParserState:             # <<<<<<<<<<<<<<
 *     __slots__ = 'parse_conf', 'lexer', 'state_stack', 'value_stack'
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_ParserState {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_ParserState *__pyx_vtab;
  struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *parse_conf;
  struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *lexer;
  PyObject *value_stack;
  PyObject *state_stack;
};


/* "lark_cython/lark_cython.pyx":490
 *                     return value_stack[-1]
 * 
 * cdef class _Parser:             # <<<<<<<<<<<<<<
 *     cdef parse_table
 *     cdef dict callbacks
 */
struct __pyx_obj_11lark_cython_11lark_cython__Parser {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython__Parser *__pyx_vtab;
  PyObject *parse_table;
  PyObject *callbacks;
  int debug;
};


/* "lark_cython/lark_cython.pyx":602
 * from collections import OrderedDict
 * 
 * cdef class Meta:             # <<<<<<<<<<<<<<
 * 
 *     cdef public bint empty
 */
struct __pyx_obj_11lark_cython_11lark_cython_Meta {
  PyObject_HEAD
  int empty;
  int line;
  int column;
  int start_pos;
  int end_line;
  int end_column;
  int end_pos;
  PyObject *orig_expansion;
  int match_tree;
};


/* "lark_cython/lark_cython.pyx":622
 *     Token
 * 
 * cdef class Tree:             # <<<<<<<<<<<<<<
 *     cdef public Token data
 *     cdef public list children #: 'List[Union[str, Tree]]'
 */
struct __pyx_obj_11lark_cython_11lark_cython_Tree {
  PyObject_HEAD
  struct __pyx_obj_11lark_cython_11lark_cython_Token *data;
  PyObject *children;
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *_meta;
};


/* "lark_cython/lark_cython.pyx":779
 *     return f
 * 
 * cdef class ExpandSingleChild:             # <<<<<<<<<<<<<<
 *     cdef node_builder
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild {
  PyObject_HEAD
  PyObject *node_builder;
};


/* "lark_cython/lark_cython.pyx":792
 * 
 * 
 * cdef class PropagatePositions:             # <<<<<<<<<<<<<<
 *     cdef node_builder
 *     cdef node_filter
 */
struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions {
  PyObject_HEAD
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_PropagatePositions *__pyx_vtab;
  PyObject *node_builder;
  PyObject *node_filter;
};


/* "lark_cython/lark_cython.pyx":859
 * 
 * 
 * cdef class ChildFilter:             # <<<<<<<<<<<<<<
 *     cdef readonly node_builder
 *     cdef readonly list to_include
 */
struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter {
  PyObject_HEAD
  PyObject *node_builder;
  PyObject *to_include;
  PyObject *append_none;
};


/* "lark_cython/lark_cython.pyx":887
 * 
 * 
 * cdef class ChildFilterLALR(ChildFilter):             # <<<<<<<<<<<<<<
 *     """Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)"""
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR {
  struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter __pyx_base;
};


/* "lark_cython/lark_cython.pyx":914
 * 
 * 
 * cdef class ChildFilterLALR_NoPlaceholders(ChildFilter):             # <<<<<<<<<<<<<<
 *     "Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)"
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders {
  struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter __pyx_base;
};


/* "lark_cython/lark_cython.pyx":145
 *         self._mres = self._build_mres(terminals, len(terminals))
 * 
 *     def _build_mres(self, terminals, max_size):             # <<<<<<<<<<<<<<
 *         # Python sets an unreasonable group limit (currently 100) in its re module
 *         # Worse, the only way to know we reached it is by catching an AssertionError!
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres {
  PyObject_HEAD
  PyObject *__pyx_v_max_size;
  PyObject *__pyx_v_postfix;
  PyObject *__pyx_v_terminals;
};


/* "lark_cython/lark_cython.pyx":152
 *         mres = []
 *         while terminals:
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])             # <<<<<<<<<<<<<<
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *__pyx_outer_scope;
  PyObject *__pyx_v_t;
};


/* "lark_cython/lark_cython.pyx":201
 *     cdef Scanner _scanner
 * 
 *     def __init__(self, conf: 'LexerConf') -> None:             # <<<<<<<<<<<<<<
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ {
  PyObject_HEAD
  PyObject *__pyx_v_terminals;
};


/* "lark_cython/lark_cython.pyx":203
 *     def __init__(self, conf: 'LexerConf') -> None:
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals             # <<<<<<<<<<<<<<
 * 
 *         self.re = conf.re_module
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_t;
};


/* "lark_cython/lark_cython.pyx":222
 * 
 *         # Init
 *         self.newline_types = frozenset(t.name for t in terminals if _regexp_has_newline(t.pattern.to_regexp()))             # <<<<<<<<<<<<<<
 *         self.ignore_types = frozenset(conf.ignore)
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *__pyx_outer_scope;
  PyObject *__pyx_v_t;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
};


/* "lark_cython/lark_cython.pyx":234
 *         self._scanner = None
 * 
 *     def _build_scanner(self):             # <<<<<<<<<<<<<<
 *         terminals, self.callback = _create_unless(self.terminals, self.g_regex_flags, self.re, self.use_bytes)
 *         assert all(self.callback.values())
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner {
  PyObject_HEAD
  PyObject *__pyx_v_type_;
};


/* "lark_cython/lark_cython.pyx":695
 *         return filter(pred, self.iter_subtrees())
 * 
 *     def find_data(self, data: str) -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Returns all nodes of the tree whose data equals the given data."""
 *         return self.find_pred(lambda t: t.data == data)
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data {
  PyObject_HEAD
  PyObject *__pyx_v_data;
};


/* "lark_cython/lark_cython.pyx":712
 * 
 * 
 *     def scan_values(self, pred: 'Callable[[Union[str, Tree]], bool]') -> Iterator[str]:             # <<<<<<<<<<<<<<
 *         """Return all values in the tree that evaluate pred(value) as true.
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values {
  PyObject_HEAD
  PyObject *__pyx_v_c;
  PyObject *__pyx_v_pred;
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self;
  PyObject *__pyx_v_t;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
};


/* "lark_cython/lark_cython.pyx":728
 *                     yield c
 * 
 *     def iter_subtrees_topdown(self):             # <<<<<<<<<<<<<<
 *         """Breadth-first iteration.
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown {
  PyObject_HEAD
  PyObject *__pyx_v_n;
  PyObject *__pyx_v_node;
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self;
  PyObject *__pyx_v_stack;
};


/* "lark_cython/lark_cython.pyx":761
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 * def apply_visit_wrapper(func, name, wrapper):             # <<<<<<<<<<<<<<
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper {
  PyObject_HEAD
  PyObject *__pyx_v_func;
  PyObject *__pyx_v_name;
  PyObject *__pyx_v_wrapper;
};


/* "lark_cython/lark_cython.pyx":770
 *     return f
 * 
 * def inplace_transformer(func):             # <<<<<<<<<<<<<<
 *     @wraps(func)
 *     def f(list children):
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer {
  PyObject_HEAD
  PyObject *__pyx_v_func;
};


/* "lark_cython/lark_cython.pyx":946
 * 
 * 
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):             # <<<<<<<<<<<<<<
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter {
  PyObject_HEAD
  PyObject *__pyx_v__empty_indices;
  PyObject *__pyx_v_to_include;
};


/* "lark_cython/lark_cython.pyx":950
 *     if _empty_indices:
 *         assert _empty_indices.count(False) == len(expansion)
 *         s = ''.join(str(int(b)) for b in _empty_indices)             # <<<<<<<<<<<<<<
 *         empty_indices = [len(ones) for ones in s.split('0')]
 *         assert len(empty_indices) == len(expansion)+1, (empty_indices, len(expansion))
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *__pyx_outer_scope;
  PyObject *__pyx_v_b;
};


/* "lark_cython/lark_cython.pyx":966
 *     nones_to_add += empty_indices[len(expansion)]
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):             # <<<<<<<<<<<<<<
 *         if _empty_indices or ambiguous:
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr {
  PyObject_HEAD
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *__pyx_outer_scope;
  PyObject *__pyx_v__;
  PyObject *__pyx_v_i;
  PyObject *__pyx_v_to_expand;
};


/* "lark_cython/lark_cython.pyx":984
 *         self.rule_builders = list(self._init_builders(rules))
 * 
 *     def _init_builders(self, rules):             # <<<<<<<<<<<<<<
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders {
  PyObject_HEAD
  PyObject *__pyx_v_expand_single_child;
  PyObject *__pyx_v_keep_all_tokens;
  PyObject *__pyx_v_options;
  PyObject *__pyx_v_propagate_positions;
  PyObject *__pyx_v_rule;
  PyObject *__pyx_v_rules;
  PyObject *__pyx_v_self;
  PyObject *__pyx_v_wrapper_chain;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "lark_cython/lark_cython.pyx":1000
 *             yield rule, wrapper_chain
 * 
 *     def create_callback(self, transformer=None):             # <<<<<<<<<<<<<<
 *         callbacks = {}
 * 
 */
struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback {
  PyObject_HEAD
  PyObject *__pyx_v_default_handler;
};



/* "lark_cython/lark_cython.pyx":16
 * 
 * @cython.freelist(10240)
 * cdef class Token:             # <<<<<<<<<<<<<<
 *     cdef public str type
 *     cdef public int start_pos
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_Token {
  PyObject *(*update)(struct __pyx_obj_11lark_cython_11lark_cython_Token *, struct __pyx_opt_args_11lark_cython_11lark_cython_5Token_update *__pyx_optional_args);
  PyObject *(*__pyx___reduce__)(struct __pyx_obj_11lark_cython_11lark_cython_Token *);
  PyObject *(*__pyx___deepcopy__)(struct __pyx_obj_11lark_cython_11lark_cython_Token *, PyObject *);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_Token *__pyx_vtabptr_11lark_cython_11lark_cython_Token;


/* "lark_cython/lark_cython.pyx":65
 *         return hash(self.value)
 * 
 * cdef class LexerState:             # <<<<<<<<<<<<<<
 *     __slots__ = 'text', 'line_ctr', 'last_token'
 * 
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerState {
  PyObject *(*__pyx___copy__)(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerState *__pyx_vtabptr_11lark_cython_11lark_cython_LexerState;


/* "lark_cython/lark_cython.pyx":86
 *         return type(self)(self.text, copy(self.line_ctr), self.last_token)
 * 
 * cdef class LineCounter:             # <<<<<<<<<<<<<<
 *     __slots__ = 'char_pos', 'line', 'column', 'line_start_pos', 'newline_char'
 * 
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_LineCounter {
  PyObject *(*feed)(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *, PyObject *, int, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_LineCounter *__pyx_vtabptr_11lark_cython_11lark_cython_LineCounter;


/* "lark_cython/lark_cython.pyx":125
 * 
 * 
 * cdef class Scanner:             # <<<<<<<<<<<<<<
 *     cdef public terminals
 *     cdef public int g_regex_flags
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_Scanner {
  PyObject *(*match)(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *, PyObject *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_Scanner *__pyx_vtabptr_11lark_cython_11lark_cython_Scanner;


/* "lark_cython/lark_cython.pyx":171
 * 
 * 
 * cdef class Lexer:             # <<<<<<<<<<<<<<
 *     """Lexer interface
 * 
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer {
  PyObject *(*make_lexer_state)(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *, PyObject *);
  PyObject *(*make_lexer_thread)(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer *__pyx_vtabptr_11lark_cython_11lark_cython_Lexer;


/* "lark_cython/lark_cython.pyx":187
 *         return LexerThread(self, text)
 * 
 * cdef class BasicLexer(Lexer):             # <<<<<<<<<<<<<<
 * 
 *     cdef list terminals #: Collection[TerminalDef]
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer {
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer __pyx_base;
  PyObject *(*match)(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *, PyObject *, PyObject *);
  PyObject *(*next_token)(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer *__pyx_vtabptr_11lark_cython_11lark_cython_BasicLexer;


/* "lark_cython/lark_cython.pyx":301
 *         raise EOFError(self)
 * 
 * cdef class ContextualLexer(Lexer):             # <<<<<<<<<<<<<<
 * 
 *     cdef dict lexers #: Dict[str, BasicLexer]
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_ContextualLexer {
  struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer __pyx_base;
  PyObject *(*make_lexer_state)(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*next_token)(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_ContextualLexer *__pyx_vtabptr_11lark_cython_11lark_cython_ContextualLexer;


/* "lark_cython/lark_cython.pyx":353
 * 
 * 
 * cdef class LexerThread:             # <<<<<<<<<<<<<<
 *     """A thread that ties a lexer instance and a lexer state, to be used by the parser"""
 * 
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerThread {
  PyObject *(*next_token)(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerThread *__pyx_vtabptr_11lark_cython_11lark_cython_LexerThread;


/* "lark_cython/lark_cython.pyx":402
 * 
 * 
 * cdef class ParserState:             # <<<<<<<<<<<<<<
 *     __slots__ = 'parse_conf', 'lexer', 'state_stack', 'value_stack'
 * 
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_ParserState {
  PyObject *(*feed_token)(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *, struct __pyx_obj_11lark_cython_11lark_cython_Token *, struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token *__pyx_optional_args);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_ParserState *__pyx_vtabptr_11lark_cython_11lark_cython_ParserState;


/* "lark_cython/lark_cython.pyx":490
 *                     return value_stack[-1]
 * 
 * cdef class _Parser:             # <<<<<<<<<<<<<<
 *     cdef parse_table
 *     cdef dict callbacks
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython__Parser {
  PyObject *(*parse_from_state)(struct __pyx_obj_11lark_cython_11lark_cython__Parser *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython__Parser *__pyx_vtabptr_11lark_cython_11lark_cython__Parser;


/* "lark_cython/lark_cython.pyx":792
 * 
 * 
 * cdef class PropagatePositions:             # <<<<<<<<<<<<<<
 *     cdef node_builder
 *     cdef node_filter
 */

struct __pyx_vtabstruct_11lark_cython_11lark_cython_PropagatePositions {
  PyObject *(*_pp_get_meta)(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *, PyObject *);
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_PropagatePositions *__pyx_vtabptr_11lark_cython_11lark_cython_PropagatePositions;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if CYTHON_FAST_PYCALL
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif // CYTHON_FAST_PYCALL
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* IncludeStringH.proto */
#include <string.h>

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_FloorDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceFloorDivide(op1, op2) : PyNumber_FloorDivide(op1, op2))
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* py_dict_values.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* SliceObject.proto */
#define __Pyx_PyObject_DelSlice(obj, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)\
    __Pyx_PyObject_SetSlice(obj, (PyObject*)NULL, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(
        PyObject* obj, PyObject* value, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* CallableCheck.proto */
#if CYTHON_USE_TYPE_SLOTS && PY_MAJOR_VERSION >= 3
#define __Pyx_PyCallable_Check(obj)   (Py_TYPE(obj)->tp_call != NULL)
#else
#define __Pyx_PyCallable_Check(obj)   PyCallable_Check(obj)
#endif

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_dealloc);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* ClassMethod.proto */
#include "descrobject.h"
static CYTHON_UNUSED PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* FusedFunction.proto */
typedef struct {
    __pyx_CyFunctionObject func;
    PyObject *__signatures__;
    PyObject *type;
    PyObject *self;
} __pyx_FusedFunctionObject;
static PyObject *__pyx_FusedFunction_New(PyMethodDef *ml, int flags,
                                         PyObject *qualname, PyObject *closure,
                                         PyObject *module, PyObject *globals,
                                         PyObject *code);
static int __pyx_FusedFunction_clear(__pyx_FusedFunctionObject *self);
static PyTypeObject *__pyx_FusedFunctionType = NULL;
static int __pyx_FusedFunction_init(void);
#define __Pyx_FusedFunction_USED

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* ImportNumPyArray.proto */
static PyObject *__pyx_numpy_ndarray = NULL;
static PyObject* __Pyx_ImportNumPyArrayTypeIfAvailable(void);

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_11lark_cython_11lark_cython_5Token_update(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, struct __pyx_opt_args_11lark_cython_11lark_cython_5Token_update *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_5Token___reduce__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_5Token___deepcopy__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_memo); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_10LexerState___copy__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_11LineCounter_feed(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_token, int __pyx_v_test_newline, int __pyx_skip_dispatch); /* proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_7Scanner_match(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_pos, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_state(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v_text); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_thread(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v_text, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_10BasicLexer_match(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_pos); /* proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_10BasicLexer_next_token(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lex_state, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state); /* proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_text, int __pyx_skip_dispatch); /* proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state__pyx_wrap_1(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_text); /* proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_next_token(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lexer_state, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_11LexerThread_next_token(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_11ParserState_feed_token(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_token, struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_7_Parser_parse_from_state(struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_state); /* proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_18PropagatePositions__pp_get_meta(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v_children); /* proto*/

/* Module declarations from 'cython' */

/* Module declarations from 'lark_cython.lark_cython' */
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_Token = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_LexerState = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_LineCounter = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_Scanner = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_Lexer = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_BasicLexer = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ContextualLexer = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_LexerThread = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ParseConf = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ParserState = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython__Parser = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_Meta = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_Tree = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ExpandSingleChild = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ChildFilter = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct___build_mres = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders = 0;
static PyTypeObject *__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback = 0;
static PyObject *__pyx_f_11lark_cython_11lark_cython_make_propagate_positions(PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Lexer__set_state(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_BasicLexer__set_state(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParseConf__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParserState__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Meta__set_state(struct __pyx_obj_11lark_cython_11lark_cython_Meta *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ExpandSingleChild__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_PropagatePositions__set_state(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilter__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *, PyObject *); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "lark_cython.lark_cython"
extern int __pyx_module_is_main_lark_cython__lark_cython;
int __pyx_module_is_main_lark_cython__lark_cython = 0;

/* Implementation of 'lark_cython.lark_cython' */
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_NotImplemented;
static PyObject *__pyx_builtin_AssertionError;
static PyObject *__pyx_builtin_all;
static PyObject *__pyx_builtin_EOFError;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_NameError;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_reversed;
static PyObject *__pyx_builtin_filter;
static PyObject *__pyx_builtin_NotImplementedError;
static const char __pyx_k_[] = ", ";
static const char __pyx_k_0[] = "0";
static const char __pyx_k_P[] = "(?P<";
static const char __pyx_k_d[] = "%d)";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_w[] = "w";
static const char __pyx_k_x[] = "x";
static const char __pyx_k__2[] = ")";
static const char __pyx_k__3[] = "";
static const char __pyx_k__4[] = "()";
static const char __pyx_k__5[] = "|";
static const char __pyx_k_e2[] = "e2";
static const char __pyx_k_eq[] = "__eq__";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_re[] = "re_";
static const char __pyx_k_Any[] = "Any";
static const char __pyx_k_END[] = "$END";
static const char __pyx_k__12[] = ">";
static const char __pyx_k__13[] = "$";
static const char __pyx_k__16[] = "\n";
static const char __pyx_k__17[] = ": ";
static const char __pyx_k__25[] = "----------------";
static const char __pyx_k__29[] = "\t";
static const char __pyx_k__30[] = "  ";
static const char __pyx_k__38[] = "_";
static const char __pyx_k_all[] = "all";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_pos[] = "pos";
static const char __pyx_k_sym[] = "sym";
static const char __pyx_k_Dict[] = "Dict";
static const char __pyx_k_Meta[] = "Meta";
static const char __pyx_k_Rule[] = "Rule '";
static const char __pyx_k_Tree[] = "Tree(";
static const char __pyx_k_Type[] = "Type";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_conf[] = "conf";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_feed[] = "feed";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_inst[] = "inst";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_memo[] = "memo";
static const char __pyx_k_meta[] = "meta";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_ones[] = "ones";
static const char __pyx_k_rule[] = "rule";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_sort[] = "sort";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_tree[] = "tree";
static const char __pyx_k_type[] = "type_";
static const char __pyx_k_Lexer[] = "Lexer";
static const char __pyx_k_Shift[] = "Shift";
static const char __pyx_k_Token[] = "Token(";
static const char __pyx_k_alias[] = "alias";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_level[] = "level";
static const char __pyx_k_lexer[] = "lexer";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_other[] = "other";
static const char __pyx_k_parse[] = "parse";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_rules[] = "rules";
static const char __pyx_k_slots[] = "__slots__";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_token[] = "token";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_wraps[] = "wraps";
static const char __pyx_k_Parser[] = "_Parser";
static const char __pyx_k_Reduce[] = "Reduce";
static const char __pyx_k_Tree_2[] = "Tree";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_column[] = "column";
static const char __pyx_k_filter[] = "filter";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_origin[] = "origin";
static const char __pyx_k_parser[] = "parser";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_pretty[] = "_pretty";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_repeat[] = "repeat";
static const char __pyx_k_rindex[] = "rindex";
static const char __pyx_k_states[] = "states";
static const char __pyx_k_type_2[] = "type";
static const char __pyx_k_typing[] = "typing";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_Pattern[] = "Pattern";
static const char __pyx_k_Scanner[] = "Scanner";
static const char __pyx_k_Token_2[] = "Token";
static const char __pyx_k_allowed[] = "allowed";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_default[] = "__default__";
static const char __pyx_k_end_pos[] = "end_pos";
static const char __pyx_k_expand1[] = "expand1";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_is_term[] = "is_term";
static const char __pyx_k_isupper[] = "isupper";
static const char __pyx_k_options[] = "options";
static const char __pyx_k_partial[] = "partial";
static const char __pyx_k_pattern[] = "pattern";
static const char __pyx_k_plugins[] = "plugins";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_product[] = "product";
static const char __pyx_k_scanner[] = "scanner";
static const char __pyx_k_unicode[] = "unicode";
static const char __pyx_k_wrapper[] = "wrapper";
static const char __pyx_k_EOFError[] = "EOFError";
static const char __pyx_k_Iterator[] = "Iterator";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_LexError[] = "LexError";
static const char __pyx_k_Optional[] = "Optional";
static const char __pyx_k_analysis[] = "analysis";
static const char __pyx_k_borrow_t[] = "borrow_t";
static const char __pyx_k_char_pos[] = "char_pos";
static const char __pyx_k_children[] = "children";
static const char __pyx_k_deepcopy[] = "deepcopy";
static const char __pyx_k_defaults[] = "defaults";
static const char __pyx_k_end_line[] = "end_line";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_line_ctr[] = "line_ctr";
static const char __pyx_k_max_size[] = "max_size";
static const char __pyx_k_on_error[] = "on_error";
static const char __pyx_k_position[] = "position";
static const char __pyx_k_priority[] = "priority";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_reversed[] = "reversed";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_CallChain[] = "CallChain";
static const char __pyx_k_NameError[] = "NameError";
static const char __pyx_k_ParseConf[] = "ParseConf";
static const char __pyx_k_Serialize[] = "Serialize";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_ambiguous[] = "ambiguous";
static const char __pyx_k_callbacks[] = "callbacks";
static const char __pyx_k_end_state[] = "end_state";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_expansion[] = "expansion";
static const char __pyx_k_find_pred[] = "find_pred";
static const char __pyx_k_functools[] = "functools";
static const char __pyx_k_itertools[] = "itertools";
static const char __pyx_k_lastindex[] = "lastindex";
static const char __pyx_k_max_width[] = "max_width";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_min_width[] = "min_width";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_re_module[] = "re_module";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_serialize[] = "serialize";
static const char __pyx_k_start_pos[] = "start_pos";
static const char __pyx_k_terminals[] = "terminals";
static const char __pyx_k_to_regexp[] = "to_regexp";
static const char __pyx_k_use_bytes[] = "use_bytes";
static const char __pyx_k_BasicLexer[] = "BasicLexer";
static const char __pyx_k_Collection[] = "Collection";
static const char __pyx_k_LexerState[] = "LexerState";
static const char __pyx_k_Token___eq[] = "Token.__eq__";
static const char __pyx_k_build_mres[] = "_build_mres";
static const char __pyx_k_end_column[] = "end_column";
static const char __pyx_k_end_states[] = "end_states";
static const char __pyx_k_filter_out[] = "filter_out";
static const char __pyx_k_groupindex[] = "groupindex";
static const char __pyx_k_indent_str[] = "indent_str";
static const char __pyx_k_lark_lexer[] = "lark.lexer";
static const char __pyx_k_lark_utils[] = "lark.utils";
static const char __pyx_k_last_token[] = "last_token";
static const char __pyx_k_next_token[] = "next_token";
static const char __pyx_k_parse_conf[] = "parse_conf";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_startswith[] = "startswith";
static const char __pyx_k_to_include[] = "to_include";
static const char __pyx_k_tree_class[] = "tree_class";
static const char __pyx_k_vargs_meta[] = "_vargs_meta";
static const char __pyx_k_ChildFilter[] = "ChildFilter";
static const char __pyx_k_END_OF_FILE[] = "<END-OF-FILE>";
static const char __pyx_k_LALR_Parser[] = "LALR_Parser";
static const char __pyx_k_LexerThread[] = "LexerThread";
static const char __pyx_k_LineCounter[] = "LineCounter";
static const char __pyx_k_OrderedDict[] = "OrderedDict";
static const char __pyx_k_ParserState[] = "ParserState";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_TerminalDef[] = "TerminalDef";
static const char __pyx_k_append_none[] = "append_none";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_deserialize[] = "deserialize";
static const char __pyx_k_lexer_state[] = "lexer_state";
static const char __pyx_k_match_whole[] = "match_whole";
static const char __pyx_k_node_filter[] = "node_filter";
static const char __pyx_k_parse_table[] = "parse_table";
static const char __pyx_k_parser_conf[] = "parser_conf";
static const char __pyx_k_scan_values[] = "scan_values";
static const char __pyx_k_start_state[] = "start_state";
static const char __pyx_k_state_stack[] = "state_stack";
static const char __pyx_k_transformer[] = "transformer";
static const char __pyx_k_value_stack[] = "value_stack";
static const char __pyx_k_GrammarError[] = "GrammarError";
static const char __pyx_k_compute_lalr[] = "compute_lalr";
static const char __pyx_k_newline_char[] = "newline_char";
static const char __pyx_k_node_builder[] = "node_builder";
static const char __pyx_k_nones_to_add[] = "nones_to_add";
static const char __pyx_k_parser_state[] = "parser_state";
static const char __pyx_k_pretty_label[] = "_pretty_label";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_resume_parse[] = "resume_parse";
static const char __pyx_k_start_states[] = "start_states";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_test_newline[] = "test_newline";
static const char __pyx_k_IntParseTable[] = "IntParseTable";
static const char __pyx_k_LALR_Analyzer[] = "LALR_Analyzer";
static const char __pyx_k_allowed_types[] = "allowed_types";
static const char __pyx_k_always_accept[] = "always_accept";
static const char __pyx_k_build_scanner[] = "_build_scanner";
static const char __pyx_k_create_unless[] = "_create_unless";
static const char __pyx_k_empty_indices[] = "_empty_indices";
static const char __pyx_k_g_regex_flags[] = "g_regex_flags";
static const char __pyx_k_init_builders[] = "_init_builders";
static const char __pyx_k_iter_subtrees[] = "iter_subtrees";
static const char __pyx_k_lark_visitors[] = "lark.visitors";
static const char __pyx_k_parse_table_2[] = "_parse_table";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_rule_builders[] = "rule_builders";
static const char __pyx_k_should_expand[] = "_should_expand";
static const char __pyx_k_token_history[] = "token_history";
static const char __pyx_k_visit_wrapper[] = "visit_wrapper";
static const char __pyx_k_wrapper_chain[] = "wrapper_chain";
static const char __pyx_k_AssertionError[] = "AssertionError";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_NotImplemented[] = "NotImplemented";
static const char __pyx_k_already_exists[] = "' already exists";
static const char __pyx_k_container_line[] = "container_line";
static const char __pyx_k_line_start_pos[] = "line_start_pos";
static const char __pyx_k_new_borrow_pos[] = "new_borrow_pos";
static const char __pyx_k_ChildFilterLALR[] = "ChildFilterLALR";
static const char __pyx_k_ContextualLexer[] = "ContextualLexer";
static const char __pyx_k_UnexpectedInput[] = "UnexpectedInput";
static const char __pyx_k_UnexpectedToken[] = "UnexpectedToken";
static const char __pyx_k_create_callback[] = "create_callback";
static const char __pyx_k_default_handler[] = "default_handler";
static const char __pyx_k_empty_indices_2[] = "empty_indices";
static const char __pyx_k_keep_all_tokens[] = "keep_all_tokens";
static const char __pyx_k_lark_exceptions[] = "lark.exceptions";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_skip_validation[] = "skip_validation";
static const char __pyx_k_template_source[] = "template_source";
static const char __pyx_k_ParseTreeBuilder[] = "ParseTreeBuilder";
static const char __pyx_k_STATE_STACK_DUMP[] = "STATE STACK DUMP";
static const char __pyx_k_Tree_scan_values[] = "Tree.scan_values";
static const char __pyx_k_container_column[] = "container_column";
static const char __pyx_k_default_callback[] = "default_callback";
static const char __pyx_k_make_lexer_state[] = "make_lexer_state";
static const char __pyx_k_ExpandSingleChild[] = "ExpandSingleChild";
static const char __pyx_k_InteractiveParser[] = "InteractiveParser";
static const char __pyx_k_LALR_Parser_parse[] = "LALR_Parser.parse";
static const char __pyx_k_container_end_pos[] = "container_end_pos";
static const char __pyx_k_make_lexer_thread[] = "make_lexer_thread";
static const char __pyx_k_parse_interactive[] = "parse_interactive";
static const char __pyx_k_pyx_unpickle_Meta[] = "__pyx_unpickle_Meta";
static const char __pyx_k_start_interactive[] = "start_interactive";
static const char __pyx_k_terminals_by_name[] = "terminals_by_name";
static const char __pyx_k_vargs_meta_inline[] = "_vargs_meta_inline";
static const char __pyx_k_ConfigurationError[] = "ConfigurationError";
static const char __pyx_k_LALR_Parser___init[] = "LALR_Parser.__init__";
static const char __pyx_k_PropagatePositions[] = "PropagatePositions";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_container_end_line[] = "container_end_line";
static const char __pyx_k_interactive_parser[] = "interactive_parser";
static const char __pyx_k_maybe_placeholders[] = "maybe_placeholders";
static const char __pyx_k_pyx_unpickle_Lexer[] = "__pyx_unpickle_Lexer";
static const char __pyx_k_regexp_has_newline[] = "_regexp_has_newline";
static const char __pyx_k_user_callback_name[] = "user_callback_name";
static const char __pyx_k_NotImplementedError[] = "NotImplementedError";
static const char __pyx_k_Transformer_InPlace[] = "Transformer_InPlace";
static const char __pyx_k_apply_visit_wrapper[] = "apply_visit_wrapper";
static const char __pyx_k_container_start_pos[] = "container_start_pos";
static const char __pyx_k_expand_single_child[] = "expand_single_child";
static const char __pyx_k_inplace_transformer[] = "inplace_transformer";
static const char __pyx_k_propagate_positions[] = "propagate_positions";
static const char __pyx_k_Cannot_compile_token[] = "Cannot compile token ";
static const char __pyx_k_UnexpectedCharacters[] = "UnexpectedCharacters";
static const char __pyx_k_container_end_column[] = "container_end_column";
static const char __pyx_k_init___locals_lambda[] = "__init__.<locals>.<lambda>";
static const char __pyx_k_LALR_Parser_serialize[] = "LALR_Parser.serialize";
static const char __pyx_k_init___locals_genexpr[] = "__init__.<locals>.genexpr";
static const char __pyx_k_iter_subtrees_topdown[] = "iter_subtrees_topdown";
static const char __pyx_k_TOKEN_DEFAULT_PRIORITY[] = "TOKEN_DEFAULT_PRIORITY";
static const char __pyx_k_pyx_unpickle_ParseConf[] = "__pyx_unpickle_ParseConf";
static const char __pyx_k_LALR_Parser_deserialize[] = "LALR_Parser.deserialize";
static const char __pyx_k_ParseTreeBuilder___init[] = "ParseTreeBuilder.__init__";
static const char __pyx_k_find_data_locals_lambda[] = "find_data.<locals>.<lambda>";
static const char __pyx_k_lark_cython_lark_cython[] = "lark_cython.lark_cython";
static const char __pyx_k_pyx_unpickle_BasicLexer[] = "__pyx_unpickle_BasicLexer";
static const char __pyx_k_pyx_unpickle_ChildFilter[] = "__pyx_unpickle_ChildFilter";
static const char __pyx_k_pyx_unpickle_ParserState[] = "__pyx_unpickle_ParserState";
static const char __pyx_k_Tree_scan_values_line_712[] = "Tree.scan_values (line 712)";
static const char __pyx_k_build_mres_locals_genexpr[] = "_build_mres.<locals>.genexpr";
static const char __pyx_k_maybe_create_child_filter[] = "maybe_create_child_filter";
static const char __pyx_k_Tree_iter_subtrees_topdown[] = "Tree.iter_subtrees_topdown";
static const char __pyx_k_lark_parsers_lalr_analysis[] = "lark.parsers.lalr_analysis";
static const char __pyx_k_No_matching_signature_found[] = "No matching signature found";
static const char __pyx_k_build_scanner_locals_lambda[] = "_build_scanner.<locals>.<lambda>";
static const char __pyx_k_lark_cython_lark_cython_pyx[] = "lark_cython\\lark_cython.pyx";
static const char __pyx_k_apply_visit_wrapper_locals_f[] = "apply_visit_wrapper.<locals>.f";
static const char __pyx_k_inplace_transformer_locals_f[] = "inplace_transformer.<locals>.f";
static const char __pyx_k_pyx_unpickle_ChildFilterLALR[] = "__pyx_unpickle_ChildFilterLALR";
static const char __pyx_k_LALR_Parser_parse_interactive[] = "LALR_Parser.parse_interactive";
static const char __pyx_k_ChildFilterLALR_NoPlaceholders[] = "ChildFilterLALR_NoPlaceholders";
static const char __pyx_k_pyx_unpickle_ChildFilterLALR_N[] = "__pyx_unpickle_ChildFilterLALR_NoPlaceholders";
static const char __pyx_k_pyx_unpickle_ExpandSingleChild[] = "__pyx_unpickle_ExpandSingleChild";
static const char __pyx_k_pyx_unpickle_PropagatePosition[] = "__pyx_unpickle_PropagatePositions";
static const char __pyx_k_Lexer_does_not_allow_zero_width[] = "Lexer does not allow zero-width terminals. (";
static const char __pyx_k_ParseTreeBuilder__init_builders[] = "ParseTreeBuilder._init_builders";
static const char __pyx_k_Callbacks_must_return_a_token_re[] = "Callbacks must return a token (returned %r)";
static const char __pyx_k_Expected_at_least_d_argument_s_g[] = "Expected at least %d argument%s, got %d";
static const char __pyx_k_Function_call_with_ambiguous_arg[] = "Function call with ambiguous argument types";
static const char __pyx_k_Ignore_terminals_are_not_defined[] = "Ignore terminals are not defined: %s";
static const char __pyx_k_Incompatible_checksums_s_vs_0x0b[] = "Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x44[] = "Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x64[] = "Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x68[] = "Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x87[] = "Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x8b[] = "Incompatible checksums (%s vs 0x8bfa35b = (node_builder))";
static const char __pyx_k_Incompatible_checksums_s_vs_0xd4[] = "Incompatible checksums (%s vs 0xd41d8cd = ())";
static const char __pyx_k_Incompatible_checksums_s_vs_0xf8[] = "Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))";
static const char __pyx_k_Invalid_option_for_propagate_pos[] = "Invalid option for propagate_positions: %r";
static const char __pyx_k_Meta_args_not_supported_for_inte[] = "Meta args not supported for internal transformer";
static const char __pyx_k_ParseTreeBuilder_create_callback[] = "ParseTreeBuilder.create_callback.<locals>.default_callback";
static const char __pyx_k_Return_all_values_in_the_tree_th[] = "Return all values in the tree that evaluate pred(value) as true.\n\n        This can be used to find all the tokens in the tree.\n\n        Example:\n            >>> all_tokens = tree.scan_values(lambda v: isinstance(v, Token))\n        ";
static const char __pyx_k_lark_parsers_lalr_interactive_pa[] = "lark.parsers.lalr_interactive_parser";
static const char __pyx_k_maybe_create_child_filter_locals[] = "maybe_create_child_filter.<locals>.genexpr";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_ParseTreeBuilder_create_callback_2[] = "ParseTreeBuilder.create_callback";
static PyObject *__pyx_kp_u_;
static PyObject *__pyx_kp_u_0;
static PyObject *__pyx_n_s_Any;
static PyObject *__pyx_n_s_AssertionError;
static PyObject *__pyx_n_s_AttributeError;
static PyObject *__pyx_n_s_BasicLexer;
static PyObject *__pyx_n_u_BasicLexer;
static PyObject *__pyx_n_s_CallChain;
static PyObject *__pyx_kp_u_Callbacks_must_return_a_token_re;
static PyObject *__pyx_kp_u_Cannot_compile_token;
static PyObject *__pyx_n_s_ChildFilter;
static PyObject *__pyx_n_s_ChildFilterLALR;
static PyObject *__pyx_n_s_ChildFilterLALR_NoPlaceholders;
static PyObject *__pyx_n_s_Collection;
static PyObject *__pyx_n_s_ConfigurationError;
static PyObject *__pyx_n_s_ContextualLexer;
static PyObject *__pyx_n_u_ContextualLexer;
static PyObject *__pyx_n_s_Dict;
static PyObject *__pyx_kp_u_END;
static PyObject *__pyx_kp_u_END_OF_FILE;
static PyObject *__pyx_n_s_EOFError;
static PyObject *__pyx_n_s_ExpandSingleChild;
static PyObject *__pyx_kp_s_Expected_at_least_d_argument_s_g;
static PyObject *__pyx_kp_s_Function_call_with_ambiguous_arg;
static PyObject *__pyx_n_s_GrammarError;
static PyObject *__pyx_kp_u_Ignore_terminals_are_not_defined;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x0b;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x44;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x64;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x68;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x87;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x8b;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xd4;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xf8;
static PyObject *__pyx_n_s_IntParseTable;
static PyObject *__pyx_n_s_InteractiveParser;
static PyObject *__pyx_kp_u_Invalid_option_for_propagate_pos;
static PyObject *__pyx_n_s_Iterator;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_n_s_LALR_Analyzer;
static PyObject *__pyx_n_s_LALR_Parser;
static PyObject *__pyx_n_u_LALR_Parser;
static PyObject *__pyx_n_s_LALR_Parser___init;
static PyObject *__pyx_n_s_LALR_Parser_deserialize;
static PyObject *__pyx_n_s_LALR_Parser_parse;
static PyObject *__pyx_n_s_LALR_Parser_parse_interactive;
static PyObject *__pyx_n_s_LALR_Parser_serialize;
static PyObject *__pyx_n_s_LexError;
static PyObject *__pyx_n_s_Lexer;
static PyObject *__pyx_n_s_LexerState;
static PyObject *__pyx_n_s_LexerThread;
static PyObject *__pyx_n_u_LexerThread;
static PyObject *__pyx_kp_u_Lexer_does_not_allow_zero_width;
static PyObject *__pyx_n_s_LineCounter;
static PyObject *__pyx_n_s_Meta;
static PyObject *__pyx_kp_u_Meta_args_not_supported_for_inte;
static PyObject *__pyx_n_s_NameError;
static PyObject *__pyx_kp_s_No_matching_signature_found;
static PyObject *__pyx_n_s_NotImplemented;
static PyObject *__pyx_n_s_NotImplementedError;
static PyObject *__pyx_n_s_Optional;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_kp_u_P;
static PyObject *__pyx_n_s_ParseConf;
static PyObject *__pyx_n_s_ParseTreeBuilder;
static PyObject *__pyx_n_s_ParseTreeBuilder___init;
static PyObject *__pyx_n_s_ParseTreeBuilder__init_builders;
static PyObject *__pyx_n_s_ParseTreeBuilder_create_callback;
static PyObject *__pyx_n_s_ParseTreeBuilder_create_callback_2;
static PyObject *__pyx_n_s_Parser;
static PyObject *__pyx_n_u_Parser;
static PyObject *__pyx_n_s_ParserState;
static PyObject *__pyx_n_s_Pattern;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_n_s_PropagatePositions;
static PyObject *__pyx_n_s_Reduce;
static PyObject *__pyx_kp_u_Return_all_values_in_the_tree_th;
static PyObject *__pyx_kp_u_Rule;
static PyObject *__pyx_kp_u_STATE_STACK_DUMP;
static PyObject *__pyx_n_s_Scanner;
static PyObject *__pyx_n_s_Serialize;
static PyObject *__pyx_n_s_Shift;
static PyObject *__pyx_n_s_TOKEN_DEFAULT_PRIORITY;
static PyObject *__pyx_n_s_TerminalDef;
static PyObject *__pyx_kp_u_Token;
static PyObject *__pyx_n_s_Token_2;
static PyObject *__pyx_n_s_Token___eq;
static PyObject *__pyx_n_s_Transformer_InPlace;
static PyObject *__pyx_kp_u_Tree;
static PyObject *__pyx_n_s_Tree_2;
static PyObject *__pyx_n_s_Tree_iter_subtrees_topdown;
static PyObject *__pyx_n_s_Tree_scan_values;
static PyObject *__pyx_kp_u_Tree_scan_values_line_712;
static PyObject *__pyx_n_s_Type;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_s_UnexpectedCharacters;
static PyObject *__pyx_n_s_UnexpectedInput;
static PyObject *__pyx_n_s_UnexpectedToken;
static PyObject *__pyx_kp_u__12;
static PyObject *__pyx_kp_u__13;
static PyObject *__pyx_kp_b__16;
static PyObject *__pyx_kp_u__16;
static PyObject *__pyx_kp_u__17;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_kp_u__25;
static PyObject *__pyx_kp_u__29;
static PyObject *__pyx_kp_s__3;
static PyObject *__pyx_kp_u__3;
static PyObject *__pyx_kp_u__30;
static PyObject *__pyx_n_s__38;
static PyObject *__pyx_n_u__38;
static PyObject *__pyx_kp_s__4;
static PyObject *__pyx_kp_s__5;
static PyObject *__pyx_kp_u__5;
static PyObject *__pyx_n_s_alias;
static PyObject *__pyx_n_s_all;
static PyObject *__pyx_n_s_allowed;
static PyObject *__pyx_n_s_allowed_types;
static PyObject *__pyx_kp_u_already_exists;
static PyObject *__pyx_n_s_always_accept;
static PyObject *__pyx_n_s_ambiguous;
static PyObject *__pyx_n_s_analysis;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_append_none;
static PyObject *__pyx_n_s_apply_visit_wrapper;
static PyObject *__pyx_n_s_apply_visit_wrapper_locals_f;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_borrow_t;
static PyObject *__pyx_n_s_build_mres;
static PyObject *__pyx_n_s_build_mres_locals_genexpr;
static PyObject *__pyx_n_s_build_scanner;
static PyObject *__pyx_n_s_build_scanner_locals_lambda;
static PyObject *__pyx_n_s_callbacks;
static PyObject *__pyx_n_u_callbacks;
static PyObject *__pyx_n_s_char_pos;
static PyObject *__pyx_n_u_char_pos;
static PyObject *__pyx_n_s_children;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_cls;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_column;
static PyObject *__pyx_n_u_column;
static PyObject *__pyx_n_s_compile;
static PyObject *__pyx_n_s_compute_lalr;
static PyObject *__pyx_n_s_conf;
static PyObject *__pyx_n_s_container_column;
static PyObject *__pyx_n_u_container_column;
static PyObject *__pyx_n_s_container_end_column;
static PyObject *__pyx_n_u_container_end_column;
static PyObject *__pyx_n_s_container_end_line;
static PyObject *__pyx_n_u_container_end_line;
static PyObject *__pyx_n_u_container_end_pos;
static PyObject *__pyx_n_s_container_line;
static PyObject *__pyx_n_u_container_line;
static PyObject *__pyx_n_u_container_start_pos;
static PyObject *__pyx_n_s_copy;
static PyObject *__pyx_n_s_count;
static PyObject *__pyx_n_s_create_callback;
static PyObject *__pyx_n_s_create_unless;
static PyObject *__pyx_kp_u_d;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_s_deepcopy;
static PyObject *__pyx_n_u_default;
static PyObject *__pyx_n_s_default_callback;
static PyObject *__pyx_n_s_default_handler;
static PyObject *__pyx_n_s_defaults;
static PyObject *__pyx_n_s_deserialize;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_e;
static PyObject *__pyx_n_s_e2;
static PyObject *__pyx_n_s_empty;
static PyObject *__pyx_n_s_empty_indices;
static PyObject *__pyx_n_s_empty_indices_2;
static PyObject *__pyx_n_s_end_column;
static PyObject *__pyx_n_s_end_line;
static PyObject *__pyx_n_u_end_line;
static PyObject *__pyx_n_s_end_pos;
static PyObject *__pyx_n_u_end_state;
static PyObject *__pyx_n_s_end_states;
static PyObject *__pyx_n_s_enumerate;
static PyObject *__pyx_n_s_eq;
static PyObject *__pyx_n_s_error;
static PyObject *__pyx_n_s_expand1;
static PyObject *__pyx_n_s_expand_single_child;
static PyObject *__pyx_n_s_expansion;
static PyObject *__pyx_n_s_f;
static PyObject *__pyx_n_s_feed;
static PyObject *__pyx_n_s_filter;
static PyObject *__pyx_n_s_filter_out;
static PyObject *__pyx_n_s_find_data_locals_lambda;
static PyObject *__pyx_n_s_find_pred;
static PyObject *__pyx_n_s_func;
static PyObject *__pyx_n_s_functools;
static PyObject *__pyx_n_s_g_regex_flags;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_group;
static PyObject *__pyx_n_s_groupindex;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_ignore;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_indent_str;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_init___locals_genexpr;
static PyObject *__pyx_n_s_init___locals_lambda;
static PyObject *__pyx_n_s_init_builders;
static PyObject *__pyx_n_s_inplace_transformer;
static PyObject *__pyx_n_s_inplace_transformer_locals_f;
static PyObject *__pyx_n_s_inst;
static PyObject *__pyx_n_s_interactive_parser;
static PyObject *__pyx_n_s_is_term;
static PyObject *__pyx_n_s_isupper;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_iter_subtrees;
static PyObject *__pyx_n_s_iter_subtrees_topdown;
static PyObject *__pyx_n_s_itertools;
static PyObject *__pyx_n_s_keep_all_tokens;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_keys;
static PyObject *__pyx_n_s_kwargs;
static PyObject *__pyx_kp_s_lark_cython_lark_cython;
static PyObject *__pyx_kp_s_lark_cython_lark_cython_pyx;
static PyObject *__pyx_n_s_lark_exceptions;
static PyObject *__pyx_n_s_lark_lexer;
static PyObject *__pyx_n_s_lark_parsers_lalr_analysis;
static PyObject *__pyx_n_s_lark_parsers_lalr_interactive_pa;
static PyObject *__pyx_n_s_lark_utils;
static PyObject *__pyx_n_s_lark_visitors;
static PyObject *__pyx_n_s_last_token;
static PyObject *__pyx_n_u_last_token;
static PyObject *__pyx_n_s_lastindex;
static PyObject *__pyx_n_s_level;
static PyObject *__pyx_n_s_lexer;
static PyObject *__pyx_n_u_lexer;
static PyObject *__pyx_n_s_lexer_state;
static PyObject *__pyx_n_s_line;
static PyObject *__pyx_n_u_line;
static PyObject *__pyx_n_s_line_ctr;
static PyObject *__pyx_n_u_line_ctr;
static PyObject *__pyx_n_u_line_start_pos;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_make_lexer_state;
static PyObject *__pyx_n_s_make_lexer_thread;
static PyObject *__pyx_n_s_match;
static PyObject *__pyx_n_s_match_whole;
static PyObject *__pyx_n_s_max_size;
static PyObject *__pyx_n_s_max_width;
static PyObject *__pyx_n_s_maybe_create_child_filter;
static PyObject *__pyx_n_s_maybe_create_child_filter_locals;
static PyObject *__pyx_n_s_maybe_placeholders;
static PyObject *__pyx_n_s_memo;
static PyObject *__pyx_n_s_meta;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_min_width;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_n_s_new_borrow_pos;
static PyObject *__pyx_n_s_newline_char;
static PyObject *__pyx_n_u_newline_char;
static PyObject *__pyx_n_s_next_token;
static PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
static PyObject *__pyx_n_s_node_builder;
static PyObject *__pyx_n_s_node_filter;
static PyObject *__pyx_n_s_nones_to_add;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_n_s_object;
static PyObject *__pyx_n_s_on_error;
static PyObject *__pyx_n_s_ones;
static PyObject *__pyx_n_s_options;
static PyObject *__pyx_n_s_origin;
static PyObject *__pyx_n_s_other;
static PyObject *__pyx_n_s_p;
static PyObject *__pyx_n_s_parse;
static PyObject *__pyx_n_s_parse_conf;
static PyObject *__pyx_n_u_parse_conf;
static PyObject *__pyx_n_s_parse_interactive;
static PyObject *__pyx_n_s_parse_table;
static PyObject *__pyx_n_u_parse_table;
static PyObject *__pyx_n_s_parse_table_2;
static PyObject *__pyx_n_s_parser;
static PyObject *__pyx_n_s_parser_conf;
static PyObject *__pyx_n_s_parser_state;
static PyObject *__pyx_n_s_partial;
static PyObject *__pyx_n_s_pattern;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_plugins;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_pos;
static PyObject *__pyx_n_s_position;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_pretty;
static PyObject *__pyx_n_s_pretty_label;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_priority;
static PyObject *__pyx_n_s_product;
static PyObject *__pyx_n_s_propagate_positions;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_BasicLexer;
static PyObject *__pyx_n_s_pyx_unpickle_ChildFilter;
static PyObject *__pyx_n_s_pyx_unpickle_ChildFilterLALR;
static PyObject *__pyx_n_s_pyx_unpickle_ChildFilterLALR_N;
static PyObject *__pyx_n_s_pyx_unpickle_ExpandSingleChild;
static PyObject *__pyx_n_s_pyx_unpickle_Lexer;
static PyObject *__pyx_n_s_pyx_unpickle_Meta;
static PyObject *__pyx_n_s_pyx_unpickle_ParseConf;
static PyObject *__pyx_n_s_pyx_unpickle_ParserState;
static PyObject *__pyx_n_s_pyx_unpickle_PropagatePosition;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_re;
static PyObject *__pyx_n_s_re_module;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_regexp_has_newline;
static PyObject *__pyx_n_s_repeat;
static PyObject *__pyx_n_s_resume_parse;
static PyObject *__pyx_n_s_reversed;
static PyObject *__pyx_n_s_rindex;
static PyObject *__pyx_n_s_rule;
static PyObject *__pyx_n_s_rule_builders;
static PyObject *__pyx_n_s_rules;
static PyObject *__pyx_n_s_s;
static PyObject *__pyx_n_s_scan_values;
static PyObject *__pyx_n_s_scanner;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_serialize;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_should_expand;
static PyObject *__pyx_n_s_skip_validation;
static PyObject *__pyx_n_s_slots;
static PyObject *__pyx_n_s_sort;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_start;
static PyObject *__pyx_n_u_start;
static PyObject *__pyx_n_s_start_interactive;
static PyObject *__pyx_n_s_start_pos;
static PyObject *__pyx_n_u_start_state;
static PyObject *__pyx_n_s_start_states;
static PyObject *__pyx_n_s_startswith;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_n_s_state_stack;
static PyObject *__pyx_n_u_state_stack;
static PyObject *__pyx_n_s_states;
static PyObject *__pyx_n_u_states;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_strip;
static PyObject *__pyx_n_s_sym;
static PyObject *__pyx_n_s_template_source;
static PyObject *__pyx_n_s_terminals;
static PyObject *__pyx_n_s_terminals_by_name;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_test_newline;
static PyObject *__pyx_n_s_text;
static PyObject *__pyx_n_u_text;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_to_include;
static PyObject *__pyx_n_s_to_regexp;
static PyObject *__pyx_n_s_token;
static PyObject *__pyx_n_s_token_history;
static PyObject *__pyx_n_s_transformer;
static PyObject *__pyx_n_s_tree;
static PyObject *__pyx_n_s_tree_class;
static PyObject *__pyx_n_s_type;
static PyObject *__pyx_n_s_type_2;
static PyObject *__pyx_n_s_typing;
static PyObject *__pyx_n_s_unicode;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_use_bytes;
static PyObject *__pyx_n_s_user_callback_name;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_value_stack;
static PyObject *__pyx_n_u_value_stack;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_n_s_vargs_meta;
static PyObject *__pyx_n_s_vargs_meta_inline;
static PyObject *__pyx_n_u_visit_wrapper;
static PyObject *__pyx_n_s_w;
static PyObject *__pyx_n_s_wrapper;
static PyObject *__pyx_n_s_wrapper_chain;
static PyObject *__pyx_n_s_wraps;
static PyObject *__pyx_n_s_x;
static int __pyx_pf_11lark_cython_11lark_cython_5Token___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_type_, PyObject *__pyx_v_value, int __pyx_v_start_pos, int __pyx_v_line, int __pyx_v_column, PyObject *__pyx_v_end_line, PyObject *__pyx_v_end_column, PyObject *__pyx_v_end_pos); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_2new_borrow_pos(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_type_, PyObject *__pyx_v_value, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_borrow_t); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_4__repr__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_6__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_10__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_12__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static Py_hash_t __pyx_pf_11lark_cython_11lark_cython_5Token_8__hash__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_4type___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_4type_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_4type_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_9start_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_9start_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_5value___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_5value_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_5value_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_4line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_4line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_6column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_6column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_8end_line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_10end_column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_line_ctr, PyObject *__pyx_v_last_token); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_2__eq__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_4text___get__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr___get__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token___get__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_newline_char); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_2__eq__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_4feed(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_token, int __pyx_v_test_newline); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_8char_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_8char_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_4line___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_4line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_6column___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_6column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_14line_start_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_terminals, PyObject *__pyx_v_g_regex_flags, PyObject *__pyx_v_re_, PyObject *__pyx_v_use_bytes, PyObject *__pyx_v_match_whole); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_11_build_mres_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_2_build_mres(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_terminals, PyObject *__pyx_v_max_size); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_4match(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_pos); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_13g_regex_flags___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_3re____get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re__2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re__4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Lexer_make_lexer_thread(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Lexer_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Lexer_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_8__init___genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_8__init___3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda3(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_10BasicLexer___init__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, PyObject *__pyx_v_conf); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda4(PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_2_build_scanner(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_7scanner___get__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_conf, PyObject *__pyx_v_states, PyObject *__pyx_v_always_accept); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_2make_lexer_state(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_4next_token(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lexer_state, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11LexerThread___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LexerThread_2__copy__(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LexerThread_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LexerThread_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_9ParseConf___init__(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_self, PyObject *__pyx_v_parse_table, PyObject *__pyx_v_callbacks, PyObject *__pyx_v_start); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_9ParseConf_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_9ParseConf_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11ParserState___init__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, PyObject *__pyx_v_parse_conf, PyObject *__pyx_v_lexer, PyObject *__pyx_v_state_stack, PyObject *__pyx_v_value_stack); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_8position___get__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_2__eq__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_4__copy__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_6copy(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_8__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_10__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_7_Parser___cinit__(struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, PyObject *__pyx_v_parse_table, PyObject *__pyx_v_callbacks, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7_Parser_2parse(struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_start, PyObject *__pyx_v_value_stack, PyObject *__pyx_v_state_stack, PyObject *__pyx_v_start_interactive); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7_Parser_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_7_Parser_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parser_conf, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_2deserialize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_data, PyObject *__pyx_v_memo, PyObject *__pyx_v_callbacks, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_4serialize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_memo); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_6parse_interactive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_start); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_8parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_start, PyObject *__pyx_v_on_error); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta___init__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_5empty___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_5empty_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_4line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_4line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_6column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_6column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_9start_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_9start_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_8end_line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_8end_line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_10end_column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_10end_column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_7end_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_7end_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_10match_tree___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Meta_10match_tree_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_data, PyObject *__pyx_v_children, PyObject *__pyx_v_meta); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_4meta___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_2__repr__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_4_pretty_label(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_6_pretty(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_level, PyObject *__pyx_v_indent_str); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_8pretty(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_indent_str); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_10__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_12__ne__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static Py_hash_t __pyx_pf_11lark_cython_11lark_cython_4Tree_14__hash__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_16iter_subtrees(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_18find_pred(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_pred); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda5(PyObject *__pyx_self, PyObject *__pyx_v_t); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_20find_data(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_22expand_kids_by_data(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_data_values); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_24scan_values(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_pred); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_27iter_subtrees_topdown(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_30__deepcopy__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_memo); /* proto */
static struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_pf_11lark_cython_11lark_cython_4Tree_32copy(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_34set(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_data, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_4data___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree_4data_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree_4data_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_8children___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree_8children_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree_8children_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_36__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_38__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_19apply_visit_wrapper_f(PyObject *__pyx_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_apply_visit_wrapper(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_name, PyObject *__pyx_v_wrapper); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_19inplace_transformer_f(PyObject *__pyx_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_2inplace_transformer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild___init__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self, PyObject *__pyx_v_node_builder); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_18PropagatePositions___init__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v_node_builder, PyObject *__pyx_v_node_filter); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_11ChildFilter___init__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self, PyObject *__pyx_v_to_include, PyObject *__pyx_v_append_none, PyObject *__pyx_v_node_builder); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_12node_builder___get__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_10to_include___get__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_11append_none___get__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR___call__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders___init__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self, PyObject *__pyx_v_to_include, PyObject *__pyx_v_node_builder); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_4_should_expand(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sym); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_25maybe_create_child_filter_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_25maybe_create_child_filter_3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_6maybe_create_child_filter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expansion, PyObject *__pyx_v_keep_all_tokens, PyObject *__pyx_v_ambiguous, PyObject *__pyx_v__empty_indices); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_rules, CYTHON_UNUSED PyObject *__pyx_v_tree_class, PyObject *__pyx_v_propagate_positions, PyObject *__pyx_v_ambiguous, PyObject *__pyx_v_maybe_placeholders); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_2_init_builders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_rules); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_default_callback(PyObject *__pyx_self, PyObject *__pyx_v_data, PyObject *__pyx_v_children); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_5create_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_transformer); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_8__pyx_unpickle_Lexer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_10__pyx_unpickle_BasicLexer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_12__pyx_unpickle_ParseConf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_14__pyx_unpickle_ParserState(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_16__pyx_unpickle_Meta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_18__pyx_unpickle_ExpandSingleChild(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_20__pyx_unpickle_PropagatePositions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_22__pyx_unpickle_ChildFilter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_24__pyx_unpickle_ChildFilterLALR(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11lark_cython_11lark_cython_26__pyx_unpickle_ChildFilterLALR_NoPlaceholders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Token(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_LexerState(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_LineCounter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Scanner(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Lexer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_BasicLexer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ContextualLexer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_LexerThread(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ParseConf(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ParserState(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython__Parser(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Meta(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Tree(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ExpandSingleChild(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_PropagatePositions(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ChildFilter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ChildFilterLALR(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct___build_mres(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_2___init__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values = {0, &__pyx_n_s_values, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_isupper = {0, &__pyx_n_s_isupper, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop = {0, &__pyx_n_s_pop, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_rindex = {0, &__pyx_n_s_rindex, 0, 0, 0};
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_11743518;
static PyObject *__pyx_int_71555863;
static PyObject *__pyx_int_104898272;
static PyObject *__pyx_int_109761734;
static PyObject *__pyx_int_141903276;
static PyObject *__pyx_int_146776923;
static PyObject *__pyx_int_222419149;
static PyObject *__pyx_int_260616610;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__88;
static PyObject *__pyx_tuple__90;
static PyObject *__pyx_tuple__92;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_codeobj__35;
static PyObject *__pyx_codeobj__37;
static PyObject *__pyx_codeobj__39;
static PyObject *__pyx_codeobj__41;
static PyObject *__pyx_codeobj__43;
static PyObject *__pyx_codeobj__49;
static PyObject *__pyx_codeobj__52;
static PyObject *__pyx_codeobj__55;
static PyObject *__pyx_codeobj__57;
static PyObject *__pyx_codeobj__59;
static PyObject *__pyx_codeobj__62;
static PyObject *__pyx_codeobj__64;
static PyObject *__pyx_codeobj__66;
static PyObject *__pyx_codeobj__68;
static PyObject *__pyx_codeobj__70;
static PyObject *__pyx_codeobj__74;
static PyObject *__pyx_codeobj__77;
static PyObject *__pyx_codeobj__79;
static PyObject *__pyx_codeobj__81;
static PyObject *__pyx_codeobj__83;
static PyObject *__pyx_codeobj__85;
static PyObject *__pyx_codeobj__87;
static PyObject *__pyx_codeobj__89;
static PyObject *__pyx_codeobj__91;
static PyObject *__pyx_codeobj__93;
static PyObject *__pyx_codeobj__95;
/* Late includes */

/* "lark_cython/lark_cython.pyx":26
 *     cdef public end_pos
 * 
 *     def __cinit__(self, str type_, str value, int start_pos, int line, int column, end_line=None, end_column=None, end_pos=None):             # <<<<<<<<<<<<<<
 *         self.type = type_
 *         self.start_pos = start_pos
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_type_ = 0;
  PyObject *__pyx_v_value = 0;
  int __pyx_v_start_pos;
  int __pyx_v_line;
  int __pyx_v_column;
  PyObject *__pyx_v_end_line = 0;
  PyObject *__pyx_v_end_column = 0;
  PyObject *__pyx_v_end_pos = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_type,&__pyx_n_s_value,&__pyx_n_s_start_pos,&__pyx_n_s_line,&__pyx_n_s_column,&__pyx_n_s_end_line,&__pyx_n_s_end_column,&__pyx_n_s_end_pos,0};
    PyObject* values[8] = {0,0,0,0,0,0,0,0};
    values[5] = ((PyObject *)Py_None);
    values[6] = ((PyObject *)Py_None);
    values[7] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 5, 8, 1); __PYX_ERR(0, 26, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start_pos)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 5, 8, 2); __PYX_ERR(0, 26, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_line)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 5, 8, 3); __PYX_ERR(0, 26, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_column)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 5, 8, 4); __PYX_ERR(0, 26, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_end_line);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_end_column);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_end_pos);
          if (value) { values[7] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 26, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_type_ = ((PyObject*)values[0]);
    __pyx_v_value = ((PyObject*)values[1]);
    __pyx_v_start_pos = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_start_pos == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 26, __pyx_L3_error)
    __pyx_v_line = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_line == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 26, __pyx_L3_error)
    __pyx_v_column = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_column == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 26, __pyx_L3_error)
    __pyx_v_end_line = values[5];
    __pyx_v_end_column = values[6];
    __pyx_v_end_pos = values[7];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 5, 8, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 26, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_type_), (&PyUnicode_Type), 1, "type_", 1))) __PYX_ERR(0, 26, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_value), (&PyUnicode_Type), 1, "value", 1))) __PYX_ERR(0, 26, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), __pyx_v_type_, __pyx_v_value, __pyx_v_start_pos, __pyx_v_line, __pyx_v_column, __pyx_v_end_line, __pyx_v_end_column, __pyx_v_end_pos);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_type_, PyObject *__pyx_v_value, int __pyx_v_start_pos, int __pyx_v_line, int __pyx_v_column, PyObject *__pyx_v_end_line, PyObject *__pyx_v_end_column, PyObject *__pyx_v_end_pos) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":27
 * 
 *     def __cinit__(self, str type_, str value, int start_pos, int line, int column, end_line=None, end_column=None, end_pos=None):
 *         self.type = type_             # <<<<<<<<<<<<<<
 *         self.start_pos = start_pos
 *         self.value = value
 */
  __Pyx_INCREF(__pyx_v_type_);
  __Pyx_GIVEREF(__pyx_v_type_);
  __Pyx_GOTREF(__pyx_v_self->type);
  __Pyx_DECREF(__pyx_v_self->type);
  __pyx_v_self->type = __pyx_v_type_;

  /* "lark_cython/lark_cython.pyx":28
 *     def __cinit__(self, str type_, str value, int start_pos, int line, int column, end_line=None, end_column=None, end_pos=None):
 *         self.type = type_
 *         self.start_pos = start_pos             # <<<<<<<<<<<<<<
 *         self.value = value
 *         self.line = line
 */
  __pyx_v_self->start_pos = __pyx_v_start_pos;

  /* "lark_cython/lark_cython.pyx":29
 *         self.type = type_
 *         self.start_pos = start_pos
 *         self.value = value             # <<<<<<<<<<<<<<
 *         self.line = line
 *         self.column = column
 */
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_v_value;

  /* "lark_cython/lark_cython.pyx":30
 *         self.start_pos = start_pos
 *         self.value = value
 *         self.line = line             # <<<<<<<<<<<<<<
 *         self.column = column
 *         self.end_line = end_line
 */
  __pyx_v_self->line = __pyx_v_line;

  /* "lark_cython/lark_cython.pyx":31
 *         self.value = value
 *         self.line = line
 *         self.column = column             # <<<<<<<<<<<<<<
 *         self.end_line = end_line
 *         self.end_column = end_column
 */
  __pyx_v_self->column = __pyx_v_column;

  /* "lark_cython/lark_cython.pyx":32
 *         self.line = line
 *         self.column = column
 *         self.end_line = end_line             # <<<<<<<<<<<<<<
 *         self.end_column = end_column
 *         self.end_pos = end_pos
 */
  __Pyx_INCREF(__pyx_v_end_line);
  __Pyx_GIVEREF(__pyx_v_end_line);
  __Pyx_GOTREF(__pyx_v_self->end_line);
  __Pyx_DECREF(__pyx_v_self->end_line);
  __pyx_v_self->end_line = __pyx_v_end_line;

  /* "lark_cython/lark_cython.pyx":33
 *         self.column = column
 *         self.end_line = end_line
 *         self.end_column = end_column             # <<<<<<<<<<<<<<
 *         self.end_pos = end_pos
 * 
 */
  __Pyx_INCREF(__pyx_v_end_column);
  __Pyx_GIVEREF(__pyx_v_end_column);
  __Pyx_GOTREF(__pyx_v_self->end_column);
  __Pyx_DECREF(__pyx_v_self->end_column);
  __pyx_v_self->end_column = __pyx_v_end_column;

  /* "lark_cython/lark_cython.pyx":34
 *         self.end_line = end_line
 *         self.end_column = end_column
 *         self.end_pos = end_pos             # <<<<<<<<<<<<<<
 * 
 *     cdef update(self, type_: Optional[str]=None, value: Optional[Any]=None):
 */
  __Pyx_INCREF(__pyx_v_end_pos);
  __Pyx_GIVEREF(__pyx_v_end_pos);
  __Pyx_GOTREF(__pyx_v_self->end_pos);
  __Pyx_DECREF(__pyx_v_self->end_pos);
  __pyx_v_self->end_pos = __pyx_v_end_pos;

  /* "lark_cython/lark_cython.pyx":26
 *     cdef public end_pos
 * 
 *     def __cinit__(self, str type_, str value, int start_pos, int line, int column, end_line=None, end_column=None, end_pos=None):             # <<<<<<<<<<<<<<
 *         self.type = type_
 *         self.start_pos = start_pos
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":36
 *         self.end_pos = end_pos
 * 
 *     cdef update(self, type_: Optional[str]=None, value: Optional[Any]=None):             # <<<<<<<<<<<<<<
 *         return Token.new_borrow_pos(
 *             type_ if type_ is not None else self.type,
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_5Token_update(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, struct __pyx_opt_args_11lark_cython_11lark_cython_5Token_update *__pyx_optional_args) {
  PyObject *__pyx_v_type_ = ((PyObject *)Py_None);
  PyObject *__pyx_v_value = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("update", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_type_ = __pyx_optional_args->type_;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_value = __pyx_optional_args->value;
      }
    }
  }

  /* "lark_cython/lark_cython.pyx":37
 * 
 *     cdef update(self, type_: Optional[str]=None, value: Optional[Any]=None):
 *         return Token.new_borrow_pos(             # <<<<<<<<<<<<<<
 *             type_ if type_ is not None else self.type,
 *             value if value is not None else self.value,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token), __pyx_n_s_new_borrow_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "lark_cython/lark_cython.pyx":38
 *     cdef update(self, type_: Optional[str]=None, value: Optional[Any]=None):
 *         return Token.new_borrow_pos(
 *             type_ if type_ is not None else self.type,             # <<<<<<<<<<<<<<
 *             value if value is not None else self.value,
 *             self
 */
  __pyx_t_4 = (__pyx_v_type_ != Py_None);
  if ((__pyx_t_4 != 0)) {
    __Pyx_INCREF(__pyx_v_type_);
    __pyx_t_3 = __pyx_v_type_;
  } else {
    __Pyx_INCREF(__pyx_v_self->type);
    __pyx_t_3 = __pyx_v_self->type;
  }

  /* "lark_cython/lark_cython.pyx":39
 *         return Token.new_borrow_pos(
 *             type_ if type_ is not None else self.type,
 *             value if value is not None else self.value,             # <<<<<<<<<<<<<<
 *             self
 *         )
 */
  __pyx_t_4 = (__pyx_v_value != Py_None);
  if ((__pyx_t_4 != 0)) {
    __Pyx_INCREF(__pyx_v_value);
    __pyx_t_5 = __pyx_v_value;
  } else {
    __Pyx_INCREF(__pyx_v_self->value);
    __pyx_t_5 = __pyx_v_self->value;
  }

  /* "lark_cython/lark_cython.pyx":40
 *             type_ if type_ is not None else self.type,
 *             value if value is not None else self.value,
 *             self             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_3, __pyx_t_5, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_3, __pyx_t_5, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_5);
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, ((PyObject *)__pyx_v_self));
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":36
 *         self.end_pos = end_pos
 * 
 *     cdef update(self, type_: Optional[str]=None, value: Optional[Any]=None):             # <<<<<<<<<<<<<<
 *         return Token.new_borrow_pos(
 *             type_ if type_ is not None else self.type,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":44
 * 
 *     @classmethod
 *     def new_borrow_pos(cls, type_: str, value: Any, borrow_t: 'Token'):             # <<<<<<<<<<<<<<
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_3new_borrow_pos(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_3new_borrow_pos(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_type_ = 0;
  PyObject *__pyx_v_value = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_borrow_t = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("new_borrow_pos (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_type,&__pyx_n_s_value,&__pyx_n_s_borrow_t,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("new_borrow_pos", 1, 3, 3, 1); __PYX_ERR(0, 44, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_borrow_t)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("new_borrow_pos", 1, 3, 3, 2); __PYX_ERR(0, 44, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "new_borrow_pos") < 0)) __PYX_ERR(0, 44, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_type_ = ((PyObject*)values[0]);
    __pyx_v_value = values[1];
    __pyx_v_borrow_t = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)values[2]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("new_borrow_pos", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 44, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.new_borrow_pos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_type_), (&PyUnicode_Type), 1, "type_", 1))) __PYX_ERR(0, 44, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_borrow_t), __pyx_ptype_11lark_cython_11lark_cython_Token, 1, "borrow_t", 0))) __PYX_ERR(0, 44, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_2new_borrow_pos(((PyTypeObject*)__pyx_v_cls), __pyx_v_type_, __pyx_v_value, __pyx_v_borrow_t);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_2new_borrow_pos(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_type_, PyObject *__pyx_v_value, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_borrow_t) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("new_borrow_pos", 0);

  /* "lark_cython/lark_cython.pyx":45
 *     @classmethod
 *     def new_borrow_pos(cls, type_: str, value: Any, borrow_t: 'Token'):
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)             # <<<<<<<<<<<<<<
 * 
 *     cdef __reduce__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_borrow_t->start_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_borrow_t->line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_borrow_t->column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_type_);
  __Pyx_GIVEREF(__pyx_v_type_);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_type_);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_value);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_borrow_t->end_line);
  __Pyx_GIVEREF(__pyx_v_borrow_t->end_line);
  PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_v_borrow_t->end_line);
  __Pyx_INCREF(__pyx_v_borrow_t->end_column);
  __Pyx_GIVEREF(__pyx_v_borrow_t->end_column);
  PyTuple_SET_ITEM(__pyx_t_4, 6, __pyx_v_borrow_t->end_column);
  __Pyx_INCREF(__pyx_v_borrow_t->end_pos);
  __Pyx_GIVEREF(__pyx_v_borrow_t->end_pos);
  PyTuple_SET_ITEM(__pyx_t_4, 7, __pyx_v_borrow_t->end_pos);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":44
 * 
 *     @classmethod
 *     def new_borrow_pos(cls, type_: str, value: Any, borrow_t: 'Token'):             # <<<<<<<<<<<<<<
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.new_borrow_pos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":47
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)
 * 
 *     cdef __reduce__(self):             # <<<<<<<<<<<<<<
 *         return (self.__class__, (self.type, self.value, self.start_pos, self.line, self.column))
 * 
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_5Token___reduce__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 0);

  /* "lark_cython/lark_cython.pyx":48
 * 
 *     cdef __reduce__(self):
 *         return (self.__class__, (self.type, self.value, self.start_pos, self.line, self.column))             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->start_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->line); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->column); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_self->type);
  __Pyx_GIVEREF(__pyx_v_self->type);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_self->type);
  __Pyx_INCREF(__pyx_v_self->value);
  __Pyx_GIVEREF(__pyx_v_self->value);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self->value);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_t_4);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":47
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)
 * 
 *     cdef __reduce__(self):             # <<<<<<<<<<<<<<
 *         return (self.__class__, (self.type, self.value, self.start_pos, self.line, self.column))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":50
 *         return (self.__class__, (self.type, self.value, self.start_pos, self.line, self.column))
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Token(%r, %r)' % (self.type, self.value)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_5__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_4__repr__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_4__repr__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "lark_cython/lark_cython.pyx":51
 * 
 *     def __repr__(self):
 *         return 'Token(%r, %r)' % (self.type, self.value)             # <<<<<<<<<<<<<<
 * 
 *     cdef __deepcopy__(self, memo):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u_Token);
  __pyx_t_2 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_Token);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_Token);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->type), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_);
  __pyx_t_2 += 2;
  __Pyx_GIVEREF(__pyx_kp_u_);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->value), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__2);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__2);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__2);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":50
 *         return (self.__class__, (self.type, self.value, self.start_pos, self.line, self.column))
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Token(%r, %r)' % (self.type, self.value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":53
 *         return 'Token(%r, %r)' % (self.type, self.value)
 * 
 *     cdef __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_5Token___deepcopy__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__deepcopy__", 0);

  /* "lark_cython/lark_cython.pyx":54
 * 
 *     cdef __deepcopy__(self, memo):
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, Token_or_str other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->start_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->type);
  __Pyx_GIVEREF(__pyx_v_self->type);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->type);
  __Pyx_INCREF(__pyx_v_self->value);
  __Pyx_GIVEREF(__pyx_v_self->value);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self->value);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":53
 *         return 'Token(%r, %r)' % (self.type, self.value)
 * 
 *     cdef __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__deepcopy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":56
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 *     def __eq__(self, Token_or_str other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_7__eq__(PyObject *__pyx_v_signatures, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_5Token_7__eq__ = {"__eq__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_5Token_7__eq__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_7__eq__(PyObject *__pyx_v_signatures, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED PyObject *__pyx_v_defaults = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fused_cpdef (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_args,&__pyx_n_s_kwargs,&__pyx_n_s_defaults,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_args)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_kwargs)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 1, 3, 3, 1); __PYX_ERR(0, 56, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_defaults)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 1, 3, 3, 2); __PYX_ERR(0, 56, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_fused_cpdef") < 0)) __PYX_ERR(0, 56, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_args = values[0];
    __pyx_v_kwargs = values[1];
    __pyx_v_defaults = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 56, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_6__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_signatures), __pyx_v_args, __pyx_v_kwargs, __pyx_v_defaults);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_6__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults) {
  PyObject *__pyx_v_dest_sig = NULL;
  Py_ssize_t __pyx_v_i;
  CYTHON_UNUSED PyTypeObject *__pyx_v_ndarray = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_v_itemsize;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_candidates = NULL;
  PyObject *__pyx_v_sig = NULL;
  int __pyx_v_match_found;
  PyObject *__pyx_v_src_sig = NULL;
  PyObject *__pyx_v_dst_type = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);
  __Pyx_INCREF(__pyx_v_kwargs);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyList_SET_ITEM(__pyx_t_1, 0, Py_None);
  __pyx_v_dest_sig = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_v_kwargs != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_3 = ((!__pyx_t_4) != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_kwargs, Py_None);
  }
  __pyx_t_1 = ((PyObject *)__Pyx_ImportNumPyArrayTypeIfAvailable()); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ndarray = ((PyTypeObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_v_itemsize = -1L;
  if (unlikely(__pyx_v_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 56, __pyx_L1_error)
  }
  __pyx_t_5 = PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_2 = ((1 < __pyx_t_5) != 0);
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 56, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(((PyObject*)__pyx_v_args), 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  __pyx_t_3 = (__pyx_v_kwargs != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  if (unlikely(__pyx_v_kwargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 56, __pyx_L1_error)
  }
  __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_other, ((PyObject*)__pyx_v_kwargs), Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_kwargs == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 56, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_kwargs), __pyx_n_s_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  /*else*/ {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 56, __pyx_L1_error)
    }
    __pyx_t_5 = PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 56, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_2);
    __Pyx_GIVEREF(__pyx_int_2);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_2);
    __Pyx_INCREF(__pyx_n_s_s);
    __Pyx_GIVEREF(__pyx_n_s_s);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_s);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 56, __pyx_L1_error)
  }
  __pyx_L6:;
  while (1) {
    __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_kp_s__3);
    __Pyx_GIVEREF(__pyx_kp_s__3);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_kp_s__3);
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_kp_s_lark_cython_lark_cython);
    __Pyx_GIVEREF(__pyx_kp_s_lark_cython_lark_cython);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_lark_cython_lark_cython);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_Token_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = PyObject_IsInstance(__pyx_v_arg, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {
      if (unlikely(__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_Token_2, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
      goto __pyx_L10_break;
    }
    __pyx_t_3 = PyUnicode_Check(__pyx_v_arg); 
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {
      if (unlikely(__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_unicode, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
      goto __pyx_L10_break;
    }
    if (unlikely(__Pyx_SetItemInt(__pyx_v_dest_sig, 0, Py_None, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
    goto __pyx_L10_break;
  }
  __pyx_L10_break:;
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_candidates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  if (unlikely(((PyObject *)__pyx_v_signatures) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 56, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_dict_iterator(((PyObject*)__pyx_v_signatures), 1, ((PyObject *)NULL), (&__pyx_t_7), (&__pyx_t_8)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_6;
  __pyx_t_6 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_7, &__pyx_t_5, &__pyx_t_6, NULL, NULL, __pyx_t_8);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_sig, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_v_match_found = 0;
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_strip); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_12, __pyx_kp_s__4) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_kp_s__4);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_split); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    __pyx_t_6 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_10, __pyx_kp_s__5) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_kp_s__5);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF_SET(__pyx_v_src_sig, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_13 = PyList_GET_SIZE(__pyx_v_dest_sig); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 56, __pyx_L1_error)
    __pyx_t_14 = __pyx_t_13;
    for (__pyx_t_15 = 0; __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
      __pyx_v_i = __pyx_t_15;
      __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_v_dest_sig, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_dst_type, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_2 = (__pyx_v_dst_type != Py_None);
      __pyx_t_3 = (__pyx_t_2 != 0);
      if (__pyx_t_3) {
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_src_sig, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 56, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_6, __pyx_v_dst_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 56, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (__pyx_t_3) {
          __pyx_v_match_found = 1;
          goto __pyx_L18;
        }
        /*else*/ {
          __pyx_v_match_found = 0;
          goto __pyx_L16_break;
        }
        __pyx_L18:;
      }
    }
    __pyx_L16_break:;
    __pyx_t_3 = (__pyx_v_match_found != 0);
    if (__pyx_t_3) {
      __pyx_t_16 = __Pyx_PyList_Append(__pyx_v_candidates, __pyx_v_sig); if (unlikely(__pyx_t_16 == ((int)-1))) __PYX_ERR(0, 56, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (PyList_GET_SIZE(__pyx_v_candidates) != 0);
  __pyx_t_2 = ((!__pyx_t_3) != 0);
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 56, __pyx_L1_error)
  }
  __pyx_t_7 = PyList_GET_SIZE(__pyx_v_candidates); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_7 > 1) != 0);
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 56, __pyx_L1_error)
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(((PyObject *)__pyx_v_signatures) == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 56, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_candidates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_signatures), __pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_11;
    __pyx_t_11 = 0;
    goto __pyx_L0;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dest_sig);
  __Pyx_XDECREF(__pyx_v_ndarray);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_candidates);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_src_sig);
  __Pyx_XDECREF(__pyx_v_dst_type);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_0__pyx_pw_11lark_cython_11lark_cython_5Token_11__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyMethodDef __pyx_fuse_0__pyx_mdef_11lark_cython_11lark_cython_5Token_11__eq__ = {"__pyx_fuse_0__eq__", (PyCFunction)__pyx_fuse_0__pyx_pw_11lark_cython_11lark_cython_5Token_11__eq__, METH_O|METH_COEXIST, 0};
static PyObject *__pyx_fuse_0__pyx_pw_11lark_cython_11lark_cython_5Token_11__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_11lark_cython_11lark_cython_Token, 1, "other", 0))) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_10__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_other));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_10__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0__eq__", 0);

  /* "lark_cython/lark_cython.pyx":57
 * 
 *     def __eq__(self, Token_or_str other):
 *         if isinstance(other, Token) and self.type != other.type:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_2 = __Pyx_TypeCheck(((PyObject *)__pyx_v_other), __pyx_ptype_11lark_cython_11lark_cython_Token); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_self->type, __pyx_v_other->type, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 57, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "lark_cython/lark_cython.pyx":58
 *     def __eq__(self, Token_or_str other):
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         return str.__eq__(self, other)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":57
 * 
 *     def __eq__(self, Token_or_str other):
 *         if isinstance(other, Token) and self.type != other.type:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":60
 *             return False
 * 
 *         return str.__eq__(self, other)             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyUnicode_Type)), __pyx_n_s_eq); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_other)};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_other)};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, ((PyObject *)__pyx_v_self));
    __Pyx_INCREF(((PyObject *)__pyx_v_other));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_other));
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, ((PyObject *)__pyx_v_other));
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":56
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 *     def __eq__(self, Token_or_str other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_1__pyx_pw_11lark_cython_11lark_cython_5Token_13__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyMethodDef __pyx_fuse_1__pyx_mdef_11lark_cython_11lark_cython_5Token_13__eq__ = {"__pyx_fuse_1__eq__", (PyCFunction)__pyx_fuse_1__pyx_pw_11lark_cython_11lark_cython_5Token_13__eq__, METH_O|METH_COEXIST, 0};
static PyObject *__pyx_fuse_1__pyx_pw_11lark_cython_11lark_cython_5Token_13__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), (&PyUnicode_Type), 1, "other", 1))) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_12__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject*)__pyx_v_other));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_12__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1__eq__", 0);

  /* "lark_cython/lark_cython.pyx":57
 * 
 *     def __eq__(self, Token_or_str other):
 *         if isinstance(other, Token) and self.type != other.type:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_11lark_cython_11lark_cython_Token); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_type_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_self->type, __pyx_t_4, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "lark_cython/lark_cython.pyx":58
 *     def __eq__(self, Token_or_str other):
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         return str.__eq__(self, other)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":57
 * 
 *     def __eq__(self, Token_or_str other):
 *         if isinstance(other, Token) and self.type != other.type:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":60
 *             return False
 * 
 *         return str.__eq__(self, other)             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)(&PyUnicode_Type)), __pyx_n_s_eq); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), __pyx_v_other};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), __pyx_v_other};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, ((PyObject *)__pyx_v_self));
    __Pyx_INCREF(__pyx_v_other);
    __Pyx_GIVEREF(__pyx_v_other);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_other);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":56
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 *     def __eq__(self, Token_or_str other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":62
 *         return str.__eq__(self, other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.value)
 * 
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_11lark_cython_11lark_cython_5Token_9__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_11lark_cython_11lark_cython_5Token_9__hash__(PyObject *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_8__hash__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_11lark_cython_11lark_cython_5Token_8__hash__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_hash_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "lark_cython/lark_cython.pyx":63
 * 
 *     def __hash__(self):
 *         return hash(self.value)             # <<<<<<<<<<<<<<
 * 
 * cdef class LexerState:
 */
  __pyx_t_1 = __pyx_v_self->value;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Hash(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_hash_t)-1))) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":62
 *         return str.__eq__(self, other)
 * 
 *     def __hash__(self):             # <<<<<<<<<<<<<<
 *         return hash(self.value)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":17
 * @cython.freelist(10240)
 * cdef class Token:
 *     cdef public str type             # <<<<<<<<<<<<<<
 *     cdef public int start_pos
 *     cdef public str value
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_4type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_4type_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_4type___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_4type___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->type);
  __pyx_r = __pyx_v_self->type;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_4type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_4type_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_4type_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_4type_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->type);
  __Pyx_DECREF(__pyx_v_self->type);
  __pyx_v_self->type = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.type.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_4type_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_4type_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_4type_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_4type_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->type);
  __Pyx_DECREF(__pyx_v_self->type);
  __pyx_v_self->type = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":18
 * cdef class Token:
 *     cdef public str type
 *     cdef public int start_pos             # <<<<<<<<<<<<<<
 *     cdef public str value
 *     cdef public int line
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_9start_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_9start_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_9start_pos___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_9start_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->start_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.start_pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_9start_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_9start_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_9start_pos_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_9start_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 18, __pyx_L1_error)
  __pyx_v_self->start_pos = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.start_pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":19
 *     cdef public str type
 *     cdef public int start_pos
 *     cdef public str value             # <<<<<<<<<<<<<<
 *     cdef public int line
 *     cdef public int column
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_5value_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_5value_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_5value___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_5value___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->value);
  __pyx_r = __pyx_v_self->value;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_5value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_5value_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_5value_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_5value_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 19, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.value.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_5value_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_5value_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_5value_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_5value_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":20
 *     cdef public int start_pos
 *     cdef public str value
 *     cdef public int line             # <<<<<<<<<<<<<<
 *     cdef public int column
 *     cdef public end_line
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_4line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_4line_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_4line___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_4line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.line.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_4line_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_4line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 20, __pyx_L1_error)
  __pyx_v_self->line = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.line.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":21
 *     cdef public str value
 *     cdef public int line
 *     cdef public int column             # <<<<<<<<<<<<<<
 *     cdef public end_line
 *     cdef public end_column
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_6column_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_6column_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_6column___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_6column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.column.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_6column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_6column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_6column_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_6column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 21, __pyx_L1_error)
  __pyx_v_self->column = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Token.column.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":22
 *     cdef public int line
 *     cdef public int column
 *     cdef public end_line             # <<<<<<<<<<<<<<
 *     cdef public end_column
 *     cdef public end_pos
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_8end_line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->end_line);
  __pyx_r = __pyx_v_self->end_line;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->end_line);
  __Pyx_DECREF(__pyx_v_self->end_line);
  __pyx_v_self->end_line = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_8end_line_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->end_line);
  __Pyx_DECREF(__pyx_v_self->end_line);
  __pyx_v_self->end_line = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":23
 *     cdef public int column
 *     cdef public end_line
 *     cdef public end_column             # <<<<<<<<<<<<<<
 *     cdef public end_pos
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_10end_column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->end_column);
  __pyx_r = __pyx_v_self->end_column;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->end_column);
  __Pyx_DECREF(__pyx_v_self->end_column);
  __pyx_v_self->end_column = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_10end_column_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->end_column);
  __Pyx_DECREF(__pyx_v_self->end_column);
  __pyx_v_self->end_column = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":24
 *     cdef public end_line
 *     cdef public end_column
 *     cdef public end_pos             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, str type_, str value, int start_pos, int line, int column, end_line=None, end_column=None, end_pos=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->end_pos);
  __pyx_r = __pyx_v_self->end_pos;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->end_pos);
  __Pyx_DECREF(__pyx_v_self->end_pos);
  __pyx_v_self->end_pos = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_5Token_7end_pos_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->end_pos);
  __Pyx_DECREF(__pyx_v_self->end_pos);
  __pyx_v_self->end_pos = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":72
 *     cdef public object last_token
 * 
 *     def __cinit__(self, text, line_ctr, last_token=None):             # <<<<<<<<<<<<<<
 *         self.text = text
 *         self.line_ctr = line_ctr
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_line_ctr = 0;
  PyObject *__pyx_v_last_token = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_text,&__pyx_n_s_line_ctr,&__pyx_n_s_last_token,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_text)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_line_ctr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(0, 72, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_last_token);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 72, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_text = values[0];
    __pyx_v_line_ctr = values[1];
    __pyx_v_last_token = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 72, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self), __pyx_v_text, __pyx_v_line_ctr, __pyx_v_last_token);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_line_ctr, PyObject *__pyx_v_last_token) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":73
 * 
 *     def __cinit__(self, text, line_ctr, last_token=None):
 *         self.text = text             # <<<<<<<<<<<<<<
 *         self.line_ctr = line_ctr
 *         self.last_token = last_token
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_text))||((__pyx_v_text) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_text)->tp_name), 0))) __PYX_ERR(0, 73, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_text;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->text);
  __Pyx_DECREF(__pyx_v_self->text);
  __pyx_v_self->text = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":74
 *     def __cinit__(self, text, line_ctr, last_token=None):
 *         self.text = text
 *         self.line_ctr = line_ctr             # <<<<<<<<<<<<<<
 *         self.last_token = last_token
 * 
 */
  if (!(likely(((__pyx_v_line_ctr) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_line_ctr, __pyx_ptype_11lark_cython_11lark_cython_LineCounter))))) __PYX_ERR(0, 74, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_line_ctr;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->line_ctr);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->line_ctr));
  __pyx_v_self->line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":75
 *         self.text = text
 *         self.line_ctr = line_ctr
 *         self.last_token = last_token             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
  __Pyx_INCREF(__pyx_v_last_token);
  __Pyx_GIVEREF(__pyx_v_last_token);
  __Pyx_GOTREF(__pyx_v_self->last_token);
  __Pyx_DECREF(__pyx_v_self->last_token);
  __pyx_v_self->last_token = __pyx_v_last_token;

  /* "lark_cython/lark_cython.pyx":72
 *     cdef public object last_token
 * 
 *     def __cinit__(self, text, line_ctr, last_token=None):             # <<<<<<<<<<<<<<
 *         self.text = text
 *         self.line_ctr = line_ctr
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":77
 *         self.last_token = last_token
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, LexerState):
 *             return NotImplemented
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_2__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_2__eq__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "lark_cython/lark_cython.pyx":78
 * 
 *     def __eq__(self, other):
 *         if not isinstance(other, LexerState):             # <<<<<<<<<<<<<<
 *             return NotImplemented
 * 
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_11lark_cython_11lark_cython_LexerState); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":79
 *     def __eq__(self, other):
 *         if not isinstance(other, LexerState):
 *             return NotImplemented             # <<<<<<<<<<<<<<
 * 
 *         return self.text is other.text and self.line_ctr == other.line_ctr and self.last_token == other.last_token
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_builtin_NotImplemented);
    __pyx_r = __pyx_builtin_NotImplemented;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":78
 * 
 *     def __eq__(self, other):
 *         if not isinstance(other, LexerState):             # <<<<<<<<<<<<<<
 *             return NotImplemented
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":81
 *             return NotImplemented
 * 
 *         return self.text is other.text and self.line_ctr == other.line_ctr and self.last_token == other.last_token             # <<<<<<<<<<<<<<
 * 
 *     cdef __copy__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_self->text == ((PyObject*)__pyx_t_4));
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {
  } else {
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 81, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_line_ctr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(((PyObject *)__pyx_v_self->line_ctr), __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 81, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_last_token); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_self->last_token, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":77
 *         self.last_token = last_token
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, LexerState):
 *             return NotImplemented
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":83
 *         return self.text is other.text and self.line_ctr == other.line_ctr and self.last_token == other.last_token
 * 
 *     cdef __copy__(self):             # <<<<<<<<<<<<<<
 *         return type(self)(self.text, copy(self.line_ctr), self.last_token)
 * 
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_10LexerState___copy__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__copy__", 0);

  /* "lark_cython/lark_cython.pyx":84
 * 
 *     cdef __copy__(self):
 *         return type(self)(self.text, copy(self.line_ctr), self.last_token)             # <<<<<<<<<<<<<<
 * 
 * cdef class LineCounter:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_self->line_ctr)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_self->line_ctr));
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __pyx_t_3 = ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))); __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_self->text, __pyx_t_2, __pyx_v_self->last_token};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_v_self->text, __pyx_t_2, __pyx_v_self->last_token};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_self->text);
    __Pyx_GIVEREF(__pyx_v_self->text);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_self->text);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->last_token);
    __Pyx_GIVEREF(__pyx_v_self->last_token);
    PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, __pyx_v_self->last_token);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":83
 *         return self.text is other.text and self.line_ctr == other.line_ctr and self.last_token == other.last_token
 * 
 *     cdef __copy__(self):             # <<<<<<<<<<<<<<
 *         return type(self)(self.text, copy(self.line_ctr), self.last_token)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":68
 *     __slots__ = 'text', 'line_ctr', 'last_token'
 * 
 *     cdef public str text             # <<<<<<<<<<<<<<
 *     cdef public LineCounter line_ctr
 *     cdef public object last_token
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_4text___get__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->text);
  __pyx_r = __pyx_v_self->text;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 68, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->text);
  __Pyx_DECREF(__pyx_v_self->text);
  __pyx_v_self->text = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.text.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_4text_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->text);
  __Pyx_DECREF(__pyx_v_self->text);
  __pyx_v_self->text = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":69
 * 
 *     cdef public str text
 *     cdef public LineCounter line_ctr             # <<<<<<<<<<<<<<
 *     cdef public object last_token
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr___get__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->line_ctr));
  __pyx_r = ((PyObject *)__pyx_v_self->line_ctr);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_11lark_cython_11lark_cython_LineCounter))))) __PYX_ERR(0, 69, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->line_ctr);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->line_ctr));
  __pyx_v_self->line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.line_ctr.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_8line_ctr_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->line_ctr);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->line_ctr));
  __pyx_v_self->line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":70
 *     cdef public str text
 *     cdef public LineCounter line_ctr
 *     cdef public object last_token             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, text, line_ctr, last_token=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token___get__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->last_token);
  __pyx_r = __pyx_v_self->last_token;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->last_token);
  __Pyx_DECREF(__pyx_v_self->last_token);
  __pyx_v_self->last_token = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_10LexerState_10last_token_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->last_token);
  __Pyx_DECREF(__pyx_v_self->last_token);
  __pyx_v_self->last_token = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10LexerState_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10LexerState_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10LexerState_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerState.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":95
 *     cdef public int line_start_pos
 * 
 *     def __cinit__(self, newline_char):             # <<<<<<<<<<<<<<
 *         self.newline_char = newline_char
 *         self.char_pos = 0
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_newline_char = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_newline_char,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_newline_char)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 95, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_newline_char = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 95, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), __pyx_v_newline_char);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_newline_char) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":96
 * 
 *     def __cinit__(self, newline_char):
 *         self.newline_char = newline_char             # <<<<<<<<<<<<<<
 *         self.char_pos = 0
 *         self.line = 1
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_newline_char))||((__pyx_v_newline_char) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_newline_char)->tp_name), 0))) __PYX_ERR(0, 96, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_newline_char;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->newline_char);
  __Pyx_DECREF(__pyx_v_self->newline_char);
  __pyx_v_self->newline_char = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":97
 *     def __cinit__(self, newline_char):
 *         self.newline_char = newline_char
 *         self.char_pos = 0             # <<<<<<<<<<<<<<
 *         self.line = 1
 *         self.column = 1
 */
  __pyx_v_self->char_pos = 0;

  /* "lark_cython/lark_cython.pyx":98
 *         self.newline_char = newline_char
 *         self.char_pos = 0
 *         self.line = 1             # <<<<<<<<<<<<<<
 *         self.column = 1
 *         self.line_start_pos = 0
 */
  __pyx_v_self->line = 1;

  /* "lark_cython/lark_cython.pyx":99
 *         self.char_pos = 0
 *         self.line = 1
 *         self.column = 1             # <<<<<<<<<<<<<<
 *         self.line_start_pos = 0
 * 
 */
  __pyx_v_self->column = 1;

  /* "lark_cython/lark_cython.pyx":100
 *         self.line = 1
 *         self.column = 1
 *         self.line_start_pos = 0             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
  __pyx_v_self->line_start_pos = 0;

  /* "lark_cython/lark_cython.pyx":95
 *     cdef public int line_start_pos
 * 
 *     def __cinit__(self, newline_char):             # <<<<<<<<<<<<<<
 *         self.newline_char = newline_char
 *         self.char_pos = 0
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":102
 *         self.line_start_pos = 0
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, LineCounter):
 *             return NotImplemented
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_2__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_2__eq__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "lark_cython/lark_cython.pyx":103
 * 
 *     def __eq__(self, other):
 *         if not isinstance(other, LineCounter):             # <<<<<<<<<<<<<<
 *             return NotImplemented
 * 
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_11lark_cython_11lark_cython_LineCounter); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":104
 *     def __eq__(self, other):
 *         if not isinstance(other, LineCounter):
 *             return NotImplemented             # <<<<<<<<<<<<<<
 * 
 *         return self.char_pos == other.char_pos and self.newline_char == other.newline_char
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_builtin_NotImplemented);
    __pyx_r = __pyx_builtin_NotImplemented;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":103
 * 
 *     def __eq__(self, other):
 *         if not isinstance(other, LineCounter):             # <<<<<<<<<<<<<<
 *             return NotImplemented
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":106
 *             return NotImplemented
 * 
 *         return self.char_pos == other.char_pos and self.newline_char == other.newline_char             # <<<<<<<<<<<<<<
 * 
 *     cpdef public feed(self, str token, bint test_newline):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->char_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_char_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 106, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = __pyx_t_6;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_newline_char); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_self->newline_char, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_3 = __pyx_t_5;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":102
 *         self.line_start_pos = 0
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, LineCounter):
 *             return NotImplemented
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":108
 *         return self.char_pos == other.char_pos and self.newline_char == other.newline_char
 * 
 *     cpdef public feed(self, str token, bint test_newline):             # <<<<<<<<<<<<<<
 *         """Consume a token and calculate the new line & column.
 * 
 */

static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_5feed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_11LineCounter_feed(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_token, int __pyx_v_test_newline, int __pyx_skip_dispatch) {
  int __pyx_v_newlines;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("feed", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_feed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11lark_cython_11lark_cython_11LineCounter_5feed)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_test_newline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 108, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_token, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_token, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 108, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (__pyx_t_5) {
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          }
          __Pyx_INCREF(__pyx_v_token);
          __Pyx_GIVEREF(__pyx_v_token);
          PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_token);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "lark_cython/lark_cython.pyx":115
 *         cdef int newlines
 * 
 *         if test_newline:             # <<<<<<<<<<<<<<
 *             newlines = token.count(self.newline_char)
 *             if newlines:
 */
  __pyx_t_8 = (__pyx_v_test_newline != 0);
  if (__pyx_t_8) {

    /* "lark_cython/lark_cython.pyx":116
 * 
 *         if test_newline:
 *             newlines = token.count(self.newline_char)             # <<<<<<<<<<<<<<
 *             if newlines:
 *                 self.line += newlines
 */
    if (unlikely(__pyx_v_token == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "count");
      __PYX_ERR(0, 116, __pyx_L1_error)
    }
    __pyx_t_9 = PyUnicode_Count(__pyx_v_token, __pyx_v_self->newline_char, 0, PY_SSIZE_T_MAX); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 116, __pyx_L1_error)
    __pyx_v_newlines = __pyx_t_9;

    /* "lark_cython/lark_cython.pyx":117
 *         if test_newline:
 *             newlines = token.count(self.newline_char)
 *             if newlines:             # <<<<<<<<<<<<<<
 *                 self.line += newlines
 *                 self.line_start_pos = self.char_pos + token.rindex(self.newline_char) + 1
 */
    __pyx_t_8 = (__pyx_v_newlines != 0);
    if (__pyx_t_8) {

      /* "lark_cython/lark_cython.pyx":118
 *             newlines = token.count(self.newline_char)
 *             if newlines:
 *                 self.line += newlines             # <<<<<<<<<<<<<<
 *                 self.line_start_pos = self.char_pos + token.rindex(self.newline_char) + 1
 * 
 */
      __pyx_v_self->line = (__pyx_v_self->line + __pyx_v_newlines);

      /* "lark_cython/lark_cython.pyx":119
 *             if newlines:
 *                 self.line += newlines
 *                 self.line_start_pos = self.char_pos + token.rindex(self.newline_char) + 1             # <<<<<<<<<<<<<<
 * 
 *         self.char_pos += len(token)
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->char_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyUnicode_Type_rindex, __pyx_v_token, __pyx_v_self->newline_char); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_self->line_start_pos = __pyx_t_6;

      /* "lark_cython/lark_cython.pyx":117
 *         if test_newline:
 *             newlines = token.count(self.newline_char)
 *             if newlines:             # <<<<<<<<<<<<<<
 *                 self.line += newlines
 *                 self.line_start_pos = self.char_pos + token.rindex(self.newline_char) + 1
 */
    }

    /* "lark_cython/lark_cython.pyx":115
 *         cdef int newlines
 * 
 *         if test_newline:             # <<<<<<<<<<<<<<
 *             newlines = token.count(self.newline_char)
 *             if newlines:
 */
  }

  /* "lark_cython/lark_cython.pyx":121
 *                 self.line_start_pos = self.char_pos + token.rindex(self.newline_char) + 1
 * 
 *         self.char_pos += len(token)             # <<<<<<<<<<<<<<
 *         self.column = self.char_pos - self.line_start_pos + 1
 * 
 */
  if (unlikely(__pyx_v_token == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 121, __pyx_L1_error)
  }
  __pyx_t_9 = __Pyx_PyUnicode_GET_LENGTH(__pyx_v_token); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 121, __pyx_L1_error)
  __pyx_v_self->char_pos = (__pyx_v_self->char_pos + __pyx_t_9);

  /* "lark_cython/lark_cython.pyx":122
 * 
 *         self.char_pos += len(token)
 *         self.column = self.char_pos - self.line_start_pos + 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->column = ((__pyx_v_self->char_pos - __pyx_v_self->line_start_pos) + 1);

  /* "lark_cython/lark_cython.pyx":108
 *         return self.char_pos == other.char_pos and self.newline_char == other.newline_char
 * 
 *     cpdef public feed(self, str token, bint test_newline):             # <<<<<<<<<<<<<<
 *         """Consume a token and calculate the new line & column.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.feed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_5feed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_11LineCounter_4feed[] = "Consume a token and calculate the new line & column.\n\n        As an optional optimization, set test_newline=False if token doesn't contain a newline.\n        ";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_5feed(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_token = 0;
  int __pyx_v_test_newline;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("feed (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_token,&__pyx_n_s_test_newline,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_token)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_test_newline)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("feed", 1, 2, 2, 1); __PYX_ERR(0, 108, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "feed") < 0)) __PYX_ERR(0, 108, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_token = ((PyObject*)values[0]);
    __pyx_v_test_newline = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_test_newline == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 108, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("feed", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 108, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.feed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_token), (&PyUnicode_Type), 1, "token", 1))) __PYX_ERR(0, 108, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_4feed(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), __pyx_v_token, __pyx_v_test_newline);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_4feed(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_token, int __pyx_v_test_newline) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("feed", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython_11LineCounter_feed(__pyx_v_self, __pyx_v_token, __pyx_v_test_newline, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.feed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":89
 *     __slots__ = 'char_pos', 'line', 'column', 'line_start_pos', 'newline_char'
 * 
 *     cdef public str newline_char             # <<<<<<<<<<<<<<
 *     cdef public int char_pos
 *     cdef public int line
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->newline_char);
  __pyx_r = __pyx_v_self->newline_char;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 89, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->newline_char);
  __Pyx_DECREF(__pyx_v_self->newline_char);
  __pyx_v_self->newline_char = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.newline_char.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_12newline_char_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->newline_char);
  __Pyx_DECREF(__pyx_v_self->newline_char);
  __pyx_v_self->newline_char = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":90
 * 
 *     cdef public str newline_char
 *     cdef public int char_pos             # <<<<<<<<<<<<<<
 *     cdef public int line
 *     cdef public int column
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_8char_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_8char_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_8char_pos___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_8char_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->char_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.char_pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_8char_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_8char_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_8char_pos_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_8char_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 90, __pyx_L1_error)
  __pyx_v_self->char_pos = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.char_pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":91
 *     cdef public str newline_char
 *     cdef public int char_pos
 *     cdef public int line             # <<<<<<<<<<<<<<
 *     cdef public int column
 *     cdef public int line_start_pos
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_4line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_4line_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_4line___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_4line___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.line.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_4line_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_4line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 91, __pyx_L1_error)
  __pyx_v_self->line = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.line.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":92
 *     cdef public int char_pos
 *     cdef public int line
 *     cdef public int column             # <<<<<<<<<<<<<<
 *     cdef public int line_start_pos
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_6column_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_6column_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_6column___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_6column___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.column.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_6column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_6column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_6column_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_6column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 92, __pyx_L1_error)
  __pyx_v_self->column = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.column.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":93
 *     cdef public int line
 *     cdef public int column
 *     cdef public int line_start_pos             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, newline_char):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_14line_start_pos___get__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_14line_start_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->line_start_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.line_start_pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 93, __pyx_L1_error)
  __pyx_v_self->line_start_pos = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.line_start_pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_6__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LineCounter_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LineCounter_8__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LineCounter_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LineCounter.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":134
 *     cdef list _mres
 * 
 *     def __cinit__(self, terminals, g_regex_flags, re_, use_bytes, match_whole=False):             # <<<<<<<<<<<<<<
 *         self.terminals = terminals
 *         self.g_regex_flags = g_regex_flags
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_terminals = 0;
  PyObject *__pyx_v_g_regex_flags = 0;
  PyObject *__pyx_v_re_ = 0;
  PyObject *__pyx_v_use_bytes = 0;
  PyObject *__pyx_v_match_whole = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_terminals,&__pyx_n_s_g_regex_flags,&__pyx_n_s_re,&__pyx_n_s_use_bytes,&__pyx_n_s_match_whole,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[4] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_terminals)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_g_regex_flags)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 4, 5, 1); __PYX_ERR(0, 134, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_re)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 4, 5, 2); __PYX_ERR(0, 134, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_use_bytes)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 4, 5, 3); __PYX_ERR(0, 134, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_match_whole);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 134, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_terminals = values[0];
    __pyx_v_g_regex_flags = values[1];
    __pyx_v_re_ = values[2];
    __pyx_v_use_bytes = values[3];
    __pyx_v_match_whole = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 4, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 134, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), __pyx_v_terminals, __pyx_v_g_regex_flags, __pyx_v_re_, __pyx_v_use_bytes, __pyx_v_match_whole);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_terminals, PyObject *__pyx_v_g_regex_flags, PyObject *__pyx_v_re_, PyObject *__pyx_v_use_bytes, PyObject *__pyx_v_match_whole) {
  PyObject *__pyx_7genexpr__pyx_v_t = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":135
 * 
 *     def __cinit__(self, terminals, g_regex_flags, re_, use_bytes, match_whole=False):
 *         self.terminals = terminals             # <<<<<<<<<<<<<<
 *         self.g_regex_flags = g_regex_flags
 *         self.re_ = re_
 */
  __Pyx_INCREF(__pyx_v_terminals);
  __Pyx_GIVEREF(__pyx_v_terminals);
  __Pyx_GOTREF(__pyx_v_self->terminals);
  __Pyx_DECREF(__pyx_v_self->terminals);
  __pyx_v_self->terminals = __pyx_v_terminals;

  /* "lark_cython/lark_cython.pyx":136
 *     def __cinit__(self, terminals, g_regex_flags, re_, use_bytes, match_whole=False):
 *         self.terminals = terminals
 *         self.g_regex_flags = g_regex_flags             # <<<<<<<<<<<<<<
 *         self.re_ = re_
 *         self.use_bytes = use_bytes
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_g_regex_flags); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 136, __pyx_L1_error)
  __pyx_v_self->g_regex_flags = __pyx_t_1;

  /* "lark_cython/lark_cython.pyx":137
 *         self.terminals = terminals
 *         self.g_regex_flags = g_regex_flags
 *         self.re_ = re_             # <<<<<<<<<<<<<<
 *         self.use_bytes = use_bytes
 *         self.match_whole = match_whole
 */
  __Pyx_INCREF(__pyx_v_re_);
  __Pyx_GIVEREF(__pyx_v_re_);
  __Pyx_GOTREF(__pyx_v_self->re_);
  __Pyx_DECREF(__pyx_v_self->re_);
  __pyx_v_self->re_ = __pyx_v_re_;

  /* "lark_cython/lark_cython.pyx":138
 *         self.g_regex_flags = g_regex_flags
 *         self.re_ = re_
 *         self.use_bytes = use_bytes             # <<<<<<<<<<<<<<
 *         self.match_whole = match_whole
 * 
 */
  __Pyx_INCREF(__pyx_v_use_bytes);
  __Pyx_GIVEREF(__pyx_v_use_bytes);
  __Pyx_GOTREF(__pyx_v_self->use_bytes);
  __Pyx_DECREF(__pyx_v_self->use_bytes);
  __pyx_v_self->use_bytes = __pyx_v_use_bytes;

  /* "lark_cython/lark_cython.pyx":139
 *         self.re_ = re_
 *         self.use_bytes = use_bytes
 *         self.match_whole = match_whole             # <<<<<<<<<<<<<<
 * 
 *         self.allowed_types = {t.name for t in self.terminals}
 */
  __Pyx_INCREF(__pyx_v_match_whole);
  __Pyx_GIVEREF(__pyx_v_match_whole);
  __Pyx_GOTREF(__pyx_v_self->match_whole);
  __Pyx_DECREF(__pyx_v_self->match_whole);
  __pyx_v_self->match_whole = __pyx_v_match_whole;

  /* "lark_cython/lark_cython.pyx":141
 *         self.match_whole = match_whole
 * 
 *         self.allowed_types = {t.name for t in self.terminals}             # <<<<<<<<<<<<<<
 * 
 *         self._mres = self._build_mres(terminals, len(terminals))
 */
  { /* enter inner scope */
    __pyx_t_2 = PySet_New(NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_v_self->terminals)) || PyTuple_CheckExact(__pyx_v_self->terminals)) {
      __pyx_t_3 = __pyx_v_self->terminals; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_self->terminals); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 141, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 141, __pyx_L5_error)
    }
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 141, __pyx_L5_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 141, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 141, __pyx_L5_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 141, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 141, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_t, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 141, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(PySet_Add(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 141, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_t); __pyx_7genexpr__pyx_v_t = 0;
    goto __pyx_L8_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_t); __pyx_7genexpr__pyx_v_t = 0;
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->allowed_types);
  __Pyx_DECREF(__pyx_v_self->allowed_types);
  __pyx_v_self->allowed_types = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":143
 *         self.allowed_types = {t.name for t in self.terminals}
 * 
 *         self._mres = self._build_mres(terminals, len(terminals))             # <<<<<<<<<<<<<<
 * 
 *     def _build_mres(self, terminals, max_size):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_build_mres); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_Length(__pyx_v_terminals); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 143, __pyx_L1_error)
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_1 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_1 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_terminals, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_1, 2+__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_terminals, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_1, 2+__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_terminals);
    __Pyx_GIVEREF(__pyx_v_terminals);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_1, __pyx_v_terminals);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_1, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_mres);
  __Pyx_DECREF(__pyx_v_self->_mres);
  __pyx_v_self->_mres = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":134
 *     cdef list _mres
 * 
 *     def __cinit__(self, terminals, g_regex_flags, re_, use_bytes, match_whole=False):             # <<<<<<<<<<<<<<
 *         self.terminals = terminals
 *         self.g_regex_flags = g_regex_flags
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":145
 *         self._mres = self._build_mres(terminals, len(terminals))
 * 
 *     def _build_mres(self, terminals, max_size):             # <<<<<<<<<<<<<<
 *         # Python sets an unreasonable group limit (currently 100) in its re module
 *         # Worse, the only way to know we reached it is by catching an AssertionError!
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_3_build_mres(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_3_build_mres(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_terminals = 0;
  PyObject *__pyx_v_max_size = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_build_mres (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_terminals,&__pyx_n_s_max_size,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_terminals)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_build_mres", 1, 2, 2, 1); __PYX_ERR(0, 145, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_build_mres") < 0)) __PYX_ERR(0, 145, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_terminals = values[0];
    __pyx_v_max_size = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_build_mres", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 145, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner._build_mres", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_2_build_mres(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), __pyx_v_terminals, __pyx_v_max_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_7Scanner_11_build_mres_2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":152
 *         mres = []
 *         while terminals:
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])             # <<<<<<<<<<<<<<
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_11_build_mres_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 152, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_7Scanner_11_build_mres_2generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_build_mres_locals_genexpr, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner._build_mres.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_7Scanner_11_build_mres_2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 152, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals)) { __Pyx_RaiseClosureNameError("terminals"); __PYX_ERR(0, 152, __pyx_L1_error) }
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_max_size)) { __Pyx_RaiseClosureNameError("max_size"); __PYX_ERR(0, 152, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals, 0, 0, NULL, &__pyx_cur_scope->__pyx_outer_scope->__pyx_v_max_size, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 152, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 152, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 152, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 152, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = 127;
    __Pyx_INCREF(__pyx_kp_u_P);
    __pyx_t_5 += 4;
    __Pyx_GIVEREF(__pyx_kp_u_P);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_P);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__12);
    __pyx_t_5 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__12);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u__12);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_t, __pyx_n_s_pattern); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_to_regexp); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_postfix)) { __Pyx_RaiseClosureNameError("postfix"); __PYX_ERR(0, 152, __pyx_L1_error) }
    __pyx_t_9 = PyNumber_Add(__pyx_t_8, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_postfix); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_9), __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__2);
    __pyx_t_5 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__2);
    PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__2);
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":145
 *         self._mres = self._build_mres(terminals, len(terminals))
 * 
 *     def _build_mres(self, terminals, max_size):             # <<<<<<<<<<<<<<
 *         # Python sets an unreasonable group limit (currently 100) in its re module
 *         # Worse, the only way to know we reached it is by catching an AssertionError!
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_2_build_mres(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_terminals, PyObject *__pyx_v_max_size) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *__pyx_cur_scope;
  PyObject *__pyx_v_mres = NULL;
  PyObject *__pyx_v_pattern = NULL;
  PyObject *__pyx_v_mre = NULL;
  PyObject *__pyx_gb_11lark_cython_11lark_cython_7Scanner_11_build_mres_2generator3 = 0;
  PyObject *__pyx_8genexpr2__pyx_v_n = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_build_mres", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct___build_mres(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct___build_mres, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 145, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_terminals = __pyx_v_terminals;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_terminals);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_terminals);
  __pyx_cur_scope->__pyx_v_max_size = __pyx_v_max_size;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_max_size);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_max_size);

  /* "lark_cython/lark_cython.pyx":149
 *         # Worse, the only way to know we reached it is by catching an AssertionError!
 *         # This function recursively tries less and less groups until it's successful.
 *         postfix = '$' if self.match_whole else ''             # <<<<<<<<<<<<<<
 *         mres = []
 *         while terminals:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->match_whole); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 149, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_kp_u__13);
    __pyx_t_1 = __pyx_kp_u__13;
  } else {
    __Pyx_INCREF(__pyx_kp_u__3);
    __pyx_t_1 = __pyx_kp_u__3;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_postfix = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":150
 *         # This function recursively tries less and less groups until it's successful.
 *         postfix = '$' if self.match_whole else ''
 *         mres = []             # <<<<<<<<<<<<<<
 *         while terminals:
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_mres = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":151
 *         postfix = '$' if self.match_whole else ''
 *         mres = []
 *         while terminals:             # <<<<<<<<<<<<<<
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])
 *             if self.use_bytes:
 */
  while (1) {
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_terminals); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 151, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "lark_cython/lark_cython.pyx":152
 *         mres = []
 *         while terminals:
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])             # <<<<<<<<<<<<<<
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')
 */
    __pyx_t_1 = __pyx_pf_11lark_cython_11lark_cython_7Scanner_11_build_mres_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_pattern, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":153
 *         while terminals:
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])
 *             if self.use_bytes:             # <<<<<<<<<<<<<<
 *                 pattern = pattern.encode('latin-1')
 *             try:
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->use_bytes); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 153, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "lark_cython/lark_cython.pyx":154
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')             # <<<<<<<<<<<<<<
 *             try:
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)
 */
      if (unlikely(__pyx_v_pattern == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
        __PYX_ERR(0, 154, __pyx_L1_error)
      }
      __pyx_t_1 = PyUnicode_AsLatin1String(__pyx_v_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_pattern, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "lark_cython/lark_cython.pyx":153
 *         while terminals:
 *             pattern = u'|'.join(u'(?P<%s>%s)' % (t.name, t.pattern.to_regexp() + postfix) for t in terminals[:max_size])
 *             if self.use_bytes:             # <<<<<<<<<<<<<<
 *                 pattern = pattern.encode('latin-1')
 *             try:
 */
    }

    /* "lark_cython/lark_cython.pyx":155
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')
 *             try:             # <<<<<<<<<<<<<<
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)
 *             except AssertionError:  # Yes, this is what Python provides us.. :/
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":156
 *                 pattern = pattern.encode('latin-1')
 *             try:
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)             # <<<<<<<<<<<<<<
 *             except AssertionError:  # Yes, this is what Python provides us.. :/
 *                 return self._build_mres(terminals, max_size//2)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->re_, __pyx_n_s_compile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 156, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->g_regex_flags); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 156, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_9 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_pattern, __pyx_t_7};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_pattern, __pyx_t_7};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        {
          __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 156, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (__pyx_t_8) {
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
          }
          __Pyx_INCREF(__pyx_v_pattern);
          __Pyx_GIVEREF(__pyx_v_pattern);
          PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_v_pattern);
          __Pyx_GIVEREF(__pyx_t_7);
          PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_7);
          __pyx_t_7 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_mre, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "lark_cython/lark_cython.pyx":155
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')
 *             try:             # <<<<<<<<<<<<<<
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)
 *             except AssertionError:  # Yes, this is what Python provides us.. :/
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L13_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":157
 *             try:
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)
 *             except AssertionError:  # Yes, this is what Python provides us.. :/             # <<<<<<<<<<<<<<
 *                 return self._build_mres(terminals, max_size//2)
 * 
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AssertionError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("lark_cython.lark_cython.Scanner._build_mres", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_10) < 0) __PYX_ERR(0, 157, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_10);

        /* "lark_cython/lark_cython.pyx":158
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)
 *             except AssertionError:  # Yes, this is what Python provides us.. :/
 *                 return self._build_mres(terminals, max_size//2)             # <<<<<<<<<<<<<<
 * 
 *             mres.append((mre, {i: n for n, i in mre.groupindex.items()}))
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_build_mres); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 158, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = __Pyx_PyInt_FloorDivideObjC(__pyx_cur_scope->__pyx_v_max_size, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 158, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
            __pyx_t_9 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_cur_scope->__pyx_v_terminals, __pyx_t_11};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 158, __pyx_L8_except_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_cur_scope->__pyx_v_terminals, __pyx_t_11};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 158, __pyx_L8_except_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 158, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_12) {
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
          }
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_terminals);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_terminals);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_9, __pyx_cur_scope->__pyx_v_terminals);
          __Pyx_GIVEREF(__pyx_t_11);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_9, __pyx_t_11);
          __pyx_t_11 = 0;
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_13, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 158, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_r = __pyx_t_7;
        __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L9_except_return;
      }
      goto __pyx_L8_except_error;
      __pyx_L8_except_error:;

      /* "lark_cython/lark_cython.pyx":155
 *             if self.use_bytes:
 *                 pattern = pattern.encode('latin-1')
 *             try:             # <<<<<<<<<<<<<<
 *                 mre = self.re_.compile(pattern, self.g_regex_flags)
 *             except AssertionError:  # Yes, this is what Python provides us.. :/
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L9_except_return:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L0;
      __pyx_L13_try_end:;
    }

    /* "lark_cython/lark_cython.pyx":160
 *                 return self._build_mres(terminals, max_size//2)
 * 
 *             mres.append((mre, {i: n for n, i in mre.groupindex.items()}))             # <<<<<<<<<<<<<<
 *             terminals = terminals[max_size:]
 *         return mres
 */
    { /* enter inner scope */
      __pyx_t_10 = PyDict_New(); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 160, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_14 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_mre, __pyx_n_s_groupindex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 160, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_t_1 == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 160, __pyx_L18_error)
      }
      __pyx_t_7 = __Pyx_dict_iterator(__pyx_t_1, 0, __pyx_n_s_items, (&__pyx_t_15), (&__pyx_t_9)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 160, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3);
      __pyx_t_3 = __pyx_t_7;
      __pyx_t_7 = 0;
      while (1) {
        __pyx_t_16 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_15, &__pyx_t_14, &__pyx_t_7, &__pyx_t_1, NULL, __pyx_t_9);
        if (unlikely(__pyx_t_16 == 0)) break;
        if (unlikely(__pyx_t_16 == -1)) __PYX_ERR(0, 160, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_n, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_i, __pyx_t_1);
        __pyx_t_1 = 0;
        if (unlikely(PyDict_SetItem(__pyx_t_10, (PyObject*)__pyx_8genexpr2__pyx_v_i, (PyObject*)__pyx_8genexpr2__pyx_v_n))) __PYX_ERR(0, 160, __pyx_L18_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_i); __pyx_8genexpr2__pyx_v_i = 0;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_n); __pyx_8genexpr2__pyx_v_n = 0;
      goto __pyx_L21_exit_scope;
      __pyx_L18_error:;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_i); __pyx_8genexpr2__pyx_v_i = 0;
      __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_n); __pyx_8genexpr2__pyx_v_n = 0;
      goto __pyx_L1_error;
      __pyx_L21_exit_scope:;
    } /* exit inner scope */
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_mre);
    __Pyx_GIVEREF(__pyx_v_mre);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_mre);
    __Pyx_GIVEREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_10);
    __pyx_t_10 = 0;
    __pyx_t_17 = __Pyx_PyList_Append(__pyx_v_mres, __pyx_t_3); if (unlikely(__pyx_t_17 == ((int)-1))) __PYX_ERR(0, 160, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":161
 * 
 *             mres.append((mre, {i: n for n, i in mre.groupindex.items()}))
 *             terminals = terminals[max_size:]             # <<<<<<<<<<<<<<
 *         return mres
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_terminals, 0, 0, &__pyx_cur_scope->__pyx_v_max_size, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_terminals);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_terminals, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
  }

  /* "lark_cython/lark_cython.pyx":162
 *             mres.append((mre, {i: n for n, i in mre.groupindex.items()}))
 *             terminals = terminals[max_size:]
 *         return mres             # <<<<<<<<<<<<<<
 * 
 *     cpdef public match(self, text: str, pos: int):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_mres);
  __pyx_r = __pyx_v_mres;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":145
 *         self._mres = self._build_mres(terminals, len(terminals))
 * 
 *     def _build_mres(self, terminals, max_size):             # <<<<<<<<<<<<<<
 *         # Python sets an unreasonable group limit (currently 100) in its re module
 *         # Worse, the only way to know we reached it is by catching an AssertionError!
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner._build_mres", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mres);
  __Pyx_XDECREF(__pyx_v_pattern);
  __Pyx_XDECREF(__pyx_v_mre);
  __Pyx_XDECREF(__pyx_gb_11lark_cython_11lark_cython_7Scanner_11_build_mres_2generator3);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_n);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_i);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":164
 *         return mres
 * 
 *     cpdef public match(self, text: str, pos: int):             # <<<<<<<<<<<<<<
 *         for mre, type_from_index in self._mres:
 *             m = mre.match(text, pos)
 */

static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_5match(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_7Scanner_match(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_pos, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_mre = NULL;
  PyObject *__pyx_v_type_from_index = NULL;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("match", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_match); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11lark_cython_11lark_cython_7Scanner_5match)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_text, __pyx_v_pos};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_text, __pyx_v_pos};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(__pyx_v_text);
          __Pyx_GIVEREF(__pyx_v_text);
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_text);
          __Pyx_INCREF(__pyx_v_pos);
          __Pyx_GIVEREF(__pyx_v_pos);
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_pos);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "lark_cython/lark_cython.pyx":165
 * 
 *     cpdef public match(self, text: str, pos: int):
 *         for mre, type_from_index in self._mres:             # <<<<<<<<<<<<<<
 *             m = mre.match(text, pos)
 *             if m:
 */
  if (unlikely(__pyx_v_self->_mres == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 165, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_mres; __Pyx_INCREF(__pyx_t_1); __pyx_t_7 = 0;
  for (;;) {
    if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 165, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 165, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 165, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 165, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 165, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_4), 2) < 0) __PYX_ERR(0, 165, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 165, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_mre, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_type_from_index, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "lark_cython/lark_cython.pyx":166
 *     cpdef public match(self, text: str, pos: int):
 *         for mre, type_from_index in self._mres:
 *             m = mre.match(text, pos)             # <<<<<<<<<<<<<<
 *             if m:
 *                 return m.group(0), type_from_index[m.lastindex]
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_mre, __pyx_n_s_match); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_text, __pyx_v_pos};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_text, __pyx_v_pos};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 166, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_v_text);
      __Pyx_GIVEREF(__pyx_v_text);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_v_text);
      __Pyx_INCREF(__pyx_v_pos);
      __Pyx_GIVEREF(__pyx_v_pos);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_v_pos);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "lark_cython/lark_cython.pyx":167
 *         for mre, type_from_index in self._mres:
 *             m = mre.match(text, pos)
 *             if m:             # <<<<<<<<<<<<<<
 *                 return m.group(0), type_from_index[m.lastindex]
 * 
 */
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_m); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 167, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "lark_cython/lark_cython.pyx":168
 *             m = mre.match(text, pos)
 *             if m:
 *                 return m.group(0), type_from_index[m.lastindex]             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_m, __pyx_n_s_group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_4, __pyx_int_0) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_int_0);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_m, __pyx_n_s_lastindex); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_type_from_index, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4);
      __pyx_t_2 = 0;
      __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "lark_cython/lark_cython.pyx":167
 *         for mre, type_from_index in self._mres:
 *             m = mre.match(text, pos)
 *             if m:             # <<<<<<<<<<<<<<
 *                 return m.group(0), type_from_index[m.lastindex]
 * 
 */
    }

    /* "lark_cython/lark_cython.pyx":165
 * 
 *     cpdef public match(self, text: str, pos: int):
 *         for mre, type_from_index in self._mres:             # <<<<<<<<<<<<<<
 *             m = mre.match(text, pos)
 *             if m:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":164
 *         return mres
 * 
 *     cpdef public match(self, text: str, pos: int):             # <<<<<<<<<<<<<<
 *         for mre, type_from_index in self._mres:
 *             m = mre.match(text, pos)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mre);
  __Pyx_XDECREF(__pyx_v_type_from_index);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_5match(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_5match(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_text = 0;
  PyObject *__pyx_v_pos = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("match (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_text,&__pyx_n_s_pos,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_text)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pos)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("match", 1, 2, 2, 1); __PYX_ERR(0, 164, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "match") < 0)) __PYX_ERR(0, 164, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_text = ((PyObject*)values[0]);
    __pyx_v_pos = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("match", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 164, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 1, "text", 1))) __PYX_ERR(0, 164, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_4match(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), __pyx_v_text, __pyx_v_pos);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_4match(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_pos) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("match", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython_7Scanner_match(__pyx_v_self, __pyx_v_text, __pyx_v_pos, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":126
 * 
 * cdef class Scanner:
 *     cdef public terminals             # <<<<<<<<<<<<<<
 *     cdef public int g_regex_flags
 *     cdef public re_
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->terminals);
  __pyx_r = __pyx_v_self->terminals;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->terminals);
  __Pyx_DECREF(__pyx_v_self->terminals);
  __pyx_v_self->terminals = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9terminals_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->terminals);
  __Pyx_DECREF(__pyx_v_self->terminals);
  __pyx_v_self->terminals = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":127
 * cdef class Scanner:
 *     cdef public terminals
 *     cdef public int g_regex_flags             # <<<<<<<<<<<<<<
 *     cdef public re_
 *     cdef public use_bytes
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_13g_regex_flags___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_13g_regex_flags___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->g_regex_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.g_regex_flags.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 127, __pyx_L1_error)
  __pyx_v_self->g_regex_flags = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.g_regex_flags.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":128
 *     cdef public terminals
 *     cdef public int g_regex_flags
 *     cdef public re_             # <<<<<<<<<<<<<<
 *     cdef public use_bytes
 *     cdef public match_whole
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re____get__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_3re____get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->re_);
  __pyx_r = __pyx_v_self->re_;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re__2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re__2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->re_);
  __Pyx_DECREF(__pyx_v_self->re_);
  __pyx_v_self->re_ = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re__4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_3re__4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->re_);
  __Pyx_DECREF(__pyx_v_self->re_);
  __pyx_v_self->re_ = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":129
 *     cdef public int g_regex_flags
 *     cdef public re_
 *     cdef public use_bytes             # <<<<<<<<<<<<<<
 *     cdef public match_whole
 *     cdef public allowed_types
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->use_bytes);
  __pyx_r = __pyx_v_self->use_bytes;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->use_bytes);
  __Pyx_DECREF(__pyx_v_self->use_bytes);
  __pyx_v_self->use_bytes = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_9use_bytes_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->use_bytes);
  __Pyx_DECREF(__pyx_v_self->use_bytes);
  __pyx_v_self->use_bytes = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":130
 *     cdef public re_
 *     cdef public use_bytes
 *     cdef public match_whole             # <<<<<<<<<<<<<<
 *     cdef public allowed_types
 *     cdef list _mres
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->match_whole);
  __pyx_r = __pyx_v_self->match_whole;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->match_whole);
  __Pyx_DECREF(__pyx_v_self->match_whole);
  __pyx_v_self->match_whole = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_11match_whole_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->match_whole);
  __Pyx_DECREF(__pyx_v_self->match_whole);
  __pyx_v_self->match_whole = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":131
 *     cdef public use_bytes
 *     cdef public match_whole
 *     cdef public allowed_types             # <<<<<<<<<<<<<<
 *     cdef list _mres
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types___get__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->allowed_types);
  __pyx_r = __pyx_v_self->allowed_types;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->allowed_types);
  __Pyx_DECREF(__pyx_v_self->allowed_types);
  __pyx_v_self->allowed_types = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7Scanner_13allowed_types_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->allowed_types);
  __Pyx_DECREF(__pyx_v_self->allowed_types);
  __pyx_v_self->allowed_types = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_6__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7Scanner_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7Scanner_8__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7Scanner_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Scanner *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Scanner.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":180
 *     #    return NotImplemented
 * 
 *     cdef make_lexer_state(self, str text):             # <<<<<<<<<<<<<<
 *         line_ctr = LineCounter(b'\n' if isinstance(text, bytes) else '\n')
 *         return LexerState(text, line_ctr)
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_state(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v_text) {
  struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_line_ctr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_lexer_state", 0);

  /* "lark_cython/lark_cython.pyx":181
 * 
 *     cdef make_lexer_state(self, str text):
 *         line_ctr = LineCounter(b'\n' if isinstance(text, bytes) else '\n')             # <<<<<<<<<<<<<<
 *         return LexerState(text, line_ctr)
 * 
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_text); 
  if ((__pyx_t_2 != 0)) {
    __Pyx_INCREF(__pyx_kp_b__16);
    __pyx_t_1 = __pyx_kp_b__16;
  } else {
    __Pyx_INCREF(__pyx_kp_u__16);
    __pyx_t_1 = __pyx_kp_u__16;
  }
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LineCounter), __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "lark_cython/lark_cython.pyx":182
 *     cdef make_lexer_state(self, str text):
 *         line_ctr = LineCounter(b'\n' if isinstance(text, bytes) else '\n')
 *         return LexerState(text, line_ctr)             # <<<<<<<<<<<<<<
 * 
 *     cpdef make_lexer_thread(self, str text):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_text);
  __Pyx_GIVEREF(__pyx_v_text);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_text);
  __Pyx_INCREF(((PyObject *)__pyx_v_line_ctr));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_line_ctr));
  PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_line_ctr));
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LexerState), __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":180
 *     #    return NotImplemented
 * 
 *     cdef make_lexer_state(self, str text):             # <<<<<<<<<<<<<<
 *         line_ctr = LineCounter(b'\n' if isinstance(text, bytes) else '\n')
 *         return LexerState(text, line_ctr)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.Lexer.make_lexer_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_line_ctr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":184
 *         return LexerState(text, line_ctr)
 * 
 *     cpdef make_lexer_thread(self, str text):             # <<<<<<<<<<<<<<
 *         return LexerThread(self, text)
 * 
 */

static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_1make_lexer_thread(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyObject *__pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_thread(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v_text, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_lexer_thread", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_make_lexer_thread); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11lark_cython_11lark_cython_5Lexer_1make_lexer_thread)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_text);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "lark_cython/lark_cython.pyx":185
 * 
 *     cpdef make_lexer_thread(self, str text):
 *         return LexerThread(self, text)             # <<<<<<<<<<<<<<
 * 
 * cdef class BasicLexer(Lexer):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
  __Pyx_INCREF(__pyx_v_text);
  __Pyx_GIVEREF(__pyx_v_text);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_text);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LexerThread), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":184
 *         return LexerState(text, line_ctr)
 * 
 *     cpdef make_lexer_thread(self, str text):             # <<<<<<<<<<<<<<
 *         return LexerThread(self, text)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.Lexer.make_lexer_thread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_1make_lexer_thread(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_1make_lexer_thread(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_lexer_thread (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 1, "text", 1))) __PYX_ERR(0, 184, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Lexer_make_lexer_thread(((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)__pyx_v_self), ((PyObject*)__pyx_v_text));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Lexer_make_lexer_thread(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_lexer_thread", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_thread(__pyx_v_self, __pyx_v_text, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Lexer.make_lexer_thread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Lexer_2__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Lexer_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_Lexer); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, None), state
 *     else:
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Lexer__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_Lexer); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_222419149);
    __Pyx_GIVEREF(__pyx_int_222419149);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_222419149);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.Lexer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Lexer__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5Lexer_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_5Lexer_4__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_5Lexer_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Lexer__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Lexer__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Lexer, (type(self), 0xd41d8cd, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Lexer__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Lexer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":201
 *     cdef Scanner _scanner
 * 
 *     def __init__(self, conf: 'LexerConf') -> None:             # <<<<<<<<<<<<<<
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_10BasicLexer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_10BasicLexer_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_conf = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_conf,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_conf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 201, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_conf = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 201, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer___init__(((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self), __pyx_v_conf);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___2generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":203
 *     def __init__(self, conf: 'LexerConf') -> None:
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals             # <<<<<<<<<<<<<<
 * 
 *         self.re = conf.re_module
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_8__init___genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 203, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___2generator4, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_init___locals_genexpr, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___2generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals)) { __Pyx_RaiseClosureNameError("terminals"); __PYX_ERR(0, 203, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 203, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_TerminalDef); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_t, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = ((!(__pyx_t_4 != 0)) != 0);
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___5generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":222
 * 
 *         # Init
 *         self.newline_types = frozenset(t.name for t in terminals if _regexp_has_newline(t.pattern.to_regexp()))             # <<<<<<<<<<<<<<
 *         self.ignore_types = frozenset(conf.ignore)
 * 
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_8__init___3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 222, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___5generator5, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_init___locals_genexpr, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__init__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___5generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 222, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals)) { __Pyx_RaiseClosureNameError("terminals"); __PYX_ERR(0, 222, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 222, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_terminals; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 222, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_regexp_has_newline); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_t, __pyx_n_s_pattern); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_to_regexp); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_8) {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 222, __pyx_L1_error)
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":225
 *         self.ignore_types = frozenset(conf.ignore)
 * 
 *         terminals.sort(key=lambda x: (-x.priority, -x.pattern.max_width, -len(x.pattern.value), x.name))             # <<<<<<<<<<<<<<
 *         self.terminals = terminals
 *         self.user_callbacks = conf.callbacks
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_8__init___6lambda3(PyObject *__pyx_self, PyObject *__pyx_v_x); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_10BasicLexer_8__init___6lambda3 = {"lambda3", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_8__init___6lambda3, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_8__init___6lambda3(PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda3 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda3(__pyx_self, ((PyObject *)__pyx_v_x));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda3(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda3", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_n_s_priority); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Negative(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_n_s_pattern); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_max_width); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Negative(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_n_s_pattern); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyInt_FromSsize_t((-__pyx_t_5)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_3);
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__init__.lambda3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":201
 *     cdef Scanner _scanner
 * 
 *     def __init__(self, conf: 'LexerConf') -> None:             # <<<<<<<<<<<<<<
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals
 */

static int __pyx_pf_11lark_cython_11lark_cython_10BasicLexer___init__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, PyObject *__pyx_v_conf) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *__pyx_cur_scope;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___2generator4 = 0;
  PyObject *__pyx_8genexpr4__pyx_v_t = NULL;
  PyObject *__pyx_8genexpr5__pyx_v_t = NULL;
  PyObject *__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___5generator5 = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_UCS4 __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_2___init__(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_2___init__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 201, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "lark_cython/lark_cython.pyx":202
 * 
 *     def __init__(self, conf: 'LexerConf') -> None:
 *         terminals = list(conf.terminals)             # <<<<<<<<<<<<<<
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_terminals); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_terminals = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":203
 *     def __init__(self, conf: 'LexerConf') -> None:
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals             # <<<<<<<<<<<<<<
 * 
 *         self.re = conf.re_module
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_2 = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer_8__init___genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) {
      PyErr_SetObject(PyExc_AssertionError, __pyx_cur_scope->__pyx_v_terminals);
      __PYX_ERR(0, 203, __pyx_L1_error)
    }
  }
  #endif

  /* "lark_cython/lark_cython.pyx":205
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals
 * 
 *         self.re = conf.re_module             # <<<<<<<<<<<<<<
 * 
 *         if not conf.skip_validation:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_re_module); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->re);
  __Pyx_DECREF(__pyx_v_self->re);
  __pyx_v_self->re = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":207
 *         self.re = conf.re_module
 * 
 *         if not conf.skip_validation:             # <<<<<<<<<<<<<<
 *             # Sanitization
 *             for t in terminals:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_skip_validation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = ((!__pyx_t_3) != 0);
  if (__pyx_t_4) {

    /* "lark_cython/lark_cython.pyx":209
 *         if not conf.skip_validation:
 *             # Sanitization
 *             for t in terminals:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 */
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_terminals; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    for (;;) {
      if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 209, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 209, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "lark_cython/lark_cython.pyx":210
 *             # Sanitization
 *             for t in terminals:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 *                 except self.re.error:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "lark_cython/lark_cython.pyx":211
 *             for t in terminals:
 *                 try:
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)             # <<<<<<<<<<<<<<
 *                 except self.re.error:
 *                     raise LexError("Cannot compile token %s: %s" % (t.name, t.pattern))
 */
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->re, __pyx_n_s_compile); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 211, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pattern); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 211, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_to_regexp); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 211, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          __pyx_t_10 = (__pyx_t_11) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_11) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 211, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_g_regex_flags); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 211, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_11 = NULL;
          __pyx_t_13 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
              __pyx_t_13 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_9)) {
            PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_t_10, __pyx_t_12};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L6_error)
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
            PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_t_10, __pyx_t_12};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L6_error)
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else
          #endif
          {
            __pyx_t_14 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 211, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_14);
            if (__pyx_t_11) {
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_11); __pyx_t_11 = NULL;
            }
            __Pyx_GIVEREF(__pyx_t_10);
            PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_13, __pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_13, __pyx_t_12);
            __pyx_t_10 = 0;
            __pyx_t_12 = 0;
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "lark_cython/lark_cython.pyx":210
 *             # Sanitization
 *             for t in terminals:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 *                 except self.re.error:
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L13_try_end;
        __pyx_L6_error:;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "lark_cython/lark_cython.pyx":212
 *                 try:
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 *                 except self.re.error:             # <<<<<<<<<<<<<<
 *                     raise LexError("Cannot compile token %s: %s" % (t.name, t.pattern))
 * 
 */
        __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_9, &__pyx_t_14);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->re, __pyx_n_s_error); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 212, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_12);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_ErrRestore(__pyx_t_2, __pyx_t_9, __pyx_t_14);
        __pyx_t_2 = 0; __pyx_t_9 = 0; __pyx_t_14 = 0;
        if (__pyx_t_13) {
          __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_9, &__pyx_t_2) < 0) __PYX_ERR(0, 212, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_t_2);

          /* "lark_cython/lark_cython.pyx":213
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 *                 except self.re.error:
 *                     raise LexError("Cannot compile token %s: %s" % (t.name, t.pattern))             # <<<<<<<<<<<<<<
 * 
 *                 if t.pattern.min_width == 0:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_LexError); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = PyTuple_New(4); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_15 = 0;
          __pyx_t_16 = 127;
          __Pyx_INCREF(__pyx_kp_u_Cannot_compile_token);
          __pyx_t_15 += 21;
          __Pyx_GIVEREF(__pyx_kp_u_Cannot_compile_token);
          PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_u_Cannot_compile_token);
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_18 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_17), __pyx_empty_unicode); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_18);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_18) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_18) : __pyx_t_16;
          __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_18);
          __Pyx_GIVEREF(__pyx_t_18);
          PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_18);
          __pyx_t_18 = 0;
          __Pyx_INCREF(__pyx_kp_u__17);
          __pyx_t_15 += 2;
          __Pyx_GIVEREF(__pyx_kp_u__17);
          PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_kp_u__17);
          __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pattern); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_18);
          __pyx_t_17 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_18), __pyx_empty_unicode); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_17) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_17) : __pyx_t_16;
          __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_17);
          __Pyx_GIVEREF(__pyx_t_17);
          PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_t_17);
          __pyx_t_17 = 0;
          __pyx_t_17 = __Pyx_PyUnicode_Join(__pyx_t_11, 4, __pyx_t_15, __pyx_t_16); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          __pyx_t_12 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_11, __pyx_t_17) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_17);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 213, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_Raise(__pyx_t_12, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __PYX_ERR(0, 213, __pyx_L8_except_error)
        }
        goto __pyx_L8_except_error;
        __pyx_L8_except_error:;

        /* "lark_cython/lark_cython.pyx":210
 *             # Sanitization
 *             for t in terminals:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 *                 except self.re.error:
 */
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L13_try_end:;
      }

      /* "lark_cython/lark_cython.pyx":215
 *                     raise LexError("Cannot compile token %s: %s" % (t.name, t.pattern))
 * 
 *                 if t.pattern.min_width == 0:             # <<<<<<<<<<<<<<
 *                     raise LexError("Lexer does not allow zero-width terminals. (%s: %s)" % (t.name, t.pattern))
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_min_width); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_9, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(__pyx_t_4)) {

        /* "lark_cython/lark_cython.pyx":216
 * 
 *                 if t.pattern.min_width == 0:
 *                     raise LexError("Lexer does not allow zero-width terminals. (%s: %s)" % (t.name, t.pattern))             # <<<<<<<<<<<<<<
 * 
 *             if not (set(conf.ignore) <= {t.name for t in terminals}):
 */
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_LexError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_14 = PyTuple_New(5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_15 = 0;
        __pyx_t_16 = 127;
        __Pyx_INCREF(__pyx_kp_u_Lexer_does_not_allow_zero_width);
        __pyx_t_15 += 44;
        __Pyx_GIVEREF(__pyx_kp_u_Lexer_does_not_allow_zero_width);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_kp_u_Lexer_does_not_allow_zero_width);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_10 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_12), __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) : __pyx_t_16;
        __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_INCREF(__pyx_kp_u__17);
        __pyx_t_15 += 2;
        __Pyx_GIVEREF(__pyx_kp_u__17);
        PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_kp_u__17);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_pattern); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_12 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_10), __pyx_empty_unicode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_12) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_12) : __pyx_t_16;
        __pyx_t_15 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_14, 3, __pyx_t_12);
        __pyx_t_12 = 0;
        __Pyx_INCREF(__pyx_kp_u__2);
        __pyx_t_15 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__2);
        PyTuple_SET_ITEM(__pyx_t_14, 4, __pyx_kp_u__2);
        __pyx_t_12 = __Pyx_PyUnicode_Join(__pyx_t_14, 5, __pyx_t_15, __pyx_t_16); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
          }
        }
        __pyx_t_2 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_14, __pyx_t_12) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_12);
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 216, __pyx_L1_error)

        /* "lark_cython/lark_cython.pyx":215
 *                     raise LexError("Cannot compile token %s: %s" % (t.name, t.pattern))
 * 
 *                 if t.pattern.min_width == 0:             # <<<<<<<<<<<<<<
 *                     raise LexError("Lexer does not allow zero-width terminals. (%s: %s)" % (t.name, t.pattern))
 * 
 */
      }

      /* "lark_cython/lark_cython.pyx":209
 *         if not conf.skip_validation:
 *             # Sanitization
 *             for t in terminals:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.re.compile(t.pattern.to_regexp(), conf.g_regex_flags)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":218
 *                     raise LexError("Lexer does not allow zero-width terminals. (%s: %s)" % (t.name, t.pattern))
 * 
 *             if not (set(conf.ignore) <= {t.name for t in terminals}):             # <<<<<<<<<<<<<<
 *                 raise LexError("Ignore terminals are not defined: %s" % (set(conf.ignore) - {t.name for t in terminals}))
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_ignore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PySet_New(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    { /* enter inner scope */
      __pyx_t_1 = PySet_New(NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 218, __pyx_L20_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __pyx_cur_scope->__pyx_v_terminals; __Pyx_INCREF(__pyx_t_9); __pyx_t_5 = 0;
      for (;;) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_9)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_12 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_5); __Pyx_INCREF(__pyx_t_12); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 218, __pyx_L20_error)
        #else
        __pyx_t_12 = PySequence_ITEM(__pyx_t_9, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 218, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_XDECREF_SET(__pyx_8genexpr4__pyx_v_t, __pyx_t_12);
        __pyx_t_12 = 0;
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr4__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 218, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (unlikely(PySet_Add(__pyx_t_1, (PyObject*)__pyx_t_12))) __PYX_ERR(0, 218, __pyx_L20_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_t); __pyx_8genexpr4__pyx_v_t = 0;
      goto __pyx_L23_exit_scope;
      __pyx_L20_error:;
      __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_t); __pyx_8genexpr4__pyx_v_t = 0;
      goto __pyx_L1_error;
      __pyx_L23_exit_scope:;
    } /* exit inner scope */
    __pyx_t_9 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_LE); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = ((!__pyx_t_4) != 0);
    if (unlikely(__pyx_t_3)) {

      /* "lark_cython/lark_cython.pyx":219
 * 
 *             if not (set(conf.ignore) <= {t.name for t in terminals}):
 *                 raise LexError("Ignore terminals are not defined: %s" % (set(conf.ignore) - {t.name for t in terminals}))             # <<<<<<<<<<<<<<
 * 
 *         # Init
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_LexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_ignore); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_12 = PySet_New(__pyx_t_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      { /* enter inner scope */
        __pyx_t_2 = PySet_New(NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_14 = __pyx_cur_scope->__pyx_v_terminals; __Pyx_INCREF(__pyx_t_14); __pyx_t_5 = 0;
        for (;;) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_14)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_10 = PyList_GET_ITEM(__pyx_t_14, __pyx_t_5); __Pyx_INCREF(__pyx_t_10); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 219, __pyx_L26_error)
          #else
          __pyx_t_10 = PySequence_ITEM(__pyx_t_14, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 219, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
          __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_t, __pyx_t_10);
          __pyx_t_10 = 0;
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr5__pyx_v_t, __pyx_n_s_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 219, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (unlikely(PySet_Add(__pyx_t_2, (PyObject*)__pyx_t_10))) __PYX_ERR(0, 219, __pyx_L26_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_t); __pyx_8genexpr5__pyx_v_t = 0;
        goto __pyx_L29_exit_scope;
        __pyx_L26_error:;
        __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_t); __pyx_8genexpr5__pyx_v_t = 0;
        goto __pyx_L1_error;
        __pyx_L29_exit_scope:;
      } /* exit inner scope */
      __pyx_t_14 = PyNumber_Subtract(__pyx_t_12, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Ignore_terminals_are_not_defined, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_9 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_14, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 219, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(0, 219, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":218
 *                     raise LexError("Lexer does not allow zero-width terminals. (%s: %s)" % (t.name, t.pattern))
 * 
 *             if not (set(conf.ignore) <= {t.name for t in terminals}):             # <<<<<<<<<<<<<<
 *                 raise LexError("Ignore terminals are not defined: %s" % (set(conf.ignore) - {t.name for t in terminals}))
 * 
 */
    }

    /* "lark_cython/lark_cython.pyx":207
 *         self.re = conf.re_module
 * 
 *         if not conf.skip_validation:             # <<<<<<<<<<<<<<
 *             # Sanitization
 *             for t in terminals:
 */
  }

  /* "lark_cython/lark_cython.pyx":222
 * 
 *         # Init
 *         self.newline_types = frozenset(t.name for t in terminals if _regexp_has_newline(t.pattern.to_regexp()))             # <<<<<<<<<<<<<<
 *         self.ignore_types = frozenset(conf.ignore)
 * 
 */
  __pyx_t_9 = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer_8__init___3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = __Pyx_PyFrozenSet_New(__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->newline_types);
  __Pyx_DECREF(__pyx_v_self->newline_types);
  __pyx_v_self->newline_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":223
 *         # Init
 *         self.newline_types = frozenset(t.name for t in terminals if _regexp_has_newline(t.pattern.to_regexp()))
 *         self.ignore_types = frozenset(conf.ignore)             # <<<<<<<<<<<<<<
 * 
 *         terminals.sort(key=lambda x: (-x.priority, -x.pattern.max_width, -len(x.pattern.value), x.name))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_ignore); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = __Pyx_PyFrozenSet_New(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_9);
  __Pyx_GOTREF(__pyx_v_self->ignore_types);
  __Pyx_DECREF(__pyx_v_self->ignore_types);
  __pyx_v_self->ignore_types = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "lark_cython/lark_cython.pyx":225
 *         self.ignore_types = frozenset(conf.ignore)
 * 
 *         terminals.sort(key=lambda x: (-x.priority, -x.pattern.max_width, -len(x.pattern.value), x.name))             # <<<<<<<<<<<<<<
 *         self.terminals = terminals
 *         self.user_callbacks = conf.callbacks
 */
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_terminals, __pyx_n_s_sort); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_10BasicLexer_8__init___6lambda3, 0, __pyx_n_s_init___locals_lambda, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_key, __pyx_t_2) < 0) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":226
 * 
 *         terminals.sort(key=lambda x: (-x.priority, -x.pattern.max_width, -len(x.pattern.value), x.name))
 *         self.terminals = terminals             # <<<<<<<<<<<<<<
 *         self.user_callbacks = conf.callbacks
 *         self.g_regex_flags = conf.g_regex_flags
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_terminals);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_terminals);
  __Pyx_GOTREF(__pyx_v_self->terminals);
  __Pyx_DECREF(__pyx_v_self->terminals);
  __pyx_v_self->terminals = __pyx_cur_scope->__pyx_v_terminals;

  /* "lark_cython/lark_cython.pyx":227
 *         terminals.sort(key=lambda x: (-x.priority, -x.pattern.max_width, -len(x.pattern.value), x.name))
 *         self.terminals = terminals
 *         self.user_callbacks = conf.callbacks             # <<<<<<<<<<<<<<
 *         self.g_regex_flags = conf.g_regex_flags
 *         self.use_bytes = conf.use_bytes
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_callbacks); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->user_callbacks);
  __Pyx_DECREF(__pyx_v_self->user_callbacks);
  __pyx_v_self->user_callbacks = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":228
 *         self.terminals = terminals
 *         self.user_callbacks = conf.callbacks
 *         self.g_regex_flags = conf.g_regex_flags             # <<<<<<<<<<<<<<
 *         self.use_bytes = conf.use_bytes
 *         self.terminals_by_name = conf.terminals_by_name
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_g_regex_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->g_regex_flags = __pyx_t_13;

  /* "lark_cython/lark_cython.pyx":229
 *         self.user_callbacks = conf.callbacks
 *         self.g_regex_flags = conf.g_regex_flags
 *         self.use_bytes = conf.use_bytes             # <<<<<<<<<<<<<<
 *         self.terminals_by_name = conf.terminals_by_name
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_use_bytes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->use_bytes = __pyx_t_13;

  /* "lark_cython/lark_cython.pyx":230
 *         self.g_regex_flags = conf.g_regex_flags
 *         self.use_bytes = conf.use_bytes
 *         self.terminals_by_name = conf.terminals_by_name             # <<<<<<<<<<<<<<
 * 
 *         self._scanner = None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_terminals_by_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->terminals_by_name);
  __Pyx_DECREF(__pyx_v_self->terminals_by_name);
  __pyx_v_self->terminals_by_name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":232
 *         self.terminals_by_name = conf.terminals_by_name
 * 
 *         self._scanner = None             # <<<<<<<<<<<<<<
 * 
 *     def _build_scanner(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_scanner);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_scanner));
  __pyx_v_self->_scanner = ((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)Py_None);

  /* "lark_cython/lark_cython.pyx":201
 *     cdef Scanner _scanner
 * 
 *     def __init__(self, conf: 'LexerConf') -> None:             # <<<<<<<<<<<<<<
 *         terminals = list(conf.terminals)
 *         assert all(isinstance(t, TerminalDef) for t in terminals), terminals
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___2generator4);
  __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_t);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_t);
  __Pyx_XDECREF(__pyx_gb_11lark_cython_11lark_cython_10BasicLexer_8__init___5generator5);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":234
 *         self._scanner = None
 * 
 *     def _build_scanner(self):             # <<<<<<<<<<<<<<
 *         terminals, self.callback = _create_unless(self.terminals, self.g_regex_flags, self.re, self.use_bytes)
 *         assert all(self.callback.values())
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_3_build_scanner(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_3_build_scanner(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_build_scanner (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer_2_build_scanner(((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":241
 *             if type_ in self.callback:
 *                 # Already a callback there, probably UnlessCallback
 *                 self.callback[type_] = CallChain(self.callback[type_], f, lambda t: t.type == type_)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.callback[type_] = f
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_14_build_scanner_lambda4(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_10BasicLexer_14_build_scanner_lambda4 = {"lambda4", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_14_build_scanner_lambda4, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_14_build_scanner_lambda4(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda4 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda4(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda4(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *__pyx_cur_scope;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda4", 0);
  __pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_type_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(!__pyx_cur_scope->__pyx_v_type_)) { __Pyx_RaiseClosureNameError("type_"); __PYX_ERR(0, 241, __pyx_L1_error) }
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_type_, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer._build_scanner.lambda4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":234
 *         self._scanner = None
 * 
 *     def _build_scanner(self):             # <<<<<<<<<<<<<<
 *         terminals, self.callback = _create_unless(self.terminals, self.g_regex_flags, self.re, self.use_bytes)
 *         assert all(self.callback.values())
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_2_build_scanner(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *__pyx_cur_scope;
  PyObject *__pyx_v_terminals = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_build_scanner", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 234, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "lark_cython/lark_cython.pyx":235
 * 
 *     def _build_scanner(self):
 *         terminals, self.callback = _create_unless(self.terminals, self.g_regex_flags, self.re, self.use_bytes)             # <<<<<<<<<<<<<<
 *         assert all(self.callback.values())
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_create_unless); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->g_regex_flags); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->use_bytes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_self->terminals, __pyx_t_3, __pyx_v_self->re, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_5, __pyx_v_self->terminals, __pyx_t_3, __pyx_v_self->re, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(4+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_self->terminals);
    __Pyx_GIVEREF(__pyx_v_self->terminals);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_self->terminals);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_self->re);
    __Pyx_GIVEREF(__pyx_v_self->re);
    PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_v_self->re);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_6, __pyx_t_4);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 235, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_7);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_7 = __pyx_t_8(__pyx_t_4); if (unlikely(!__pyx_t_7)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_4), 2) < 0) __PYX_ERR(0, 235, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 235, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_7))||((__pyx_t_7) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_7)->tp_name), 0))) __PYX_ERR(0, 235, __pyx_L1_error)
  __pyx_v_terminals = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_7);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "lark_cython/lark_cython.pyx":236
 *     def _build_scanner(self):
 *         terminals, self.callback = _create_unless(self.terminals, self.g_regex_flags, self.re, self.use_bytes)
 *         assert all(self.callback.values())             # <<<<<<<<<<<<<<
 * 
 *         for type_, f in self.user_callbacks.items():
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(__pyx_v_self->callback == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 236, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyDict_Values(__pyx_v_self->callback); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_all, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_9)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 236, __pyx_L1_error)
    }
  }
  #endif

  /* "lark_cython/lark_cython.pyx":238
 *         assert all(self.callback.values())
 * 
 *         for type_, f in self.user_callbacks.items():             # <<<<<<<<<<<<<<
 *             if type_ in self.callback:
 *                 # Already a callback there, probably UnlessCallback
 */
  __pyx_t_10 = 0;
  if (unlikely(__pyx_v_self->user_callbacks == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 238, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_dict_iterator(__pyx_v_self->user_callbacks, 1, __pyx_n_s_items, (&__pyx_t_11), (&__pyx_t_6)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __pyx_t_7 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_7, __pyx_t_11, &__pyx_t_10, &__pyx_t_1, &__pyx_t_2, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_12 == 0)) break;
    if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_type_);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_type_, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_f, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "lark_cython/lark_cython.pyx":239
 * 
 *         for type_, f in self.user_callbacks.items():
 *             if type_ in self.callback:             # <<<<<<<<<<<<<<
 *                 # Already a callback there, probably UnlessCallback
 *                 self.callback[type_] = CallChain(self.callback[type_], f, lambda t: t.type == type_)
 */
    if (unlikely(__pyx_v_self->callback == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 239, __pyx_L1_error)
    }
    __pyx_t_9 = (__Pyx_PyDict_ContainsTF(__pyx_cur_scope->__pyx_v_type_, __pyx_v_self->callback, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 239, __pyx_L1_error)
    __pyx_t_13 = (__pyx_t_9 != 0);
    if (__pyx_t_13) {

      /* "lark_cython/lark_cython.pyx":241
 *             if type_ in self.callback:
 *                 # Already a callback there, probably UnlessCallback
 *                 self.callback[type_] = CallChain(self.callback[type_], f, lambda t: t.type == type_)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.callback[type_] = f
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CallChain); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_v_self->callback == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 241, __pyx_L1_error)
      }
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_self->callback, __pyx_cur_scope->__pyx_v_type_); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 241, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_10BasicLexer_14_build_scanner_lambda4, 0, __pyx_n_s_build_scanner_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_kp_s_lark_cython_lark_cython, __pyx_d, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 241, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_t_4, __pyx_v_f, __pyx_t_3};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_t_4, __pyx_v_f, __pyx_t_3};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_14 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 241, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_12, __pyx_t_4);
        __Pyx_INCREF(__pyx_v_f);
        __Pyx_GIVEREF(__pyx_v_f);
        PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_12, __pyx_v_f);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_14, 2+__pyx_t_12, __pyx_t_3);
        __pyx_t_4 = 0;
        __pyx_t_3 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_self->callback == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 241, __pyx_L1_error)
      }
      if (unlikely(PyDict_SetItem(__pyx_v_self->callback, __pyx_cur_scope->__pyx_v_type_, __pyx_t_2) < 0)) __PYX_ERR(0, 241, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "lark_cython/lark_cython.pyx":239
 * 
 *         for type_, f in self.user_callbacks.items():
 *             if type_ in self.callback:             # <<<<<<<<<<<<<<
 *                 # Already a callback there, probably UnlessCallback
 *                 self.callback[type_] = CallChain(self.callback[type_], f, lambda t: t.type == type_)
 */
      goto __pyx_L7;
    }

    /* "lark_cython/lark_cython.pyx":243
 *                 self.callback[type_] = CallChain(self.callback[type_], f, lambda t: t.type == type_)
 *             else:
 *                 self.callback[type_] = f             # <<<<<<<<<<<<<<
 * 
 *         self._scanner = Scanner(terminals, self.g_regex_flags, self.re, self.use_bytes)
 */
    /*else*/ {
      if (unlikely(__pyx_v_self->callback == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 243, __pyx_L1_error)
      }
      if (unlikely(PyDict_SetItem(__pyx_v_self->callback, __pyx_cur_scope->__pyx_v_type_, __pyx_v_f) < 0)) __PYX_ERR(0, 243, __pyx_L1_error)
    }
    __pyx_L7:;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "lark_cython/lark_cython.pyx":245
 *                 self.callback[type_] = f
 * 
 *         self._scanner = Scanner(terminals, self.g_regex_flags, self.re, self.use_bytes)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->g_regex_flags); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->use_bytes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_terminals);
  __Pyx_GIVEREF(__pyx_v_terminals);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_terminals);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_7);
  __Pyx_INCREF(__pyx_v_self->re);
  __Pyx_GIVEREF(__pyx_v_self->re);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->re);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_2);
  __pyx_t_7 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Scanner), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_scanner);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_scanner));
  __pyx_v_self->_scanner = ((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":234
 *         self._scanner = None
 * 
 *     def _build_scanner(self):             # <<<<<<<<<<<<<<
 *         terminals, self.callback = _create_unless(self.terminals, self.g_regex_flags, self.re, self.use_bytes)
 *         assert all(self.callback.values())
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer._build_scanner", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_terminals);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":248
 * 
 *     @property
 *     def scanner(self):             # <<<<<<<<<<<<<<
 *         if self._scanner is None:
 *             self._build_scanner()
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_7scanner_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_7scanner_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer_7scanner___get__(((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_7scanner___get__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "lark_cython/lark_cython.pyx":249
 *     @property
 *     def scanner(self):
 *         if self._scanner is None:             # <<<<<<<<<<<<<<
 *             self._build_scanner()
 *         return self._scanner
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_scanner) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":250
 *     def scanner(self):
 *         if self._scanner is None:
 *             self._build_scanner()             # <<<<<<<<<<<<<<
 *         return self._scanner
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_build_scanner); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":249
 *     @property
 *     def scanner(self):
 *         if self._scanner is None:             # <<<<<<<<<<<<<<
 *             self._build_scanner()
 *         return self._scanner
 */
  }

  /* "lark_cython/lark_cython.pyx":251
 *         if self._scanner is None:
 *             self._build_scanner()
 *         return self._scanner             # <<<<<<<<<<<<<<
 * 
 *     cdef match(self, text, pos):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_scanner));
  __pyx_r = ((PyObject *)__pyx_v_self->_scanner);
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":248
 * 
 *     @property
 *     def scanner(self):             # <<<<<<<<<<<<<<
 *         if self._scanner is None:
 *             self._build_scanner()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.scanner.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":253
 *         return self._scanner
 * 
 *     cdef match(self, text, pos):             # <<<<<<<<<<<<<<
 *         return self.scanner.match(text, pos)
 * 
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_10BasicLexer_match(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, PyObject *__pyx_v_text, PyObject *__pyx_v_pos) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("match", 0);

  /* "lark_cython/lark_cython.pyx":254
 * 
 *     cdef match(self, text, pos):
 *         return self.scanner.match(text, pos)             # <<<<<<<<<<<<<<
 * 
 *     # def lex(self, state: LexerState, parser_state: Any):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scanner); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_text, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_text, __pyx_v_pos};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_text);
    __Pyx_GIVEREF(__pyx_v_text);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_text);
    __Pyx_INCREF(__pyx_v_pos);
    __Pyx_GIVEREF(__pyx_v_pos);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_pos);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 254, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":253
 *         return self._scanner
 * 
 *     cdef match(self, text, pos):             # <<<<<<<<<<<<<<
 *         return self.scanner.match(text, pos)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":261
 *     #            yield self.next_token(state, parser_state)
 * 
 *     cdef public next_token(self, LexerState lex_state, ParserState parser_state):             # <<<<<<<<<<<<<<
 *         cdef LineCounter line_ctr = lex_state.line_ctr
 *         cdef str value
 */

PyObject *__pyx_f_11lark_cython_11lark_cython_10BasicLexer_next_token(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lex_state, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state) {
  struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *__pyx_v_line_ctr = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_type_ = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_t = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_t2 = 0;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_allowed = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_token", 0);

  /* "lark_cython/lark_cython.pyx":262
 * 
 *     cdef public next_token(self, LexerState lex_state, ParserState parser_state):
 *         cdef LineCounter line_ctr = lex_state.line_ctr             # <<<<<<<<<<<<<<
 *         cdef str value
 *         cdef str type_
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_lex_state->line_ctr);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":268
 *         cdef Token t2
 * 
 *         while line_ctr.char_pos < len(lex_state.text):             # <<<<<<<<<<<<<<
 *             res = self.match(lex_state.text, line_ctr.char_pos)
 *             if not res:
 */
  while (1) {
    __pyx_t_1 = __pyx_v_lex_state->text;
    __Pyx_INCREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 268, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 268, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = ((__pyx_v_line_ctr->char_pos < __pyx_t_2) != 0);
    if (!__pyx_t_3) break;

    /* "lark_cython/lark_cython.pyx":269
 * 
 *         while line_ctr.char_pos < len(lex_state.text):
 *             res = self.match(lex_state.text, line_ctr.char_pos)             # <<<<<<<<<<<<<<
 *             if not res:
 *                 allowed = self.scanner.allowed_types - self.ignore_types
 */
    __pyx_t_1 = __pyx_v_lex_state->text;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->char_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self->__pyx_base.__pyx_vtab)->match(__pyx_v_self, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_res, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "lark_cython/lark_cython.pyx":270
 *         while line_ctr.char_pos < len(lex_state.text):
 *             res = self.match(lex_state.text, line_ctr.char_pos)
 *             if not res:             # <<<<<<<<<<<<<<
 *                 allowed = self.scanner.allowed_types - self.ignore_types
 *                 if not allowed:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_res); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 270, __pyx_L1_error)
    __pyx_t_6 = ((!__pyx_t_3) != 0);
    if (__pyx_t_6) {

      /* "lark_cython/lark_cython.pyx":271
 *             res = self.match(lex_state.text, line_ctr.char_pos)
 *             if not res:
 *                 allowed = self.scanner.allowed_types - self.ignore_types             # <<<<<<<<<<<<<<
 *                 if not allowed:
 *                     allowed = {"<END-OF-FILE>"}
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scanner); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_allowed_types); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Subtract(__pyx_t_4, __pyx_v_self->ignore_types); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_allowed = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "lark_cython/lark_cython.pyx":272
 *             if not res:
 *                 allowed = self.scanner.allowed_types - self.ignore_types
 *                 if not allowed:             # <<<<<<<<<<<<<<
 *                     allowed = {"<END-OF-FILE>"}
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,
 */
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_allowed); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 272, __pyx_L1_error)
      __pyx_t_3 = ((!__pyx_t_6) != 0);
      if (__pyx_t_3) {

        /* "lark_cython/lark_cython.pyx":273
 *                 allowed = self.scanner.allowed_types - self.ignore_types
 *                 if not allowed:
 *                     allowed = {"<END-OF-FILE>"}             # <<<<<<<<<<<<<<
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,
 *                                            allowed=allowed, token_history=lex_state.last_token and [lex_state.last_token],
 */
        __pyx_t_5 = PySet_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 273, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (PySet_Add(__pyx_t_5, __pyx_kp_u_END_OF_FILE) < 0) __PYX_ERR(0, 273, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_allowed, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "lark_cython/lark_cython.pyx":272
 *             if not res:
 *                 allowed = self.scanner.allowed_types - self.ignore_types
 *                 if not allowed:             # <<<<<<<<<<<<<<
 *                     allowed = {"<END-OF-FILE>"}
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,
 */
      }

      /* "lark_cython/lark_cython.pyx":274
 *                 if not allowed:
 *                     allowed = {"<END-OF-FILE>"}
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,             # <<<<<<<<<<<<<<
 *                                            allowed=allowed, token_history=lex_state.last_token and [lex_state.last_token],
 *                                            state=parser_state, terminals_by_name=self.terminals_by_name)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->char_pos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->column); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyTuple_New(4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_v_lex_state->text);
      __Pyx_GIVEREF(__pyx_v_lex_state->text);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_lex_state->text);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_8, 3, __pyx_t_7);
      __pyx_t_4 = 0;
      __pyx_t_1 = 0;
      __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":275
 *                     allowed = {"<END-OF-FILE>"}
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,
 *                                            allowed=allowed, token_history=lex_state.last_token and [lex_state.last_token],             # <<<<<<<<<<<<<<
 *                                            state=parser_state, terminals_by_name=self.terminals_by_name)
 * 
 */
      __pyx_t_7 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 275, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_allowed, __pyx_v_allowed) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_lex_state->last_token); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 275, __pyx_L1_error)
      if (__pyx_t_3) {
      } else {
        __Pyx_INCREF(__pyx_v_lex_state->last_token);
        __pyx_t_1 = __pyx_v_lex_state->last_token;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_lex_state->last_token);
      __Pyx_GIVEREF(__pyx_v_lex_state->last_token);
      PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_lex_state->last_token);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_1 = __pyx_t_4;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_L7_bool_binop_done:;
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_token_history, __pyx_t_1) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "lark_cython/lark_cython.pyx":276
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,
 *                                            allowed=allowed, token_history=lex_state.last_token and [lex_state.last_token],
 *                                            state=parser_state, terminals_by_name=self.terminals_by_name)             # <<<<<<<<<<<<<<
 * 
 *             value, type_ = res
 */
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_state, ((PyObject *)__pyx_v_parser_state)) < 0) __PYX_ERR(0, 275, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_terminals_by_name, __pyx_v_self->terminals_by_name) < 0) __PYX_ERR(0, 275, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":274
 *                 if not allowed:
 *                     allowed = {"<END-OF-FILE>"}
 *                 raise UnexpectedCharacters(lex_state.text, line_ctr.char_pos, line_ctr.line, line_ctr.column,             # <<<<<<<<<<<<<<
 *                                            allowed=allowed, token_history=lex_state.last_token and [lex_state.last_token],
 *                                            state=parser_state, terminals_by_name=self.terminals_by_name)
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 274, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":270
 *         while line_ctr.char_pos < len(lex_state.text):
 *             res = self.match(lex_state.text, line_ctr.char_pos)
 *             if not res:             # <<<<<<<<<<<<<<
 *                 allowed = self.scanner.allowed_types - self.ignore_types
 *                 if not allowed:
 */
    }

    /* "lark_cython/lark_cython.pyx":278
 *                                            state=parser_state, terminals_by_name=self.terminals_by_name)
 * 
 *             value, type_ = res             # <<<<<<<<<<<<<<
 * 
 *             if type_ not in self.ignore_types:
 */
    if ((likely(PyTuple_CheckExact(__pyx_v_res))) || (PyList_CheckExact(__pyx_v_res))) {
      PyObject* sequence = __pyx_v_res;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 278, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_v_res); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) __PYX_ERR(0, 278, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L10_unpacking_done;
      __pyx_L9_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 278, __pyx_L1_error)
      __pyx_L10_unpacking_done:;
    }
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 278, __pyx_L1_error)
    if (!(likely(PyUnicode_CheckExact(__pyx_t_7))||((__pyx_t_7) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_7)->tp_name), 0))) __PYX_ERR(0, 278, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_value, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_type_, ((PyObject*)__pyx_t_7));
    __pyx_t_7 = 0;

    /* "lark_cython/lark_cython.pyx":280
 *             value, type_ = res
 * 
 *             if type_ not in self.ignore_types:             # <<<<<<<<<<<<<<
 *                 t = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                 line_ctr.feed(value, type_ in self.newline_types)
 */
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_type_, __pyx_v_self->ignore_types, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 280, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_3 != 0);
    if (__pyx_t_6) {

      /* "lark_cython/lark_cython.pyx":281
 * 
 *             if type_ not in self.ignore_types:
 *                 t = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)             # <<<<<<<<<<<<<<
 *                 line_ctr.feed(value, type_ in self.newline_types)
 *                 t.end_line = line_ctr.line
 */
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->char_pos); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->column); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_type_);
      __Pyx_GIVEREF(__pyx_v_type_);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_type_);
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_value);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_t_8);
      __pyx_t_7 = 0;
      __pyx_t_1 = 0;
      __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token), __pyx_t_5, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_t = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_8);
      __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":282
 *             if type_ not in self.ignore_types:
 *                 t = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                 line_ctr.feed(value, type_ in self.newline_types)             # <<<<<<<<<<<<<<
 *                 t.end_line = line_ctr.line
 *                 t.end_column = line_ctr.column
 */
      __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_v_type_, __pyx_v_self->newline_types, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 282, __pyx_L1_error)
      __pyx_t_8 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_LineCounter *)__pyx_v_line_ctr->__pyx_vtab)->feed(__pyx_v_line_ctr, __pyx_v_value, __pyx_t_6, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":283
 *                 t = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                 line_ctr.feed(value, type_ in self.newline_types)
 *                 t.end_line = line_ctr.line             # <<<<<<<<<<<<<<
 *                 t.end_column = line_ctr.column
 *                 t.end_pos = line_ctr.char_pos
 */
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->line); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_v_t->end_line);
      __Pyx_DECREF(__pyx_v_t->end_line);
      __pyx_v_t->end_line = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":284
 *                 line_ctr.feed(value, type_ in self.newline_types)
 *                 t.end_line = line_ctr.line
 *                 t.end_column = line_ctr.column             # <<<<<<<<<<<<<<
 *                 t.end_pos = line_ctr.char_pos
 *                 if t.type in self.callback:
 */
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->column); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 284, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_v_t->end_column);
      __Pyx_DECREF(__pyx_v_t->end_column);
      __pyx_v_t->end_column = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":285
 *                 t.end_line = line_ctr.line
 *                 t.end_column = line_ctr.column
 *                 t.end_pos = line_ctr.char_pos             # <<<<<<<<<<<<<<
 *                 if t.type in self.callback:
 *                     t = self.callback[t.type](t)
 */
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->char_pos); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_v_t->end_pos);
      __Pyx_DECREF(__pyx_v_t->end_pos);
      __pyx_v_t->end_pos = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":286
 *                 t.end_column = line_ctr.column
 *                 t.end_pos = line_ctr.char_pos
 *                 if t.type in self.callback:             # <<<<<<<<<<<<<<
 *                     t = self.callback[t.type](t)
 *                     if not isinstance(t, Token):
 */
      if (unlikely(__pyx_v_self->callback == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 286, __pyx_L1_error)
      }
      __pyx_t_6 = (__Pyx_PyDict_ContainsTF(__pyx_v_t->type, __pyx_v_self->callback, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 286, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_6 != 0);
      if (__pyx_t_3) {

        /* "lark_cython/lark_cython.pyx":287
 *                 t.end_pos = line_ctr.char_pos
 *                 if t.type in self.callback:
 *                     t = self.callback[t.type](t)             # <<<<<<<<<<<<<<
 *                     if not isinstance(t, Token):
 *                         raise LexError("Callbacks must return a token (returned %r)" % t)
 */
        if (unlikely(__pyx_v_self->callback == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 287, __pyx_L1_error)
        }
        __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_self->callback, __pyx_v_t->type); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 287, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        __pyx_t_8 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_1, ((PyObject *)__pyx_v_t)) : __Pyx_PyObject_CallOneArg(__pyx_t_5, ((PyObject *)__pyx_v_t));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 287, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 287, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_t, ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_8));
        __pyx_t_8 = 0;

        /* "lark_cython/lark_cython.pyx":288
 *                 if t.type in self.callback:
 *                     t = self.callback[t.type](t)
 *                     if not isinstance(t, Token):             # <<<<<<<<<<<<<<
 *                         raise LexError("Callbacks must return a token (returned %r)" % t)
 *                 lex_state.last_token = t
 */
        __pyx_t_3 = __Pyx_TypeCheck(((PyObject *)__pyx_v_t), __pyx_ptype_11lark_cython_11lark_cython_Token); 
        __pyx_t_6 = ((!(__pyx_t_3 != 0)) != 0);
        if (unlikely(__pyx_t_6)) {

          /* "lark_cython/lark_cython.pyx":289
 *                     t = self.callback[t.type](t)
 *                     if not isinstance(t, Token):
 *                         raise LexError("Callbacks must return a token (returned %r)" % t)             # <<<<<<<<<<<<<<
 *                 lex_state.last_token = t
 *                 return t
 */
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_LexError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 289, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_1 = PyUnicode_Format(__pyx_kp_u_Callbacks_must_return_a_token_re, ((PyObject *)__pyx_v_t)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 289, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_Raise(__pyx_t_8, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __PYX_ERR(0, 289, __pyx_L1_error)

          /* "lark_cython/lark_cython.pyx":288
 *                 if t.type in self.callback:
 *                     t = self.callback[t.type](t)
 *                     if not isinstance(t, Token):             # <<<<<<<<<<<<<<
 *                         raise LexError("Callbacks must return a token (returned %r)" % t)
 *                 lex_state.last_token = t
 */
        }

        /* "lark_cython/lark_cython.pyx":286
 *                 t.end_column = line_ctr.column
 *                 t.end_pos = line_ctr.char_pos
 *                 if t.type in self.callback:             # <<<<<<<<<<<<<<
 *                     t = self.callback[t.type](t)
 *                     if not isinstance(t, Token):
 */
      }

      /* "lark_cython/lark_cython.pyx":290
 *                     if not isinstance(t, Token):
 *                         raise LexError("Callbacks must return a token (returned %r)" % t)
 *                 lex_state.last_token = t             # <<<<<<<<<<<<<<
 *                 return t
 *             else:
 */
      __Pyx_INCREF(((PyObject *)__pyx_v_t));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_t));
      __Pyx_GOTREF(__pyx_v_lex_state->last_token);
      __Pyx_DECREF(__pyx_v_lex_state->last_token);
      __pyx_v_lex_state->last_token = ((PyObject *)__pyx_v_t);

      /* "lark_cython/lark_cython.pyx":291
 *                         raise LexError("Callbacks must return a token (returned %r)" % t)
 *                 lex_state.last_token = t
 *                 return t             # <<<<<<<<<<<<<<
 *             else:
 *                 if type_ in self.callback:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(((PyObject *)__pyx_v_t));
      __pyx_r = ((PyObject *)__pyx_v_t);
      goto __pyx_L0;

      /* "lark_cython/lark_cython.pyx":280
 *             value, type_ = res
 * 
 *             if type_ not in self.ignore_types:             # <<<<<<<<<<<<<<
 *                 t = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                 line_ctr.feed(value, type_ in self.newline_types)
 */
    }

    /* "lark_cython/lark_cython.pyx":293
 *                 return t
 *             else:
 *                 if type_ in self.callback:             # <<<<<<<<<<<<<<
 *                     t2 = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                     self.callback[type_](t2)
 */
    /*else*/ {
      if (unlikely(__pyx_v_self->callback == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 293, __pyx_L1_error)
      }
      __pyx_t_6 = (__Pyx_PyDict_ContainsTF(__pyx_v_type_, __pyx_v_self->callback, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 293, __pyx_L1_error)
      __pyx_t_3 = (__pyx_t_6 != 0);
      if (__pyx_t_3) {

        /* "lark_cython/lark_cython.pyx":294
 *             else:
 *                 if type_ in self.callback:
 *                     t2 = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)             # <<<<<<<<<<<<<<
 *                     self.callback[type_](t2)
 *                 line_ctr.feed(value, type_ in self.newline_types)
 */
        __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->char_pos); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->line); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_line_ctr->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = PyTuple_New(5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_v_type_);
        __Pyx_GIVEREF(__pyx_v_type_);
        PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_type_);
        __Pyx_INCREF(__pyx_v_value);
        __Pyx_GIVEREF(__pyx_v_value);
        PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_value);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_7, 4, __pyx_t_1);
        __pyx_t_8 = 0;
        __pyx_t_5 = 0;
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token), __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 294, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_v_t2, ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "lark_cython/lark_cython.pyx":295
 *                 if type_ in self.callback:
 *                     t2 = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                     self.callback[type_](t2)             # <<<<<<<<<<<<<<
 *                 line_ctr.feed(value, type_ in self.newline_types)
 * 
 */
        if (unlikely(__pyx_v_self->callback == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 295, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_PyDict_GetItem(__pyx_v_self->callback, __pyx_v_type_); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 295, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, ((PyObject *)__pyx_v_t2)) : __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)__pyx_v_t2));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 295, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "lark_cython/lark_cython.pyx":293
 *                 return t
 *             else:
 *                 if type_ in self.callback:             # <<<<<<<<<<<<<<
 *                     t2 = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                     self.callback[type_](t2)
 */
      }

      /* "lark_cython/lark_cython.pyx":296
 *                     t2 = Token(type_, value, line_ctr.char_pos, line_ctr.line, line_ctr.column)
 *                     self.callback[type_](t2)
 *                 line_ctr.feed(value, type_ in self.newline_types)             # <<<<<<<<<<<<<<
 * 
 *         # EOF
 */
      __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_v_type_, __pyx_v_self->newline_types, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 296, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_LineCounter *)__pyx_v_line_ctr->__pyx_vtab)->feed(__pyx_v_line_ctr, __pyx_v_value, __pyx_t_3, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 296, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }

  /* "lark_cython/lark_cython.pyx":299
 * 
 *         # EOF
 *         raise EOFError(self)             # <<<<<<<<<<<<<<
 * 
 * cdef class ContextualLexer(Lexer):
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_EOFError, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 299, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":261
 *     #            yield self.next_token(state, parser_state)
 * 
 *     cdef public next_token(self, LexerState lex_state, ParserState parser_state):             # <<<<<<<<<<<<<<
 *         cdef LineCounter line_ctr = lex_state.line_ctr
 *         cdef str value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_line_ctr);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_type_);
  __Pyx_XDECREF((PyObject *)__pyx_v_t);
  __Pyx_XDECREF((PyObject *)__pyx_v_t2);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_allowed);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self._scanner, self.callback, self.g_regex_flags, self.ignore_types, self.newline_types, self.re, self.terminals, self.terminals_by_name, self.use_bytes, self.user_callbacks)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->g_regex_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->use_bytes); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(10); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_scanner));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->_scanner));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self->_scanner));
  __Pyx_INCREF(__pyx_v_self->callback);
  __Pyx_GIVEREF(__pyx_v_self->callback);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_self->callback);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->ignore_types);
  __Pyx_GIVEREF(__pyx_v_self->ignore_types);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_self->ignore_types);
  __Pyx_INCREF(__pyx_v_self->newline_types);
  __Pyx_GIVEREF(__pyx_v_self->newline_types);
  PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_v_self->newline_types);
  __Pyx_INCREF(__pyx_v_self->re);
  __Pyx_GIVEREF(__pyx_v_self->re);
  PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_v_self->re);
  __Pyx_INCREF(__pyx_v_self->terminals);
  __Pyx_GIVEREF(__pyx_v_self->terminals);
  PyTuple_SET_ITEM(__pyx_t_3, 6, __pyx_v_self->terminals);
  __Pyx_INCREF(__pyx_v_self->terminals_by_name);
  __Pyx_GIVEREF(__pyx_v_self->terminals_by_name);
  PyTuple_SET_ITEM(__pyx_t_3, 7, __pyx_v_self->terminals_by_name);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 8, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->user_callbacks);
  __Pyx_GIVEREF(__pyx_v_self->user_callbacks);
  PyTuple_SET_ITEM(__pyx_t_3, 9, __pyx_v_self->user_callbacks);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self._scanner, self.callback, self.g_regex_flags, self.ignore_types, self.newline_types, self.re, self.terminals, self.terminals_by_name, self.use_bytes, self.user_callbacks)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":7
 *     state = (self._scanner, self.callback, self.g_regex_flags, self.ignore_types, self.newline_types, self.re, self.terminals, self.terminals_by_name, self.use_bytes, self.user_callbacks)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._scanner is not None or self.callback is not None or self.ignore_types is not None or self.newline_types is not None or self.re is not None or self.terminals is not None or self.terminals_by_name is not None or self.user_callbacks is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self._scanner, self.callback, self.g_regex_flags, self.ignore_types, self.newline_types, self.re, self.terminals, self.terminals_by_name, self.use_bytes, self.user_callbacks)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self._scanner is not None or self.callback is not None or self.ignore_types is not None or self.newline_types is not None or self.re is not None or self.terminals is not None or self.terminals_by_name is not None or self.user_callbacks is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, None), state
 */
  /*else*/ {
    __pyx_t_4 = (((PyObject *)__pyx_v_self->_scanner) != Py_None);
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->callback != ((PyObject*)Py_None));
    __pyx_t_4 = (__pyx_t_6 != 0);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_5 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->ignore_types != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->newline_types != ((PyObject*)Py_None));
    __pyx_t_4 = (__pyx_t_6 != 0);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_5 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->re != Py_None);
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->terminals != ((PyObject*)Py_None));
    __pyx_t_4 = (__pyx_t_6 != 0);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_5 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->terminals_by_name != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->user_callbacks != ((PyObject*)Py_None));
    __pyx_t_4 = (__pyx_t_6 != 0);
    __pyx_t_5 = __pyx_t_4;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_5;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._scanner is not None or self.callback is not None or self.ignore_types is not None or self.newline_types is not None or self.re is not None or self.terminals is not None or self.terminals_by_name is not None or self.user_callbacks is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, None), state
 *     else:
 */
  __pyx_t_5 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_5) {

    /* "(tree fragment)":13
 *         use_setstate = self._scanner is not None or self.callback is not None or self.ignore_types is not None or self.newline_types is not None or self.re is not None or self.terminals is not None or self.terminals_by_name is not None or self.user_callbacks is not None
 *     if use_setstate:
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pyx_unpickle_BasicLexer); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_104898272);
    __Pyx_GIVEREF(__pyx_int_104898272);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_104898272);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._scanner is not None or self.callback is not None or self.ignore_types is not None or self.newline_types is not None or self.re is not None or self.terminals is not None or self.terminals_by_name is not None or self.user_callbacks is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, None), state
 *     else:
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BasicLexer__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_BasicLexer); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_104898272);
    __Pyx_GIVEREF(__pyx_int_104898272);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_104898272);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BasicLexer__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10BasicLexer_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10BasicLexer_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BasicLexer__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_BasicLexer__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BasicLexer, (type(self), 0x6409ee0, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BasicLexer__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.BasicLexer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":306
 *     cdef BasicLexer root_lexer
 * 
 *     def __cinit__(self, conf: 'LexerConf', states: Dict[str, Collection[str]], always_accept: Collection[str]=()):             # <<<<<<<<<<<<<<
 * 
 *         terminals = list(conf.terminals)
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_conf = 0;
  PyObject *__pyx_v_states = 0;
  PyObject *__pyx_v_always_accept = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_conf,&__pyx_n_s_states,&__pyx_n_s_always_accept,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)__pyx_empty_tuple);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_conf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_states)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(0, 306, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_always_accept);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 306, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_conf = values[0];
    __pyx_v_states = values[1];
    __pyx_v_always_accept = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 306, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)__pyx_v_self), __pyx_v_conf, __pyx_v_states, __pyx_v_always_accept);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_conf, PyObject *__pyx_v_states, PyObject *__pyx_v_always_accept) {
  PyObject *__pyx_v_terminals = NULL;
  PyObject *__pyx_v_terminals_by_name = NULL;
  PyObject *__pyx_v_trad_conf = NULL;
  PyObject *__pyx_v_lexer_by_tokens = NULL;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v_accepts = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_lexer = NULL;
  PyObject *__pyx_v_lexer_conf = NULL;
  PyObject *__pyx_8genexpr7__pyx_v_n = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":308
 *     def __cinit__(self, conf: 'LexerConf', states: Dict[str, Collection[str]], always_accept: Collection[str]=()):
 * 
 *         terminals = list(conf.terminals)             # <<<<<<<<<<<<<<
 *         terminals_by_name = conf.terminals_by_name
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_terminals); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_terminals = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":309
 * 
 *         terminals = list(conf.terminals)
 *         terminals_by_name = conf.terminals_by_name             # <<<<<<<<<<<<<<
 * 
 *         trad_conf = copy(conf)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_terminals_by_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_terminals_by_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":311
 *         terminals_by_name = conf.terminals_by_name
 * 
 *         trad_conf = copy(conf)             # <<<<<<<<<<<<<<
 *         trad_conf.terminals = terminals
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_v_conf) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_conf);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_trad_conf = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":312
 * 
 *         trad_conf = copy(conf)
 *         trad_conf.terminals = terminals             # <<<<<<<<<<<<<<
 * 
 *         lexer_by_tokens: Dict[FrozenSet[str], BasicLexer] = {}
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_trad_conf, __pyx_n_s_terminals, __pyx_v_terminals) < 0) __PYX_ERR(0, 312, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":314
 *         trad_conf.terminals = terminals
 * 
 *         lexer_by_tokens: Dict[FrozenSet[str], BasicLexer] = {}             # <<<<<<<<<<<<<<
 *         self.lexers = {}
 *         for state, accepts in states.items():
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_lexer_by_tokens = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":315
 * 
 *         lexer_by_tokens: Dict[FrozenSet[str], BasicLexer] = {}
 *         self.lexers = {}             # <<<<<<<<<<<<<<
 *         for state, accepts in states.items():
 *             key = frozenset(accepts)
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->lexers);
  __Pyx_DECREF(__pyx_v_self->lexers);
  __pyx_v_self->lexers = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":316
 *         lexer_by_tokens: Dict[FrozenSet[str], BasicLexer] = {}
 *         self.lexers = {}
 *         for state, accepts in states.items():             # <<<<<<<<<<<<<<
 *             key = frozenset(accepts)
 *             try:
 */
  __pyx_t_4 = 0;
  if (unlikely(__pyx_v_states == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 316, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_dict_iterator(__pyx_v_states, 0, __pyx_n_s_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __pyx_t_2 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_5, &__pyx_t_4, &__pyx_t_1, &__pyx_t_3, NULL, __pyx_t_6);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_state, __pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_accepts, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":317
 *         self.lexers = {}
 *         for state, accepts in states.items():
 *             key = frozenset(accepts)             # <<<<<<<<<<<<<<
 *             try:
 *                 lexer = lexer_by_tokens[key]
 */
    __pyx_t_3 = __Pyx_PyFrozenSet_New(__pyx_v_accepts); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_key, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":318
 *         for state, accepts in states.items():
 *             key = frozenset(accepts)
 *             try:             # <<<<<<<<<<<<<<
 *                 lexer = lexer_by_tokens[key]
 *             except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":319
 *             key = frozenset(accepts)
 *             try:
 *                 lexer = lexer_by_tokens[key]             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 accepts = set(accepts) | set(conf.ignore) | set(always_accept)
 */
        __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_lexer_by_tokens, __pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_lexer, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "lark_cython/lark_cython.pyx":318
 *         for state, accepts in states.items():
 *             key = frozenset(accepts)
 *             try:             # <<<<<<<<<<<<<<
 *                 lexer = lexer_by_tokens[key]
 *             except KeyError:
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "lark_cython/lark_cython.pyx":320
 *             try:
 *                 lexer = lexer_by_tokens[key]
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 accepts = set(accepts) | set(conf.ignore) | set(always_accept)
 *                 lexer_conf = copy(trad_conf)
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_7) {
        __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_11) < 0) __PYX_ERR(0, 320, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_11);

        /* "lark_cython/lark_cython.pyx":321
 *                 lexer = lexer_by_tokens[key]
 *             except KeyError:
 *                 accepts = set(accepts) | set(conf.ignore) | set(always_accept)             # <<<<<<<<<<<<<<
 *                 lexer_conf = copy(trad_conf)
 *                 lexer_conf.terminals = [terminals_by_name[n] for n in accepts if n in terminals_by_name]
 */
        __pyx_t_12 = PySet_New(__pyx_v_accepts); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_conf, __pyx_n_s_ignore); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = PySet_New(__pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = PyNumber_Or(__pyx_t_12, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = PySet_New(__pyx_v_always_accept); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_12 = PyNumber_Or(__pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF_SET(__pyx_v_accepts, __pyx_t_12);
        __pyx_t_12 = 0;

        /* "lark_cython/lark_cython.pyx":322
 *             except KeyError:
 *                 accepts = set(accepts) | set(conf.ignore) | set(always_accept)
 *                 lexer_conf = copy(trad_conf)             # <<<<<<<<<<<<<<
 *                 lexer_conf.terminals = [terminals_by_name[n] for n in accepts if n in terminals_by_name]
 *                 lexer = BasicLexer(lexer_conf)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_copy); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 322, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_13 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_14, function);
          }
        }
        __pyx_t_12 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, __pyx_v_trad_conf) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_v_trad_conf);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 322, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF_SET(__pyx_v_lexer_conf, __pyx_t_12);
        __pyx_t_12 = 0;

        /* "lark_cython/lark_cython.pyx":323
 *                 accepts = set(accepts) | set(conf.ignore) | set(always_accept)
 *                 lexer_conf = copy(trad_conf)
 *                 lexer_conf.terminals = [terminals_by_name[n] for n in accepts if n in terminals_by_name]             # <<<<<<<<<<<<<<
 *                 lexer = BasicLexer(lexer_conf)
 *                 lexer_by_tokens[key] = lexer
 */
        { /* enter inner scope */
          __pyx_t_12 = PyList_New(0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 323, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (likely(PyList_CheckExact(__pyx_v_accepts)) || PyTuple_CheckExact(__pyx_v_accepts)) {
            __pyx_t_14 = __pyx_v_accepts; __Pyx_INCREF(__pyx_t_14); __pyx_t_15 = 0;
            __pyx_t_16 = NULL;
          } else {
            __pyx_t_15 = -1; __pyx_t_14 = PyObject_GetIter(__pyx_v_accepts); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 323, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_16 = Py_TYPE(__pyx_t_14)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 323, __pyx_L17_error)
          }
          for (;;) {
            if (likely(!__pyx_t_16)) {
              if (likely(PyList_CheckExact(__pyx_t_14))) {
                if (__pyx_t_15 >= PyList_GET_SIZE(__pyx_t_14)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_13 = PyList_GET_ITEM(__pyx_t_14, __pyx_t_15); __Pyx_INCREF(__pyx_t_13); __pyx_t_15++; if (unlikely(0 < 0)) __PYX_ERR(0, 323, __pyx_L17_error)
                #else
                __pyx_t_13 = PySequence_ITEM(__pyx_t_14, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 323, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_13);
                #endif
              } else {
                if (__pyx_t_15 >= PyTuple_GET_SIZE(__pyx_t_14)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_13 = PyTuple_GET_ITEM(__pyx_t_14, __pyx_t_15); __Pyx_INCREF(__pyx_t_13); __pyx_t_15++; if (unlikely(0 < 0)) __PYX_ERR(0, 323, __pyx_L17_error)
                #else
                __pyx_t_13 = PySequence_ITEM(__pyx_t_14, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 323, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_13);
                #endif
              }
            } else {
              __pyx_t_13 = __pyx_t_16(__pyx_t_14);
              if (unlikely(!__pyx_t_13)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 323, __pyx_L17_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_13);
            }
            __Pyx_XDECREF_SET(__pyx_8genexpr7__pyx_v_n, __pyx_t_13);
            __pyx_t_13 = 0;
            __pyx_t_17 = (__Pyx_PySequence_ContainsTF(__pyx_8genexpr7__pyx_v_n, __pyx_v_terminals_by_name, Py_EQ)); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 323, __pyx_L17_error)
            __pyx_t_18 = (__pyx_t_17 != 0);
            if (__pyx_t_18) {
              __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_v_terminals_by_name, __pyx_8genexpr7__pyx_v_n); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 323, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_13);
              if (unlikely(__Pyx_ListComp_Append(__pyx_t_12, (PyObject*)__pyx_t_13))) __PYX_ERR(0, 323, __pyx_L17_error)
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_n); __pyx_8genexpr7__pyx_v_n = 0;
          goto __pyx_L21_exit_scope;
          __pyx_L17_error:;
          __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_n); __pyx_8genexpr7__pyx_v_n = 0;
          goto __pyx_L7_except_error;
          __pyx_L21_exit_scope:;
        } /* exit inner scope */
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_lexer_conf, __pyx_n_s_terminals, __pyx_t_12) < 0) __PYX_ERR(0, 323, __pyx_L7_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "lark_cython/lark_cython.pyx":324
 *                 lexer_conf = copy(trad_conf)
 *                 lexer_conf.terminals = [terminals_by_name[n] for n in accepts if n in terminals_by_name]
 *                 lexer = BasicLexer(lexer_conf)             # <<<<<<<<<<<<<<
 *                 lexer_by_tokens[key] = lexer
 * 
 */
        __pyx_t_12 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_BasicLexer), __pyx_v_lexer_conf); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 324, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_XDECREF_SET(__pyx_v_lexer, __pyx_t_12);
        __pyx_t_12 = 0;

        /* "lark_cython/lark_cython.pyx":325
 *                 lexer_conf.terminals = [terminals_by_name[n] for n in accepts if n in terminals_by_name]
 *                 lexer = BasicLexer(lexer_conf)
 *                 lexer_by_tokens[key] = lexer             # <<<<<<<<<<<<<<
 * 
 *             self.lexers[state] = lexer
 */
        if (unlikely(PyDict_SetItem(__pyx_v_lexer_by_tokens, __pyx_v_key, __pyx_v_lexer) < 0)) __PYX_ERR(0, 325, __pyx_L7_except_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "lark_cython/lark_cython.pyx":318
 *         for state, accepts in states.items():
 *             key = frozenset(accepts)
 *             try:             # <<<<<<<<<<<<<<
 *                 lexer = lexer_by_tokens[key]
 *             except KeyError:
 */
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L12_try_end:;
    }

    /* "lark_cython/lark_cython.pyx":327
 *                 lexer_by_tokens[key] = lexer
 * 
 *             self.lexers[state] = lexer             # <<<<<<<<<<<<<<
 * 
 *         assert trad_conf.terminals is terminals
 */
    if (unlikely(__pyx_v_self->lexers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 327, __pyx_L1_error)
    }
    if (unlikely(PyDict_SetItem(__pyx_v_self->lexers, __pyx_v_state, __pyx_v_lexer) < 0)) __PYX_ERR(0, 327, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":329
 *             self.lexers[state] = lexer
 * 
 *         assert trad_conf.terminals is terminals             # <<<<<<<<<<<<<<
 *         self.root_lexer = BasicLexer(trad_conf)
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_trad_conf, __pyx_n_s_terminals); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_18 = (__pyx_t_2 == __pyx_v_terminals);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!(__pyx_t_18 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 329, __pyx_L1_error)
    }
  }
  #endif

  /* "lark_cython/lark_cython.pyx":330
 * 
 *         assert trad_conf.terminals is terminals
 *         self.root_lexer = BasicLexer(trad_conf)             # <<<<<<<<<<<<<<
 * 
 *     cpdef public make_lexer_state(self, str text):
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_BasicLexer), __pyx_v_trad_conf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->root_lexer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->root_lexer));
  __pyx_v_self->root_lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":306
 *     cdef BasicLexer root_lexer
 * 
 *     def __cinit__(self, conf: 'LexerConf', states: Dict[str, Collection[str]], always_accept: Collection[str]=()):             # <<<<<<<<<<<<<<
 * 
 *         terminals = list(conf.terminals)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_terminals);
  __Pyx_XDECREF(__pyx_v_terminals_by_name);
  __Pyx_XDECREF(__pyx_v_trad_conf);
  __Pyx_XDECREF(__pyx_v_lexer_by_tokens);
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v_accepts);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_lexer);
  __Pyx_XDECREF(__pyx_v_lexer_conf);
  __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_n);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":332
 *         self.root_lexer = BasicLexer(trad_conf)
 * 
 *     cpdef public make_lexer_state(self, str text):             # <<<<<<<<<<<<<<
 *         return self.root_lexer.make_lexer_state(text)
 * 
 */

static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_3make_lexer_state(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_text, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_lexer_state", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_make_lexer_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 332, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_3make_lexer_state)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_text);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "lark_cython/lark_cython.pyx":333
 * 
 *     cpdef public make_lexer_state(self, str text):
 *         return self.root_lexer.make_lexer_state(text)             # <<<<<<<<<<<<<<
 * 
 *     cpdef public next_token(self, LexerState lexer_state, ParserState parser_state):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self->root_lexer->__pyx_base.__pyx_vtab)->__pyx_base.make_lexer_state(((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)__pyx_v_self->root_lexer), __pyx_v_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":332
 *         self.root_lexer = BasicLexer(trad_conf)
 * 
 *     cpdef public make_lexer_state(self, str text):             # <<<<<<<<<<<<<<
 *         return self.root_lexer.make_lexer_state(text)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.make_lexer_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_3make_lexer_state(PyObject *__pyx_v_self, PyObject *__pyx_v_text); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_3make_lexer_state(PyObject *__pyx_v_self, PyObject *__pyx_v_text) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("make_lexer_state (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_text), (&PyUnicode_Type), 1, "text", 1))) __PYX_ERR(0, 332, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_2make_lexer_state(((struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)__pyx_v_self), ((PyObject*)__pyx_v_text));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_2make_lexer_state(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_lexer_state", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state(__pyx_v_self, __pyx_v_text, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.make_lexer_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

PyObject *__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state__pyx_wrap_1(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, PyObject *__pyx_v_text) {
  return __pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state(__pyx_v_self, __pyx_v_text, 0);
}

/* "lark_cython/lark_cython.pyx":335
 *         return self.root_lexer.make_lexer_state(text)
 * 
 *     cpdef public next_token(self, LexerState lexer_state, ParserState parser_state):             # <<<<<<<<<<<<<<
 *         cdef BasicLexer lexer
 *         cdef Token last_token
 */

static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_5next_token(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyObject *__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_next_token(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lexer_state, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state, int __pyx_skip_dispatch) {
  struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v_lexer = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_last_token = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_token = 0;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_token", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_token); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_5next_token)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_lexer_state), ((PyObject *)__pyx_v_parser_state)};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, ((PyObject *)__pyx_v_lexer_state), ((PyObject *)__pyx_v_parser_state)};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_lexer_state));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_lexer_state));
          PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_lexer_state));
          __Pyx_INCREF(((PyObject *)__pyx_v_parser_state));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_parser_state));
          PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, ((PyObject *)__pyx_v_parser_state));
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "lark_cython/lark_cython.pyx":339
 *         cdef Token last_token
 *         cdef Token token
 *         try:             # <<<<<<<<<<<<<<
 *             lexer = self.lexers[parser_state.position]
 *             return lexer.next_token(lexer_state, parser_state)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "lark_cython/lark_cython.pyx":340
 *         cdef Token token
 *         try:
 *             lexer = self.lexers[parser_state.position]             # <<<<<<<<<<<<<<
 *             return lexer.next_token(lexer_state, parser_state)
 *         except UnexpectedCharacters as e:
 */
      if (unlikely(__pyx_v_self->lexers == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 340, __pyx_L3_error)
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_parser_state), __pyx_n_s_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 340, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_self->lexers, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 340, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_11lark_cython_11lark_cython_BasicLexer))))) __PYX_ERR(0, 340, __pyx_L3_error)
      __pyx_v_lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "lark_cython/lark_cython.pyx":341
 *         try:
 *             lexer = self.lexers[parser_state.position]
 *             return lexer.next_token(lexer_state, parser_state)             # <<<<<<<<<<<<<<
 *         except UnexpectedCharacters as e:
 *             # In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_lexer->__pyx_base.__pyx_vtab)->next_token(__pyx_v_lexer, __pyx_v_lexer_state, __pyx_v_parser_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L7_try_return;

      /* "lark_cython/lark_cython.pyx":339
 *         cdef Token last_token
 *         cdef Token token
 *         try:             # <<<<<<<<<<<<<<
 *             lexer = self.lexers[parser_state.position]
 *             return lexer.next_token(lexer_state, parser_state)
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "lark_cython/lark_cython.pyx":342
 *             lexer = self.lexers[parser_state.position]
 *             return lexer.next_token(lexer_state, parser_state)
 *         except UnexpectedCharacters as e:             # <<<<<<<<<<<<<<
 *             # In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
 *             # This tests the input against the global context, to provide a nicer error.
 */
    __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_1, &__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 342, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_ErrRestore(__pyx_t_2, __pyx_t_1, __pyx_t_3);
    __pyx_t_2 = 0; __pyx_t_1 = 0; __pyx_t_3 = 0;
    if (__pyx_t_5) {
      __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 342, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_e = __pyx_t_1;
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":345
 *             # In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
 *             # This tests the input against the global context, to provide a nicer error.
 *             try:             # <<<<<<<<<<<<<<
 *                 last_token = lexer_state.last_token  # Save last_token. Calling root_lexer.next_token will change this to the wrong token
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {

            /* "lark_cython/lark_cython.pyx":346
 *             # This tests the input against the global context, to provide a nicer error.
 *             try:
 *                 last_token = lexer_state.last_token  # Save last_token. Calling root_lexer.next_token will change this to the wrong token             # <<<<<<<<<<<<<<
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)
 *                 raise UnexpectedToken(token, e.allowed, state=parser_state, token_history=[last_token], terminals_by_name=self.root_lexer.terminals_by_name)
 */
            if (!(likely(((__pyx_v_lexer_state->last_token) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_lexer_state->last_token, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 346, __pyx_L16_error)
            __pyx_t_6 = __pyx_v_lexer_state->last_token;
            __Pyx_INCREF(__pyx_t_6);
            __pyx_v_last_token = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_6);
            __pyx_t_6 = 0;

            /* "lark_cython/lark_cython.pyx":347
 *             try:
 *                 last_token = lexer_state.last_token  # Save last_token. Calling root_lexer.next_token will change this to the wrong token
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)             # <<<<<<<<<<<<<<
 *                 raise UnexpectedToken(token, e.allowed, state=parser_state, token_history=[last_token], terminals_by_name=self.root_lexer.terminals_by_name)
 *             except UnexpectedCharacters:
 */
            __pyx_t_6 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer *)__pyx_v_self->root_lexer->__pyx_base.__pyx_vtab)->next_token(__pyx_v_self->root_lexer, __pyx_v_lexer_state, __pyx_v_parser_state); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 347, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_6);
            if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 347, __pyx_L16_error)
            __pyx_v_token = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_6);
            __pyx_t_6 = 0;

            /* "lark_cython/lark_cython.pyx":348
 *                 last_token = lexer_state.last_token  # Save last_token. Calling root_lexer.next_token will change this to the wrong token
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)
 *                 raise UnexpectedToken(token, e.allowed, state=parser_state, token_history=[last_token], terminals_by_name=self.root_lexer.terminals_by_name)             # <<<<<<<<<<<<<<
 *             except UnexpectedCharacters:
 *                 raise e  # Raise the original UnexpectedCharacters. The root lexer raises it with the wrong expected set.
 */
            __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_allowed); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_INCREF(((PyObject *)__pyx_v_token));
            __Pyx_GIVEREF(((PyObject *)__pyx_v_token));
            PyTuple_SET_ITEM(__pyx_t_13, 0, ((PyObject *)__pyx_v_token));
            __Pyx_GIVEREF(__pyx_t_4);
            PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_4);
            __pyx_t_4 = 0;
            __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_4);
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_state, ((PyObject *)__pyx_v_parser_state)) < 0) __PYX_ERR(0, 348, __pyx_L16_error)
            __pyx_t_14 = PyList_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_INCREF(((PyObject *)__pyx_v_last_token));
            __Pyx_GIVEREF(((PyObject *)__pyx_v_last_token));
            PyList_SET_ITEM(__pyx_t_14, 0, ((PyObject *)__pyx_v_last_token));
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_token_history, __pyx_t_14) < 0) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_terminals_by_name, __pyx_v_self->root_lexer->terminals_by_name) < 0) __PYX_ERR(0, 348, __pyx_L16_error)
            __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 348, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_Raise(__pyx_t_14, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __PYX_ERR(0, 348, __pyx_L16_error)

            /* "lark_cython/lark_cython.pyx":345
 *             # In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
 *             # This tests the input against the global context, to provide a nicer error.
 *             try:             # <<<<<<<<<<<<<<
 *                 last_token = lexer_state.last_token  # Save last_token. Calling root_lexer.next_token will change this to the wrong token
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)
 */
          }
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "lark_cython/lark_cython.pyx":349
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)
 *                 raise UnexpectedToken(token, e.allowed, state=parser_state, token_history=[last_token], terminals_by_name=self.root_lexer.terminals_by_name)
 *             except UnexpectedCharacters:             # <<<<<<<<<<<<<<
 *                 raise e  # Raise the original UnexpectedCharacters. The root lexer raises it with the wrong expected set.
 * 
 */
          __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_4, &__pyx_t_13);
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 349, __pyx_L18_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_14, __pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_4, __pyx_t_13);
          __pyx_t_14 = 0; __pyx_t_4 = 0; __pyx_t_13 = 0;
          if (__pyx_t_5) {
            __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_4, &__pyx_t_14) < 0) __PYX_ERR(0, 349, __pyx_L18_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GOTREF(__pyx_t_14);

            /* "lark_cython/lark_cython.pyx":350
 *                 raise UnexpectedToken(token, e.allowed, state=parser_state, token_history=[last_token], terminals_by_name=self.root_lexer.terminals_by_name)
 *             except UnexpectedCharacters:
 *                 raise e  # Raise the original UnexpectedCharacters. The root lexer raises it with the wrong expected set.             # <<<<<<<<<<<<<<
 * 
 * 
 */
            __Pyx_Raise(__pyx_v_e, 0, 0, 0);
            __PYX_ERR(0, 350, __pyx_L18_except_error)
          }
          goto __pyx_L18_except_error;
          __pyx_L18_except_error:;

          /* "lark_cython/lark_cython.pyx":345
 *             # In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
 *             # This tests the input against the global context, to provide a nicer error.
 *             try:             # <<<<<<<<<<<<<<
 *                 last_token = lexer_state.last_token  # Save last_token. Calling root_lexer.next_token will change this to the wrong token
 *                 token = self.root_lexer.next_token(lexer_state, parser_state)
 */
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L14_error;
        }
      }

      /* "lark_cython/lark_cython.pyx":342
 *             lexer = self.lexers[parser_state.position]
 *             return lexer.next_token(lexer_state, parser_state)
 *         except UnexpectedCharacters as e:             # <<<<<<<<<<<<<<
 *             # In the contextual lexer, UnexpectedCharacters can mean that the terminal is defined, but not in the current context.
 *             # This tests the input against the global context, to provide a nicer error.
 */
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_5 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e);
            __pyx_v_e = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          }
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "lark_cython/lark_cython.pyx":339
 *         cdef Token last_token
 *         cdef Token token
 *         try:             # <<<<<<<<<<<<<<
 *             lexer = self.lexers[parser_state.position]
 *             return lexer.next_token(lexer_state, parser_state)
 */
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L0;
  }

  /* "lark_cython/lark_cython.pyx":335
 *         return self.root_lexer.make_lexer_state(text)
 * 
 *     cpdef public next_token(self, LexerState lexer_state, ParserState parser_state):             # <<<<<<<<<<<<<<
 *         cdef BasicLexer lexer
 *         cdef Token last_token
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_lexer);
  __Pyx_XDECREF((PyObject *)__pyx_v_last_token);
  __Pyx_XDECREF((PyObject *)__pyx_v_token);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_5next_token(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_5next_token(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lexer_state = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("next_token (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lexer_state,&__pyx_n_s_parser_state,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lexer_state)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parser_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("next_token", 1, 2, 2, 1); __PYX_ERR(0, 335, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "next_token") < 0)) __PYX_ERR(0, 335, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_lexer_state = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)values[0]);
    __pyx_v_parser_state = ((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("next_token", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 335, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_lexer_state), __pyx_ptype_11lark_cython_11lark_cython_LexerState, 1, "lexer_state", 0))) __PYX_ERR(0, 335, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_parser_state), __pyx_ptype_11lark_cython_11lark_cython_ParserState, 1, "parser_state", 0))) __PYX_ERR(0, 335, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_4next_token(((struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)__pyx_v_self), __pyx_v_lexer_state, __pyx_v_parser_state);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_4next_token(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *__pyx_v_lexer_state, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_token", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython_15ContextualLexer_next_token(__pyx_v_self, __pyx_v_lexer_state, __pyx_v_parser_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_6__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_8__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ContextualLexer_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ContextualLexer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":359
 *     cdef object state
 * 
 *     def __cinit__(self, lexer, text):             # <<<<<<<<<<<<<<
 *         self.lexer = lexer
 *         self.state = lexer.make_lexer_state(text)
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11LexerThread_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11LexerThread_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_lexer = 0;
  PyObject *__pyx_v_text = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lexer,&__pyx_n_s_text,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lexer)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_text)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(0, 359, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 359, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_lexer = values[0];
    __pyx_v_text = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 359, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerThread.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LexerThread___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)__pyx_v_self), __pyx_v_lexer, __pyx_v_text);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11LexerThread___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_text) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":360
 * 
 *     def __cinit__(self, lexer, text):
 *         self.lexer = lexer             # <<<<<<<<<<<<<<
 *         self.state = lexer.make_lexer_state(text)
 * 
 */
  if (!(likely(((__pyx_v_lexer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_lexer, __pyx_ptype_11lark_cython_11lark_cython_Lexer))))) __PYX_ERR(0, 360, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_lexer;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->lexer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->lexer));
  __pyx_v_self->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":361
 *     def __cinit__(self, lexer, text):
 *         self.lexer = lexer
 *         self.state = lexer.make_lexer_state(text)             # <<<<<<<<<<<<<<
 * 
 *     cdef next_token(self, ParserState parser_state):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_lexer, __pyx_n_s_make_lexer_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_text);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->state);
  __Pyx_DECREF(__pyx_v_self->state);
  __pyx_v_self->state = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":359
 *     cdef object state
 * 
 *     def __cinit__(self, lexer, text):             # <<<<<<<<<<<<<<
 *         self.lexer = lexer
 *         self.state = lexer.make_lexer_state(text)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerThread.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":363
 *         self.state = lexer.make_lexer_state(text)
 * 
 *     cdef next_token(self, ParserState parser_state):             # <<<<<<<<<<<<<<
 *         return self.lexer.next_token(self.state, parser_state)
 * 
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_11LexerThread_next_token(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_token", 0);

  /* "lark_cython/lark_cython.pyx":364
 * 
 *     cdef next_token(self, ParserState parser_state):
 *         return self.lexer.next_token(self.state, parser_state)             # <<<<<<<<<<<<<<
 * 
 *     def __copy__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->lexer), __pyx_n_s_next_token); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_self->state, ((PyObject *)__pyx_v_parser_state)};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_self->state, ((PyObject *)__pyx_v_parser_state)};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_self->state);
    __Pyx_GIVEREF(__pyx_v_self->state);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_self->state);
    __Pyx_INCREF(((PyObject *)__pyx_v_parser_state));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_parser_state));
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, ((PyObject *)__pyx_v_parser_state));
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":363
 *         self.state = lexer.make_lexer_state(text)
 * 
 *     cdef next_token(self, ParserState parser_state):             # <<<<<<<<<<<<<<
 *         return self.lexer.next_token(self.state, parser_state)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerThread.next_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":366
 *         return self.lexer.next_token(self.state, parser_state)
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         copied = object.__new__(LexerThread)
 *         copied.lexer = self.lexer
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LexerThread_3__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LexerThread_3__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__copy__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LexerThread_2__copy__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LexerThread_2__copy__(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self) {
  PyObject *__pyx_v_copied = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__copy__", 0);

  /* "lark_cython/lark_cython.pyx":367
 * 
 *     def __copy__(self):
 *         copied = object.__new__(LexerThread)             # <<<<<<<<<<<<<<
 *         copied.lexer = self.lexer
 *         copied.state = copy(self.state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LexerThread)) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LexerThread));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_copied = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":368
 *     def __copy__(self):
 *         copied = object.__new__(LexerThread)
 *         copied.lexer = self.lexer             # <<<<<<<<<<<<<<
 *         copied.state = copy(self.state)
 *         return copied
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->lexer);
  __Pyx_INCREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_copied, __pyx_n_s_lexer, __pyx_t_1) < 0) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":369
 *         copied = object.__new__(LexerThread)
 *         copied.lexer = self.lexer
 *         copied.state = copy(self.state)             # <<<<<<<<<<<<<<
 *         return copied
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_self->state) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->state);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_copied, __pyx_n_s_state, __pyx_t_1) < 0) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":370
 *         copied.lexer = self.lexer
 *         copied.state = copy(self.state)
 *         return copied             # <<<<<<<<<<<<<<
 * 
 * ####
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_copied);
  __pyx_r = __pyx_v_copied;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":366
 *         return self.lexer.next_token(self.state, parser_state)
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         copied = object.__new__(LexerThread)
 *         copied.lexer = self.lexer
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerThread.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_copied);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LexerThread_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LexerThread_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LexerThread_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LexerThread_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerThread.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LexerThread_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LexerThread_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LexerThread_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LexerThread_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.LexerThread.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":391
 *     cdef str start
 * 
 *     def __init__(self, parse_table, callbacks, start):             # <<<<<<<<<<<<<<
 *         self.parse_table = parse_table
 * 
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_9ParseConf_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_9ParseConf_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_parse_table = 0;
  PyObject *__pyx_v_callbacks = 0;
  PyObject *__pyx_v_start = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_parse_table,&__pyx_n_s_callbacks,&__pyx_n_s_start,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parse_table)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callbacks)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(0, 391, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(0, 391, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 391, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_parse_table = values[0];
    __pyx_v_callbacks = values[1];
    __pyx_v_start = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 391, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseConf.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_9ParseConf___init__(((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_v_self), __pyx_v_parse_table, __pyx_v_callbacks, __pyx_v_start);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_9ParseConf___init__(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_self, PyObject *__pyx_v_parse_table, PyObject *__pyx_v_callbacks, PyObject *__pyx_v_start) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":392
 * 
 *     def __init__(self, parse_table, callbacks, start):
 *         self.parse_table = parse_table             # <<<<<<<<<<<<<<
 * 
 *         self.start_state = self.parse_table.start_states[start]
 */
  __Pyx_INCREF(__pyx_v_parse_table);
  __Pyx_GIVEREF(__pyx_v_parse_table);
  __Pyx_GOTREF(__pyx_v_self->parse_table);
  __Pyx_DECREF(__pyx_v_self->parse_table);
  __pyx_v_self->parse_table = __pyx_v_parse_table;

  /* "lark_cython/lark_cython.pyx":394
 *         self.parse_table = parse_table
 * 
 *         self.start_state = self.parse_table.start_states[start]             # <<<<<<<<<<<<<<
 *         self.end_state = self.parse_table.end_states[start]
 *         self.states = self.parse_table.states
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->parse_table, __pyx_n_s_start_states); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->start_state = __pyx_t_3;

  /* "lark_cython/lark_cython.pyx":395
 * 
 *         self.start_state = self.parse_table.start_states[start]
 *         self.end_state = self.parse_table.end_states[start]             # <<<<<<<<<<<<<<
 *         self.states = self.parse_table.states
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->parse_table, __pyx_n_s_end_states); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_start); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->end_state = __pyx_t_3;

  /* "lark_cython/lark_cython.pyx":396
 *         self.start_state = self.parse_table.start_states[start]
 *         self.end_state = self.parse_table.end_states[start]
 *         self.states = self.parse_table.states             # <<<<<<<<<<<<<<
 * 
 *         self.callbacks = callbacks
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->parse_table, __pyx_n_s_states); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->states);
  __Pyx_DECREF(__pyx_v_self->states);
  __pyx_v_self->states = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":398
 *         self.states = self.parse_table.states
 * 
 *         self.callbacks = callbacks             # <<<<<<<<<<<<<<
 *         self.start = start
 * 
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_callbacks))||((__pyx_v_callbacks) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_callbacks)->tp_name), 0))) __PYX_ERR(0, 398, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_callbacks;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->callbacks);
  __Pyx_DECREF(__pyx_v_self->callbacks);
  __pyx_v_self->callbacks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":399
 * 
 *         self.callbacks = callbacks
 *         self.start = start             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_start))||((__pyx_v_start) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_start)->tp_name), 0))) __PYX_ERR(0, 399, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_start;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->start);
  __Pyx_DECREF(__pyx_v_self->start);
  __pyx_v_self->start = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":391
 *     cdef str start
 * 
 *     def __init__(self, parse_table, callbacks, start):             # <<<<<<<<<<<<<<
 *         self.parse_table = parse_table
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseConf.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_9ParseConf_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_9ParseConf_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_9ParseConf_2__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_9ParseConf_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.callbacks, self.end_state, self.parse_table, self.start, self.start_state, self.states)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->end_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->start_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->callbacks);
  __Pyx_GIVEREF(__pyx_v_self->callbacks);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->callbacks);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->parse_table);
  __Pyx_GIVEREF(__pyx_v_self->parse_table);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_self->parse_table);
  __Pyx_INCREF(__pyx_v_self->start);
  __Pyx_GIVEREF(__pyx_v_self->start);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_self->start);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->states);
  __Pyx_GIVEREF(__pyx_v_self->states);
  PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_v_self->states);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.callbacks, self.end_state, self.parse_table, self.start, self.start_state, self.states)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":7
 *     state = (self.callbacks, self.end_state, self.parse_table, self.start, self.start_state, self.states)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.callbacks is not None or self.parse_table is not None or self.start is not None or self.states is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.callbacks, self.end_state, self.parse_table, self.start, self.start_state, self.states)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.callbacks is not None or self.parse_table is not None or self.start is not None or self.states is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, None), state
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->callbacks != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->parse_table != Py_None);
    __pyx_t_4 = (__pyx_t_6 != 0);
    if (!__pyx_t_4) {
    } else {
      __pyx_t_5 = __pyx_t_4;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_self->start != ((PyObject*)Py_None));
    __pyx_t_6 = (__pyx_t_4 != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->states != ((PyObject*)Py_None));
    __pyx_t_4 = (__pyx_t_6 != 0);
    __pyx_t_5 = __pyx_t_4;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_5;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.callbacks is not None or self.parse_table is not None or self.start is not None or self.states is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, None), state
 *     else:
 */
  __pyx_t_5 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_5) {

    /* "(tree fragment)":13
 *         use_setstate = self.callbacks is not None or self.parse_table is not None or self.start is not None or self.states is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pyx_unpickle_ParseConf); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_141903276);
    __Pyx_GIVEREF(__pyx_int_141903276);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_141903276);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.callbacks is not None or self.parse_table is not None or self.start is not None or self.states is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, None), state
 *     else:
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ParseConf__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_ParseConf); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_141903276);
    __Pyx_GIVEREF(__pyx_int_141903276);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_141903276);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseConf.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ParseConf__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_9ParseConf_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_9ParseConf_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_9ParseConf_4__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_9ParseConf_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ParseConf__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParseConf__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ParseConf, (type(self), 0x87545ac, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ParseConf__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseConf.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":409
 *     cdef list value_stack, state_stack
 * 
 *     def __init__(self, parse_conf, lexer, state_stack=None, value_stack=None):             # <<<<<<<<<<<<<<
 *         self.parse_conf = parse_conf
 *         self.lexer = lexer
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11ParserState_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11ParserState_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_parse_conf = 0;
  PyObject *__pyx_v_lexer = 0;
  PyObject *__pyx_v_state_stack = 0;
  PyObject *__pyx_v_value_stack = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_parse_conf,&__pyx_n_s_lexer,&__pyx_n_s_state_stack,&__pyx_n_s_value_stack,0};
    PyObject* values[4] = {0,0,0,0};
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parse_conf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lexer)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, 1); __PYX_ERR(0, 409, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_state_stack);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value_stack);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 409, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_parse_conf = values[0];
    __pyx_v_lexer = values[1];
    __pyx_v_state_stack = values[2];
    __pyx_v_value_stack = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 409, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState___init__(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self), __pyx_v_parse_conf, __pyx_v_lexer, __pyx_v_state_stack, __pyx_v_value_stack);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11ParserState___init__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, PyObject *__pyx_v_parse_conf, PyObject *__pyx_v_lexer, PyObject *__pyx_v_state_stack, PyObject *__pyx_v_value_stack) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":410
 * 
 *     def __init__(self, parse_conf, lexer, state_stack=None, value_stack=None):
 *         self.parse_conf = parse_conf             # <<<<<<<<<<<<<<
 *         self.lexer = lexer
 *         self.state_stack = state_stack or [self.parse_conf.start_state]
 */
  if (!(likely(((__pyx_v_parse_conf) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_parse_conf, __pyx_ptype_11lark_cython_11lark_cython_ParseConf))))) __PYX_ERR(0, 410, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_parse_conf;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->parse_conf);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->parse_conf));
  __pyx_v_self->parse_conf = ((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":411
 *     def __init__(self, parse_conf, lexer, state_stack=None, value_stack=None):
 *         self.parse_conf = parse_conf
 *         self.lexer = lexer             # <<<<<<<<<<<<<<
 *         self.state_stack = state_stack or [self.parse_conf.start_state]
 *         self.value_stack = value_stack or []
 */
  if (!(likely(((__pyx_v_lexer) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_lexer, __pyx_ptype_11lark_cython_11lark_cython_LexerThread))))) __PYX_ERR(0, 411, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_lexer;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->lexer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->lexer));
  __pyx_v_self->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":412
 *         self.parse_conf = parse_conf
 *         self.lexer = lexer
 *         self.state_stack = state_stack or [self.parse_conf.start_state]             # <<<<<<<<<<<<<<
 *         self.value_stack = value_stack or []
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_state_stack); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 412, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    if (!(likely(PyList_CheckExact(__pyx_v_state_stack))||((__pyx_v_state_stack) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_state_stack)->tp_name), 0))) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_state_stack);
    __pyx_t_1 = __pyx_v_state_stack;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->parse_conf->start_state); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L3_bool_binop_done:;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->state_stack);
  __Pyx_DECREF(__pyx_v_self->state_stack);
  __pyx_v_self->state_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":413
 *         self.lexer = lexer
 *         self.state_stack = state_stack or [self.parse_conf.start_state]
 *         self.value_stack = value_stack or []             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_value_stack); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 413, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    if (!(likely(PyList_CheckExact(__pyx_v_value_stack))||((__pyx_v_value_stack) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value_stack)->tp_name), 0))) __PYX_ERR(0, 413, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_value_stack);
    __pyx_t_1 = __pyx_v_value_stack;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L5_bool_binop_done:;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->value_stack);
  __Pyx_DECREF(__pyx_v_self->value_stack);
  __pyx_v_self->value_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":409
 *     cdef list value_stack, state_stack
 * 
 *     def __init__(self, parse_conf, lexer, state_stack=None, value_stack=None):             # <<<<<<<<<<<<<<
 *         self.parse_conf = parse_conf
 *         self.lexer = lexer
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":416
 * 
 *     @property
 *     def position(self):             # <<<<<<<<<<<<<<
 *         return self.state_stack[-1]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_8position_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_8position_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState_8position___get__(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_8position___get__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "lark_cython/lark_cython.pyx":417
 *     @property
 *     def position(self):
 *         return self.state_stack[-1]             # <<<<<<<<<<<<<<
 * 
 *     # Necessary for match_examples() to work
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->state_stack == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 417, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->state_stack, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":416
 * 
 *     @property
 *     def position(self):             # <<<<<<<<<<<<<<
 *         return self.state_stack[-1]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.position.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":420
 * 
 *     # Necessary for match_examples() to work
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserState):
 *             return NotImplemented
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState_2__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_2__eq__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "lark_cython/lark_cython.pyx":421
 *     # Necessary for match_examples() to work
 *     def __eq__(self, other):
 *         if not isinstance(other, ParserState):             # <<<<<<<<<<<<<<
 *             return NotImplemented
 *         return len(self.state_stack) == len(other.state_stack) and self.position == other.position
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_11lark_cython_11lark_cython_ParserState); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":422
 *     def __eq__(self, other):
 *         if not isinstance(other, ParserState):
 *             return NotImplemented             # <<<<<<<<<<<<<<
 *         return len(self.state_stack) == len(other.state_stack) and self.position == other.position
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_builtin_NotImplemented);
    __pyx_r = __pyx_builtin_NotImplemented;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":421
 *     # Necessary for match_examples() to work
 *     def __eq__(self, other):
 *         if not isinstance(other, ParserState):             # <<<<<<<<<<<<<<
 *             return NotImplemented
 *         return len(self.state_stack) == len(other.state_stack) and self.position == other.position
 */
  }

  /* "lark_cython/lark_cython.pyx":423
 *         if not isinstance(other, ParserState):
 *             return NotImplemented
 *         return len(self.state_stack) == len(other.state_stack) and self.position == other.position             # <<<<<<<<<<<<<<
 * 
 *     def __copy__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_self->state_stack;
  __Pyx_INCREF(__pyx_t_4);
  if (unlikely(__pyx_t_4 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 423, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_4); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_state_stack); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (__pyx_t_5 == __pyx_t_6);
  if (__pyx_t_2) {
  } else {
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_position); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_position); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = PyObject_RichCompare(__pyx_t_4, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_3 = __pyx_t_8;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":420
 * 
 *     # Necessary for match_examples() to work
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, ParserState):
 *             return NotImplemented
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":425
 *         return len(self.state_stack) == len(other.state_stack) and self.position == other.position
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         return type(self)(
 *             self.parse_conf,
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_5__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_5__copy__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__copy__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState_4__copy__(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_4__copy__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__copy__", 0);

  /* "lark_cython/lark_cython.pyx":426
 * 
 *     def __copy__(self):
 *         return type(self)(             # <<<<<<<<<<<<<<
 *             self.parse_conf,
 *             self.lexer, # XXX copy
 */
  __Pyx_XDECREF(__pyx_r);

  /* "lark_cython/lark_cython.pyx":429
 *             self.parse_conf,
 *             self.lexer, # XXX copy
 *             copy(self.state_stack),             # <<<<<<<<<<<<<<
 *             deepcopy(self.value_stack),
 *         )
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_self->state_stack) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_self->state_stack);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "lark_cython/lark_cython.pyx":430
 *             self.lexer, # XXX copy
 *             copy(self.state_stack),
 *             deepcopy(self.value_stack),             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_self->value_stack) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_self->value_stack);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __pyx_t_4 = ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))); __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[5] = {__pyx_t_5, ((PyObject *)__pyx_v_self->parse_conf), ((PyObject *)__pyx_v_self->lexer), __pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[5] = {__pyx_t_5, ((PyObject *)__pyx_v_self->parse_conf), ((PyObject *)__pyx_v_self->lexer), __pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 4+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(4+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_self->parse_conf));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self->parse_conf));
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, ((PyObject *)__pyx_v_self->parse_conf));
    __Pyx_INCREF(((PyObject *)__pyx_v_self->lexer));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self->lexer));
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_v_self->lexer));
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_6, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 3+__pyx_t_6, __pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":425
 *         return len(self.state_stack) == len(other.state_stack) and self.position == other.position
 * 
 *     def __copy__(self):             # <<<<<<<<<<<<<<
 *         return type(self)(
 *             self.parse_conf,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.__copy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":433
 *         )
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         return copy(self)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_7copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_7copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState_6copy(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_6copy(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "lark_cython/lark_cython.pyx":434
 * 
 *     def copy(self):
 *         return copy(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef feed_token(self, Token token, bint is_end=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, ((PyObject *)__pyx_v_self)) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)__pyx_v_self));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":433
 *         )
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         return copy(self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":436
 *         return copy(self)
 * 
 *     cdef feed_token(self, Token token, bint is_end=False):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list state_stack = self.state_stack
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_11ParserState_feed_token(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_token, struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token *__pyx_optional_args) {
  int __pyx_v_is_end = ((int)0);
  PyObject *__pyx_v_state_stack = 0;
  PyObject *__pyx_v_value_stack = 0;
  PyObject *__pyx_v_states = 0;
  int __pyx_v_end_state;
  PyObject *__pyx_v_callbacks = 0;
  int __pyx_v_state;
  int __pyx_v_new_state;
  PyObject *__pyx_v_action = 0;
  PyObject *__pyx_v__action = 0;
  PyObject *__pyx_v_arg = 0;
  int __pyx_v_size;
  PyObject *__pyx_v_s = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_rule = 0;
  PyObject *__pyx_v_expected = NULL;
  PyObject *__pyx_8genexpr8__pyx_v_s = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("feed_token", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_is_end = __pyx_optional_args->is_end;
    }
  }

  /* "lark_cython/lark_cython.pyx":438
 *     cdef feed_token(self, Token token, bint is_end=False):
 *         cdef:
 *             list state_stack = self.state_stack             # <<<<<<<<<<<<<<
 *             list value_stack = self.value_stack
 *             dict states = self.parse_conf.states
 */
  __pyx_t_1 = __pyx_v_self->state_stack;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_state_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":439
 *         cdef:
 *             list state_stack = self.state_stack
 *             list value_stack = self.value_stack             # <<<<<<<<<<<<<<
 *             dict states = self.parse_conf.states
 *             int end_state = self.parse_conf.end_state
 */
  __pyx_t_1 = __pyx_v_self->value_stack;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_value_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":440
 *             list state_stack = self.state_stack
 *             list value_stack = self.value_stack
 *             dict states = self.parse_conf.states             # <<<<<<<<<<<<<<
 *             int end_state = self.parse_conf.end_state
 *             dict callbacks = self.parse_conf.callbacks
 */
  __pyx_t_1 = __pyx_v_self->parse_conf->states;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_states = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":441
 *             list value_stack = self.value_stack
 *             dict states = self.parse_conf.states
 *             int end_state = self.parse_conf.end_state             # <<<<<<<<<<<<<<
 *             dict callbacks = self.parse_conf.callbacks
 * 
 */
  __pyx_t_2 = __pyx_v_self->parse_conf->end_state;
  __pyx_v_end_state = __pyx_t_2;

  /* "lark_cython/lark_cython.pyx":442
 *             dict states = self.parse_conf.states
 *             int end_state = self.parse_conf.end_state
 *             dict callbacks = self.parse_conf.callbacks             # <<<<<<<<<<<<<<
 * 
 *             int state, new_state
 */
  __pyx_t_1 = __pyx_v_self->parse_conf->callbacks;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_callbacks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":453
 * 
 * 
 *         while True:             # <<<<<<<<<<<<<<
 *             state = state_stack[-1]
 *             try:
 */
  while (1) {

    /* "lark_cython/lark_cython.pyx":454
 * 
 *         while True:
 *             state = state_stack[-1]             # <<<<<<<<<<<<<<
 *             try:
 *                 action, arg = states[state][token.type]
 */
    if (unlikely(__pyx_v_state_stack == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 454, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_state_stack, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 454, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 454, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_state = __pyx_t_2;

    /* "lark_cython/lark_cython.pyx":455
 *         while True:
 *             state = state_stack[-1]
 *             try:             # <<<<<<<<<<<<<<
 *                 action, arg = states[state][token.type]
 *             except KeyError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":456
 *             state = state_stack[-1]
 *             try:
 *                 action, arg = states[state][token.type]             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 expected = {s for s in states[state].keys() if s.isupper()}
 */
        if (unlikely(__pyx_v_states == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 456, __pyx_L5_error)
        }
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_states, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 456, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_6, __pyx_v_token->type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 456, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 456, __pyx_L5_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          #else
          __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 456, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 456, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
          index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L13_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) __PYX_ERR(0, 456, __pyx_L5_error)
          __pyx_t_9 = NULL;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L14_unpacking_done;
          __pyx_L13_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 456, __pyx_L5_error)
          __pyx_L14_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_action, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "lark_cython/lark_cython.pyx":455
 *         while True:
 *             state = state_stack[-1]
 *             try:             # <<<<<<<<<<<<<<
 *                 action, arg = states[state][token.type]
 *             except KeyError:
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":457
 *             try:
 *                 action, arg = states[state][token.type]
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 expected = {s for s in states[state].keys() if s.isupper()}
 *                 raise UnexpectedToken(token, expected, state=self, interactive_parser=None)
 */
      __pyx_t_2 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_2) {
        __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.feed_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(0, 457, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_6);

        /* "lark_cython/lark_cython.pyx":458
 *                 action, arg = states[state][token.type]
 *             except KeyError:
 *                 expected = {s for s in states[state].keys() if s.isupper()}             # <<<<<<<<<<<<<<
 *                 raise UnexpectedToken(token, expected, state=self, interactive_parser=None)
 * 
 */
        { /* enter inner scope */
          __pyx_t_8 = PySet_New(NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 458, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_11 = 0;
          if (unlikely(__pyx_v_states == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 458, __pyx_L19_error)
          }
          __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_state); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 458, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_states, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 458, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(__pyx_t_14 == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "keys");
            __PYX_ERR(0, 458, __pyx_L19_error)
          }
          __pyx_t_13 = __Pyx_dict_iterator(__pyx_t_14, 0, __pyx_n_s_keys, (&__pyx_t_12), (&__pyx_t_2)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 458, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_10);
          __pyx_t_10 = __pyx_t_13;
          __pyx_t_13 = 0;
          while (1) {
            __pyx_t_15 = __Pyx_dict_iter_next(__pyx_t_10, __pyx_t_12, &__pyx_t_11, &__pyx_t_13, NULL, NULL, __pyx_t_2);
            if (unlikely(__pyx_t_15 == 0)) break;
            if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(0, 458, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_13);
            if (!(likely(PyList_CheckExact(__pyx_t_13))||((__pyx_t_13) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_13)->tp_name), 0))) __PYX_ERR(0, 458, __pyx_L19_error)
            __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_s, ((PyObject*)__pyx_t_13));
            __pyx_t_13 = 0;
            __pyx_t_13 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_isupper, __pyx_8genexpr8__pyx_v_s); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 458, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 458, __pyx_L19_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (__pyx_t_16) {
              if (unlikely(PySet_Add(__pyx_t_8, (PyObject*)__pyx_8genexpr8__pyx_v_s))) __PYX_ERR(0, 458, __pyx_L19_error)
            }
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_s); __pyx_8genexpr8__pyx_v_s = 0;
          goto __pyx_L23_exit_scope;
          __pyx_L19_error:;
          __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_s); __pyx_8genexpr8__pyx_v_s = 0;
          goto __pyx_L7_except_error;
          __pyx_L23_exit_scope:;
        } /* exit inner scope */
        __pyx_v_expected = ((PyObject*)__pyx_t_8);
        __pyx_t_8 = 0;

        /* "lark_cython/lark_cython.pyx":459
 *             except KeyError:
 *                 expected = {s for s in states[state].keys() if s.isupper()}
 *                 raise UnexpectedToken(token, expected, state=self, interactive_parser=None)             # <<<<<<<<<<<<<<
 * 
 *             assert arg != end_state
 */
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 459, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 459, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(((PyObject *)__pyx_v_token));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_token));
        PyTuple_SET_ITEM(__pyx_t_10, 0, ((PyObject *)__pyx_v_token));
        __Pyx_INCREF(__pyx_v_expected);
        __Pyx_GIVEREF(__pyx_v_expected);
        PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_v_expected);
        __pyx_t_13 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 459, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_state, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(0, 459, __pyx_L7_except_error)
        if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_interactive_parser, Py_None) < 0) __PYX_ERR(0, 459, __pyx_L7_except_error)
        __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 459, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_Raise(__pyx_t_14, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __PYX_ERR(0, 459, __pyx_L7_except_error)
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "lark_cython/lark_cython.pyx":455
 *         while True:
 *             state = state_stack[-1]
 *             try:             # <<<<<<<<<<<<<<
 *                 action, arg = states[state][token.type]
 *             except KeyError:
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L12_try_end:;
    }

    /* "lark_cython/lark_cython.pyx":461
 *                 raise UnexpectedToken(token, expected, state=self, interactive_parser=None)
 * 
 *             assert arg != end_state             # <<<<<<<<<<<<<<
 * 
 *             if action is Shift:
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_end_state); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 461, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_arg, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 461, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 461, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_16)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 461, __pyx_L1_error)
      }
    }
    #endif

    /* "lark_cython/lark_cython.pyx":463
 *             assert arg != end_state
 * 
 *             if action is Shift:             # <<<<<<<<<<<<<<
 *                 # shift once and return
 *                 assert not is_end
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_Shift); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_16 = (__pyx_v_action == __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_17 = (__pyx_t_16 != 0);
    if (__pyx_t_17) {

      /* "lark_cython/lark_cython.pyx":465
 *             if action is Shift:
 *                 # shift once and return
 *                 assert not is_end             # <<<<<<<<<<<<<<
 *                 state_stack.append(arg)
 *                 value_stack.append(token if token.type not in callbacks else callbacks[token.type](token))
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        if (unlikely(!((!(__pyx_v_is_end != 0)) != 0))) {
          PyErr_SetNone(PyExc_AssertionError);
          __PYX_ERR(0, 465, __pyx_L1_error)
        }
      }
      #endif

      /* "lark_cython/lark_cython.pyx":466
 *                 # shift once and return
 *                 assert not is_end
 *                 state_stack.append(arg)             # <<<<<<<<<<<<<<
 *                 value_stack.append(token if token.type not in callbacks else callbacks[token.type](token))
 *                 return
 */
      if (unlikely(__pyx_v_state_stack == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 466, __pyx_L1_error)
      }
      __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_state_stack, __pyx_v_arg); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 466, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":467
 *                 assert not is_end
 *                 state_stack.append(arg)
 *                 value_stack.append(token if token.type not in callbacks else callbacks[token.type](token))             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
      if (unlikely(__pyx_v_value_stack == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 467, __pyx_L1_error)
      }
      if (unlikely(__pyx_v_callbacks == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
        __PYX_ERR(0, 467, __pyx_L1_error)
      }
      __pyx_t_17 = (__Pyx_PyDict_ContainsTF(__pyx_v_token->type, __pyx_v_callbacks, Py_NE)); if (unlikely(__pyx_t_17 < 0)) __PYX_ERR(0, 467, __pyx_L1_error)
      if ((__pyx_t_17 != 0)) {
        __Pyx_INCREF(((PyObject *)__pyx_v_token));
        __pyx_t_7 = ((PyObject *)__pyx_v_token);
      } else {
        if (unlikely(__pyx_v_callbacks == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 467, __pyx_L1_error)
        }
        __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_callbacks, __pyx_v_token->type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_6 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_14, ((PyObject *)__pyx_v_token)) : __Pyx_PyObject_CallOneArg(__pyx_t_1, ((PyObject *)__pyx_v_token));
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = __pyx_t_6;
        __pyx_t_6 = 0;
      }
      __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_value_stack, __pyx_t_7); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 467, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":468
 *                 state_stack.append(arg)
 *                 value_stack.append(token if token.type not in callbacks else callbacks[token.type](token))
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 # reduce+shift as many times as necessary
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "lark_cython/lark_cython.pyx":463
 *             assert arg != end_state
 * 
 *             if action is Shift:             # <<<<<<<<<<<<<<
 *                 # shift once and return
 *                 assert not is_end
 */
    }

    /* "lark_cython/lark_cython.pyx":471
 *             else:
 *                 # reduce+shift as many times as necessary
 *                 rule = arg             # <<<<<<<<<<<<<<
 *                 size = len(rule.expansion)
 *                 if size:
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_arg);
      __Pyx_XDECREF_SET(__pyx_v_rule, __pyx_v_arg);

      /* "lark_cython/lark_cython.pyx":472
 *                 # reduce+shift as many times as necessary
 *                 rule = arg
 *                 size = len(rule.expansion)             # <<<<<<<<<<<<<<
 *                 if size:
 *                     s = value_stack[-size:]
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rule, __pyx_n_s_expansion); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = PyObject_Length(__pyx_t_7); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 472, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_size = __pyx_t_12;

      /* "lark_cython/lark_cython.pyx":473
 *                 rule = arg
 *                 size = len(rule.expansion)
 *                 if size:             # <<<<<<<<<<<<<<
 *                     s = value_stack[-size:]
 *                     del state_stack[-size:]
 */
      __pyx_t_17 = (__pyx_v_size != 0);
      if (__pyx_t_17) {

        /* "lark_cython/lark_cython.pyx":474
 *                 size = len(rule.expansion)
 *                 if size:
 *                     s = value_stack[-size:]             # <<<<<<<<<<<<<<
 *                     del state_stack[-size:]
 *                     del value_stack[-size:]
 */
        if (unlikely(__pyx_v_value_stack == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 474, __pyx_L1_error)
        }
        __pyx_t_7 = __Pyx_PyList_GetSlice(__pyx_v_value_stack, (-__pyx_v_size), PY_SSIZE_T_MAX); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 474, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_XDECREF_SET(__pyx_v_s, ((PyObject*)__pyx_t_7));
        __pyx_t_7 = 0;

        /* "lark_cython/lark_cython.pyx":475
 *                 if size:
 *                     s = value_stack[-size:]
 *                     del state_stack[-size:]             # <<<<<<<<<<<<<<
 *                     del value_stack[-size:]
 *                 else:
 */
        if (unlikely(__pyx_v_state_stack == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 475, __pyx_L1_error)
        }
        if (__Pyx_PyObject_DelSlice(__pyx_v_state_stack, (-__pyx_v_size), 0, NULL, NULL, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 475, __pyx_L1_error)

        /* "lark_cython/lark_cython.pyx":476
 *                     s = value_stack[-size:]
 *                     del state_stack[-size:]
 *                     del value_stack[-size:]             # <<<<<<<<<<<<<<
 *                 else:
 *                     s = []
 */
        if (unlikely(__pyx_v_value_stack == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 476, __pyx_L1_error)
        }
        if (__Pyx_PyObject_DelSlice(__pyx_v_value_stack, (-__pyx_v_size), 0, NULL, NULL, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 476, __pyx_L1_error)

        /* "lark_cython/lark_cython.pyx":473
 *                 rule = arg
 *                 size = len(rule.expansion)
 *                 if size:             # <<<<<<<<<<<<<<
 *                     s = value_stack[-size:]
 *                     del state_stack[-size:]
 */
        goto __pyx_L25;
      }

      /* "lark_cython/lark_cython.pyx":478
 *                     del value_stack[-size:]
 *                 else:
 *                     s = []             # <<<<<<<<<<<<<<
 * 
 *                 value = callbacks[rule](s)
 */
      /*else*/ {
        __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 478, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_XDECREF_SET(__pyx_v_s, ((PyObject*)__pyx_t_7));
        __pyx_t_7 = 0;
      }
      __pyx_L25:;

      /* "lark_cython/lark_cython.pyx":480
 *                     s = []
 * 
 *                 value = callbacks[rule](s)             # <<<<<<<<<<<<<<
 * 
 *                 _action, new_state = states[state_stack[-1]][rule.origin.name]
 */
      if (unlikely(__pyx_v_callbacks == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 480, __pyx_L1_error)
      }
      __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_callbacks, __pyx_v_rule); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_7 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_1, __pyx_v_s) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_s);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":482
 *                 value = callbacks[rule](s)
 * 
 *                 _action, new_state = states[state_stack[-1]][rule.origin.name]             # <<<<<<<<<<<<<<
 *                 assert _action is Shift
 *                 state_stack.append(new_state)
 */
      if (unlikely(__pyx_v_states == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 482, __pyx_L1_error)
      }
      if (unlikely(__pyx_v_state_stack == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 482, __pyx_L1_error)
      }
      __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_state_stack, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_states, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rule, __pyx_n_s_origin); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
        PyObject* sequence = __pyx_t_7;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 482, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 482, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 482, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_14 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 482, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_9 = Py_TYPE(__pyx_t_14)->tp_iternext;
        index = 0; __pyx_t_1 = __pyx_t_9(__pyx_t_14); if (unlikely(!__pyx_t_1)) goto __pyx_L26_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_6 = __pyx_t_9(__pyx_t_14); if (unlikely(!__pyx_t_6)) goto __pyx_L26_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_14), 2) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        goto __pyx_L27_unpacking_done;
        __pyx_L26_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 482, __pyx_L1_error)
        __pyx_L27_unpacking_done:;
      }
      __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v__action, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_v_new_state = __pyx_t_2;

      /* "lark_cython/lark_cython.pyx":483
 * 
 *                 _action, new_state = states[state_stack[-1]][rule.origin.name]
 *                 assert _action is Shift             # <<<<<<<<<<<<<<
 *                 state_stack.append(new_state)
 *                 value_stack.append(value)
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_Shift); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_17 = (__pyx_v__action == __pyx_t_7);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!(__pyx_t_17 != 0))) {
          PyErr_SetNone(PyExc_AssertionError);
          __PYX_ERR(0, 483, __pyx_L1_error)
        }
      }
      #endif

      /* "lark_cython/lark_cython.pyx":484
 *                 _action, new_state = states[state_stack[-1]][rule.origin.name]
 *                 assert _action is Shift
 *                 state_stack.append(new_state)             # <<<<<<<<<<<<<<
 *                 value_stack.append(value)
 * 
 */
      if (unlikely(__pyx_v_state_stack == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 484, __pyx_L1_error)
      }
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_new_state); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_state_stack, __pyx_t_7); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 484, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":485
 *                 assert _action is Shift
 *                 state_stack.append(new_state)
 *                 value_stack.append(value)             # <<<<<<<<<<<<<<
 * 
 *                 if is_end and state_stack[-1] == end_state:
 */
      if (unlikely(__pyx_v_value_stack == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 485, __pyx_L1_error)
      }
      __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_value_stack, __pyx_v_value); if (unlikely(__pyx_t_18 == ((int)-1))) __PYX_ERR(0, 485, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":487
 *                 value_stack.append(value)
 * 
 *                 if is_end and state_stack[-1] == end_state:             # <<<<<<<<<<<<<<
 *                     return value_stack[-1]
 * 
 */
      __pyx_t_16 = (__pyx_v_is_end != 0);
      if (__pyx_t_16) {
      } else {
        __pyx_t_17 = __pyx_t_16;
        goto __pyx_L29_bool_binop_done;
      }
      if (unlikely(__pyx_v_state_stack == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 487, __pyx_L1_error)
      }
      __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_state_stack, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 487, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_end_state); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 487, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = PyObject_RichCompare(__pyx_t_7, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 487, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_16 < 0)) __PYX_ERR(0, 487, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_17 = __pyx_t_16;
      __pyx_L29_bool_binop_done:;
      if (__pyx_t_17) {

        /* "lark_cython/lark_cython.pyx":488
 * 
 *                 if is_end and state_stack[-1] == end_state:
 *                     return value_stack[-1]             # <<<<<<<<<<<<<<
 * 
 * cdef class _Parser:
 */
        __Pyx_XDECREF(__pyx_r);
        if (unlikely(__pyx_v_value_stack == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(0, 488, __pyx_L1_error)
        }
        __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_value_stack, -1L, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L0;

        /* "lark_cython/lark_cython.pyx":487
 *                 value_stack.append(value)
 * 
 *                 if is_end and state_stack[-1] == end_state:             # <<<<<<<<<<<<<<
 *                     return value_stack[-1]
 * 
 */
      }
    }
  }

  /* "lark_cython/lark_cython.pyx":436
 *         return copy(self)
 * 
 *     cdef feed_token(self, Token token, bint is_end=False):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list state_stack = self.state_stack
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.feed_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state_stack);
  __Pyx_XDECREF(__pyx_v_value_stack);
  __Pyx_XDECREF(__pyx_v_states);
  __Pyx_XDECREF(__pyx_v_callbacks);
  __Pyx_XDECREF(__pyx_v_action);
  __Pyx_XDECREF(__pyx_v__action);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_rule);
  __Pyx_XDECREF(__pyx_v_expected);
  __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState_8__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_8__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.lexer, self.parse_conf, self.state_stack, self.value_stack)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->lexer));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->lexer));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->lexer));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->parse_conf));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->parse_conf));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->parse_conf));
  __Pyx_INCREF(__pyx_v_self->state_stack);
  __Pyx_GIVEREF(__pyx_v_self->state_stack);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->state_stack);
  __Pyx_INCREF(__pyx_v_self->value_stack);
  __Pyx_GIVEREF(__pyx_v_self->value_stack);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_self->value_stack);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.lexer, self.parse_conf, self.state_stack, self.value_stack)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.lexer, self.parse_conf, self.state_stack, self.value_stack)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.lexer is not None or self.parse_conf is not None or self.state_stack is not None or self.value_stack is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.lexer, self.parse_conf, self.state_stack, self.value_stack)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.lexer is not None or self.parse_conf is not None or self.state_stack is not None or self.value_stack is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, None), state
 */
  /*else*/ {
    __pyx_t_2 = (((PyObject *)__pyx_v_self->lexer) != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (((PyObject *)__pyx_v_self->parse_conf) != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->state_stack != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->value_stack != ((PyObject*)Py_None));
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.lexer is not None or self.parse_conf is not None or self.state_stack is not None or self.value_stack is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.lexer is not None or self.parse_conf is not None or self.state_stack is not None or self.value_stack is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_ParserState); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_11743518);
    __Pyx_GIVEREF(__pyx_int_11743518);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_11743518);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.lexer is not None or self.parse_conf is not None or self.state_stack is not None or self.value_stack is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, None), state
 *     else:
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ParserState__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_ParserState); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_11743518);
    __Pyx_GIVEREF(__pyx_int_11743518);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_11743518);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ParserState__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ParserState_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ParserState_10__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ParserState_10__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ParserState__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParserState__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ParserState, (type(self), 0x0b3311e, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ParserState__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParserState.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":495
 *     cdef bint debug
 * 
 *     def __cinit__(self, parse_table, callbacks, debug=False):             # <<<<<<<<<<<<<<
 *         self.parse_table = parse_table
 *         self.callbacks = callbacks
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_7_Parser_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_7_Parser_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_parse_table = 0;
  PyObject *__pyx_v_callbacks = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_parse_table,&__pyx_n_s_callbacks,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parse_table)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callbacks)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(0, 495, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 495, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_parse_table = values[0];
    __pyx_v_callbacks = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 495, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7_Parser___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython__Parser *)__pyx_v_self), __pyx_v_parse_table, __pyx_v_callbacks, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_7_Parser___cinit__(struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, PyObject *__pyx_v_parse_table, PyObject *__pyx_v_callbacks, PyObject *__pyx_v_debug) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":496
 * 
 *     def __cinit__(self, parse_table, callbacks, debug=False):
 *         self.parse_table = parse_table             # <<<<<<<<<<<<<<
 *         self.callbacks = callbacks
 *         self.debug = debug
 */
  __Pyx_INCREF(__pyx_v_parse_table);
  __Pyx_GIVEREF(__pyx_v_parse_table);
  __Pyx_GOTREF(__pyx_v_self->parse_table);
  __Pyx_DECREF(__pyx_v_self->parse_table);
  __pyx_v_self->parse_table = __pyx_v_parse_table;

  /* "lark_cython/lark_cython.pyx":497
 *     def __cinit__(self, parse_table, callbacks, debug=False):
 *         self.parse_table = parse_table
 *         self.callbacks = callbacks             # <<<<<<<<<<<<<<
 *         self.debug = debug
 * 
 */
  if (!(likely(PyDict_CheckExact(__pyx_v_callbacks))||((__pyx_v_callbacks) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_callbacks)->tp_name), 0))) __PYX_ERR(0, 497, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_callbacks;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->callbacks);
  __Pyx_DECREF(__pyx_v_self->callbacks);
  __pyx_v_self->callbacks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":498
 *         self.parse_table = parse_table
 *         self.callbacks = callbacks
 *         self.debug = debug             # <<<<<<<<<<<<<<
 * 
 *     def parse(self, lexer, start, value_stack=None, state_stack=None, start_interactive=False):
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_debug); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 498, __pyx_L1_error)
  __pyx_v_self->debug = __pyx_t_2;

  /* "lark_cython/lark_cython.pyx":495
 *     cdef bint debug
 * 
 *     def __cinit__(self, parse_table, callbacks, debug=False):             # <<<<<<<<<<<<<<
 *         self.parse_table = parse_table
 *         self.callbacks = callbacks
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":500
 *         self.debug = debug
 * 
 *     def parse(self, lexer, start, value_stack=None, state_stack=None, start_interactive=False):             # <<<<<<<<<<<<<<
 *         parse_conf = ParseConf(self.parse_table, self.callbacks, start)
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7_Parser_3parse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7_Parser_3parse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_lexer = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_value_stack = 0;
  PyObject *__pyx_v_state_stack = 0;
  PyObject *__pyx_v_start_interactive = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lexer,&__pyx_n_s_start,&__pyx_n_s_value_stack,&__pyx_n_s_state_stack,&__pyx_n_s_start_interactive,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lexer)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse", 0, 2, 5, 1); __PYX_ERR(0, 500, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_value_stack);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_state_stack);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start_interactive);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse") < 0)) __PYX_ERR(0, 500, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_lexer = values[0];
    __pyx_v_start = values[1];
    __pyx_v_value_stack = values[2];
    __pyx_v_state_stack = values[3];
    __pyx_v_start_interactive = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse", 0, 2, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 500, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7_Parser_2parse(((struct __pyx_obj_11lark_cython_11lark_cython__Parser *)__pyx_v_self), __pyx_v_lexer, __pyx_v_start, __pyx_v_value_stack, __pyx_v_state_stack, __pyx_v_start_interactive);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7_Parser_2parse(struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_start, PyObject *__pyx_v_value_stack, PyObject *__pyx_v_state_stack, PyObject *__pyx_v_start_interactive) {
  struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v_parse_conf = NULL;
  struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_parser_state = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse", 0);

  /* "lark_cython/lark_cython.pyx":501
 * 
 *     def parse(self, lexer, start, value_stack=None, state_stack=None, start_interactive=False):
 *         parse_conf = ParseConf(self.parse_table, self.callbacks, start)             # <<<<<<<<<<<<<<
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)
 *         if start_interactive:
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->parse_table);
  __Pyx_GIVEREF(__pyx_v_self->parse_table);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->parse_table);
  __Pyx_INCREF(__pyx_v_self->callbacks);
  __Pyx_GIVEREF(__pyx_v_self->callbacks);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->callbacks);
  __Pyx_INCREF(__pyx_v_start);
  __Pyx_GIVEREF(__pyx_v_start);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_start);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ParseConf), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_parse_conf = ((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":502
 *     def parse(self, lexer, start, value_stack=None, state_stack=None, start_interactive=False):
 *         parse_conf = ParseConf(self.parse_table, self.callbacks, start)
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)             # <<<<<<<<<<<<<<
 *         if start_interactive:
 *             return InteractiveParser(self, parser_state, parser_state.lexer)
 */
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_parse_conf));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_parse_conf));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_parse_conf));
  __Pyx_INCREF(__pyx_v_lexer);
  __Pyx_GIVEREF(__pyx_v_lexer);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_lexer);
  __Pyx_INCREF(__pyx_v_state_stack);
  __Pyx_GIVEREF(__pyx_v_state_stack);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state_stack);
  __Pyx_INCREF(__pyx_v_value_stack);
  __Pyx_GIVEREF(__pyx_v_value_stack);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_value_stack);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ParserState), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_parser_state = ((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":503
 *         parse_conf = ParseConf(self.parse_table, self.callbacks, start)
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)
 *         if start_interactive:             # <<<<<<<<<<<<<<
 *             return InteractiveParser(self, parser_state, parser_state.lexer)
 *         return self.parse_from_state(parser_state)
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_start_interactive); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 503, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "lark_cython/lark_cython.pyx":504
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)
 *         if start_interactive:
 *             return InteractiveParser(self, parser_state, parser_state.lexer)             # <<<<<<<<<<<<<<
 *         return self.parse_from_state(parser_state)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_InteractiveParser); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_4, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_parser_state), ((PyObject *)__pyx_v_parser_state->lexer)};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[4] = {__pyx_t_4, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_parser_state), ((PyObject *)__pyx_v_parser_state->lexer)};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, ((PyObject *)__pyx_v_self));
      __Pyx_INCREF(((PyObject *)__pyx_v_parser_state));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_parser_state));
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, ((PyObject *)__pyx_v_parser_state));
      __Pyx_INCREF(((PyObject *)__pyx_v_parser_state->lexer));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_parser_state->lexer));
      PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_5, ((PyObject *)__pyx_v_parser_state->lexer));
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":503
 *         parse_conf = ParseConf(self.parse_table, self.callbacks, start)
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)
 *         if start_interactive:             # <<<<<<<<<<<<<<
 *             return InteractiveParser(self, parser_state, parser_state.lexer)
 *         return self.parse_from_state(parser_state)
 */
  }

  /* "lark_cython/lark_cython.pyx":505
 *         if start_interactive:
 *             return InteractiveParser(self, parser_state, parser_state.lexer)
 *         return self.parse_from_state(parser_state)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython__Parser *)__pyx_v_self->__pyx_vtab)->parse_from_state(__pyx_v_self, __pyx_v_parser_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":500
 *         self.debug = debug
 * 
 *     def parse(self, lexer, start, value_stack=None, state_stack=None, start_interactive=False):             # <<<<<<<<<<<<<<
 *         parse_conf = ParseConf(self.parse_table, self.callbacks, start)
 *         parser_state = ParserState(parse_conf, lexer, state_stack, value_stack)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_parse_conf);
  __Pyx_XDECREF((PyObject *)__pyx_v_parser_state);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":508
 * 
 * 
 *     cdef parse_from_state(self, ParserState state):             # <<<<<<<<<<<<<<
 *         # Main LALR-parser loop
 *         cdef Token token
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_7_Parser_parse_from_state(struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v_state) {
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_token = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_end_token = 0;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  Py_ssize_t __pyx_t_22;
  char const *__pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse_from_state", 0);

  /* "lark_cython/lark_cython.pyx":513
 *         cdef Token end_token
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             token = None
 *             #for token in state.lexer.lex(state):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "lark_cython/lark_cython.pyx":514
 * 
 *         try:
 *             token = None             # <<<<<<<<<<<<<<
 *             #for token in state.lexer.lex(state):
 *             try:
 */
      __Pyx_INCREF(Py_None);
      __pyx_v_token = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)Py_None);

      /* "lark_cython/lark_cython.pyx":516
 *             token = None
 *             #for token in state.lexer.lex(state):
 *             try:             # <<<<<<<<<<<<<<
 *                 while True:
 *                     token = state.lexer.next_token(state)
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        /*try:*/ {

          /* "lark_cython/lark_cython.pyx":517
 *             #for token in state.lexer.lex(state):
 *             try:
 *                 while True:             # <<<<<<<<<<<<<<
 *                     token = state.lexer.next_token(state)
 *                     state.feed_token(token)
 */
          while (1) {

            /* "lark_cython/lark_cython.pyx":518
 *             try:
 *                 while True:
 *                     token = state.lexer.next_token(state)             # <<<<<<<<<<<<<<
 *                     state.feed_token(token)
 *             except EOFError:
 */
            __pyx_t_7 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerThread *)__pyx_v_state->lexer->__pyx_vtab)->next_token(__pyx_v_state->lexer, __pyx_v_state); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 518, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_7);
            if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 518, __pyx_L9_error)
            __Pyx_DECREF_SET(__pyx_v_token, ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_7));
            __pyx_t_7 = 0;

            /* "lark_cython/lark_cython.pyx":519
 *                 while True:
 *                     token = state.lexer.next_token(state)
 *                     state.feed_token(token)             # <<<<<<<<<<<<<<
 *             except EOFError:
 *                 pass
 */
            __pyx_t_7 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_ParserState *)__pyx_v_state->__pyx_vtab)->feed_token(__pyx_v_state, __pyx_v_token, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 519, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }

          /* "lark_cython/lark_cython.pyx":516
 *             token = None
 *             #for token in state.lexer.lex(state):
 *             try:             # <<<<<<<<<<<<<<
 *                 while True:
 *                     token = state.lexer.next_token(state)
 */
        }
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L14_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "lark_cython/lark_cython.pyx":520
 *                     token = state.lexer.next_token(state)
 *                     state.feed_token(token)
 *             except EOFError:             # <<<<<<<<<<<<<<
 *                 pass
 * 
 */
        __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_EOFError);
        if (__pyx_t_8) {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L10_exception_handled;
        }
        goto __pyx_L11_except_error;
        __pyx_L11_except_error:;

        /* "lark_cython/lark_cython.pyx":516
 *             token = None
 *             #for token in state.lexer.lex(state):
 *             try:             # <<<<<<<<<<<<<<
 *                 while True:
 *                     token = state.lexer.next_token(state)
 */
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        goto __pyx_L3_error;
        __pyx_L10_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        __pyx_L14_try_end:;
      }

      /* "lark_cython/lark_cython.pyx":523
 *                 pass
 * 
 *             end_token = Token.new_borrow_pos('$END', '', token) if token else Token('$END', '', 0, 1, 1)             # <<<<<<<<<<<<<<
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:
 */
      __pyx_t_9 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_token)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 523, __pyx_L3_error)
      if (__pyx_t_9) {
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token), __pyx_n_s_new_borrow_pos); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 523, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_8 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_8 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_11)) {
          PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u_END, __pyx_kp_u__3, ((PyObject *)__pyx_v_token)};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 523, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
          PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u_END, __pyx_kp_u__3, ((PyObject *)__pyx_v_token)};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 523, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(3+__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 523, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_12) {
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
          }
          __Pyx_INCREF(__pyx_kp_u_END);
          __Pyx_GIVEREF(__pyx_kp_u_END);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_8, __pyx_kp_u_END);
          __Pyx_INCREF(__pyx_kp_u__3);
          __Pyx_GIVEREF(__pyx_kp_u__3);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_8, __pyx_kp_u__3);
          __Pyx_INCREF(((PyObject *)__pyx_v_token));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_token));
          PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_8, ((PyObject *)__pyx_v_token));
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 523, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (!(likely(((__pyx_t_10) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_10, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 523, __pyx_L3_error)
        __pyx_t_7 = __pyx_t_10;
        __pyx_t_10 = 0;
      } else {
        __pyx_t_10 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token), __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 523, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = __pyx_t_10;
        __pyx_t_10 = 0;
      }
      __pyx_v_end_token = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":524
 * 
 *             end_token = Token.new_borrow_pos('$END', '', token) if token else Token('$END', '', 0, 1, 1)
 *             return state.feed_token(end_token, True)             # <<<<<<<<<<<<<<
 *         except UnexpectedInput as e:
 *             try:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_14.__pyx_n = 1;
      __pyx_t_14.is_end = 1;
      __pyx_t_7 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_ParserState *)__pyx_v_state->__pyx_vtab)->feed_token(__pyx_v_state, __pyx_v_end_token, &__pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L7_try_return;

      /* "lark_cython/lark_cython.pyx":513
 *         cdef Token end_token
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             token = None
 *             #for token in state.lexer.lex(state):
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "lark_cython/lark_cython.pyx":525
 *             end_token = Token.new_borrow_pos('$END', '', token) if token else Token('$END', '', 0, 1, 1)
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:             # <<<<<<<<<<<<<<
 *             try:
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)
 */
    __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_10, &__pyx_t_11);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_UnexpectedInput); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 525, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_7, __pyx_t_13);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_ErrRestore(__pyx_t_7, __pyx_t_10, __pyx_t_11);
    __pyx_t_7 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("lark_cython.lark_cython._Parser.parse_from_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_10, &__pyx_t_7) < 0) __PYX_ERR(0, 525, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_v_e = __pyx_t_10;
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":526
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:
 *             try:             # <<<<<<<<<<<<<<
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)
 *             except NameError:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_4);
          /*try:*/ {

            /* "lark_cython/lark_cython.pyx":527
 *         except UnexpectedInput as e:
 *             try:
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)             # <<<<<<<<<<<<<<
 *             except NameError:
 *                 pass
 */
            __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_InteractiveParser); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 527, __pyx_L24_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_15 = NULL;
            __pyx_t_8 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
              __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_12);
              if (likely(__pyx_t_15)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_15);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_12, function);
                __pyx_t_8 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_15, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_state), ((PyObject *)__pyx_v_state->lexer)};
              __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 527, __pyx_L24_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_13);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[4] = {__pyx_t_15, ((PyObject *)__pyx_v_self), ((PyObject *)__pyx_v_state), ((PyObject *)__pyx_v_state->lexer)};
              __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 527, __pyx_L24_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_13);
            } else
            #endif
            {
              __pyx_t_16 = PyTuple_New(3+__pyx_t_8); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 527, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_16);
              if (__pyx_t_15) {
                __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_15); __pyx_t_15 = NULL;
              }
              __Pyx_INCREF(((PyObject *)__pyx_v_self));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
              PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_8, ((PyObject *)__pyx_v_self));
              __Pyx_INCREF(((PyObject *)__pyx_v_state));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_state));
              PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_8, ((PyObject *)__pyx_v_state));
              __Pyx_INCREF(((PyObject *)__pyx_v_state->lexer));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_state->lexer));
              PyTuple_SET_ITEM(__pyx_t_16, 2+__pyx_t_8, ((PyObject *)__pyx_v_state->lexer));
              __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_16, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 527, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            }
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_e, __pyx_n_s_interactive_parser, __pyx_t_13) < 0) __PYX_ERR(0, 527, __pyx_L24_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

            /* "lark_cython/lark_cython.pyx":526
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:
 *             try:             # <<<<<<<<<<<<<<
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)
 *             except NameError:
 */
          }
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L31_try_end;
          __pyx_L24_error:;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;

          /* "lark_cython/lark_cython.pyx":528
 *             try:
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)
 *             except NameError:             # <<<<<<<<<<<<<<
 *                 pass
 *             raise e
 */
          __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_NameError);
          if (__pyx_t_8) {
            __Pyx_ErrRestore(0,0,0);
            goto __pyx_L25_exception_handled;
          }
          goto __pyx_L26_except_error;
          __pyx_L26_except_error:;

          /* "lark_cython/lark_cython.pyx":526
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:
 *             try:             # <<<<<<<<<<<<<<
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)
 *             except NameError:
 */
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
          goto __pyx_L22_error;
          __pyx_L25_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
          __pyx_L31_try_end:;
        }

        /* "lark_cython/lark_cython.pyx":530
 *             except NameError:
 *                 pass
 *             raise e             # <<<<<<<<<<<<<<
 *         except Exception as e:
 *             if self.debug:
 */
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(0, 530, __pyx_L22_error)
      }

      /* "lark_cython/lark_cython.pyx":525
 *             end_token = Token.new_borrow_pos('$END', '', token) if token else Token('$END', '', 0, 1, 1)
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:             # <<<<<<<<<<<<<<
 *             try:
 *                 e.interactive_parser = InteractiveParser(self, state, state.lexer)
 */
      /*finally:*/ {
        __pyx_L22_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0)) __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_8 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e);
            __pyx_v_e = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_6);
          __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
          goto __pyx_L5_except_error;
        }
      }
    }

    /* "lark_cython/lark_cython.pyx":531
 *                 pass
 *             raise e
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if self.debug:
 *                 print("")
 */
    __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_17) {
      __Pyx_AddTraceback("lark_cython.lark_cython._Parser.parse_from_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_10, &__pyx_t_11) < 0) __PYX_ERR(0, 531, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_v_e = __pyx_t_10;
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":532
 *             raise e
 *         except Exception as e:
 *             if self.debug:             # <<<<<<<<<<<<<<
 *                 print("")
 *                 print("STATE STACK DUMP")
 */
        __pyx_t_9 = (__pyx_v_self->debug != 0);
        if (__pyx_t_9) {

          /* "lark_cython/lark_cython.pyx":533
 *         except Exception as e:
 *             if self.debug:
 *                 print("")             # <<<<<<<<<<<<<<
 *                 print("STATE STACK DUMP")
 *                 print("----------------")
 */
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 533, __pyx_L41_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "lark_cython/lark_cython.pyx":534
 *             if self.debug:
 *                 print("")
 *                 print("STATE STACK DUMP")             # <<<<<<<<<<<<<<
 *                 print("----------------")
 *                 for i, s in enumerate(state.state_stack):
 */
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 534, __pyx_L41_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "lark_cython/lark_cython.pyx":535
 *                 print("")
 *                 print("STATE STACK DUMP")
 *                 print("----------------")             # <<<<<<<<<<<<<<
 *                 for i, s in enumerate(state.state_stack):
 *                     print('%d)' % i , s)
 */
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 535, __pyx_L41_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "lark_cython/lark_cython.pyx":536
 *                 print("STATE STACK DUMP")
 *                 print("----------------")
 *                 for i, s in enumerate(state.state_stack):             # <<<<<<<<<<<<<<
 *                     print('%d)' % i , s)
 *                 print("")
 */
          __Pyx_INCREF(__pyx_int_0);
          __pyx_t_13 = __pyx_int_0;
          __pyx_t_12 = __pyx_v_state->state_stack; __Pyx_INCREF(__pyx_t_12); __pyx_t_22 = 0;
          for (;;) {
            if (__pyx_t_22 >= PyList_GET_SIZE(__pyx_t_12)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyList_GET_ITEM(__pyx_t_12, __pyx_t_22); __Pyx_INCREF(__pyx_t_16); __pyx_t_22++; if (unlikely(0 < 0)) __PYX_ERR(0, 536, __pyx_L41_error)
            #else
            __pyx_t_16 = PySequence_ITEM(__pyx_t_12, __pyx_t_22); __pyx_t_22++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 536, __pyx_L41_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
            __Pyx_XDECREF_SET(__pyx_v_s, __pyx_t_16);
            __pyx_t_16 = 0;
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_13);
            __pyx_t_16 = __Pyx_PyInt_AddObjC(__pyx_t_13, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 536, __pyx_L41_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_13);
            __pyx_t_13 = __pyx_t_16;
            __pyx_t_16 = 0;

            /* "lark_cython/lark_cython.pyx":537
 *                 print("----------------")
 *                 for i, s in enumerate(state.state_stack):
 *                     print('%d)' % i , s)             # <<<<<<<<<<<<<<
 *                 print("")
 * 
 */
            __pyx_t_16 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_d, __pyx_v_i); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 537, __pyx_L41_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 537, __pyx_L41_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_GIVEREF(__pyx_t_16);
            PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_16);
            __Pyx_INCREF(__pyx_v_s);
            __Pyx_GIVEREF(__pyx_v_s);
            PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_v_s);
            __pyx_t_16 = 0;
            __pyx_t_16 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_15, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 537, __pyx_L41_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

            /* "lark_cython/lark_cython.pyx":536
 *                 print("STATE STACK DUMP")
 *                 print("----------------")
 *                 for i, s in enumerate(state.state_stack):             # <<<<<<<<<<<<<<
 *                     print('%d)' % i , s)
 *                 print("")
 */
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "lark_cython/lark_cython.pyx":538
 *                 for i, s in enumerate(state.state_stack):
 *                     print('%d)' % i , s)
 *                 print("")             # <<<<<<<<<<<<<<
 * 
 *             raise
 */
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 538, __pyx_L41_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

          /* "lark_cython/lark_cython.pyx":532
 *             raise e
 *         except Exception as e:
 *             if self.debug:             # <<<<<<<<<<<<<<
 *                 print("")
 *                 print("STATE STACK DUMP")
 */
        }

        /* "lark_cython/lark_cython.pyx":540
 *                 print("")
 * 
 *             raise             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __Pyx_GIVEREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_10, __pyx_t_11);
        __pyx_t_7 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; 
        __PYX_ERR(0, 540, __pyx_L41_error)
      }

      /* "lark_cython/lark_cython.pyx":531
 *                 pass
 *             raise e
 *         except Exception as e:             # <<<<<<<<<<<<<<
 *             if self.debug:
 *                 print("")
 */
      /*finally:*/ {
        __pyx_L41_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_4);
          __pyx_t_17 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_23 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e);
            __pyx_v_e = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_6);
            __Pyx_XGIVEREF(__pyx_t_5);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
          }
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ErrRestore(__pyx_t_21, __pyx_t_20, __pyx_t_19);
          __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0;
          __pyx_lineno = __pyx_t_17; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_23;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "lark_cython/lark_cython.pyx":513
 *         cdef Token end_token
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             token = None
 *             #for token in state.lexer.lex(state):
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "lark_cython/lark_cython.pyx":508
 * 
 * 
 *     cdef parse_from_state(self, ParserState state):             # <<<<<<<<<<<<<<
 *         # Main LALR-parser loop
 *         cdef Token token
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.parse_from_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_token);
  __Pyx_XDECREF((PyObject *)__pyx_v_end_token);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7_Parser_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7_Parser_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7_Parser_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython__Parser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7_Parser_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7_Parser_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7_Parser_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_7_Parser_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython__Parser *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_7_Parser_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython__Parser *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython._Parser.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":544
 * 
 * class LALR_Parser(Serialize):
 *     def __init__(self, parser_conf, debug=False):             # <<<<<<<<<<<<<<
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 *         analysis.compute_lalr()
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_1__init__ = {"__init__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_parser_conf = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_parser_conf,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_parser_conf)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 544, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 544, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_parser_conf = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 544, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LALR_Parser___init__(__pyx_self, __pyx_v_self, __pyx_v_parser_conf, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_parser_conf, PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_analysis = NULL;
  PyObject *__pyx_v_callbacks = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":545
 * class LALR_Parser(Serialize):
 *     def __init__(self, parser_conf, debug=False):
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)             # <<<<<<<<<<<<<<
 *         analysis.compute_lalr()
 *         callbacks = parser_conf.callbacks
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_LALR_Analyzer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_parser_conf);
  __Pyx_GIVEREF(__pyx_v_parser_conf);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_parser_conf);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_debug, __pyx_v_debug) < 0) __PYX_ERR(0, 545, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_analysis = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":546
 *     def __init__(self, parser_conf, debug=False):
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 *         analysis.compute_lalr()             # <<<<<<<<<<<<<<
 *         callbacks = parser_conf.callbacks
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_analysis, __pyx_n_s_compute_lalr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":547
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 *         analysis.compute_lalr()
 *         callbacks = parser_conf.callbacks             # <<<<<<<<<<<<<<
 * 
 *         self._parse_table = analysis.parse_table
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_parser_conf, __pyx_n_s_callbacks); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_callbacks = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":549
 *         callbacks = parser_conf.callbacks
 * 
 *         self._parse_table = analysis.parse_table             # <<<<<<<<<<<<<<
 *         self.parser_conf = parser_conf
 *         self.parser = _Parser(analysis.parse_table, callbacks, debug)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_analysis, __pyx_n_s_parse_table); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parse_table_2, __pyx_t_4) < 0) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":550
 * 
 *         self._parse_table = analysis.parse_table
 *         self.parser_conf = parser_conf             # <<<<<<<<<<<<<<
 *         self.parser = _Parser(analysis.parse_table, callbacks, debug)
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parser_conf, __pyx_v_parser_conf) < 0) __PYX_ERR(0, 550, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":551
 *         self._parse_table = analysis.parse_table
 *         self.parser_conf = parser_conf
 *         self.parser = _Parser(analysis.parse_table, callbacks, debug)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_analysis, __pyx_n_s_parse_table); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_INCREF(__pyx_v_callbacks);
  __Pyx_GIVEREF(__pyx_v_callbacks);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_callbacks);
  __Pyx_INCREF(__pyx_v_debug);
  __Pyx_GIVEREF(__pyx_v_debug);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_debug);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython__Parser), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parser, __pyx_t_4) < 0) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":544
 * 
 * class LALR_Parser(Serialize):
 *     def __init__(self, parser_conf, debug=False):             # <<<<<<<<<<<<<<
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 *         analysis.compute_lalr()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_analysis);
  __Pyx_XDECREF(__pyx_v_callbacks);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":554
 * 
 *     @classmethod
 *     def deserialize(cls, data, memo, callbacks, debug=False):             # <<<<<<<<<<<<<<
 *         inst = cls.__new__(cls)
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_3deserialize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_3deserialize = {"deserialize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_3deserialize, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_3deserialize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_v_memo = 0;
  PyObject *__pyx_v_callbacks = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("deserialize (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_data,&__pyx_n_s_memo,&__pyx_n_s_callbacks,&__pyx_n_s_debug,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[4] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cls)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("deserialize", 0, 4, 5, 1); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_memo)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("deserialize", 0, 4, 5, 2); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callbacks)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("deserialize", 0, 4, 5, 3); __PYX_ERR(0, 554, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "deserialize") < 0)) __PYX_ERR(0, 554, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cls = values[0];
    __pyx_v_data = values[1];
    __pyx_v_memo = values[2];
    __pyx_v_callbacks = values[3];
    __pyx_v_debug = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("deserialize", 0, 4, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 554, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.deserialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_2deserialize(__pyx_self, __pyx_v_cls, __pyx_v_data, __pyx_v_memo, __pyx_v_callbacks, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_2deserialize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_data, PyObject *__pyx_v_memo, PyObject *__pyx_v_callbacks, PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_inst = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("deserialize", 0);

  /* "lark_cython/lark_cython.pyx":555
 *     @classmethod
 *     def deserialize(cls, data, memo, callbacks, debug=False):
 *         inst = cls.__new__(cls)             # <<<<<<<<<<<<<<
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 *         inst.parser = _Parser(inst._parse_table, callbacks, debug)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cls, __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_cls) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_cls);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_inst = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":556
 *     def deserialize(cls, data, memo, callbacks, debug=False):
 *         inst = cls.__new__(cls)
 *         inst._parse_table = IntParseTable.deserialize(data, memo)             # <<<<<<<<<<<<<<
 *         inst.parser = _Parser(inst._parse_table, callbacks, debug)
 *         return inst
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IntParseTable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_deserialize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_data, __pyx_v_memo};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_data, __pyx_v_memo};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_data);
    __Pyx_INCREF(__pyx_v_memo);
    __Pyx_GIVEREF(__pyx_v_memo);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_memo);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_inst, __pyx_n_s_parse_table_2, __pyx_t_1) < 0) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":557
 *         inst = cls.__new__(cls)
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 *         inst.parser = _Parser(inst._parse_table, callbacks, debug)             # <<<<<<<<<<<<<<
 *         return inst
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_inst, __pyx_n_s_parse_table_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_callbacks);
  __Pyx_GIVEREF(__pyx_v_callbacks);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_callbacks);
  __Pyx_INCREF(__pyx_v_debug);
  __Pyx_GIVEREF(__pyx_v_debug);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_debug);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython__Parser), __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_inst, __pyx_n_s_parser, __pyx_t_1) < 0) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":558
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 *         inst.parser = _Parser(inst._parse_table, callbacks, debug)
 *         return inst             # <<<<<<<<<<<<<<
 * 
 *     def serialize(self, memo):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_inst);
  __pyx_r = __pyx_v_inst;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":554
 * 
 *     @classmethod
 *     def deserialize(cls, data, memo, callbacks, debug=False):             # <<<<<<<<<<<<<<
 *         inst = cls.__new__(cls)
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.deserialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_inst);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":560
 *         return inst
 * 
 *     def serialize(self, memo):             # <<<<<<<<<<<<<<
 *         return self._parse_table.serialize(memo)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_5serialize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_5serialize = {"serialize", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_5serialize, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_5serialize(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_memo = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("serialize (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_memo,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_memo)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("serialize", 1, 2, 2, 1); __PYX_ERR(0, 560, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "serialize") < 0)) __PYX_ERR(0, 560, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_memo = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("serialize", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 560, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.serialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_4serialize(__pyx_self, __pyx_v_self, __pyx_v_memo);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_4serialize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("serialize", 0);

  /* "lark_cython/lark_cython.pyx":561
 * 
 *     def serialize(self, memo):
 *         return self._parse_table.serialize(memo)             # <<<<<<<<<<<<<<
 * 
 *     def parse_interactive(self, lexer, start):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse_table_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_serialize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_memo) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_memo);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":560
 *         return inst
 * 
 *     def serialize(self, memo):             # <<<<<<<<<<<<<<
 *         return self._parse_table.serialize(memo)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.serialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":563
 *         return self._parse_table.serialize(memo)
 * 
 *     def parse_interactive(self, lexer, start):             # <<<<<<<<<<<<<<
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_7parse_interactive(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_7parse_interactive = {"parse_interactive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_7parse_interactive, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_7parse_interactive(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_lexer = 0;
  PyObject *__pyx_v_start = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse_interactive (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_lexer,&__pyx_n_s_start,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lexer)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse_interactive", 1, 3, 3, 1); __PYX_ERR(0, 563, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse_interactive", 1, 3, 3, 2); __PYX_ERR(0, 563, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse_interactive") < 0)) __PYX_ERR(0, 563, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_lexer = values[1];
    __pyx_v_start = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse_interactive", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 563, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse_interactive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_6parse_interactive(__pyx_self, __pyx_v_self, __pyx_v_lexer, __pyx_v_start);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_6parse_interactive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_start) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse_interactive", 0);

  /* "lark_cython/lark_cython.pyx":564
 * 
 *     def parse_interactive(self, lexer, start):
 *         return self.parser.parse(lexer, start, start_interactive=True)             # <<<<<<<<<<<<<<
 * 
 *     def parse(self, lexer, start, on_error=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parser); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_parse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_lexer);
  __Pyx_GIVEREF(__pyx_v_lexer);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_lexer);
  __Pyx_INCREF(__pyx_v_start);
  __Pyx_GIVEREF(__pyx_v_start);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_start);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_start_interactive, Py_True) < 0) __PYX_ERR(0, 564, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":563
 *         return self._parse_table.serialize(memo)
 * 
 *     def parse_interactive(self, lexer, start):             # <<<<<<<<<<<<<<
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse_interactive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":566
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 *     def parse(self, lexer, start, on_error=None):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.parser.parse(lexer, start)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_9parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_9parse = {"parse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_9parse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11LALR_Parser_9parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_lexer = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_on_error = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_lexer,&__pyx_n_s_start,&__pyx_n_s_on_error,0};
    PyObject* values[4] = {0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_lexer)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse", 0, 3, 4, 1); __PYX_ERR(0, 566, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse", 0, 3, 4, 2); __PYX_ERR(0, 566, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_on_error);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse") < 0)) __PYX_ERR(0, 566, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_lexer = values[1];
    __pyx_v_start = values[2];
    __pyx_v_on_error = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse", 0, 3, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 566, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_8parse(__pyx_self, __pyx_v_self, __pyx_v_lexer, __pyx_v_start, __pyx_v_on_error);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11LALR_Parser_8parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_lexer, PyObject *__pyx_v_start, PyObject *__pyx_v_on_error) {
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_v_e2 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_t_20;
  char const *__pyx_t_21;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  char const *__pyx_t_28;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse", 0);

  /* "lark_cython/lark_cython.pyx":567
 * 
 *     def parse(self, lexer, start, on_error=None):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "lark_cython/lark_cython.pyx":568
 *     def parse(self, lexer, start, on_error=None):
 *         try:
 *             return self.parser.parse(lexer, start)             # <<<<<<<<<<<<<<
 *         except UnexpectedInput as e:
 *             if on_error is None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parser); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 568, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_parse); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 568, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_lexer, __pyx_v_start};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 568, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_lexer, __pyx_v_start};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 568, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 568, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_lexer);
        __Pyx_GIVEREF(__pyx_v_lexer);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_lexer);
        __Pyx_INCREF(__pyx_v_start);
        __Pyx_GIVEREF(__pyx_v_start);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_start);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 568, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "lark_cython/lark_cython.pyx":567
 * 
 *     def parse(self, lexer, start, on_error=None):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "lark_cython/lark_cython.pyx":569
 *         try:
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:             # <<<<<<<<<<<<<<
 *             if on_error is None:
 *                 raise
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_6, &__pyx_t_8);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_UnexpectedInput); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 569, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_6, __pyx_t_8);
    __pyx_t_4 = 0; __pyx_t_6 = 0; __pyx_t_8 = 0;
    if (__pyx_t_7) {
      __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 569, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_e = __pyx_t_6;
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":570
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:
 *             if on_error is None:             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_9 = (__pyx_v_on_error == Py_None);
        __pyx_t_10 = (__pyx_t_9 != 0);
        if (unlikely(__pyx_t_10)) {

          /* "lark_cython/lark_cython.pyx":571
 *         except UnexpectedInput as e:
 *             if on_error is None:
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *             while True:
 */
          __Pyx_GIVEREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ErrRestoreWithState(__pyx_t_8, __pyx_t_6, __pyx_t_4);
          __pyx_t_8 = 0; __pyx_t_6 = 0; __pyx_t_4 = 0; 
          __PYX_ERR(0, 571, __pyx_L14_error)

          /* "lark_cython/lark_cython.pyx":570
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:
 *             if on_error is None:             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        }

        /* "lark_cython/lark_cython.pyx":573
 *                 raise
 * 
 *             while True:             # <<<<<<<<<<<<<<
 *                 if isinstance(e, UnexpectedCharacters):
 *                     s = e.interactive_parser.lexer_state.state
 */
        while (1) {

          /* "lark_cython/lark_cython.pyx":574
 * 
 *             while True:
 *                 if isinstance(e, UnexpectedCharacters):             # <<<<<<<<<<<<<<
 *                     s = e.interactive_parser.lexer_state.state
 *                     p = s.line_ctr.char_pos
 */
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 574, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_10 = PyObject_IsInstance(__pyx_v_e, __pyx_t_5); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 574, __pyx_L14_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_9 = (__pyx_t_10 != 0);
          if (__pyx_t_9) {

            /* "lark_cython/lark_cython.pyx":575
 *             while True:
 *                 if isinstance(e, UnexpectedCharacters):
 *                     s = e.interactive_parser.lexer_state.state             # <<<<<<<<<<<<<<
 *                     p = s.line_ctr.char_pos
 * 
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_interactive_parser); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_lexer_state); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 575, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF_SET(__pyx_v_s, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "lark_cython/lark_cython.pyx":576
 *                 if isinstance(e, UnexpectedCharacters):
 *                     s = e.interactive_parser.lexer_state.state
 *                     p = s.line_ctr.char_pos             # <<<<<<<<<<<<<<
 * 
 *                 if not on_error(e):
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_line_ctr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 576, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_char_pos); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 576, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_11);
            __pyx_t_11 = 0;

            /* "lark_cython/lark_cython.pyx":574
 * 
 *             while True:
 *                 if isinstance(e, UnexpectedCharacters):             # <<<<<<<<<<<<<<
 *                     s = e.interactive_parser.lexer_state.state
 *                     p = s.line_ctr.char_pos
 */
          }

          /* "lark_cython/lark_cython.pyx":578
 *                     p = s.line_ctr.char_pos
 * 
 *                 if not on_error(e):             # <<<<<<<<<<<<<<
 *                     raise e
 * 
 */
          __Pyx_INCREF(__pyx_v_on_error);
          __pyx_t_5 = __pyx_v_on_error; __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_11 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_v_e) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_e);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 578, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 578, __pyx_L14_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_10 = ((!__pyx_t_9) != 0);
          if (unlikely(__pyx_t_10)) {

            /* "lark_cython/lark_cython.pyx":579
 * 
 *                 if not on_error(e):
 *                     raise e             # <<<<<<<<<<<<<<
 * 
 *                 if isinstance(e, UnexpectedCharacters):
 */
            __Pyx_Raise(__pyx_v_e, 0, 0, 0);
            __PYX_ERR(0, 579, __pyx_L14_error)

            /* "lark_cython/lark_cython.pyx":578
 *                     p = s.line_ctr.char_pos
 * 
 *                 if not on_error(e):             # <<<<<<<<<<<<<<
 *                     raise e
 * 
 */
          }

          /* "lark_cython/lark_cython.pyx":581
 *                     raise e
 * 
 *                 if isinstance(e, UnexpectedCharacters):             # <<<<<<<<<<<<<<
 *                     # If user didn't change the character position, then we should
 *                     if p == s.line_ctr.char_pos:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 581, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_10 = PyObject_IsInstance(__pyx_v_e, __pyx_t_11); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 581, __pyx_L14_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_9 = (__pyx_t_10 != 0);
          if (__pyx_t_9) {

            /* "lark_cython/lark_cython.pyx":583
 *                 if isinstance(e, UnexpectedCharacters):
 *                     # If user didn't change the character position, then we should
 *                     if p == s.line_ctr.char_pos:             # <<<<<<<<<<<<<<
 *                         s.line_ctr.feed(s.text[p:p+1])
 * 
 */
            if (unlikely(!__pyx_v_p)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(0, 583, __pyx_L14_error) }
            if (unlikely(!__pyx_v_s)) { __Pyx_RaiseUnboundLocalError("s"); __PYX_ERR(0, 583, __pyx_L14_error) }
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_line_ctr); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 583, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_char_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 583, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_11 = PyObject_RichCompare(__pyx_v_p, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 583, __pyx_L14_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 583, __pyx_L14_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_9) {

              /* "lark_cython/lark_cython.pyx":584
 *                     # If user didn't change the character position, then we should
 *                     if p == s.line_ctr.char_pos:
 *                         s.line_ctr.feed(s.text[p:p+1])             # <<<<<<<<<<<<<<
 * 
 *                 try:
 */
              if (unlikely(!__pyx_v_s)) { __Pyx_RaiseUnboundLocalError("s"); __PYX_ERR(0, 584, __pyx_L14_error) }
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_line_ctr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 584, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_feed); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 584, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_v_s)) { __Pyx_RaiseUnboundLocalError("s"); __PYX_ERR(0, 584, __pyx_L14_error) }
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_s, __pyx_n_s_text); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 584, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_5);
              if (unlikely(!__pyx_v_p)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(0, 584, __pyx_L14_error) }
              if (unlikely(!__pyx_v_p)) { __Pyx_RaiseUnboundLocalError("p"); __PYX_ERR(0, 584, __pyx_L14_error) }
              __pyx_t_13 = __Pyx_PyInt_AddObjC(__pyx_v_p, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 584, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_14 = __Pyx_PyObject_GetSlice(__pyx_t_5, 0, 0, &__pyx_v_p, &__pyx_t_13, NULL, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 584, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __pyx_t_13 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
                __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
                if (likely(__pyx_t_13)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                  __Pyx_INCREF(__pyx_t_13);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_12, function);
                }
              }
              __pyx_t_11 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_13, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_14);
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 584, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

              /* "lark_cython/lark_cython.pyx":583
 *                 if isinstance(e, UnexpectedCharacters):
 *                     # If user didn't change the character position, then we should
 *                     if p == s.line_ctr.char_pos:             # <<<<<<<<<<<<<<
 *                         s.line_ctr.feed(s.text[p:p+1])
 * 
 */
            }

            /* "lark_cython/lark_cython.pyx":581
 *                     raise e
 * 
 *                 if isinstance(e, UnexpectedCharacters):             # <<<<<<<<<<<<<<
 *                     # If user didn't change the character position, then we should
 *                     if p == s.line_ctr.char_pos:
 */
          }

          /* "lark_cython/lark_cython.pyx":586
 *                         s.line_ctr.feed(s.text[p:p+1])
 * 
 *                 try:             # <<<<<<<<<<<<<<
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            /*try:*/ {

              /* "lark_cython/lark_cython.pyx":587
 * 
 *                 try:
 *                     return e.interactive_parser.resume_parse()             # <<<<<<<<<<<<<<
 *                 except UnexpectedToken as e2:
 *                     if (isinstance(e, UnexpectedToken)
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_interactive_parser); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 587, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_resume_parse); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 587, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __pyx_t_12 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_14);
                if (likely(__pyx_t_12)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                  __Pyx_INCREF(__pyx_t_12);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_14, function);
                }
              }
              __pyx_t_11 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 587, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __pyx_r = __pyx_t_11;
              __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              goto __pyx_L27_try_return;

              /* "lark_cython/lark_cython.pyx":586
 *                         s.line_ctr.feed(s.text[p:p+1])
 * 
 *                 try:             # <<<<<<<<<<<<<<
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:
 */
            }
            __pyx_L23_error:;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "lark_cython/lark_cython.pyx":588
 *                 try:
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:             # <<<<<<<<<<<<<<
 *                     if (isinstance(e, UnexpectedToken)
 *                         and e.token.type == e2.token.type == '$END'
 */
            __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_14, &__pyx_t_12);
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 588, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_11, __pyx_t_13);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_ErrRestore(__pyx_t_11, __pyx_t_14, __pyx_t_12);
            __pyx_t_11 = 0; __pyx_t_14 = 0; __pyx_t_12 = 0;
            if (__pyx_t_7) {
              __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_14, &__pyx_t_11) < 0) __PYX_ERR(0, 588, __pyx_L25_except_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_14);
              __pyx_v_e2 = __pyx_t_14;
              /*try:*/ {

                /* "lark_cython/lark_cython.pyx":589
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:
 *                     if (isinstance(e, UnexpectedToken)             # <<<<<<<<<<<<<<
 *                         and e.token.type == e2.token.type == '$END'
 *                         and e.interactive_parser == e2.interactive_parser):
 */
                __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 589, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_10 = PyObject_IsInstance(__pyx_v_e, __pyx_t_13); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 589, __pyx_L36_error)
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                __pyx_t_18 = (__pyx_t_10 != 0);
                if (__pyx_t_18) {
                } else {
                  __pyx_t_9 = __pyx_t_18;
                  goto __pyx_L39_bool_binop_done;
                }

                /* "lark_cython/lark_cython.pyx":590
 *                 except UnexpectedToken as e2:
 *                     if (isinstance(e, UnexpectedToken)
 *                         and e.token.type == e2.token.type == '$END'             # <<<<<<<<<<<<<<
 *                         and e.interactive_parser == e2.interactive_parser):
 *                         # Prevent infinite loop
 */
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 590, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_type_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 590, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_e2, __pyx_n_s_token); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 590, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_type_2); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 590, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_19);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                __pyx_t_13 = PyObject_RichCompare(__pyx_t_5, __pyx_t_19, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 590, __pyx_L36_error)
                if (__Pyx_PyObject_IsTrue(__pyx_t_13)) {
                  __Pyx_DECREF(__pyx_t_13);
                  __pyx_t_13 = PyObject_RichCompare(__pyx_t_19, __pyx_kp_u_END, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 590, __pyx_L36_error)
                }
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely(__pyx_t_18 < 0)) __PYX_ERR(0, 590, __pyx_L36_error)
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                if (__pyx_t_18) {
                } else {
                  __pyx_t_9 = __pyx_t_18;
                  goto __pyx_L39_bool_binop_done;
                }

                /* "lark_cython/lark_cython.pyx":591
 *                     if (isinstance(e, UnexpectedToken)
 *                         and e.token.type == e2.token.type == '$END'
 *                         and e.interactive_parser == e2.interactive_parser):             # <<<<<<<<<<<<<<
 *                         # Prevent infinite loop
 *                         raise e2
 */
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_e, __pyx_n_s_interactive_parser); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 591, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_v_e2, __pyx_n_s_interactive_parser); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 591, __pyx_L36_error)
                __Pyx_GOTREF(__pyx_t_19);
                __pyx_t_5 = PyObject_RichCompare(__pyx_t_13, __pyx_t_19, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 591, __pyx_L36_error)
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_18 < 0)) __PYX_ERR(0, 591, __pyx_L36_error)
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                __pyx_t_9 = __pyx_t_18;
                __pyx_L39_bool_binop_done:;

                /* "lark_cython/lark_cython.pyx":589
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:
 *                     if (isinstance(e, UnexpectedToken)             # <<<<<<<<<<<<<<
 *                         and e.token.type == e2.token.type == '$END'
 *                         and e.interactive_parser == e2.interactive_parser):
 */
                if (unlikely(__pyx_t_9)) {

                  /* "lark_cython/lark_cython.pyx":593
 *                         and e.interactive_parser == e2.interactive_parser):
 *                         # Prevent infinite loop
 *                         raise e2             # <<<<<<<<<<<<<<
 *                     e = e2
 *                 except UnexpectedCharacters as e2:
 */
                  __Pyx_Raise(__pyx_v_e2, 0, 0, 0);
                  __PYX_ERR(0, 593, __pyx_L36_error)

                  /* "lark_cython/lark_cython.pyx":589
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:
 *                     if (isinstance(e, UnexpectedToken)             # <<<<<<<<<<<<<<
 *                         and e.token.type == e2.token.type == '$END'
 *                         and e.interactive_parser == e2.interactive_parser):
 */
                }

                /* "lark_cython/lark_cython.pyx":594
 *                         # Prevent infinite loop
 *                         raise e2
 *                     e = e2             # <<<<<<<<<<<<<<
 *                 except UnexpectedCharacters as e2:
 *                     e = e2
 */
                __Pyx_INCREF(__pyx_v_e2);
                __Pyx_DECREF_SET(__pyx_v_e, __pyx_v_e2);
              }

              /* "lark_cython/lark_cython.pyx":588
 *                 try:
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:             # <<<<<<<<<<<<<<
 *                     if (isinstance(e, UnexpectedToken)
 *                         and e.token.type == e2.token.type == '$END'
 */
              /*finally:*/ {
                /*normal exit:*/{
                  __Pyx_DECREF(__pyx_v_e2);
                  __pyx_v_e2 = NULL;
                  goto __pyx_L37;
                }
                __pyx_L36_error:;
                /*exception exit:*/{
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
                  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                  __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                  if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
                  if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
                  __Pyx_XGOTREF(__pyx_t_22);
                  __Pyx_XGOTREF(__pyx_t_23);
                  __Pyx_XGOTREF(__pyx_t_24);
                  __Pyx_XGOTREF(__pyx_t_25);
                  __Pyx_XGOTREF(__pyx_t_26);
                  __Pyx_XGOTREF(__pyx_t_27);
                  __pyx_t_7 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
                  {
                    __Pyx_DECREF(__pyx_v_e2);
                    __pyx_v_e2 = NULL;
                  }
                  if (PY_MAJOR_VERSION >= 3) {
                    __Pyx_XGIVEREF(__pyx_t_25);
                    __Pyx_XGIVEREF(__pyx_t_26);
                    __Pyx_XGIVEREF(__pyx_t_27);
                    __Pyx_ExceptionReset(__pyx_t_25, __pyx_t_26, __pyx_t_27);
                  }
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_XGIVEREF(__pyx_t_23);
                  __Pyx_XGIVEREF(__pyx_t_24);
                  __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
                  __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
                  __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_21;
                  goto __pyx_L25_except_error;
                }
                __pyx_L37:;
              }
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              goto __pyx_L24_exception_handled;
            }

            /* "lark_cython/lark_cython.pyx":595
 *                         raise e2
 *                     e = e2
 *                 except UnexpectedCharacters as e2:             # <<<<<<<<<<<<<<
 *                     e = e2
 * 
 */
            __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_14, &__pyx_t_12);
            __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 595, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_20 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_11, __pyx_t_5);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_ErrRestore(__pyx_t_11, __pyx_t_14, __pyx_t_12);
            __pyx_t_11 = 0; __pyx_t_14 = 0; __pyx_t_12 = 0;
            if (__pyx_t_20) {
              __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_14, &__pyx_t_11) < 0) __PYX_ERR(0, 595, __pyx_L25_except_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_14);
              __pyx_v_e2 = __pyx_t_14;
              /*try:*/ {

                /* "lark_cython/lark_cython.pyx":596
 *                     e = e2
 *                 except UnexpectedCharacters as e2:
 *                     e = e2             # <<<<<<<<<<<<<<
 * 
 * ###}
 */
                __Pyx_INCREF(__pyx_v_e2);
                __Pyx_DECREF_SET(__pyx_v_e, __pyx_v_e2);
              }

              /* "lark_cython/lark_cython.pyx":595
 *                         raise e2
 *                     e = e2
 *                 except UnexpectedCharacters as e2:             # <<<<<<<<<<<<<<
 *                     e = e2
 * 
 */
              /*finally:*/ {
                /*normal exit:*/{
                  __Pyx_DECREF(__pyx_v_e2);
                  __pyx_v_e2 = NULL;
                  goto __pyx_L52;
                }
                __pyx_L52:;
              }
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              goto __pyx_L24_exception_handled;
            }
            goto __pyx_L25_except_error;
            __pyx_L25_except_error:;

            /* "lark_cython/lark_cython.pyx":586
 *                         s.line_ctr.feed(s.text[p:p+1])
 * 
 *                 try:             # <<<<<<<<<<<<<<
 *                     return e.interactive_parser.resume_parse()
 *                 except UnexpectedToken as e2:
 */
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
            goto __pyx_L14_error;
            __pyx_L27_try_return:;
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
            goto __pyx_L13_return;
            __pyx_L24_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          }
        }
      }

      /* "lark_cython/lark_cython.pyx":569
 *         try:
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:             # <<<<<<<<<<<<<<
 *             if on_error is None:
 *                 raise
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_e);
          __pyx_v_e = NULL;
          goto __pyx_L15;
        }
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_27 = 0; __pyx_t_26 = 0; __pyx_t_25 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_27, &__pyx_t_26, &__pyx_t_25);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_27);
          __Pyx_XGOTREF(__pyx_t_26);
          __Pyx_XGOTREF(__pyx_t_25);
          __pyx_t_20 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e);
            __pyx_v_e = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_27);
            __Pyx_XGIVEREF(__pyx_t_26);
            __Pyx_XGIVEREF(__pyx_t_25);
            __Pyx_ExceptionReset(__pyx_t_27, __pyx_t_26, __pyx_t_25);
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ErrRestore(__pyx_t_17, __pyx_t_16, __pyx_t_15);
          __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_27 = 0; __pyx_t_26 = 0; __pyx_t_25 = 0;
          __pyx_lineno = __pyx_t_20; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_28;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_25 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_e);
          __pyx_v_e = NULL;
          __pyx_r = __pyx_t_25;
          __pyx_t_25 = 0;
          goto __pyx_L6_except_return;
        }
        __pyx_L15:;
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "lark_cython/lark_cython.pyx":567
 * 
 *     def parse(self, lexer, start, on_error=None):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.parser.parse(lexer, start)
 *         except UnexpectedInput as e:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "lark_cython/lark_cython.pyx":566
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 *     def parse(self, lexer, start, on_error=None):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.parser.parse(lexer, start)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("lark_cython.lark_cython.LALR_Parser.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XDECREF(__pyx_v_e2);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":614
 *     cdef public bint match_tree
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.empty = True
 * 
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta___init__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta___init__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":615
 * 
 *     def __init__(self):
 *         self.empty = True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->empty = 1;

  /* "lark_cython/lark_cython.pyx":614
 *     cdef public bint match_tree
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.empty = True
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":604
 * cdef class Meta:
 * 
 *     cdef public bint empty             # <<<<<<<<<<<<<<
 *     cdef public int line
 *     cdef public int column
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_5empty_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_5empty_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_5empty___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_5empty___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.empty.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_5empty_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_5empty_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_5empty_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_5empty_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 604, __pyx_L1_error)
  __pyx_v_self->empty = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.empty.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":605
 * 
 *     cdef public bint empty
 *     cdef public int line             # <<<<<<<<<<<<<<
 *     cdef public int column
 *     cdef public int start_pos
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_4line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_4line_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_4line___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_4line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.line.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_4line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_4line_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_4line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 605, __pyx_L1_error)
  __pyx_v_self->line = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.line.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":606
 *     cdef public bint empty
 *     cdef public int line
 *     cdef public int column             # <<<<<<<<<<<<<<
 *     cdef public int start_pos
 *     cdef public int end_line
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_6column_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_6column_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_6column___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_6column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.column.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_6column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_6column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_6column_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_6column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 606, __pyx_L1_error)
  __pyx_v_self->column = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.column.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":607
 *     cdef public int line
 *     cdef public int column
 *     cdef public int start_pos             # <<<<<<<<<<<<<<
 *     cdef public int end_line
 *     cdef public int end_column
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_9start_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_9start_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_9start_pos___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_9start_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->start_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.start_pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_9start_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_9start_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_9start_pos_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_9start_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 607, __pyx_L1_error)
  __pyx_v_self->start_pos = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.start_pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":608
 *     cdef public int column
 *     cdef public int start_pos
 *     cdef public int end_line             # <<<<<<<<<<<<<<
 *     cdef public int end_column
 *     cdef public int end_pos
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_8end_line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_8end_line_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_8end_line___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_8end_line___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->end_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.end_line.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_8end_line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_8end_line_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_8end_line_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_8end_line_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 608, __pyx_L1_error)
  __pyx_v_self->end_line = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.end_line.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":609
 *     cdef public int start_pos
 *     cdef public int end_line
 *     cdef public int end_column             # <<<<<<<<<<<<<<
 *     cdef public int end_pos
 *     cdef public list orig_expansion
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_10end_column_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_10end_column_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_10end_column___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_10end_column___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->end_column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.end_column.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_10end_column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_10end_column_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_10end_column_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_10end_column_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 609, __pyx_L1_error)
  __pyx_v_self->end_column = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.end_column.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":610
 *     cdef public int end_line
 *     cdef public int end_column
 *     cdef public int end_pos             # <<<<<<<<<<<<<<
 *     cdef public list orig_expansion
 *     cdef public bint match_tree
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_7end_pos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_7end_pos_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_7end_pos___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_7end_pos___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->end_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.end_pos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_7end_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_7end_pos_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_7end_pos_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_7end_pos_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 610, __pyx_L1_error)
  __pyx_v_self->end_pos = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.end_pos.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":611
 *     cdef public int end_column
 *     cdef public int end_pos
 *     cdef public list orig_expansion             # <<<<<<<<<<<<<<
 *     cdef public bint match_tree
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->orig_expansion);
  __pyx_r = __pyx_v_self->orig_expansion;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 611, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->orig_expansion);
  __Pyx_DECREF(__pyx_v_self->orig_expansion);
  __pyx_v_self->orig_expansion = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.orig_expansion.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_14orig_expansion_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->orig_expansion);
  __Pyx_DECREF(__pyx_v_self->orig_expansion);
  __pyx_v_self->orig_expansion = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":612
 *     cdef public int end_pos
 *     cdef public list orig_expansion
 *     cdef public bint match_tree             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_10match_tree_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_10match_tree_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_10match_tree___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_10match_tree___get__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->match_tree); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.match_tree.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_10match_tree_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Meta_10match_tree_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_10match_tree_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Meta_10match_tree_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 612, __pyx_L1_error)
  __pyx_v_self->match_tree = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.match_tree.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_2__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.column, self.empty, self.end_column, self.end_line, self.end_pos, self.line, self.match_tree, self.orig_expansion, self.start_pos)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->end_column); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->end_line); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->end_pos); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->line); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_self->match_tree); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->start_pos); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = PyTuple_New(9); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_9, 5, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_9, 6, __pyx_t_7);
  __Pyx_INCREF(__pyx_v_self->orig_expansion);
  __Pyx_GIVEREF(__pyx_v_self->orig_expansion);
  PyTuple_SET_ITEM(__pyx_t_9, 7, __pyx_v_self->orig_expansion);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_9, 8, __pyx_t_8);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.column, self.empty, self.end_column, self.end_line, self.end_pos, self.line, self.match_tree, self.orig_expansion, self.start_pos)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_9 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_v__dict = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "(tree fragment)":7
 *     state = (self.column, self.empty, self.end_column, self.end_line, self.end_pos, self.line, self.match_tree, self.orig_expansion, self.start_pos)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_10 = (__pyx_v__dict != Py_None);
  __pyx_t_11 = (__pyx_t_10 != 0);
  if (__pyx_t_11) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v__dict);
    __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_8));
    __pyx_t_8 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.orig_expansion is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.column, self.empty, self.end_column, self.end_line, self.end_pos, self.line, self.match_tree, self.orig_expansion, self.start_pos)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.orig_expansion is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, None), state
 */
  /*else*/ {
    __pyx_t_11 = (__pyx_v_self->orig_expansion != ((PyObject*)Py_None));
    __pyx_v_use_setstate = __pyx_t_11;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.orig_expansion is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, None), state
 *     else:
 */
  __pyx_t_11 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_11) {

    /* "(tree fragment)":13
 *         use_setstate = self.orig_expansion is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pyx_unpickle_Meta); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_9, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_109761734);
    __Pyx_GIVEREF(__pyx_int_109761734);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_int_109761734);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_9, 2, Py_None);
    __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_9);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_v_state);
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.orig_expansion is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, None), state
 *     else:
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Meta__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pyx_unpickle_Meta); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_9, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_109761734);
    __Pyx_GIVEREF(__pyx_int_109761734);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_int_109761734);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_v_state);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_9);
    __pyx_t_7 = 0;
    __pyx_t_9 = 0;
    __pyx_r = __pyx_t_8;
    __pyx_t_8 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Meta__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Meta_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Meta_4__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Meta_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Meta__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Meta__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Meta, (type(self), 0x68ad4c6, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Meta__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Meta.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":627
 *     cdef public Meta _meta
 * 
 *     def __cinit__(self, Token data, list children, meta=None):             # <<<<<<<<<<<<<<
 *         self.data = data
 *         self.children = children
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_data = 0;
  PyObject *__pyx_v_children = 0;
  PyObject *__pyx_v_meta = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,&__pyx_n_s_children,&__pyx_n_s_meta,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(0, 627, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_meta);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(0, 627, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_data = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)values[0]);
    __pyx_v_children = ((PyObject*)values[1]);
    __pyx_v_meta = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 627, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_data), __pyx_ptype_11lark_cython_11lark_cython_Token, 1, "data", 0))) __PYX_ERR(0, 627, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_children), (&PyList_Type), 1, "children", 1))) __PYX_ERR(0, 627, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree___cinit__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), __pyx_v_data, __pyx_v_children, __pyx_v_meta);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree___cinit__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_v_data, PyObject *__pyx_v_children, PyObject *__pyx_v_meta) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "lark_cython/lark_cython.pyx":628
 * 
 *     def __cinit__(self, Token data, list children, meta=None):
 *         self.data = data             # <<<<<<<<<<<<<<
 *         self.children = children
 *         self._meta = meta
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_data));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_data));
  __Pyx_GOTREF(__pyx_v_self->data);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->data));
  __pyx_v_self->data = __pyx_v_data;

  /* "lark_cython/lark_cython.pyx":629
 *     def __cinit__(self, Token data, list children, meta=None):
 *         self.data = data
 *         self.children = children             # <<<<<<<<<<<<<<
 *         self._meta = meta
 * 
 */
  __Pyx_INCREF(__pyx_v_children);
  __Pyx_GIVEREF(__pyx_v_children);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = __pyx_v_children;

  /* "lark_cython/lark_cython.pyx":630
 *         self.data = data
 *         self.children = children
 *         self._meta = meta             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  if (!(likely(((__pyx_v_meta) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_meta, __pyx_ptype_11lark_cython_11lark_cython_Meta))))) __PYX_ERR(0, 630, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_meta;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_meta);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_meta));
  __pyx_v_self->_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":627
 *     cdef public Meta _meta
 * 
 *     def __cinit__(self, Token data, list children, meta=None):             # <<<<<<<<<<<<<<
 *         self.data = data
 *         self.children = children
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":633
 * 
 *     @property
 *     def meta(self) -> Meta:             # <<<<<<<<<<<<<<
 *         if self._meta is None:
 *             self._meta = Meta()
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_4meta_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_4meta_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_4meta___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_4meta___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "lark_cython/lark_cython.pyx":634
 *     @property
 *     def meta(self) -> Meta:
 *         if self._meta is None:             # <<<<<<<<<<<<<<
 *             self._meta = Meta()
 *         return self._meta
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_meta) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":635
 *     def meta(self) -> Meta:
 *         if self._meta is None:
 *             self._meta = Meta()             # <<<<<<<<<<<<<<
 *         return self._meta
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Meta)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_meta);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->_meta));
    __pyx_v_self->_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":634
 *     @property
 *     def meta(self) -> Meta:
 *         if self._meta is None:             # <<<<<<<<<<<<<<
 *             self._meta = Meta()
 *         return self._meta
 */
  }

  /* "lark_cython/lark_cython.pyx":636
 *         if self._meta is None:
 *             self._meta = Meta()
 *         return self._meta             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_meta));
  __pyx_r = ((PyObject *)__pyx_v_self->_meta);
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":633
 * 
 *     @property
 *     def meta(self) -> Meta:             # <<<<<<<<<<<<<<
 *         if self._meta is None:
 *             self._meta = Meta()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.meta.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":638
 *         return self._meta
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Tree(%r, %r)' % (self.data, self.children)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_2__repr__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_2__repr__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "lark_cython/lark_cython.pyx":639
 * 
 *     def __repr__(self):
 *         return 'Tree(%r, %r)' % (self.data, self.children)             # <<<<<<<<<<<<<<
 * 
 *     def _pretty_label(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u_Tree);
  __pyx_t_2 += 5;
  __Pyx_GIVEREF(__pyx_kp_u_Tree);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_Tree);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(((PyObject *)__pyx_v_self->data)), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_);
  __pyx_t_2 += 2;
  __Pyx_GIVEREF(__pyx_kp_u_);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_self->children), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__2);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__2);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__2);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":638
 *         return self._meta
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return 'Tree(%r, %r)' % (self.data, self.children)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":641
 *         return 'Tree(%r, %r)' % (self.data, self.children)
 * 
 *     def _pretty_label(self):             # <<<<<<<<<<<<<<
 *         return self.data
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_5_pretty_label(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_5_pretty_label(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_pretty_label (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_4_pretty_label(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_4_pretty_label(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_pretty_label", 0);

  /* "lark_cython/lark_cython.pyx":642
 * 
 *     def _pretty_label(self):
 *         return self.data             # <<<<<<<<<<<<<<
 * 
 *     def _pretty(self, level, indent_str):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  __pyx_r = ((PyObject *)__pyx_v_self->data);
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":641
 *         return 'Tree(%r, %r)' % (self.data, self.children)
 * 
 *     def _pretty_label(self):             # <<<<<<<<<<<<<<
 *         return self.data
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":644
 *         return self.data
 * 
 *     def _pretty(self, level, indent_str):             # <<<<<<<<<<<<<<
 *         if len(self.children) == 1 and not isinstance(self.children[0], Tree):
 *             return [indent_str*level, self._pretty_label(), '\t', '%s' % (self.children[0],), '\n']
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_7_pretty(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_7_pretty(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_level = 0;
  PyObject *__pyx_v_indent_str = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_pretty (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,&__pyx_n_s_indent_str,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_level)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_indent_str)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_pretty", 1, 2, 2, 1); __PYX_ERR(0, 644, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_pretty") < 0)) __PYX_ERR(0, 644, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_level = values[0];
    __pyx_v_indent_str = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_pretty", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 644, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree._pretty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_6_pretty(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), __pyx_v_level, __pyx_v_indent_str);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_6_pretty(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_level, PyObject *__pyx_v_indent_str) {
  PyObject *__pyx_v_l = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pretty", 0);

  /* "lark_cython/lark_cython.pyx":645
 * 
 *     def _pretty(self, level, indent_str):
 *         if len(self.children) == 1 and not isinstance(self.children[0], Tree):             # <<<<<<<<<<<<<<
 *             return [indent_str*level, self._pretty_label(), '\t', '%s' % (self.children[0],), '\n']
 * 
 */
  __pyx_t_2 = __pyx_v_self->children;
  __Pyx_INCREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 645, __pyx_L1_error)
  }
  __pyx_t_3 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = ((__pyx_t_3 == 1) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_self->children == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 645, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->children, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_t_2, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = ((!(__pyx_t_4 != 0)) != 0);
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "lark_cython/lark_cython.pyx":646
 *     def _pretty(self, level, indent_str):
 *         if len(self.children) == 1 and not isinstance(self.children[0], Tree):
 *             return [indent_str*level, self._pretty_label(), '\t', '%s' % (self.children[0],), '\n']             # <<<<<<<<<<<<<<
 * 
 *         l = [indent_str*level, self._pretty_label(), '\n']
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyNumber_Multiply(__pyx_v_indent_str, __pyx_v_level); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pretty_label); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v_self->children == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 646, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->children, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_7), __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyList_New(5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_7, 1, __pyx_t_6);
    __Pyx_INCREF(__pyx_kp_u__29);
    __Pyx_GIVEREF(__pyx_kp_u__29);
    PyList_SET_ITEM(__pyx_t_7, 2, __pyx_kp_u__29);
    __Pyx_GIVEREF(__pyx_t_8);
    PyList_SET_ITEM(__pyx_t_7, 3, __pyx_t_8);
    __Pyx_INCREF(__pyx_kp_u__16);
    __Pyx_GIVEREF(__pyx_kp_u__16);
    PyList_SET_ITEM(__pyx_t_7, 4, __pyx_kp_u__16);
    __pyx_t_2 = 0;
    __pyx_t_6 = 0;
    __pyx_t_8 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":645
 * 
 *     def _pretty(self, level, indent_str):
 *         if len(self.children) == 1 and not isinstance(self.children[0], Tree):             # <<<<<<<<<<<<<<
 *             return [indent_str*level, self._pretty_label(), '\t', '%s' % (self.children[0],), '\n']
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":648
 *             return [indent_str*level, self._pretty_label(), '\t', '%s' % (self.children[0],), '\n']
 * 
 *         l = [indent_str*level, self._pretty_label(), '\n']             # <<<<<<<<<<<<<<
 *         for n in self.children:
 *             if isinstance(n, Tree):
 */
  __pyx_t_7 = PyNumber_Multiply(__pyx_v_indent_str, __pyx_v_level); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pretty_label); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_8 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_8);
  __Pyx_INCREF(__pyx_kp_u__16);
  __Pyx_GIVEREF(__pyx_kp_u__16);
  PyList_SET_ITEM(__pyx_t_6, 2, __pyx_kp_u__16);
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_v_l = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "lark_cython/lark_cython.pyx":649
 * 
 *         l = [indent_str*level, self._pretty_label(), '\n']
 *         for n in self.children:             # <<<<<<<<<<<<<<
 *             if isinstance(n, Tree):
 *                 l += n._pretty(level+1, indent_str)
 */
  if (unlikely(__pyx_v_self->children == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 649, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_v_self->children; __Pyx_INCREF(__pyx_t_6); __pyx_t_3 = 0;
  for (;;) {
    if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_6)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_8 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_3); __Pyx_INCREF(__pyx_t_8); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 649, __pyx_L1_error)
    #else
    __pyx_t_8 = PySequence_ITEM(__pyx_t_6, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_n, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "lark_cython/lark_cython.pyx":650
 *         l = [indent_str*level, self._pretty_label(), '\n']
 *         for n in self.children:
 *             if isinstance(n, Tree):             # <<<<<<<<<<<<<<
 *                 l += n._pretty(level+1, indent_str)
 *             else:
 */
    __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_n, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
    __pyx_t_5 = (__pyx_t_1 != 0);
    if (__pyx_t_5) {

      /* "lark_cython/lark_cython.pyx":651
 *         for n in self.children:
 *             if isinstance(n, Tree):
 *                 l += n._pretty(level+1, indent_str)             # <<<<<<<<<<<<<<
 *             else:
 *                 l += [indent_str*(level+1), '%s' % (n,), '\n']
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_n, __pyx_n_s_pretty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_level, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_2, __pyx_v_indent_str};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_2, __pyx_v_indent_str};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_t_2);
        __Pyx_INCREF(__pyx_v_indent_str);
        __Pyx_GIVEREF(__pyx_v_indent_str);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_v_indent_str);
        __pyx_t_2 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_11, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_l, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_l, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":650
 *         l = [indent_str*level, self._pretty_label(), '\n']
 *         for n in self.children:
 *             if isinstance(n, Tree):             # <<<<<<<<<<<<<<
 *                 l += n._pretty(level+1, indent_str)
 *             else:
 */
      goto __pyx_L8;
    }

    /* "lark_cython/lark_cython.pyx":653
 *                 l += n._pretty(level+1, indent_str)
 *             else:
 *                 l += [indent_str*(level+1), '%s' % (n,), '\n']             # <<<<<<<<<<<<<<
 * 
 *         return l
 */
    /*else*/ {
      __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_level, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = PyNumber_Multiply(__pyx_v_indent_str, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_n), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = PyList_New(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_8);
      PyList_SET_ITEM(__pyx_t_11, 0, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_7);
      PyList_SET_ITEM(__pyx_t_11, 1, __pyx_t_7);
      __Pyx_INCREF(__pyx_kp_u__16);
      __Pyx_GIVEREF(__pyx_kp_u__16);
      PyList_SET_ITEM(__pyx_t_11, 2, __pyx_kp_u__16);
      __pyx_t_8 = 0;
      __pyx_t_7 = 0;
      __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_l, __pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF_SET(__pyx_v_l, __pyx_t_7);
      __pyx_t_7 = 0;
    }
    __pyx_L8:;

    /* "lark_cython/lark_cython.pyx":649
 * 
 *         l = [indent_str*level, self._pretty_label(), '\n']
 *         for n in self.children:             # <<<<<<<<<<<<<<
 *             if isinstance(n, Tree):
 *                 l += n._pretty(level+1, indent_str)
 */
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "lark_cython/lark_cython.pyx":655
 *                 l += [indent_str*(level+1), '%s' % (n,), '\n']
 * 
 *         return l             # <<<<<<<<<<<<<<
 * 
 *     def pretty(self, indent_str: str='  ') -> str:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_l);
  __pyx_r = __pyx_v_l;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":644
 *         return self.data
 * 
 *     def _pretty(self, level, indent_str):             # <<<<<<<<<<<<<<
 *         if len(self.children) == 1 and not isinstance(self.children[0], Tree):
 *             return [indent_str*level, self._pretty_label(), '\t', '%s' % (self.children[0],), '\n']
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree._pretty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_l);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":657
 *         return l
 * 
 *     def pretty(self, indent_str: str='  ') -> str:             # <<<<<<<<<<<<<<
 *         """Returns an indented string representation of the tree.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_9pretty(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_8pretty[] = "Returns an indented string representation of the tree.\n\n        Great for debugging.\n        ";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_9pretty(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_indent_str = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pretty (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_indent_str,0};
    PyObject* values[1] = {0};
    values[0] = ((PyObject*)__pyx_kp_u__30);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_indent_str);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "pretty") < 0)) __PYX_ERR(0, 657, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_indent_str = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pretty", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 657, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.pretty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_indent_str), (&PyUnicode_Type), 1, "indent_str", 1))) __PYX_ERR(0, 657, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_8pretty(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), __pyx_v_indent_str);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_8pretty(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_indent_str) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pretty", 0);

  /* "lark_cython/lark_cython.pyx":662
 *         Great for debugging.
 *         """
 *         return ''.join(self._pretty(0, indent_str))             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pretty); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_int_0, __pyx_v_indent_str};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_int_0, __pyx_v_indent_str};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_int_0);
    __Pyx_INCREF(__pyx_v_indent_str);
    __Pyx_GIVEREF(__pyx_v_indent_str);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_indent_str);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyUnicode_Join(__pyx_kp_u__3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":657
 *         return l
 * 
 *     def pretty(self, indent_str: str='  ') -> str:             # <<<<<<<<<<<<<<
 *         """Returns an indented string representation of the tree.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.pretty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":664
 *         return ''.join(self._pretty(0, indent_str))
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.data == other.data and self.children == other.children
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_11__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_11__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_10__eq__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_10__eq__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "lark_cython/lark_cython.pyx":665
 * 
 *     def __eq__(self, other):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.data == other.data and self.children == other.children
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "lark_cython/lark_cython.pyx":666
 *     def __eq__(self, other):
 *         try:
 *             return self.data == other.data and self.children == other.children             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             return False
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyObject_RichCompare(((PyObject *)__pyx_v_self->data), __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 666, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 666, __pyx_L3_error)
      if (__pyx_t_7) {
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_6);
        __pyx_t_4 = __pyx_t_6;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_children); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 666, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_self->children, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 666, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_4 = __pyx_t_5;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_L9_bool_binop_done:;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "lark_cython/lark_cython.pyx":665
 * 
 *     def __eq__(self, other):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.data == other.data and self.children == other.children
 *         except AttributeError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "lark_cython/lark_cython.pyx":667
 *         try:
 *             return self.data == other.data and self.children == other.children
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 667, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "lark_cython/lark_cython.pyx":668
 *             return self.data == other.data and self.children == other.children
 *         except AttributeError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def __ne__(self, other):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "lark_cython/lark_cython.pyx":665
 * 
 *     def __eq__(self, other):
 *         try:             # <<<<<<<<<<<<<<
 *             return self.data == other.data and self.children == other.children
 *         except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "lark_cython/lark_cython.pyx":664
 *         return ''.join(self._pretty(0, indent_str))
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.data == other.data and self.children == other.children
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":670
 *             return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_13__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_13__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ne__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_12__ne__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_12__ne__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ne__", 0);

  /* "lark_cython/lark_cython.pyx":671
 * 
 *     def __ne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self) -> int:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self), __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":670
 *             return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":673
 *         return not (self == other)
 * 
 *     def __hash__(self) -> int:             # <<<<<<<<<<<<<<
 *         return hash((self.data, tuple(self.children)))
 * 
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_11lark_cython_11lark_cython_4Tree_15__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_11lark_cython_11lark_cython_4Tree_15__hash__(PyObject *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_14__hash__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_11lark_cython_11lark_cython_4Tree_14__hash__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_hash_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 0);

  /* "lark_cython/lark_cython.pyx":674
 * 
 *     def __hash__(self) -> int:
 *         return hash((self.data, tuple(self.children)))             # <<<<<<<<<<<<<<
 * 
 *     def iter_subtrees(self) -> 'Iterator[Tree]':
 */
  if (unlikely(__pyx_v_self->children == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 674, __pyx_L1_error)
  }
  __pyx_t_1 = PyList_AsTuple(__pyx_v_self->children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->data));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_Hash(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_hash_t)-1))) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":673
 *         return not (self == other)
 * 
 *     def __hash__(self) -> int:             # <<<<<<<<<<<<<<
 *         return hash((self.data, tuple(self.children)))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":676
 *         return hash((self.data, tuple(self.children)))
 * 
 *     def iter_subtrees(self) -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Depth-first iteration.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_17iter_subtrees(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_16iter_subtrees[] = "Depth-first iteration.\n\n        Iterates over all the subtrees, never returning to the same node twice (Lark's parse-tree is actually a DAG).\n        ";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_17iter_subtrees(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iter_subtrees (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_16iter_subtrees(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_16iter_subtrees(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_v_queue = NULL;
  PyObject *__pyx_v_subtrees = NULL;
  PyObject *__pyx_v_subtree = NULL;
  PyObject *__pyx_8genexpr9__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iter_subtrees", 0);

  /* "lark_cython/lark_cython.pyx":681
 *         Iterates over all the subtrees, never returning to the same node twice (Lark's parse-tree is actually a DAG).
 *         """
 *         queue = [self]             # <<<<<<<<<<<<<<
 *         subtrees = OrderedDict()
 *         for subtree in queue:
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
  __pyx_v_queue = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":682
 *         """
 *         queue = [self]
 *         subtrees = OrderedDict()             # <<<<<<<<<<<<<<
 *         for subtree in queue:
 *             subtrees[id(subtree)] = subtree
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_subtrees = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":683
 *         queue = [self]
 *         subtrees = OrderedDict()
 *         for subtree in queue:             # <<<<<<<<<<<<<<
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)
 */
  __pyx_t_1 = __pyx_v_queue; __Pyx_INCREF(__pyx_t_1); __pyx_t_4 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 683, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_subtree, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "lark_cython/lark_cython.pyx":684
 *         subtrees = OrderedDict()
 *         for subtree in queue:
 *             subtrees[id(subtree)] = subtree             # <<<<<<<<<<<<<<
 *             queue += [c for c in reversed(subtree.children)
 *                       if isinstance(c, Tree) and id(c) not in subtrees]
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, __pyx_v_subtree); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(PyObject_SetItem(__pyx_v_subtrees, __pyx_t_2, __pyx_v_subtree) < 0)) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "lark_cython/lark_cython.pyx":685
 *         for subtree in queue:
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)             # <<<<<<<<<<<<<<
 *                       if isinstance(c, Tree) and id(c) not in subtrees]
 * 
 */
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 685, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_subtree, __pyx_n_s_children); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 685, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_reversed, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 685, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
        __pyx_t_3 = __pyx_t_5; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 685, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 685, __pyx_L7_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 685, __pyx_L7_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 685, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_5); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 685, __pyx_L7_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 685, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_7(__pyx_t_3);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 685, __pyx_L7_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr9__pyx_v_c, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "lark_cython/lark_cython.pyx":686
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)
 *                       if isinstance(c, Tree) and id(c) not in subtrees]             # <<<<<<<<<<<<<<
 * 
 *         del queue
 */
        __pyx_t_9 = __Pyx_TypeCheck(__pyx_8genexpr9__pyx_v_c, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
        __pyx_t_10 = (__pyx_t_9 != 0);
        if (__pyx_t_10) {
        } else {
          __pyx_t_8 = __pyx_t_10;
          goto __pyx_L11_bool_binop_done;
        }
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, __pyx_8genexpr9__pyx_v_c); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_t_5, __pyx_v_subtrees, Py_NE)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 686, __pyx_L7_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_9 = (__pyx_t_10 != 0);
        __pyx_t_8 = __pyx_t_9;
        __pyx_L11_bool_binop_done:;
        if (__pyx_t_8) {

          /* "lark_cython/lark_cython.pyx":685
 *         for subtree in queue:
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)             # <<<<<<<<<<<<<<
 *                       if isinstance(c, Tree) and id(c) not in subtrees]
 * 
 */
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_8genexpr9__pyx_v_c))) __PYX_ERR(0, 685, __pyx_L7_error)

          /* "lark_cython/lark_cython.pyx":686
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)
 *                       if isinstance(c, Tree) and id(c) not in subtrees]             # <<<<<<<<<<<<<<
 * 
 *         del queue
 */
        }

        /* "lark_cython/lark_cython.pyx":685
 *         for subtree in queue:
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)             # <<<<<<<<<<<<<<
 *                       if isinstance(c, Tree) and id(c) not in subtrees]
 * 
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_c); __pyx_8genexpr9__pyx_v_c = 0;
      goto __pyx_L13_exit_scope;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_c); __pyx_8genexpr9__pyx_v_c = 0;
      goto __pyx_L1_error;
      __pyx_L13_exit_scope:;
    } /* exit inner scope */
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_queue, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_queue, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":683
 *         queue = [self]
 *         subtrees = OrderedDict()
 *         for subtree in queue:             # <<<<<<<<<<<<<<
 *             subtrees[id(subtree)] = subtree
 *             queue += [c for c in reversed(subtree.children)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":688
 *                       if isinstance(c, Tree) and id(c) not in subtrees]
 * 
 *         del queue             # <<<<<<<<<<<<<<
 *         return reversed(list(subtrees.values()))
 * 
 */
  __Pyx_DECREF(__pyx_v_queue);
  __pyx_v_queue = NULL;

  /* "lark_cython/lark_cython.pyx":689
 * 
 *         del queue
 *         return reversed(list(subtrees.values()))             # <<<<<<<<<<<<<<
 * 
 *     def find_pred(self, pred: 'Callable[[Tree], bool]') -> 'Iterator[Tree]':
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_subtrees, __pyx_n_s_values); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_reversed, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":676
 *         return hash((self.data, tuple(self.children)))
 * 
 *     def iter_subtrees(self) -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Depth-first iteration.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.iter_subtrees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_queue);
  __Pyx_XDECREF(__pyx_v_subtrees);
  __Pyx_XDECREF(__pyx_v_subtree);
  __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":691
 *         return reversed(list(subtrees.values()))
 * 
 *     def find_pred(self, pred: 'Callable[[Tree], bool]') -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Returns all nodes of the tree that evaluate pred(node) as true."""
 *         return filter(pred, self.iter_subtrees())
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_19find_pred(PyObject *__pyx_v_self, PyObject *__pyx_v_pred); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_18find_pred[] = "Returns all nodes of the tree that evaluate pred(node) as true.";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_19find_pred(PyObject *__pyx_v_self, PyObject *__pyx_v_pred) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_pred (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_18find_pred(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_pred));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_18find_pred(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_pred) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_pred", 0);

  /* "lark_cython/lark_cython.pyx":693
 *     def find_pred(self, pred: 'Callable[[Tree], bool]') -> 'Iterator[Tree]':
 *         """Returns all nodes of the tree that evaluate pred(node) as true."""
 *         return filter(pred, self.iter_subtrees())             # <<<<<<<<<<<<<<
 * 
 *     def find_data(self, data: str) -> 'Iterator[Tree]':
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_iter_subtrees); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_pred);
  __Pyx_GIVEREF(__pyx_v_pred);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_pred);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_filter, __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":691
 *         return reversed(list(subtrees.values()))
 * 
 *     def find_pred(self, pred: 'Callable[[Tree], bool]') -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Returns all nodes of the tree that evaluate pred(node) as true."""
 *         return filter(pred, self.iter_subtrees())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.find_pred", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":695
 *         return filter(pred, self.iter_subtrees())
 * 
 *     def find_data(self, data: str) -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Returns all nodes of the tree whose data equals the given data."""
 *         return self.find_pred(lambda t: t.data == data)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_21find_data(PyObject *__pyx_v_self, PyObject *__pyx_v_data); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_20find_data[] = "Returns all nodes of the tree whose data equals the given data.";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_21find_data(PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("find_data (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_data), (&PyUnicode_Type), 1, "data", 1))) __PYX_ERR(0, 695, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_20find_data(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject*)__pyx_v_data));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":697
 *     def find_data(self, data: str) -> 'Iterator[Tree]':
 *         """Returns all nodes of the tree whose data equals the given data."""
 *         return self.find_pred(lambda t: t.data == data)             # <<<<<<<<<<<<<<
 * 
 * ###}
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_9find_data_lambda5(PyObject *__pyx_self, PyObject *__pyx_v_t); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_4Tree_9find_data_lambda5 = {"lambda5", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_9find_data_lambda5, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_9find_data_lambda5(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda5 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda5(__pyx_self, ((PyObject *)__pyx_v_t));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda5(PyObject *__pyx_self, PyObject *__pyx_v_t) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *__pyx_cur_scope;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda5", 0);
  __pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(!__pyx_cur_scope->__pyx_v_data)) { __Pyx_RaiseClosureNameError("data"); __PYX_ERR(0, 697, __pyx_L1_error) }
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_cur_scope->__pyx_v_data, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.find_data.lambda5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":695
 *         return filter(pred, self.iter_subtrees())
 * 
 *     def find_data(self, data: str) -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Returns all nodes of the tree whose data equals the given data."""
 *         return self.find_pred(lambda t: t.data == data)
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_20find_data(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_data) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("find_data", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 695, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_data = __pyx_v_data;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_data);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_data);

  /* "lark_cython/lark_cython.pyx":697
 *     def find_data(self, data: str) -> 'Iterator[Tree]':
 *         """Returns all nodes of the tree whose data equals the given data."""
 *         return self.find_pred(lambda t: t.data == data)             # <<<<<<<<<<<<<<
 * 
 * ###}
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_find_pred); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_4Tree_9find_data_lambda5, 0, __pyx_n_s_find_data_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_kp_s_lark_cython_lark_cython, __pyx_d, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":695
 *         return filter(pred, self.iter_subtrees())
 * 
 *     def find_data(self, data: str) -> 'Iterator[Tree]':             # <<<<<<<<<<<<<<
 *         """Returns all nodes of the tree whose data equals the given data."""
 *         return self.find_pred(lambda t: t.data == data)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.find_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":701
 * ###}
 * 
 *     def expand_kids_by_data(self, *data_values):             # <<<<<<<<<<<<<<
 *         """Expand (inline) children with any of the given data values. Returns True if anything changed"""
 *         changed = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_23expand_kids_by_data(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_22expand_kids_by_data[] = "Expand (inline) children with any of the given data values. Returns True if anything changed";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_23expand_kids_by_data(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_data_values = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("expand_kids_by_data (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "expand_kids_by_data", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_data_values = __pyx_args;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_22expand_kids_by_data(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), __pyx_v_data_values);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_data_values);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_22expand_kids_by_data(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_data_values) {
  int __pyx_v_changed;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_child = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("expand_kids_by_data", 0);

  /* "lark_cython/lark_cython.pyx":703
 *     def expand_kids_by_data(self, *data_values):
 *         """Expand (inline) children with any of the given data values. Returns True if anything changed"""
 *         changed = False             # <<<<<<<<<<<<<<
 *         for i in range(len(self.children)-1, -1, -1):
 *             child = self.children[i]
 */
  __pyx_v_changed = 0;

  /* "lark_cython/lark_cython.pyx":704
 *         """Expand (inline) children with any of the given data values. Returns True if anything changed"""
 *         changed = False
 *         for i in range(len(self.children)-1, -1, -1):             # <<<<<<<<<<<<<<
 *             child = self.children[i]
 *             if isinstance(child, Tree) and child.data in data_values:
 */
  __pyx_t_1 = __pyx_v_self->children;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 704, __pyx_L1_error)
  }
  __pyx_t_2 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t((__pyx_t_2 - 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_int_neg_1);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_neg_1);
  __Pyx_INCREF(__pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_int_neg_1);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_int_neg_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_2 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 704, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_2); __Pyx_INCREF(__pyx_t_1); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 704, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_2); __Pyx_INCREF(__pyx_t_1); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 704, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 704, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":705
 *         changed = False
 *         for i in range(len(self.children)-1, -1, -1):
 *             child = self.children[i]             # <<<<<<<<<<<<<<
 *             if isinstance(child, Tree) and child.data in data_values:
 *                 self.children[i:i+1] = child.children
 */
    if (unlikely(__pyx_v_self->children == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 705, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_self->children, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_child, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":706
 *         for i in range(len(self.children)-1, -1, -1):
 *             child = self.children[i]
 *             if isinstance(child, Tree) and child.data in data_values:             # <<<<<<<<<<<<<<
 *                 self.children[i:i+1] = child.children
 *                 changed = True
 */
    __pyx_t_6 = __Pyx_TypeCheck(__pyx_v_child, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_child, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_v_data_values, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 706, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = (__pyx_t_7 != 0);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "lark_cython/lark_cython.pyx":707
 *             child = self.children[i]
 *             if isinstance(child, Tree) and child.data in data_values:
 *                 self.children[i:i+1] = child.children             # <<<<<<<<<<<<<<
 *                 changed = True
 *         return changed
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_child, __pyx_n_s_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__pyx_v_self->children == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 707, __pyx_L1_error)
      }
      __Pyx_INCREF(__pyx_v_i);
      __pyx_t_8 = __pyx_v_i;
      __pyx_t_5 = (__pyx_t_8 == Py_None);
      if (__pyx_t_5) {
        __pyx_t_9 = 0;
      } else {
        __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 707, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_10;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 707, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_5 = (__pyx_t_8 == Py_None);
      if (__pyx_t_5) {
        __pyx_t_10 = PY_SSIZE_T_MAX;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 707, __pyx_L1_error)
        __pyx_t_10 = __pyx_t_11;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__Pyx_PyObject_SetSlice(__pyx_v_self->children, __pyx_t_1, __pyx_t_9, __pyx_t_10, NULL, NULL, NULL, 1, 1, 1) < 0) __PYX_ERR(0, 707, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "lark_cython/lark_cython.pyx":708
 *             if isinstance(child, Tree) and child.data in data_values:
 *                 self.children[i:i+1] = child.children
 *                 changed = True             # <<<<<<<<<<<<<<
 *         return changed
 * 
 */
      __pyx_v_changed = 1;

      /* "lark_cython/lark_cython.pyx":706
 *         for i in range(len(self.children)-1, -1, -1):
 *             child = self.children[i]
 *             if isinstance(child, Tree) and child.data in data_values:             # <<<<<<<<<<<<<<
 *                 self.children[i:i+1] = child.children
 *                 changed = True
 */
    }

    /* "lark_cython/lark_cython.pyx":704
 *         """Expand (inline) children with any of the given data values. Returns True if anything changed"""
 *         changed = False
 *         for i in range(len(self.children)-1, -1, -1):             # <<<<<<<<<<<<<<
 *             child = self.children[i]
 *             if isinstance(child, Tree) and child.data in data_values:
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "lark_cython/lark_cython.pyx":709
 *                 self.children[i:i+1] = child.children
 *                 changed = True
 *         return changed             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_changed); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":701
 * ###}
 * 
 *     def expand_kids_by_data(self, *data_values):             # <<<<<<<<<<<<<<
 *         """Expand (inline) children with any of the given data values. Returns True if anything changed"""
 *         changed = False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.expand_kids_by_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_child);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_4Tree_26generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":712
 * 
 * 
 *     def scan_values(self, pred: 'Callable[[Union[str, Tree]], bool]') -> Iterator[str]:             # <<<<<<<<<<<<<<
 *         """Return all values in the tree that evaluate pred(value) as true.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_25scan_values(PyObject *__pyx_v_self, PyObject *__pyx_v_pred); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_24scan_values[] = "Return all values in the tree that evaluate pred(value) as true.\n\n        This can be used to find all the tokens in the tree.\n\n        Example:\n            >>> all_tokens = tree.scan_values(lambda v: isinstance(v, Token))\n        ";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_25scan_values(PyObject *__pyx_v_self, PyObject *__pyx_v_pred) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scan_values (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_24scan_values(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_pred));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_24scan_values(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_pred) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scan_values", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 712, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_pred = __pyx_v_pred;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_pred);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_pred);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_4Tree_26generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_scan_values, __pyx_n_s_Tree_scan_values, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.scan_values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_4Tree_26generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scan_values", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L9_resume_from_yield;
    case 2: goto __pyx_L11_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 712, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":720
 *             >>> all_tokens = tree.scan_values(lambda v: isinstance(v, Token))
 *         """
 *         for c in self.children:             # <<<<<<<<<<<<<<
 *             if isinstance(c, Tree):
 *                 for t in c.scan_values(pred):
 */
  if (unlikely(__pyx_cur_scope->__pyx_v_self->children == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 720, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self->children; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 720, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_c);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_c, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":721
 *         """
 *         for c in self.children:
 *             if isinstance(c, Tree):             # <<<<<<<<<<<<<<
 *                 for t in c.scan_values(pred):
 *                     yield t
 */
    __pyx_t_4 = __Pyx_TypeCheck(__pyx_cur_scope->__pyx_v_c, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (__pyx_t_5) {

      /* "lark_cython/lark_cython.pyx":722
 *         for c in self.children:
 *             if isinstance(c, Tree):
 *                 for t in c.scan_values(pred):             # <<<<<<<<<<<<<<
 *                     yield t
 *             else:
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_c, __pyx_n_s_scan_values); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, __pyx_cur_scope->__pyx_v_pred) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_cur_scope->__pyx_v_pred);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_6 = __pyx_t_3; __Pyx_INCREF(__pyx_t_6); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 722, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_9 = Py_TYPE(__pyx_t_6)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 722, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_6)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 722, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 722, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 722, __pyx_L1_error)
            #else
            __pyx_t_3 = PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 722, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_9(__pyx_t_6);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 722, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_t);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_t, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __pyx_t_3 = 0;

        /* "lark_cython/lark_cython.pyx":723
 *             if isinstance(c, Tree):
 *                 for t in c.scan_values(pred):
 *                     yield t             # <<<<<<<<<<<<<<
 *             else:
 *                 if pred(c):
 */
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_t);
        __pyx_r = __pyx_cur_scope->__pyx_v_t;
        __Pyx_XGIVEREF(__pyx_t_1);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
        __Pyx_XGIVEREF(__pyx_t_6);
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
        __pyx_cur_scope->__pyx_t_3 = __pyx_t_8;
        __pyx_cur_scope->__pyx_t_4 = __pyx_t_9;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, yielding value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L9_resume_from_yield:;
        __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_1);
        __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
        __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = 0;
        __Pyx_XGOTREF(__pyx_t_6);
        __pyx_t_8 = __pyx_cur_scope->__pyx_t_3;
        __pyx_t_9 = __pyx_cur_scope->__pyx_t_4;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 723, __pyx_L1_error)

        /* "lark_cython/lark_cython.pyx":722
 *         for c in self.children:
 *             if isinstance(c, Tree):
 *                 for t in c.scan_values(pred):             # <<<<<<<<<<<<<<
 *                     yield t
 *             else:
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "lark_cython/lark_cython.pyx":721
 *         """
 *         for c in self.children:
 *             if isinstance(c, Tree):             # <<<<<<<<<<<<<<
 *                 for t in c.scan_values(pred):
 *                     yield t
 */
      goto __pyx_L6;
    }

    /* "lark_cython/lark_cython.pyx":725
 *                     yield t
 *             else:
 *                 if pred(c):             # <<<<<<<<<<<<<<
 *                     yield c
 * 
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_pred);
      __pyx_t_3 = __pyx_cur_scope->__pyx_v_pred; __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_cur_scope->__pyx_v_c) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_c);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 725, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 725, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_5) {

        /* "lark_cython/lark_cython.pyx":726
 *             else:
 *                 if pred(c):
 *                     yield c             # <<<<<<<<<<<<<<
 * 
 *     def iter_subtrees_topdown(self):
 */
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_c);
        __pyx_r = __pyx_cur_scope->__pyx_v_c;
        __Pyx_XGIVEREF(__pyx_t_1);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, yielding value */
        __pyx_generator->resume_label = 2;
        return __pyx_r;
        __pyx_L11_resume_from_yield:;
        __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_1);
        __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 726, __pyx_L1_error)

        /* "lark_cython/lark_cython.pyx":725
 *                     yield t
 *             else:
 *                 if pred(c):             # <<<<<<<<<<<<<<
 *                     yield c
 * 
 */
      }
    }
    __pyx_L6:;

    /* "lark_cython/lark_cython.pyx":720
 *             >>> all_tokens = tree.scan_values(lambda v: isinstance(v, Token))
 *         """
 *         for c in self.children:             # <<<<<<<<<<<<<<
 *             if isinstance(c, Tree):
 *                 for t in c.scan_values(pred):
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "lark_cython/lark_cython.pyx":712
 * 
 * 
 *     def scan_values(self, pred: 'Callable[[Union[str, Tree]], bool]') -> Iterator[str]:             # <<<<<<<<<<<<<<
 *         """Return all values in the tree that evaluate pred(value) as true.
 * 
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("scan_values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_4Tree_29generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":728
 *                     yield c
 * 
 *     def iter_subtrees_topdown(self):             # <<<<<<<<<<<<<<
 *         """Breadth-first iteration.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_28iter_subtrees_topdown(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_11lark_cython_11lark_cython_4Tree_27iter_subtrees_topdown[] = "Breadth-first iteration.\n\n        Iterates over all the subtrees, return nodes in order like pretty() does.\n        ";
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_28iter_subtrees_topdown(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iter_subtrees_topdown (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_27iter_subtrees_topdown(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_27iter_subtrees_topdown(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("iter_subtrees_topdown", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 728, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_4Tree_29generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter_subtrees_topdown, __pyx_n_s_Tree_iter_subtrees_topdown, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 728, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.iter_subtrees_topdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_4Tree_29generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("iter_subtrees_topdown", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 728, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":733
 *         Iterates over all the subtrees, return nodes in order like pretty() does.
 *         """
 *         stack = [self]             # <<<<<<<<<<<<<<
 *         while stack:
 *             node = stack.pop()
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
  PyList_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":734
 *         """
 *         stack = [self]
 *         while stack:             # <<<<<<<<<<<<<<
 *             node = stack.pop()
 *             if not isinstance(node, Tree):
 */
  while (1) {
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_cur_scope->__pyx_v_stack) != 0);
    if (!__pyx_t_2) break;

    /* "lark_cython/lark_cython.pyx":735
 *         stack = [self]
 *         while stack:
 *             node = stack.pop()             # <<<<<<<<<<<<<<
 *             if not isinstance(node, Tree):
 *                 continue
 */
    __pyx_t_1 = __Pyx_PyList_Pop(__pyx_cur_scope->__pyx_v_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_node);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_node, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":736
 *         while stack:
 *             node = stack.pop()
 *             if not isinstance(node, Tree):             # <<<<<<<<<<<<<<
 *                 continue
 *             yield node
 */
    __pyx_t_2 = __Pyx_TypeCheck(__pyx_cur_scope->__pyx_v_node, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
    __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
    if (__pyx_t_3) {

      /* "lark_cython/lark_cython.pyx":737
 *             node = stack.pop()
 *             if not isinstance(node, Tree):
 *                 continue             # <<<<<<<<<<<<<<
 *             yield node
 *             for n in reversed(node.children):
 */
      goto __pyx_L4_continue;

      /* "lark_cython/lark_cython.pyx":736
 *         while stack:
 *             node = stack.pop()
 *             if not isinstance(node, Tree):             # <<<<<<<<<<<<<<
 *                 continue
 *             yield node
 */
    }

    /* "lark_cython/lark_cython.pyx":738
 *             if not isinstance(node, Tree):
 *                 continue
 *             yield node             # <<<<<<<<<<<<<<
 *             for n in reversed(node.children):
 *                 stack.append(n)
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_node);
    __pyx_r = __pyx_cur_scope->__pyx_v_node;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L7_resume_from_yield:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 738, __pyx_L1_error)

    /* "lark_cython/lark_cython.pyx":739
 *                 continue
 *             yield node
 *             for n in reversed(node.children):             # <<<<<<<<<<<<<<
 *                 stack.append(n)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_node, __pyx_n_s_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_reversed, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 739, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 739, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 739, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 739, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 739, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 739, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_6(__pyx_t_1);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 739, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_n);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_n, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;

      /* "lark_cython/lark_cython.pyx":740
 *             yield node
 *             for n in reversed(node.children):
 *                 stack.append(n)             # <<<<<<<<<<<<<<
 * 
 *     def __deepcopy__(self, memo):
 */
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_stack, __pyx_cur_scope->__pyx_v_n); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 740, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":739
 *                 continue
 *             yield node
 *             for n in reversed(node.children):             # <<<<<<<<<<<<<<
 *                 stack.append(n)
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_L4_continue:;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "lark_cython/lark_cython.pyx":728
 *                     yield c
 * 
 *     def iter_subtrees_topdown(self):             # <<<<<<<<<<<<<<
 *         """Breadth-first iteration.
 * 
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("iter_subtrees_topdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":742
 *                 stack.append(n)
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return type(self)(self.data, deepcopy(self.children, memo), meta=self._meta)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_31__deepcopy__(PyObject *__pyx_v_self, PyObject *__pyx_v_memo); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_31__deepcopy__(PyObject *__pyx_v_self, PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__deepcopy__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_30__deepcopy__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_memo));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_30__deepcopy__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_memo) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__deepcopy__", 0);

  /* "lark_cython/lark_cython.pyx":743
 * 
 *     def __deepcopy__(self, memo):
 *         return type(self)(self.data, deepcopy(self.children, memo), meta=self._meta)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self) -> 'Tree':
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_self->children, __pyx_v_memo};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_self->children, __pyx_v_memo};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_self->children);
    __Pyx_GIVEREF(__pyx_v_self->children);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_self->children);
    __Pyx_INCREF(__pyx_v_memo);
    __Pyx_GIVEREF(__pyx_v_memo);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_memo);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->data));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_meta, ((PyObject *)__pyx_v_self->_meta)) < 0) __PYX_ERR(0, 743, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":742
 *                 stack.append(n)
 * 
 *     def __deepcopy__(self, memo):             # <<<<<<<<<<<<<<
 *         return type(self)(self.data, deepcopy(self.children, memo), meta=self._meta)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__deepcopy__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":745
 *         return type(self)(self.data, deepcopy(self.children, memo), meta=self._meta)
 * 
 *     def copy(self) -> 'Tree':             # <<<<<<<<<<<<<<
 *         return type(self)(self.data, self.children)
 * 
 */

/* Python wrapper */
static struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_pw_11lark_cython_11lark_cython_4Tree_33copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_pw_11lark_cython_11lark_cython_4Tree_33copy(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_32copy(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_pf_11lark_cython_11lark_cython_4Tree_32copy(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "lark_cython/lark_cython.pyx":746
 * 
 *     def copy(self) -> 'Tree':
 *         return type(self)(self.data, self.children)             # <<<<<<<<<<<<<<
 * 
 *     def set(self, data: str, children: 'List[Union[str, Tree]]') -> None:
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __pyx_t_2 = ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))); __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, ((PyObject *)__pyx_v_self->data), __pyx_v_self->children};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, ((PyObject *)__pyx_v_self->data), __pyx_v_self->children};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self->data));
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, ((PyObject *)__pyx_v_self->data));
    __Pyx_INCREF(__pyx_v_self->children);
    __Pyx_GIVEREF(__pyx_v_self->children);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_self->children);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_Tree))))) __PYX_ERR(0, 746, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":745
 *         return type(self)(self.data, deepcopy(self.children, memo), meta=self._meta)
 * 
 *     def copy(self) -> 'Tree':             # <<<<<<<<<<<<<<
 *         return type(self)(self.data, self.children)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":748
 *         return type(self)(self.data, self.children)
 * 
 *     def set(self, data: str, children: 'List[Union[str, Tree]]') -> None:             # <<<<<<<<<<<<<<
 *         self.data = data
 *         self.children = children
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_35set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_35set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,&__pyx_n_s_children,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, 1); __PYX_ERR(0, 748, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) __PYX_ERR(0, 748, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_data = ((PyObject*)values[0]);
    __pyx_v_children = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 748, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_data), (&PyUnicode_Type), 1, "data", 1))) __PYX_ERR(0, 748, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_34set(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), __pyx_v_data, __pyx_v_children);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_34set(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_data, PyObject *__pyx_v_children) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 0);

  /* "lark_cython/lark_cython.pyx":749
 * 
 *     def set(self, data: str, children: 'List[Union[str, Tree]]') -> None:
 *         self.data = data             # <<<<<<<<<<<<<<
 *         self.children = children
 * 
 */
  if (!(likely(((__pyx_v_data) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_data, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 749, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_data;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->data);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->data));
  __pyx_v_self->data = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":750
 *     def set(self, data: str, children: 'List[Union[str, Tree]]') -> None:
 *         self.data = data
 *         self.children = children             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (!(likely(PyList_CheckExact(__pyx_v_children))||((__pyx_v_children) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_children)->tp_name), 0))) __PYX_ERR(0, 750, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_children;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":748
 *         return type(self)(self.data, self.children)
 * 
 *     def set(self, data: str, children: 'List[Union[str, Tree]]') -> None:             # <<<<<<<<<<<<<<
 *         self.data = data
 *         self.children = children
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":623
 * 
 * cdef class Tree:
 *     cdef public Token data             # <<<<<<<<<<<<<<
 *     cdef public list children #: 'List[Union[str, Tree]]'
 *     cdef public Meta _meta
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_4data_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_4data_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_4data___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_4data___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  __pyx_r = ((PyObject *)__pyx_v_self->data);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_4data_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree_4data_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_11lark_cython_11lark_cython_Token))))) __PYX_ERR(0, 623, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->data);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->data));
  __pyx_v_self->data = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.data.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_4data_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree_4data_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->data);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->data));
  __pyx_v_self->data = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":624
 * cdef class Tree:
 *     cdef public Token data
 *     cdef public list children #: 'List[Union[str, Tree]]'             # <<<<<<<<<<<<<<
 *     cdef public Meta _meta
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_8children_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_8children_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_8children___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_8children___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->children);
  __pyx_r = __pyx_v_self->children;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_8children_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree_8children_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(PyList_CheckExact(__pyx_v_value))||((__pyx_v_value) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_value)->tp_name), 0))) __PYX_ERR(0, 624, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.children.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_8children_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree_8children_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->children);
  __Pyx_DECREF(__pyx_v_self->children);
  __pyx_v_self->children = ((PyObject*)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":625
 *     cdef public Token data
 *     cdef public list children #: 'List[Union[str, Tree]]'
 *     cdef public Meta _meta             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, Token data, list children, meta=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta___get__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta___get__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_meta));
  __pyx_r = ((PyObject *)__pyx_v_self->_meta);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta_2__set__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta_2__set__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_11lark_cython_11lark_cython_Meta))))) __PYX_ERR(0, 625, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_meta);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_meta));
  __pyx_v_self->_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree._meta.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta_4__del__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_4Tree_5_meta_4__del__(struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_meta);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_meta));
  __pyx_v_self->_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_37__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_37__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_36__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_36__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_39__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_4Tree_39__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4Tree_38__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4Tree_38__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.Tree.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":761
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 * def apply_visit_wrapper(func, name, wrapper):             # <<<<<<<<<<<<<<
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_1apply_visit_wrapper(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_1apply_visit_wrapper = {"apply_visit_wrapper", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_1apply_visit_wrapper, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_1apply_visit_wrapper(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_wrapper = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("apply_visit_wrapper (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,&__pyx_n_s_name,&__pyx_n_s_wrapper,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_func)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("apply_visit_wrapper", 1, 3, 3, 1); __PYX_ERR(0, 761, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_wrapper)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("apply_visit_wrapper", 1, 3, 3, 2); __PYX_ERR(0, 761, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "apply_visit_wrapper") < 0)) __PYX_ERR(0, 761, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_func = values[0];
    __pyx_v_name = values[1];
    __pyx_v_wrapper = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("apply_visit_wrapper", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 761, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.apply_visit_wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_apply_visit_wrapper(__pyx_self, __pyx_v_func, __pyx_v_name, __pyx_v_wrapper);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":766
 * 
 *     @wraps(func)
 *     def f(children):             # <<<<<<<<<<<<<<
 *         return wrapper(func, name, children, None)
 *     return f
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_19apply_visit_wrapper_1f(PyObject *__pyx_self, PyObject *__pyx_v_children); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_19apply_visit_wrapper_1f = {"f", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_19apply_visit_wrapper_1f, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_19apply_visit_wrapper_1f(PyObject *__pyx_self, PyObject *__pyx_v_children) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("f (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_19apply_visit_wrapper_f(__pyx_self, ((PyObject *)__pyx_v_children));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_19apply_visit_wrapper_f(PyObject *__pyx_self, PyObject *__pyx_v_children) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *__pyx_cur_scope;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("f", 0);
  __pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "lark_cython/lark_cython.pyx":767
 *     @wraps(func)
 *     def f(children):
 *         return wrapper(func, name, children, None)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_wrapper)) { __Pyx_RaiseClosureNameError("wrapper"); __PYX_ERR(0, 767, __pyx_L1_error) }
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 767, __pyx_L1_error) }
  if (unlikely(!__pyx_cur_scope->__pyx_v_name)) { __Pyx_RaiseClosureNameError("name"); __PYX_ERR(0, 767, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_wrapper);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_wrapper; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_func, __pyx_cur_scope->__pyx_v_name, __pyx_v_children, Py_None};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_func, __pyx_cur_scope->__pyx_v_name, __pyx_v_children, Py_None};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 4+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(4+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_cur_scope->__pyx_v_func);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_name);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_cur_scope->__pyx_v_name);
    __Pyx_INCREF(__pyx_v_children);
    __Pyx_GIVEREF(__pyx_v_children);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_v_children);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_5, 3+__pyx_t_4, Py_None);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":766
 * 
 *     @wraps(func)
 *     def f(children):             # <<<<<<<<<<<<<<
 *         return wrapper(func, name, children, None)
 *     return f
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.apply_visit_wrapper.f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":761
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 * def apply_visit_wrapper(func, name, wrapper):             # <<<<<<<<<<<<<<
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_apply_visit_wrapper(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_name, PyObject *__pyx_v_wrapper) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *__pyx_cur_scope;
  PyObject *__pyx_v_f = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_visit_wrapper", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 761, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_cur_scope->__pyx_v_name = __pyx_v_name;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_name);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_name);
  __pyx_cur_scope->__pyx_v_wrapper = __pyx_v_wrapper;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_wrapper);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_wrapper);

  /* "lark_cython/lark_cython.pyx":762
 * 
 * def apply_visit_wrapper(func, name, wrapper):
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_vargs_meta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_cur_scope->__pyx_v_wrapper == __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_vargs_meta_inline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__pyx_cur_scope->__pyx_v_wrapper == __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "lark_cython/lark_cython.pyx":763
 * def apply_visit_wrapper(func, name, wrapper):
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")             # <<<<<<<<<<<<<<
 * 
 *     @wraps(func)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 763, __pyx_L1_error)

    /* "lark_cython/lark_cython.pyx":762
 * 
 * def apply_visit_wrapper(func, name, wrapper):
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":765
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 * 
 *     @wraps(func)             # <<<<<<<<<<<<<<
 *     def f(children):
 *         return wrapper(func, name, children, None)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, __pyx_cur_scope->__pyx_v_func) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_cur_scope->__pyx_v_func);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "lark_cython/lark_cython.pyx":766
 * 
 *     @wraps(func)
 *     def f(children):             # <<<<<<<<<<<<<<
 *         return wrapper(func, name, children, None)
 *     return f
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_19apply_visit_wrapper_1f, 0, __pyx_n_s_apply_visit_wrapper_locals_f, ((PyObject*)__pyx_cur_scope), __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__35)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_f = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":768
 *     def f(children):
 *         return wrapper(func, name, children, None)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * def inplace_transformer(func):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_f);
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":761
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 * def apply_visit_wrapper(func, name, wrapper):             # <<<<<<<<<<<<<<
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("lark_cython.lark_cython.apply_visit_wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":770
 *     return f
 * 
 * def inplace_transformer(func):             # <<<<<<<<<<<<<<
 *     @wraps(func)
 *     def f(list children):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_3inplace_transformer(PyObject *__pyx_self, PyObject *__pyx_v_func); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_3inplace_transformer = {"inplace_transformer", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_3inplace_transformer, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_3inplace_transformer(PyObject *__pyx_self, PyObject *__pyx_v_func) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("inplace_transformer (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_2inplace_transformer(__pyx_self, ((PyObject *)__pyx_v_func));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":772
 * def inplace_transformer(func):
 *     @wraps(func)
 *     def f(list children):             # <<<<<<<<<<<<<<
 *         # function name in a Transformer is a rule name.
 *         cdef Tree tree
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_19inplace_transformer_1f(PyObject *__pyx_self, PyObject *__pyx_v_children); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_19inplace_transformer_1f = {"f", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_19inplace_transformer_1f, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_19inplace_transformer_1f(PyObject *__pyx_self, PyObject *__pyx_v_children) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("f (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_children), (&PyList_Type), 1, "children", 1))) __PYX_ERR(0, 772, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_19inplace_transformer_f(__pyx_self, ((PyObject*)__pyx_v_children));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_19inplace_transformer_f(PyObject *__pyx_self, PyObject *__pyx_v_children) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *__pyx_cur_scope;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *__pyx_outer_scope;
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_tree = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("f", 0);
  __pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "lark_cython/lark_cython.pyx":775
 *         # function name in a Transformer is a rule name.
 *         cdef Tree tree
 *         tree = Tree(func.__name__, children)             # <<<<<<<<<<<<<<
 *         return func(tree)
 *     return f
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 775, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_func, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_children);
  __Pyx_GIVEREF(__pyx_v_children);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_children);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Tree), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tree = ((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":776
 *         cdef Tree tree
 *         tree = Tree(func.__name__, children)
 *         return func(tree)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 776, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_func; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, ((PyObject *)__pyx_v_tree)) : __Pyx_PyObject_CallOneArg(__pyx_t_2, ((PyObject *)__pyx_v_tree));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":772
 * def inplace_transformer(func):
 *     @wraps(func)
 *     def f(list children):             # <<<<<<<<<<<<<<
 *         # function name in a Transformer is a rule name.
 *         cdef Tree tree
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.inplace_transformer.f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tree);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":770
 *     return f
 * 
 * def inplace_transformer(func):             # <<<<<<<<<<<<<<
 *     @wraps(func)
 *     def f(list children):
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_2inplace_transformer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *__pyx_cur_scope;
  PyObject *__pyx_v_f = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("inplace_transformer", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 770, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);

  /* "lark_cython/lark_cython.pyx":771
 * 
 * def inplace_transformer(func):
 *     @wraps(func)             # <<<<<<<<<<<<<<
 *     def f(list children):
 *         # function name in a Transformer is a rule name.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_wraps); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_cur_scope->__pyx_v_func) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_func);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "lark_cython/lark_cython.pyx":772
 * def inplace_transformer(func):
 *     @wraps(func)
 *     def f(list children):             # <<<<<<<<<<<<<<
 *         # function name in a Transformer is a rule name.
 *         cdef Tree tree
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_19inplace_transformer_1f, 0, __pyx_n_s_inplace_transformer_locals_f, ((PyObject*)__pyx_cur_scope), __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__37)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_f = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":777
 *         tree = Tree(func.__name__, children)
 *         return func(tree)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * cdef class ExpandSingleChild:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_f);
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":770
 *     return f
 * 
 * def inplace_transformer(func):             # <<<<<<<<<<<<<<
 *     @wraps(func)
 *     def f(list children):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("lark_cython.lark_cython.inplace_transformer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":782
 *     cdef node_builder
 * 
 *     def __init__(self, node_builder):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 * 
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_node_builder = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_node_builder,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node_builder)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 782, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_node_builder = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 782, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ExpandSingleChild.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild___init__(((struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)__pyx_v_self), __pyx_v_node_builder);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild___init__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self, PyObject *__pyx_v_node_builder) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":783
 * 
 *     def __init__(self, node_builder):
 *         self.node_builder = node_builder             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, list children):
 */
  __Pyx_INCREF(__pyx_v_node_builder);
  __Pyx_GIVEREF(__pyx_v_node_builder);
  __Pyx_GOTREF(__pyx_v_self->node_builder);
  __Pyx_DECREF(__pyx_v_self->node_builder);
  __pyx_v_self->node_builder = __pyx_v_node_builder;

  /* "lark_cython/lark_cython.pyx":782
 *     cdef node_builder
 * 
 *     def __init__(self, node_builder):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":785
 *         self.node_builder = node_builder
 * 
 *     def __call__(self, list children):             # <<<<<<<<<<<<<<
 *         if len(children) == 1:
 *             return children[0]
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_children,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 785, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_children = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 785, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ExpandSingleChild.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_children), (&PyList_Type), 1, "children", 1))) __PYX_ERR(0, 785, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_2__call__(((struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)__pyx_v_self), __pyx_v_children);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self, PyObject *__pyx_v_children) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "lark_cython/lark_cython.pyx":786
 * 
 *     def __call__(self, list children):
 *         if len(children) == 1:             # <<<<<<<<<<<<<<
 *             return children[0]
 *         else:
 */
  if (unlikely(__pyx_v_children == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 786, __pyx_L1_error)
  }
  __pyx_t_1 = PyList_GET_SIZE(__pyx_v_children); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 786, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 == 1) != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":787
 *     def __call__(self, list children):
 *         if len(children) == 1:
 *             return children[0]             # <<<<<<<<<<<<<<
 *         else:
 *             return self.node_builder(children)
 */
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_children == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 787, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_children, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 787, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":786
 * 
 *     def __call__(self, list children):
 *         if len(children) == 1:             # <<<<<<<<<<<<<<
 *             return children[0]
 *         else:
 */
  }

  /* "lark_cython/lark_cython.pyx":789
 *             return children[0]
 *         else:
 *             return self.node_builder(children)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->node_builder);
    __pyx_t_4 = __pyx_v_self->node_builder; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_children) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_children);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "lark_cython/lark_cython.pyx":785
 *         self.node_builder = node_builder
 * 
 *     def __call__(self, list children):             # <<<<<<<<<<<<<<
 *         if len(children) == 1:
 *             return children[0]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.ExpandSingleChild.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.node_builder,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->node_builder);
  __Pyx_GIVEREF(__pyx_v_self->node_builder);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->node_builder);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.node_builder,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.node_builder,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.node_builder is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.node_builder,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.node_builder is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, None), state
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->node_builder != Py_None);
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.node_builder is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.node_builder is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_ExpandSingleChild); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_146776923);
    __Pyx_GIVEREF(__pyx_int_146776923);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_146776923);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.node_builder is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, None), state
 *     else:
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ExpandSingleChild__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_ExpandSingleChild); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_146776923);
    __Pyx_GIVEREF(__pyx_int_146776923);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_146776923);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.ExpandSingleChild.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ExpandSingleChild__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_17ExpandSingleChild_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ExpandSingleChild__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ExpandSingleChild__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ExpandSingleChild, (type(self), 0x8bfa35b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ExpandSingleChild__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ExpandSingleChild.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":796
 *     cdef node_filter
 * 
 *     def __init__(self, node_builder, node_filter=None):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 *         self.node_filter = node_filter
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_node_builder = 0;
  PyObject *__pyx_v_node_filter = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_node_builder,&__pyx_n_s_node_filter,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node_builder)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node_filter);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 796, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_node_builder = values[0];
    __pyx_v_node_filter = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 796, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.PropagatePositions.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_18PropagatePositions___init__(((struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v_self), __pyx_v_node_builder, __pyx_v_node_filter);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_18PropagatePositions___init__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v_node_builder, PyObject *__pyx_v_node_filter) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":797
 * 
 *     def __init__(self, node_builder, node_filter=None):
 *         self.node_builder = node_builder             # <<<<<<<<<<<<<<
 *         self.node_filter = node_filter
 * 
 */
  __Pyx_INCREF(__pyx_v_node_builder);
  __Pyx_GIVEREF(__pyx_v_node_builder);
  __Pyx_GOTREF(__pyx_v_self->node_builder);
  __Pyx_DECREF(__pyx_v_self->node_builder);
  __pyx_v_self->node_builder = __pyx_v_node_builder;

  /* "lark_cython/lark_cython.pyx":798
 *     def __init__(self, node_builder, node_filter=None):
 *         self.node_builder = node_builder
 *         self.node_filter = node_filter             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, children):
 */
  __Pyx_INCREF(__pyx_v_node_filter);
  __Pyx_GIVEREF(__pyx_v_node_filter);
  __Pyx_GOTREF(__pyx_v_self->node_filter);
  __Pyx_DECREF(__pyx_v_self->node_filter);
  __pyx_v_self->node_filter = __pyx_v_node_filter;

  /* "lark_cython/lark_cython.pyx":796
 *     cdef node_filter
 * 
 *     def __init__(self, node_builder, node_filter=None):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 *         self.node_filter = node_filter
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":800
 *         self.node_filter = node_filter
 * 
 *     def __call__(self, children):             # <<<<<<<<<<<<<<
 *         cdef Meta res_meta, first_meta, last_meta
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_children,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 800, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_children = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 800, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.PropagatePositions.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_2__call__(((struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v_self), __pyx_v_children);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v_children) {
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_res_meta = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_first_meta = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v_last_meta = 0;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "lark_cython/lark_cython.pyx":803
 *         cdef Meta res_meta, first_meta, last_meta
 * 
 *         res = self.node_builder(children)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(res, Tree):
 */
  __Pyx_INCREF(__pyx_v_self->node_builder);
  __pyx_t_2 = __pyx_v_self->node_builder; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_children) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_children);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_res = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":805
 *         res = self.node_builder(children)
 * 
 *         if isinstance(res, Tree):             # <<<<<<<<<<<<<<
 *             # Calculate positions while the tree is streaming, according to the rule:
 *             # - nodes start at the start of their first child's container,
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_res, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "lark_cython/lark_cython.pyx":811
 *             # Containers are nodes that take up space in text, but have been inlined in the tree.
 * 
 *             res_meta = res.meta             # <<<<<<<<<<<<<<
 * 
 *             first_meta = self._pp_get_meta(children)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_meta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_Meta))))) __PYX_ERR(0, 811, __pyx_L1_error)
    __pyx_v_res_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":813
 *             res_meta = res.meta
 * 
 *             first_meta = self._pp_get_meta(children)             # <<<<<<<<<<<<<<
 *             if first_meta is not None:
 *                 if not hasattr(res_meta, 'line'):
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v_self->__pyx_vtab)->_pp_get_meta(__pyx_v_self, __pyx_v_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_Meta))))) __PYX_ERR(0, 813, __pyx_L1_error)
    __pyx_v_first_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":814
 * 
 *             first_meta = self._pp_get_meta(children)
 *             if first_meta is not None:             # <<<<<<<<<<<<<<
 *                 if not hasattr(res_meta, 'line'):
 *                     # meta was already set, probably because the rule has been inlined (e.g. `?rule`)
 */
    __pyx_t_5 = (((PyObject *)__pyx_v_first_meta) != Py_None);
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (__pyx_t_4) {

      /* "lark_cython/lark_cython.pyx":815
 *             first_meta = self._pp_get_meta(children)
 *             if first_meta is not None:
 *                 if not hasattr(res_meta, 'line'):             # <<<<<<<<<<<<<<
 *                     # meta was already set, probably because the rule has been inlined (e.g. `?rule`)
 *                     res_meta.line = getattr(first_meta, 'container_line', first_meta.line)
 */
      __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v_res_meta), __pyx_n_u_line); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 815, __pyx_L1_error)
      __pyx_t_5 = ((!(__pyx_t_4 != 0)) != 0);
      if (__pyx_t_5) {

        /* "lark_cython/lark_cython.pyx":817
 *                 if not hasattr(res_meta, 'line'):
 *                     # meta was already set, probably because the rule has been inlined (e.g. `?rule`)
 *                     res_meta.line = getattr(first_meta, 'container_line', first_meta.line)             # <<<<<<<<<<<<<<
 *                     res_meta.column = getattr(first_meta, 'container_column', first_meta.column)
 *                     res_meta.start_pos = getattr(first_meta, 'container_start_pos', first_meta.start_pos)
 */
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_first_meta->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_first_meta), __pyx_n_u_container_line, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_res_meta->line = __pyx_t_6;

        /* "lark_cython/lark_cython.pyx":818
 *                     # meta was already set, probably because the rule has been inlined (e.g. `?rule`)
 *                     res_meta.line = getattr(first_meta, 'container_line', first_meta.line)
 *                     res_meta.column = getattr(first_meta, 'container_column', first_meta.column)             # <<<<<<<<<<<<<<
 *                     res_meta.start_pos = getattr(first_meta, 'container_start_pos', first_meta.start_pos)
 *                     res_meta.empty = False
 */
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_first_meta->column); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_first_meta), __pyx_n_u_container_column, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 818, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 818, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_res_meta->column = __pyx_t_6;

        /* "lark_cython/lark_cython.pyx":819
 *                     res_meta.line = getattr(first_meta, 'container_line', first_meta.line)
 *                     res_meta.column = getattr(first_meta, 'container_column', first_meta.column)
 *                     res_meta.start_pos = getattr(first_meta, 'container_start_pos', first_meta.start_pos)             # <<<<<<<<<<<<<<
 *                     res_meta.empty = False
 * 
 */
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_first_meta->start_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 819, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_first_meta), __pyx_n_u_container_start_pos, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 819, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 819, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_res_meta->start_pos = __pyx_t_6;

        /* "lark_cython/lark_cython.pyx":820
 *                     res_meta.column = getattr(first_meta, 'container_column', first_meta.column)
 *                     res_meta.start_pos = getattr(first_meta, 'container_start_pos', first_meta.start_pos)
 *                     res_meta.empty = False             # <<<<<<<<<<<<<<
 * 
 *                 res_meta.container_line = getattr(first_meta, 'container_line', first_meta.line)
 */
        __pyx_v_res_meta->empty = 0;

        /* "lark_cython/lark_cython.pyx":815
 *             first_meta = self._pp_get_meta(children)
 *             if first_meta is not None:
 *                 if not hasattr(res_meta, 'line'):             # <<<<<<<<<<<<<<
 *                     # meta was already set, probably because the rule has been inlined (e.g. `?rule`)
 *                     res_meta.line = getattr(first_meta, 'container_line', first_meta.line)
 */
      }

      /* "lark_cython/lark_cython.pyx":822
 *                     res_meta.empty = False
 * 
 *                 res_meta.container_line = getattr(first_meta, 'container_line', first_meta.line)             # <<<<<<<<<<<<<<
 *                 res_meta.container_column = getattr(first_meta, 'container_column', first_meta.column)
 * 
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_first_meta->line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_first_meta), __pyx_n_u_container_line, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_res_meta), __pyx_n_s_container_line, __pyx_t_1) < 0) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "lark_cython/lark_cython.pyx":823
 * 
 *                 res_meta.container_line = getattr(first_meta, 'container_line', first_meta.line)
 *                 res_meta.container_column = getattr(first_meta, 'container_column', first_meta.column)             # <<<<<<<<<<<<<<
 * 
 *             last_meta = self._pp_get_meta(reversed(children))
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_first_meta->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_first_meta), __pyx_n_u_container_column, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_res_meta), __pyx_n_s_container_column, __pyx_t_2) < 0) __PYX_ERR(0, 823, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "lark_cython/lark_cython.pyx":814
 * 
 *             first_meta = self._pp_get_meta(children)
 *             if first_meta is not None:             # <<<<<<<<<<<<<<
 *                 if not hasattr(res_meta, 'line'):
 *                     # meta was already set, probably because the rule has been inlined (e.g. `?rule`)
 */
    }

    /* "lark_cython/lark_cython.pyx":825
 *                 res_meta.container_column = getattr(first_meta, 'container_column', first_meta.column)
 * 
 *             last_meta = self._pp_get_meta(reversed(children))             # <<<<<<<<<<<<<<
 *             if last_meta is not None:
 *                 if not hasattr(res_meta, 'end_line'):
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_reversed, __pyx_v_children); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = ((struct __pyx_vtabstruct_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v_self->__pyx_vtab)->_pp_get_meta(__pyx_v_self, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_Meta))))) __PYX_ERR(0, 825, __pyx_L1_error)
    __pyx_v_last_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":826
 * 
 *             last_meta = self._pp_get_meta(reversed(children))
 *             if last_meta is not None:             # <<<<<<<<<<<<<<
 *                 if not hasattr(res_meta, 'end_line'):
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 */
    __pyx_t_5 = (((PyObject *)__pyx_v_last_meta) != Py_None);
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (__pyx_t_4) {

      /* "lark_cython/lark_cython.pyx":827
 *             last_meta = self._pp_get_meta(reversed(children))
 *             if last_meta is not None:
 *                 if not hasattr(res_meta, 'end_line'):             # <<<<<<<<<<<<<<
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 *                     res_meta.end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 */
      __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v_res_meta), __pyx_n_u_end_line); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 827, __pyx_L1_error)
      __pyx_t_5 = ((!(__pyx_t_4 != 0)) != 0);
      if (__pyx_t_5) {

        /* "lark_cython/lark_cython.pyx":828
 *             if last_meta is not None:
 *                 if not hasattr(res_meta, 'end_line'):
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)             # <<<<<<<<<<<<<<
 *                     res_meta.end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 *                     res_meta.end_pos = getattr(last_meta, 'container_end_pos', last_meta.end_pos)
 */
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_last_meta->end_line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_last_meta), __pyx_n_u_container_end_line, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 828, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_res_meta->end_line = __pyx_t_6;

        /* "lark_cython/lark_cython.pyx":829
 *                 if not hasattr(res_meta, 'end_line'):
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 *                     res_meta.end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)             # <<<<<<<<<<<<<<
 *                     res_meta.end_pos = getattr(last_meta, 'container_end_pos', last_meta.end_pos)
 *                     res_meta.empty = False
 */
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_last_meta->end_column); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 829, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_last_meta), __pyx_n_u_container_end_column, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 829, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_res_meta->end_column = __pyx_t_6;

        /* "lark_cython/lark_cython.pyx":830
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 *                     res_meta.end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 *                     res_meta.end_pos = getattr(last_meta, 'container_end_pos', last_meta.end_pos)             # <<<<<<<<<<<<<<
 *                     res_meta.empty = False
 * 
 */
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_last_meta->end_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 830, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_last_meta), __pyx_n_u_container_end_pos, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 830, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 830, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_res_meta->end_pos = __pyx_t_6;

        /* "lark_cython/lark_cython.pyx":831
 *                     res_meta.end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 *                     res_meta.end_pos = getattr(last_meta, 'container_end_pos', last_meta.end_pos)
 *                     res_meta.empty = False             # <<<<<<<<<<<<<<
 * 
 *                 res_meta.container_end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 */
        __pyx_v_res_meta->empty = 0;

        /* "lark_cython/lark_cython.pyx":827
 *             last_meta = self._pp_get_meta(reversed(children))
 *             if last_meta is not None:
 *                 if not hasattr(res_meta, 'end_line'):             # <<<<<<<<<<<<<<
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 *                     res_meta.end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 */
      }

      /* "lark_cython/lark_cython.pyx":833
 *                     res_meta.empty = False
 * 
 *                 res_meta.container_end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)             # <<<<<<<<<<<<<<
 *                 res_meta.container_end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 * 
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_last_meta->end_line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_last_meta), __pyx_n_u_container_end_line, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 833, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_res_meta), __pyx_n_s_container_end_line, __pyx_t_1) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "lark_cython/lark_cython.pyx":834
 * 
 *                 res_meta.container_end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 *                 res_meta.container_end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)             # <<<<<<<<<<<<<<
 * 
 *         return res
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_last_meta->end_column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 834, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_last_meta), __pyx_n_u_container_end_column, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 834, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_res_meta), __pyx_n_s_container_end_column, __pyx_t_2) < 0) __PYX_ERR(0, 834, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "lark_cython/lark_cython.pyx":826
 * 
 *             last_meta = self._pp_get_meta(reversed(children))
 *             if last_meta is not None:             # <<<<<<<<<<<<<<
 *                 if not hasattr(res_meta, 'end_line'):
 *                     res_meta.end_line = getattr(last_meta, 'container_end_line', last_meta.end_line)
 */
    }

    /* "lark_cython/lark_cython.pyx":805
 *         res = self.node_builder(children)
 * 
 *         if isinstance(res, Tree):             # <<<<<<<<<<<<<<
 *             # Calculate positions while the tree is streaming, according to the rule:
 *             # - nodes start at the start of their first child's container,
 */
  }

  /* "lark_cython/lark_cython.pyx":836
 *                 res_meta.container_end_column = getattr(last_meta, 'container_end_column', last_meta.end_column)
 * 
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     cdef _pp_get_meta(self, children):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":800
 *         self.node_filter = node_filter
 * 
 *     def __call__(self, children):             # <<<<<<<<<<<<<<
 *         cdef Meta res_meta, first_meta, last_meta
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.PropagatePositions.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_res_meta);
  __Pyx_XDECREF((PyObject *)__pyx_v_first_meta);
  __Pyx_XDECREF((PyObject *)__pyx_v_last_meta);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":838
 *         return res
 * 
 *     cdef _pp_get_meta(self, children):             # <<<<<<<<<<<<<<
 *         for c in children:
 *             if self.node_filter is not None and not self.node_filter(c):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_18PropagatePositions__pp_get_meta(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v_children) {
  PyObject *__pyx_v_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pp_get_meta", 0);

  /* "lark_cython/lark_cython.pyx":839
 * 
 *     cdef _pp_get_meta(self, children):
 *         for c in children:             # <<<<<<<<<<<<<<
 *             if self.node_filter is not None and not self.node_filter(c):
 *                 continue
 */
  if (likely(PyList_CheckExact(__pyx_v_children)) || PyTuple_CheckExact(__pyx_v_children)) {
    __pyx_t_1 = __pyx_v_children; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_children); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 839, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 839, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 839, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 839, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_c, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "lark_cython/lark_cython.pyx":840
 *     cdef _pp_get_meta(self, children):
 *         for c in children:
 *             if self.node_filter is not None and not self.node_filter(c):             # <<<<<<<<<<<<<<
 *                 continue
 *             if isinstance(c, Tree):
 */
    __pyx_t_6 = (__pyx_v_self->node_filter != Py_None);
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L6_bool_binop_done;
    }
    __Pyx_INCREF(__pyx_v_self->node_filter);
    __pyx_t_8 = __pyx_v_self->node_filter; __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_v_c) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_c);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 840, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = ((!__pyx_t_7) != 0);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "lark_cython/lark_cython.pyx":841
 *         for c in children:
 *             if self.node_filter is not None and not self.node_filter(c):
 *                 continue             # <<<<<<<<<<<<<<
 *             if isinstance(c, Tree):
 *                 if not c.meta.empty:
 */
      goto __pyx_L3_continue;

      /* "lark_cython/lark_cython.pyx":840
 *     cdef _pp_get_meta(self, children):
 *         for c in children:
 *             if self.node_filter is not None and not self.node_filter(c):             # <<<<<<<<<<<<<<
 *                 continue
 *             if isinstance(c, Tree):
 */
    }

    /* "lark_cython/lark_cython.pyx":842
 *             if self.node_filter is not None and not self.node_filter(c):
 *                 continue
 *             if isinstance(c, Tree):             # <<<<<<<<<<<<<<
 *                 if not c.meta.empty:
 *                     return c.meta
 */
    __pyx_t_5 = __Pyx_TypeCheck(__pyx_v_c, __pyx_ptype_11lark_cython_11lark_cython_Tree); 
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "lark_cython/lark_cython.pyx":843
 *                 continue
 *             if isinstance(c, Tree):
 *                 if not c.meta.empty:             # <<<<<<<<<<<<<<
 *                     return c.meta
 *             elif isinstance(c, Token):
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_c, __pyx_n_s_meta); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 843, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 843, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 843, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_5 = ((!__pyx_t_6) != 0);
      if (__pyx_t_5) {

        /* "lark_cython/lark_cython.pyx":844
 *             if isinstance(c, Tree):
 *                 if not c.meta.empty:
 *                     return c.meta             # <<<<<<<<<<<<<<
 *             elif isinstance(c, Token):
 *                 return c
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_c, __pyx_n_s_meta); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;

        /* "lark_cython/lark_cython.pyx":843
 *                 continue
 *             if isinstance(c, Tree):
 *                 if not c.meta.empty:             # <<<<<<<<<<<<<<
 *                     return c.meta
 *             elif isinstance(c, Token):
 */
      }

      /* "lark_cython/lark_cython.pyx":842
 *             if self.node_filter is not None and not self.node_filter(c):
 *                 continue
 *             if isinstance(c, Tree):             # <<<<<<<<<<<<<<
 *                 if not c.meta.empty:
 *                     return c.meta
 */
      goto __pyx_L8;
    }

    /* "lark_cython/lark_cython.pyx":845
 *                 if not c.meta.empty:
 *                     return c.meta
 *             elif isinstance(c, Token):             # <<<<<<<<<<<<<<
 *                 return c
 * 
 */
    __pyx_t_5 = __Pyx_TypeCheck(__pyx_v_c, __pyx_ptype_11lark_cython_11lark_cython_Token); 
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {

      /* "lark_cython/lark_cython.pyx":846
 *                     return c.meta
 *             elif isinstance(c, Token):
 *                 return c             # <<<<<<<<<<<<<<
 * 
 * cdef make_propagate_positions(option):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_c);
      __pyx_r = __pyx_v_c;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "lark_cython/lark_cython.pyx":845
 *                 if not c.meta.empty:
 *                     return c.meta
 *             elif isinstance(c, Token):             # <<<<<<<<<<<<<<
 *                 return c
 * 
 */
    }
    __pyx_L8:;

    /* "lark_cython/lark_cython.pyx":839
 * 
 *     cdef _pp_get_meta(self, children):
 *         for c in children:             # <<<<<<<<<<<<<<
 *             if self.node_filter is not None and not self.node_filter(c):
 *                 continue
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":838
 *         return res
 * 
 *     cdef _pp_get_meta(self, children):             # <<<<<<<<<<<<<<
 *         for c in children:
 *             if self.node_filter is not None and not self.node_filter(c):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("lark_cython.lark_cython.PropagatePositions._pp_get_meta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.node_builder, self.node_filter)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->node_builder);
  __Pyx_GIVEREF(__pyx_v_self->node_builder);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->node_builder);
  __Pyx_INCREF(__pyx_v_self->node_filter);
  __Pyx_GIVEREF(__pyx_v_self->node_filter);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->node_filter);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.node_builder, self.node_filter)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.node_builder, self.node_filter)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.node_builder is not None or self.node_filter is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.node_builder, self.node_filter)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.node_builder is not None or self.node_filter is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->node_builder != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->node_filter != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.node_builder is not None or self.node_filter is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.node_builder is not None or self.node_filter is not None
 *     if use_setstate:
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_PropagatePosition); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_260616610);
    __Pyx_GIVEREF(__pyx_int_260616610);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_260616610);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.node_builder is not None or self.node_filter is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, None), state
 *     else:
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_PropagatePositions__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_PropagatePosition); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_260616610);
    __Pyx_GIVEREF(__pyx_int_260616610);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_260616610);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.PropagatePositions.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_PropagatePositions__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_18PropagatePositions_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_PropagatePositions__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_PropagatePositions__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_PropagatePositions, (type(self), 0xf88b1a2, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_PropagatePositions__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.PropagatePositions.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":848
 *                 return c
 * 
 * cdef make_propagate_positions(option):             # <<<<<<<<<<<<<<
 *     if callable(option):
 *         return partial(PropagatePositions, node_filter=option)
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython_make_propagate_positions(PyObject *__pyx_v_option) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("make_propagate_positions", 0);

  /* "lark_cython/lark_cython.pyx":849
 * 
 * cdef make_propagate_positions(option):
 *     if callable(option):             # <<<<<<<<<<<<<<
 *         return partial(PropagatePositions, node_filter=option)
 *     elif option is True:
 */
  __pyx_t_1 = __Pyx_PyCallable_Check(__pyx_v_option); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 849, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":850
 * cdef make_propagate_positions(option):
 *     if callable(option):
 *         return partial(PropagatePositions, node_filter=option)             # <<<<<<<<<<<<<<
 *     elif option is True:
 *         return PropagatePositions
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_partial); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions));
    __Pyx_GIVEREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions));
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_node_filter, __pyx_v_option) < 0) __PYX_ERR(0, 850, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":849
 * 
 * cdef make_propagate_positions(option):
 *     if callable(option):             # <<<<<<<<<<<<<<
 *         return partial(PropagatePositions, node_filter=option)
 *     elif option is True:
 */
  }

  /* "lark_cython/lark_cython.pyx":851
 *     if callable(option):
 *         return partial(PropagatePositions, node_filter=option)
 *     elif option is True:             # <<<<<<<<<<<<<<
 *         return PropagatePositions
 *     elif option is False:
 */
  __pyx_t_2 = (__pyx_v_option == Py_True);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "lark_cython/lark_cython.pyx":852
 *         return partial(PropagatePositions, node_filter=option)
 *     elif option is True:
 *         return PropagatePositions             # <<<<<<<<<<<<<<
 *     elif option is False:
 *         return None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions));
    __pyx_r = ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions);
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":851
 *     if callable(option):
 *         return partial(PropagatePositions, node_filter=option)
 *     elif option is True:             # <<<<<<<<<<<<<<
 *         return PropagatePositions
 *     elif option is False:
 */
  }

  /* "lark_cython/lark_cython.pyx":853
 *     elif option is True:
 *         return PropagatePositions
 *     elif option is False:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_1 = (__pyx_v_option == Py_False);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":854
 *         return PropagatePositions
 *     elif option is False:
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     raise ConfigurationError('Invalid option for propagate_positions: %r' % option)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "lark_cython/lark_cython.pyx":853
 *     elif option is True:
 *         return PropagatePositions
 *     elif option is False:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":856
 *         return None
 * 
 *     raise ConfigurationError('Invalid option for propagate_positions: %r' % option)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ConfigurationError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_Invalid_option_for_propagate_pos, __pyx_v_option); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_Raise(__pyx_t_6, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __PYX_ERR(0, 856, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":848
 *                 return c
 * 
 * cdef make_propagate_positions(option):             # <<<<<<<<<<<<<<
 *     if callable(option):
 *         return partial(PropagatePositions, node_filter=option)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.make_propagate_positions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":864
 *     cdef readonly append_none
 * 
 *     def __init__(self, to_include, append_none, node_builder):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 *         self.to_include = to_include
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_to_include = 0;
  PyObject *__pyx_v_append_none = 0;
  PyObject *__pyx_v_node_builder = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_to_include,&__pyx_n_s_append_none,&__pyx_n_s_node_builder,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_to_include)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_append_none)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(0, 864, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node_builder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(0, 864, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 864, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_to_include = values[0];
    __pyx_v_append_none = values[1];
    __pyx_v_node_builder = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 864, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter___init__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self), __pyx_v_to_include, __pyx_v_append_none, __pyx_v_node_builder);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_11ChildFilter___init__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self, PyObject *__pyx_v_to_include, PyObject *__pyx_v_append_none, PyObject *__pyx_v_node_builder) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":865
 * 
 *     def __init__(self, to_include, append_none, node_builder):
 *         self.node_builder = node_builder             # <<<<<<<<<<<<<<
 *         self.to_include = to_include
 *         self.append_none = append_none
 */
  __Pyx_INCREF(__pyx_v_node_builder);
  __Pyx_GIVEREF(__pyx_v_node_builder);
  __Pyx_GOTREF(__pyx_v_self->node_builder);
  __Pyx_DECREF(__pyx_v_self->node_builder);
  __pyx_v_self->node_builder = __pyx_v_node_builder;

  /* "lark_cython/lark_cython.pyx":866
 *     def __init__(self, to_include, append_none, node_builder):
 *         self.node_builder = node_builder
 *         self.to_include = to_include             # <<<<<<<<<<<<<<
 *         self.append_none = append_none
 * 
 */
  if (!(likely(PyList_CheckExact(__pyx_v_to_include))||((__pyx_v_to_include) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_to_include)->tp_name), 0))) __PYX_ERR(0, 866, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_to_include;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->to_include);
  __Pyx_DECREF(__pyx_v_self->to_include);
  __pyx_v_self->to_include = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":867
 *         self.node_builder = node_builder
 *         self.to_include = to_include
 *         self.append_none = append_none             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, children):
 */
  __Pyx_INCREF(__pyx_v_append_none);
  __Pyx_GIVEREF(__pyx_v_append_none);
  __Pyx_GOTREF(__pyx_v_self->append_none);
  __Pyx_DECREF(__pyx_v_self->append_none);
  __pyx_v_self->append_none = __pyx_v_append_none;

  /* "lark_cython/lark_cython.pyx":864
 *     cdef readonly append_none
 * 
 *     def __init__(self, to_include, append_none, node_builder):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 *         self.to_include = to_include
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":869
 *         self.append_none = append_none
 * 
 *     def __call__(self, children):             # <<<<<<<<<<<<<<
 *         assert False
 *         filtered = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_children,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 869, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_children = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 869, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilter.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter_2__call__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self), __pyx_v_children);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self, PyObject *__pyx_v_children) {
  PyObject *__pyx_v_filtered = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_to_expand = NULL;
  PyObject *__pyx_v_add_none = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "lark_cython/lark_cython.pyx":870
 * 
 *     def __call__(self, children):
 *         assert False             # <<<<<<<<<<<<<<
 *         filtered = []
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!0)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 870, __pyx_L1_error)
    }
  }
  #endif

  /* "lark_cython/lark_cython.pyx":871
 *     def __call__(self, children):
 *         assert False
 *         filtered = []             # <<<<<<<<<<<<<<
 * 
 *         for i, to_expand, add_none in self.to_include:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_filtered = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":873
 *         filtered = []
 * 
 *         for i, to_expand, add_none in self.to_include:             # <<<<<<<<<<<<<<
 *             if add_none:
 *                 filtered += [None] * add_none
 */
  if (unlikely(__pyx_v_self->to_include == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 873, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->to_include; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 873, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 873, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 873, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 2; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < 0) __PYX_ERR(0, 873, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 873, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_to_expand, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_add_none, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "lark_cython/lark_cython.pyx":874
 * 
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:             # <<<<<<<<<<<<<<
 *                 filtered += [None] * add_none
 *             if to_expand:
 */
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_add_none); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 874, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "lark_cython/lark_cython.pyx":875
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:
 *                 filtered += [None] * add_none             # <<<<<<<<<<<<<<
 *             if to_expand:
 *                 filtered += children[i].children
 */
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 875, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      PyList_SET_ITEM(__pyx_t_3, 0, Py_None);
      { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_3, __pyx_v_add_none); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 875, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_temp);
        __Pyx_DECREF(__pyx_t_3);
        __pyx_t_3 = __pyx_temp;
      }
      __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 875, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_filtered, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "lark_cython/lark_cython.pyx":874
 * 
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:             # <<<<<<<<<<<<<<
 *                 filtered += [None] * add_none
 *             if to_expand:
 */
    }

    /* "lark_cython/lark_cython.pyx":876
 *             if add_none:
 *                 filtered += [None] * add_none
 *             if to_expand:             # <<<<<<<<<<<<<<
 *                 filtered += children[i].children
 *             else:
 */
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_to_expand); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 876, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "lark_cython/lark_cython.pyx":877
 *                 filtered += [None] * add_none
 *             if to_expand:
 *                 filtered += children[i].children             # <<<<<<<<<<<<<<
 *             else:
 *                 filtered.append(children[i])
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_children, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_children); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 877, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_filtered, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "lark_cython/lark_cython.pyx":876
 *             if add_none:
 *                 filtered += [None] * add_none
 *             if to_expand:             # <<<<<<<<<<<<<<
 *                 filtered += children[i].children
 *             else:
 */
      goto __pyx_L8;
    }

    /* "lark_cython/lark_cython.pyx":879
 *                 filtered += children[i].children
 *             else:
 *                 filtered.append(children[i])             # <<<<<<<<<<<<<<
 * 
 *         if self.append_none:
 */
    /*else*/ {
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_children, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = __Pyx_PyObject_Append(__pyx_v_filtered, __pyx_t_6); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 879, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L8:;

    /* "lark_cython/lark_cython.pyx":873
 *         filtered = []
 * 
 *         for i, to_expand, add_none in self.to_include:             # <<<<<<<<<<<<<<
 *             if add_none:
 *                 filtered += [None] * add_none
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":881
 *                 filtered.append(children[i])
 * 
 *         if self.append_none:             # <<<<<<<<<<<<<<
 *             filtered += [None] * self.append_none
 * 
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_self->append_none); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 881, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "lark_cython/lark_cython.pyx":882
 * 
 *         if self.append_none:
 *             filtered += [None] * self.append_none             # <<<<<<<<<<<<<<
 * 
 *         return self.node_builder(filtered)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyList_SET_ITEM(__pyx_t_1, 0, Py_None);
    { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_1, __pyx_v_self->append_none); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_temp);
      __Pyx_DECREF(__pyx_t_1);
      __pyx_t_1 = __pyx_temp;
    }
    __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_filtered, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "lark_cython/lark_cython.pyx":881
 *                 filtered.append(children[i])
 * 
 *         if self.append_none:             # <<<<<<<<<<<<<<
 *             filtered += [None] * self.append_none
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":884
 *             filtered += [None] * self.append_none
 * 
 *         return self.node_builder(filtered)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->node_builder);
  __pyx_t_1 = __pyx_v_self->node_builder; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_v_filtered) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_filtered);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":869
 *         self.append_none = append_none
 * 
 *     def __call__(self, children):             # <<<<<<<<<<<<<<
 *         assert False
 *         filtered = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilter.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_filtered);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_to_expand);
  __Pyx_XDECREF(__pyx_v_add_none);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":860
 * 
 * cdef class ChildFilter:
 *     cdef readonly node_builder             # <<<<<<<<<<<<<<
 *     cdef readonly list to_include
 *     cdef readonly append_none
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_12node_builder_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_12node_builder_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter_12node_builder___get__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_12node_builder___get__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->node_builder);
  __pyx_r = __pyx_v_self->node_builder;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":861
 * cdef class ChildFilter:
 *     cdef readonly node_builder
 *     cdef readonly list to_include             # <<<<<<<<<<<<<<
 *     cdef readonly append_none
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_10to_include_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_10to_include_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter_10to_include___get__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_10to_include___get__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->to_include);
  __pyx_r = __pyx_v_self->to_include;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":862
 *     cdef readonly node_builder
 *     cdef readonly list to_include
 *     cdef readonly append_none             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, to_include, append_none, node_builder):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_11append_none_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_11append_none_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter_11append_none___get__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_11append_none___get__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->append_none);
  __pyx_r = __pyx_v_self->append_none;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.append_none, self.node_builder, self.to_include)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->append_none);
  __Pyx_GIVEREF(__pyx_v_self->append_none);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->append_none);
  __Pyx_INCREF(__pyx_v_self->node_builder);
  __Pyx_GIVEREF(__pyx_v_self->node_builder);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->node_builder);
  __Pyx_INCREF(__pyx_v_self->to_include);
  __Pyx_GIVEREF(__pyx_v_self->to_include);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->to_include);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->append_none != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->node_builder != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->to_include != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    __pyx_t_3 = __pyx_t_5;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_ChildFilter); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_71555863);
    __Pyx_GIVEREF(__pyx_int_71555863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_71555863);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, None), state
 *     else:
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ChildFilter__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_ChildFilter); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_71555863);
    __Pyx_GIVEREF(__pyx_int_71555863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_71555863);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilter.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ChildFilter__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_11ChildFilter_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_11ChildFilter_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ChildFilter__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilter__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ChildFilter, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ChildFilter__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilter.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":890
 *     """Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)"""
 * 
 *     def __call__(self, children):             # <<<<<<<<<<<<<<
 *         assert False
 *         cdef int i
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_1__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_children,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 890, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_children = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 890, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR___call__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *)__pyx_v_self), __pyx_v_children);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR___call__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v_self, PyObject *__pyx_v_children) {
  int __pyx_v_i;
  int __pyx_v_to_expand;
  int __pyx_v_add_none;
  PyObject *__pyx_v_filtered = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "lark_cython/lark_cython.pyx":891
 * 
 *     def __call__(self, children):
 *         assert False             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef bint to_expand
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!0)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 891, __pyx_L1_error)
    }
  }
  #endif

  /* "lark_cython/lark_cython.pyx":896
 *         cdef int add_none
 *         cdef list filtered
 *         filtered = []             # <<<<<<<<<<<<<<
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_filtered = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":897
 *         cdef list filtered
 *         filtered = []
 *         for i, to_expand, add_none in self.to_include:             # <<<<<<<<<<<<<<
 *             if add_none:
 *                 filtered += [None] * add_none
 */
  if (unlikely(__pyx_v_self->__pyx_base.to_include == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 897, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->__pyx_base.to_include; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 897, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 897, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 2; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < 0) __PYX_ERR(0, 897, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 897, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_i = __pyx_t_9;
    __pyx_v_to_expand = __pyx_t_10;
    __pyx_v_add_none = __pyx_t_11;

    /* "lark_cython/lark_cython.pyx":898
 *         filtered = []
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:             # <<<<<<<<<<<<<<
 *                 filtered += [None] * add_none
 *             if to_expand:
 */
    __pyx_t_10 = (__pyx_v_add_none != 0);
    if (__pyx_t_10) {

      /* "lark_cython/lark_cython.pyx":899
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:
 *                 filtered += [None] * add_none             # <<<<<<<<<<<<<<
 *             if to_expand:
 *                 if filtered:
 */
      __pyx_t_3 = PyList_New(1 * ((__pyx_v_add_none<0) ? 0:__pyx_v_add_none)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      { Py_ssize_t __pyx_temp;
        for (__pyx_temp=0; __pyx_temp < __pyx_v_add_none; __pyx_temp++) {
          __Pyx_INCREF(Py_None);
          __Pyx_GIVEREF(Py_None);
          PyList_SET_ITEM(__pyx_t_3, __pyx_temp, Py_None);
        }
      }
      __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_filtered, ((PyObject*)__pyx_t_6));
      __pyx_t_6 = 0;

      /* "lark_cython/lark_cython.pyx":898
 *         filtered = []
 *         for i, to_expand, add_none in self.to_include:
 *             if add_none:             # <<<<<<<<<<<<<<
 *                 filtered += [None] * add_none
 *             if to_expand:
 */
    }

    /* "lark_cython/lark_cython.pyx":900
 *             if add_none:
 *                 filtered += [None] * add_none
 *             if to_expand:             # <<<<<<<<<<<<<<
 *                 if filtered:
 *                     filtered += children[i].children
 */
    __pyx_t_10 = (__pyx_v_to_expand != 0);
    if (__pyx_t_10) {

      /* "lark_cython/lark_cython.pyx":901
 *                 filtered += [None] * add_none
 *             if to_expand:
 *                 if filtered:             # <<<<<<<<<<<<<<
 *                     filtered += children[i].children
 *                 else:   # Optimize for left-recursion
 */
      __pyx_t_10 = (__pyx_v_filtered != Py_None)&&(PyList_GET_SIZE(__pyx_v_filtered) != 0);
      if (__pyx_t_10) {

        /* "lark_cython/lark_cython.pyx":902
 *             if to_expand:
 *                 if filtered:
 *                     filtered += children[i].children             # <<<<<<<<<<<<<<
 *                 else:   # Optimize for left-recursion
 *                     filtered = children[i].children
 */
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_children, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_children); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_6)->tp_name), 0))) __PYX_ERR(0, 902, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_filtered, ((PyObject*)__pyx_t_6));
        __pyx_t_6 = 0;

        /* "lark_cython/lark_cython.pyx":901
 *                 filtered += [None] * add_none
 *             if to_expand:
 *                 if filtered:             # <<<<<<<<<<<<<<
 *                     filtered += children[i].children
 *                 else:   # Optimize for left-recursion
 */
        goto __pyx_L9;
      }

      /* "lark_cython/lark_cython.pyx":904
 *                     filtered += children[i].children
 *                 else:   # Optimize for left-recursion
 *                     filtered = children[i].children             # <<<<<<<<<<<<<<
 *             else:
 *                 filtered.append(children[i])
 */
      /*else*/ {
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_children, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 904, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_children); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 904, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (!(likely(PyList_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 904, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_filtered, ((PyObject*)__pyx_t_3));
        __pyx_t_3 = 0;
      }
      __pyx_L9:;

      /* "lark_cython/lark_cython.pyx":900
 *             if add_none:
 *                 filtered += [None] * add_none
 *             if to_expand:             # <<<<<<<<<<<<<<
 *                 if filtered:
 *                     filtered += children[i].children
 */
      goto __pyx_L8;
    }

    /* "lark_cython/lark_cython.pyx":906
 *                     filtered = children[i].children
 *             else:
 *                 filtered.append(children[i])             # <<<<<<<<<<<<<<
 * 
 *         if self.append_none:
 */
    /*else*/ {
      if (unlikely(__pyx_v_filtered == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 906, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_children, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 906, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_filtered, __pyx_t_3); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 906, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "lark_cython/lark_cython.pyx":897
 *         cdef list filtered
 *         filtered = []
 *         for i, to_expand, add_none in self.to_include:             # <<<<<<<<<<<<<<
 *             if add_none:
 *                 filtered += [None] * add_none
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":908
 *                 filtered.append(children[i])
 * 
 *         if self.append_none:             # <<<<<<<<<<<<<<
 *             filtered += [None] * self.append_none
 * 
 */
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_self->__pyx_base.append_none); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 908, __pyx_L1_error)
  if (__pyx_t_10) {

    /* "lark_cython/lark_cython.pyx":909
 * 
 *         if self.append_none:
 *             filtered += [None] * self.append_none             # <<<<<<<<<<<<<<
 * 
 *         return self.node_builder(filtered)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyList_SET_ITEM(__pyx_t_1, 0, Py_None);
    { PyObject* __pyx_temp = PyNumber_InPlaceMultiply(__pyx_t_1, __pyx_v_self->__pyx_base.append_none); if (unlikely(!__pyx_temp)) __PYX_ERR(0, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_temp);
      __Pyx_DECREF(__pyx_t_1);
      __pyx_t_1 = __pyx_temp;
    }
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_filtered, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":908
 *                 filtered.append(children[i])
 * 
 *         if self.append_none:             # <<<<<<<<<<<<<<
 *             filtered += [None] * self.append_none
 * 
 */
  }

  /* "lark_cython/lark_cython.pyx":911
 *             filtered += [None] * self.append_none
 * 
 *         return self.node_builder(filtered)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.node_builder);
  __pyx_t_1 = __pyx_v_self->__pyx_base.node_builder; __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, __pyx_v_filtered) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_filtered);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":890
 *     """Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)"""
 * 
 *     def __call__(self, children):             # <<<<<<<<<<<<<<
 *         assert False
 *         cdef int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_filtered);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR_2__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR_2__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.append_none, self.node_builder, self.to_include)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.append_none);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.append_none);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx_base.append_none);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.node_builder);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.node_builder);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->__pyx_base.node_builder);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.to_include);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.to_include);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->__pyx_base.to_include);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->__pyx_base.append_none != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx_base.node_builder != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->__pyx_base.to_include != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    __pyx_t_3 = __pyx_t_5;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_ChildFilterLALR); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_71555863);
    __Pyx_GIVEREF(__pyx_int_71555863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_71555863);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, None), state
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ChildFilterLALR__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_ChildFilterLALR); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_71555863);
    __Pyx_GIVEREF(__pyx_int_71555863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_71555863);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ChildFilterLALR__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR_4__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_15ChildFilterLALR_4__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ChildFilterLALR__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ChildFilterLALR__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":917
 *     "Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)"
 * 
 *     def __init__(self, to_include, node_builder):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 *         self.to_include = to_include
 */

/* Python wrapper */
static int __pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_to_include = 0;
  PyObject *__pyx_v_node_builder = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_to_include,&__pyx_n_s_node_builder,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_to_include)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_node_builder)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 917, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 917, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_to_include = values[0];
    __pyx_v_node_builder = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 917, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders___init__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *)__pyx_v_self), __pyx_v_to_include, __pyx_v_node_builder);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders___init__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self, PyObject *__pyx_v_to_include, PyObject *__pyx_v_node_builder) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":918
 * 
 *     def __init__(self, to_include, node_builder):
 *         self.node_builder = node_builder             # <<<<<<<<<<<<<<
 *         self.to_include = to_include
 * 
 */
  __Pyx_INCREF(__pyx_v_node_builder);
  __Pyx_GIVEREF(__pyx_v_node_builder);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.node_builder);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.node_builder);
  __pyx_v_self->__pyx_base.node_builder = __pyx_v_node_builder;

  /* "lark_cython/lark_cython.pyx":919
 *     def __init__(self, to_include, node_builder):
 *         self.node_builder = node_builder
 *         self.to_include = to_include             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, list children):
 */
  if (!(likely(PyList_CheckExact(__pyx_v_to_include))||((__pyx_v_to_include) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_to_include)->tp_name), 0))) __PYX_ERR(0, 919, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_to_include;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.to_include);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.to_include);
  __pyx_v_self->__pyx_base.to_include = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":917
 *     "Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)"
 * 
 *     def __init__(self, to_include, node_builder):             # <<<<<<<<<<<<<<
 *         self.node_builder = node_builder
 *         self.to_include = to_include
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":921
 *         self.to_include = to_include
 * 
 *     def __call__(self, list children):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef bint to_expand
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_3__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_children,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__call__") < 0)) __PYX_ERR(0, 921, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_children = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 921, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_children), (&PyList_Type), 1, "children", 1))) __PYX_ERR(0, 921, __pyx_L1_error)
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_2__call__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *)__pyx_v_self), __pyx_v_children);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_2__call__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self, PyObject *__pyx_v_children) {
  int __pyx_v_i;
  int __pyx_v_to_expand;
  PyObject *__pyx_v_filtered = 0;
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *__pyx_v_child = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 0);

  /* "lark_cython/lark_cython.pyx":926
 *         cdef list filtered
 *         cdef Tree child
 *         filtered = []             # <<<<<<<<<<<<<<
 *         for i, to_expand in self.to_include:
 *             if to_expand:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_filtered = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":927
 *         cdef Tree child
 *         filtered = []
 *         for i, to_expand in self.to_include:             # <<<<<<<<<<<<<<
 *             if to_expand:
 *                 child = children[i]
 */
  if (unlikely(__pyx_v_self->__pyx_base.to_include == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 927, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->__pyx_base.to_include; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 927, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 927, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 927, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 927, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 927, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 927, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
      index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 927, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 927, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 927, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 927, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_i = __pyx_t_8;
    __pyx_v_to_expand = __pyx_t_9;

    /* "lark_cython/lark_cython.pyx":928
 *         filtered = []
 *         for i, to_expand in self.to_include:
 *             if to_expand:             # <<<<<<<<<<<<<<
 *                 child = children[i]
 *                 if filtered:
 */
    __pyx_t_9 = (__pyx_v_to_expand != 0);
    if (__pyx_t_9) {

      /* "lark_cython/lark_cython.pyx":929
 *         for i, to_expand in self.to_include:
 *             if to_expand:
 *                 child = children[i]             # <<<<<<<<<<<<<<
 *                 if filtered:
 *                     filtered += child.children
 */
      if (unlikely(__pyx_v_children == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 929, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_children, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 929, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_11lark_cython_11lark_cython_Tree))))) __PYX_ERR(0, 929, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_child, ((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "lark_cython/lark_cython.pyx":930
 *             if to_expand:
 *                 child = children[i]
 *                 if filtered:             # <<<<<<<<<<<<<<
 *                     filtered += child.children
 *                 else:   # Optimize for left-recursion
 */
      __pyx_t_9 = (__pyx_v_filtered != Py_None)&&(PyList_GET_SIZE(__pyx_v_filtered) != 0);
      if (__pyx_t_9) {

        /* "lark_cython/lark_cython.pyx":931
 *                 child = children[i]
 *                 if filtered:
 *                     filtered += child.children             # <<<<<<<<<<<<<<
 *                 else:   # Optimize for left-recursion
 *                     filtered = child.children
 */
        __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_filtered, __pyx_v_child->children); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 931, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF_SET(__pyx_v_filtered, ((PyObject*)__pyx_t_3));
        __pyx_t_3 = 0;

        /* "lark_cython/lark_cython.pyx":930
 *             if to_expand:
 *                 child = children[i]
 *                 if filtered:             # <<<<<<<<<<<<<<
 *                     filtered += child.children
 *                 else:   # Optimize for left-recursion
 */
        goto __pyx_L8;
      }

      /* "lark_cython/lark_cython.pyx":933
 *                     filtered += child.children
 *                 else:   # Optimize for left-recursion
 *                     filtered = child.children             # <<<<<<<<<<<<<<
 *             else:
 *                 filtered.append(children[i])
 */
      /*else*/ {
        __pyx_t_3 = __pyx_v_child->children;
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_DECREF_SET(__pyx_v_filtered, ((PyObject*)__pyx_t_3));
        __pyx_t_3 = 0;
      }
      __pyx_L8:;

      /* "lark_cython/lark_cython.pyx":928
 *         filtered = []
 *         for i, to_expand in self.to_include:
 *             if to_expand:             # <<<<<<<<<<<<<<
 *                 child = children[i]
 *                 if filtered:
 */
      goto __pyx_L7;
    }

    /* "lark_cython/lark_cython.pyx":935
 *                     filtered = child.children
 *             else:
 *                 filtered.append(children[i])             # <<<<<<<<<<<<<<
 *         return self.node_builder(filtered)
 * 
 */
    /*else*/ {
      if (unlikely(__pyx_v_filtered == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 935, __pyx_L1_error)
      }
      if (unlikely(__pyx_v_children == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 935, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_children, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_filtered, __pyx_t_3); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 935, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L7:;

    /* "lark_cython/lark_cython.pyx":927
 *         cdef Tree child
 *         filtered = []
 *         for i, to_expand in self.to_include:             # <<<<<<<<<<<<<<
 *             if to_expand:
 *                 child = children[i]
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":936
 *             else:
 *                 filtered.append(children[i])
 *         return self.node_builder(filtered)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.node_builder);
  __pyx_t_3 = __pyx_v_self->__pyx_base.node_builder; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_v_filtered) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_filtered);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":921
 *         self.to_include = to_include
 * 
 *     def __call__(self, list children):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef bint to_expand
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_filtered);
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_4__reduce_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_4__reduce_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.append_none, self.node_builder, self.to_include)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.append_none);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.append_none);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx_base.append_none);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.node_builder);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.node_builder);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->__pyx_base.node_builder);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.to_include);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.to_include);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->__pyx_base.to_include);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.append_none, self.node_builder, self.to_include)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->__pyx_base.append_none != Py_None);
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->__pyx_base.node_builder != Py_None);
    __pyx_t_2 = (__pyx_t_5 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_self->__pyx_base.to_include != ((PyObject*)Py_None));
    __pyx_t_5 = (__pyx_t_2 != 0);
    __pyx_t_3 = __pyx_t_5;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_3;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, None), state
 *     else:
 */
  __pyx_t_3 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_3) {

    /* "(tree fragment)":13
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_ChildFilterLALR_N); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_71555863);
    __Pyx_GIVEREF(__pyx_int_71555863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_71555863);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.append_none is not None or self.node_builder is not None or self.to_include is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, None), state
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pyx_unpickle_ChildFilterLALR_N); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_71555863);
    __Pyx_GIVEREF(__pyx_int_71555863);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_71555863);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_6__setstate_cython__(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_6__setstate_cython__(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_ChildFilterLALR_NoPlaceholders, (type(self), 0x443db17, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":939
 * 
 * 
 * def _should_expand(sym):             # <<<<<<<<<<<<<<
 *     name = sym.name
 *     if not isinstance(name, str):
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5_should_expand(PyObject *__pyx_self, PyObject *__pyx_v_sym); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_5_should_expand = {"_should_expand", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_5_should_expand, METH_O, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_5_should_expand(PyObject *__pyx_self, PyObject *__pyx_v_sym) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_should_expand (wrapper)", 0);
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_4_should_expand(__pyx_self, ((PyObject *)__pyx_v_sym));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_4_should_expand(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_sym) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_should_expand", 0);

  /* "lark_cython/lark_cython.pyx":940
 * 
 * def _should_expand(sym):
 *     name = sym.name             # <<<<<<<<<<<<<<
 *     if not isinstance(name, str):
 *         name = name.value
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sym, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":941
 * def _should_expand(sym):
 *     name = sym.name
 *     if not isinstance(name, str):             # <<<<<<<<<<<<<<
 *         name = name.value
 *     return not sym.is_term and name.startswith('_')
 */
  __pyx_t_2 = PyUnicode_Check(__pyx_v_name); 
  __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
  if (__pyx_t_3) {

    /* "lark_cython/lark_cython.pyx":942
 *     name = sym.name
 *     if not isinstance(name, str):
 *         name = name.value             # <<<<<<<<<<<<<<
 *     return not sym.is_term and name.startswith('_')
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":941
 * def _should_expand(sym):
 *     name = sym.name
 *     if not isinstance(name, str):             # <<<<<<<<<<<<<<
 *         name = name.value
 *     return not sym.is_term and name.startswith('_')
 */
  }

  /* "lark_cython/lark_cython.pyx":943
 *     if not isinstance(name, str):
 *         name = name.value
 *     return not sym.is_term and name.startswith('_')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sym, __pyx_n_s_is_term); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (!__pyx_t_3);
  if (__pyx_t_2) {
  } else {
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_startswith); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_n_u__38) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u__38);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":939
 * 
 * 
 * def _should_expand(sym):             # <<<<<<<<<<<<<<
 *     name = sym.name
 *     if not isinstance(name, str):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("lark_cython.lark_cython._should_expand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":946
 * 
 * 
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):             # <<<<<<<<<<<<<<
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7maybe_create_child_filter(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_7maybe_create_child_filter = {"maybe_create_child_filter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_7maybe_create_child_filter, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_7maybe_create_child_filter(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_expansion = 0;
  PyObject *__pyx_v_keep_all_tokens = 0;
  PyObject *__pyx_v_ambiguous = 0;
  PyObject *__pyx_v__empty_indices = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("maybe_create_child_filter (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_expansion,&__pyx_n_s_keep_all_tokens,&__pyx_n_s_ambiguous,&__pyx_n_s_empty_indices,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_expansion)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_keep_all_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("maybe_create_child_filter", 1, 4, 4, 1); __PYX_ERR(0, 946, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ambiguous)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("maybe_create_child_filter", 1, 4, 4, 2); __PYX_ERR(0, 946, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_empty_indices)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("maybe_create_child_filter", 1, 4, 4, 3); __PYX_ERR(0, 946, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "maybe_create_child_filter") < 0)) __PYX_ERR(0, 946, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_expansion = values[0];
    __pyx_v_keep_all_tokens = values[1];
    __pyx_v_ambiguous = values[2];
    __pyx_v__empty_indices = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("maybe_create_child_filter", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 946, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.maybe_create_child_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_6maybe_create_child_filter(__pyx_self, __pyx_v_expansion, __pyx_v_keep_all_tokens, __pyx_v_ambiguous, __pyx_v__empty_indices);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_2generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":950
 *     if _empty_indices:
 *         assert _empty_indices.count(False) == len(expansion)
 *         s = ''.join(str(int(b)) for b in _empty_indices)             # <<<<<<<<<<<<<<
 *         empty_indices = [len(ones) for ones in s.split('0')]
 *         assert len(empty_indices) == len(expansion)+1, (empty_indices, len(expansion))
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_25maybe_create_child_filter_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 950, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_2generator6, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_maybe_create_child_filter_locals, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.maybe_create_child_filter.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_2generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 950, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v__empty_indices)) { __Pyx_RaiseClosureNameError("_empty_indices"); __PYX_ERR(0, 950, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v__empty_indices)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_outer_scope->__pyx_v__empty_indices)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v__empty_indices; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_outer_scope->__pyx_v__empty_indices); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 950, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 950, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 950, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 950, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_b);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_b, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_cur_scope->__pyx_v_b); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_5))) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_5generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":966
 *     nones_to_add += empty_indices[len(expansion)]
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):             # <<<<<<<<<<<<<<
 *         if _empty_indices or ambiguous:
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_25maybe_create_child_filter_3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 966, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_5generator7, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_maybe_create_child_filter_locals, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 966, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.maybe_create_child_filter.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_5generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 966, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_to_include)) { __Pyx_RaiseClosureNameError("to_include"); __PYX_ERR(0, 966, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_to_include == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 966, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_to_include; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 966, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
      PyObject* sequence = __pyx_t_3;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 966, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 966, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 2; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 3) < 0) __PYX_ERR(0, 966, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 966, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_i);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_i, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_to_expand);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_to_expand, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v__);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_to_expand); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 966, __pyx_L1_error)
    if (__pyx_t_9) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":946
 * 
 * 
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):             # <<<<<<<<<<<<<<
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_6maybe_create_child_filter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_expansion, PyObject *__pyx_v_keep_all_tokens, PyObject *__pyx_v_ambiguous, PyObject *__pyx_v__empty_indices) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *__pyx_cur_scope;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_empty_indices = NULL;
  PyObject *__pyx_v_nones_to_add = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_sym = NULL;
  PyObject *__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_2generator6 = 0;
  PyObject *__pyx_9genexpr11__pyx_v_ones = NULL;
  PyObject *__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_5generator7 = 0;
  PyObject *__pyx_9genexpr13__pyx_v_i = NULL;
  PyObject *__pyx_9genexpr13__pyx_v_x = NULL;
  CYTHON_UNUSED PyObject *__pyx_9genexpr13__pyx_v__ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *(*__pyx_t_19)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("maybe_create_child_filter", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 946, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v__empty_indices = __pyx_v__empty_indices;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v__empty_indices);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v__empty_indices);

  /* "lark_cython/lark_cython.pyx":948
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:             # <<<<<<<<<<<<<<
 *         assert _empty_indices.count(False) == len(expansion)
 *         s = ''.join(str(int(b)) for b in _empty_indices)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v__empty_indices); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 948, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "lark_cython/lark_cython.pyx":949
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 *         assert _empty_indices.count(False) == len(expansion)             # <<<<<<<<<<<<<<
 *         s = ''.join(str(int(b)) for b in _empty_indices)
 *         empty_indices = [len(ones) for ones in s.split('0')]
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v__empty_indices, __pyx_n_s_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_3, Py_False);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = PyObject_Length(__pyx_v_expansion); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 949, __pyx_L1_error)
      __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 949, __pyx_L1_error)
      }
    }
    #endif

    /* "lark_cython/lark_cython.pyx":950
 *     if _empty_indices:
 *         assert _empty_indices.count(False) == len(expansion)
 *         s = ''.join(str(int(b)) for b in _empty_indices)             # <<<<<<<<<<<<<<
 *         empty_indices = [len(ones) for ones in s.split('0')]
 *         assert len(empty_indices) == len(expansion)+1, (empty_indices, len(expansion))
 */
    __pyx_t_4 = __pyx_pf_11lark_cython_11lark_cython_25maybe_create_child_filter_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyUnicode_Join(__pyx_kp_u__3, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_s = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "lark_cython/lark_cython.pyx":951
 *         assert _empty_indices.count(False) == len(expansion)
 *         s = ''.join(str(int(b)) for b in _empty_indices)
 *         empty_indices = [len(ones) for ones in s.split('0')]             # <<<<<<<<<<<<<<
 *         assert len(empty_indices) == len(expansion)+1, (empty_indices, len(expansion))
 *     else:
 */
    { /* enter inner scope */
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__pyx_v_s == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "split");
        __PYX_ERR(0, 951, __pyx_L6_error)
      }
      __pyx_t_3 = PyUnicode_Split(__pyx_v_s, __pyx_kp_u_0, -1L); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 951, __pyx_L6_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_ones, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_6 = PyObject_Length(__pyx_9genexpr11__pyx_v_ones); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 951, __pyx_L6_error)
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 951, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_ones); __pyx_9genexpr11__pyx_v_ones = 0;
      goto __pyx_L9_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_ones); __pyx_9genexpr11__pyx_v_ones = 0;
      goto __pyx_L1_error;
      __pyx_L9_exit_scope:;
    } /* exit inner scope */
    __pyx_v_empty_indices = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "lark_cython/lark_cython.pyx":952
 *         s = ''.join(str(int(b)) for b in _empty_indices)
 *         empty_indices = [len(ones) for ones in s.split('0')]
 *         assert len(empty_indices) == len(expansion)+1, (empty_indices, len(expansion))             # <<<<<<<<<<<<<<
 *     else:
 *         empty_indices = [0] * (len(expansion)+1)
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_5 = PyList_GET_SIZE(__pyx_v_empty_indices); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 952, __pyx_L1_error)
      __pyx_t_6 = PyObject_Length(__pyx_v_expansion); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 952, __pyx_L1_error)
      if (unlikely(!((__pyx_t_5 == (__pyx_t_6 + 1)) != 0))) {
        __pyx_t_7 = PyObject_Length(__pyx_v_expansion); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 952, __pyx_L1_error)
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_empty_indices);
        __Pyx_GIVEREF(__pyx_v_empty_indices);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_empty_indices);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        PyErr_SetObject(PyExc_AssertionError, __pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 952, __pyx_L1_error)
      }
    }
    #endif

    /* "lark_cython/lark_cython.pyx":948
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:             # <<<<<<<<<<<<<<
 *         assert _empty_indices.count(False) == len(expansion)
 *         s = ''.join(str(int(b)) for b in _empty_indices)
 */
    goto __pyx_L3;
  }

  /* "lark_cython/lark_cython.pyx":954
 *         assert len(empty_indices) == len(expansion)+1, (empty_indices, len(expansion))
 *     else:
 *         empty_indices = [0] * (len(expansion)+1)             # <<<<<<<<<<<<<<
 * 
 *     to_include = []
 */
  /*else*/ {
    __pyx_t_6 = PyObject_Length(__pyx_v_expansion); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 954, __pyx_L1_error)
    __pyx_t_4 = PyList_New(1 * (((__pyx_t_6 + 1)<0) ? 0:(__pyx_t_6 + 1))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    { Py_ssize_t __pyx_temp;
      for (__pyx_temp=0; __pyx_temp < (__pyx_t_6 + 1); __pyx_temp++) {
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyList_SET_ITEM(__pyx_t_4, __pyx_temp, __pyx_int_0);
      }
    }
    __pyx_v_empty_indices = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "lark_cython/lark_cython.pyx":956
 *         empty_indices = [0] * (len(expansion)+1)
 * 
 *     to_include = []             # <<<<<<<<<<<<<<
 *     nones_to_add = 0
 *     for i, sym in enumerate(expansion):
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_to_include = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":957
 * 
 *     to_include = []
 *     nones_to_add = 0             # <<<<<<<<<<<<<<
 *     for i, sym in enumerate(expansion):
 *         nones_to_add += empty_indices[i]
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_nones_to_add = __pyx_int_0;

  /* "lark_cython/lark_cython.pyx":958
 *     to_include = []
 *     nones_to_add = 0
 *     for i, sym in enumerate(expansion):             # <<<<<<<<<<<<<<
 *         nones_to_add += empty_indices[i]
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_4 = __pyx_int_0;
  if (likely(PyList_CheckExact(__pyx_v_expansion)) || PyTuple_CheckExact(__pyx_v_expansion)) {
    __pyx_t_2 = __pyx_v_expansion; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_expansion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 958, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 958, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 958, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 958, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 958, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_8(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 958, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_sym, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4);
    __pyx_t_4 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "lark_cython/lark_cython.pyx":959
 *     nones_to_add = 0
 *     for i, sym in enumerate(expansion):
 *         nones_to_add += empty_indices[i]             # <<<<<<<<<<<<<<
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):
 *             to_include.append((i, _should_expand(sym), nones_to_add))
 */
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_empty_indices, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = PyNumber_InPlaceAdd(__pyx_v_nones_to_add, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_nones_to_add, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "lark_cython/lark_cython.pyx":960
 *     for i, sym in enumerate(expansion):
 *         nones_to_add += empty_indices[i]
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):             # <<<<<<<<<<<<<<
 *             to_include.append((i, _should_expand(sym), nones_to_add))
 *             nones_to_add = 0
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_keep_all_tokens); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 960, __pyx_L1_error)
    if (!__pyx_t_10) {
    } else {
      __pyx_t_1 = __pyx_t_10;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_sym, __pyx_n_s_is_term); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 960, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_11) {
    } else {
      __pyx_t_10 = __pyx_t_11;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_sym, __pyx_n_s_filter_out); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 960, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_10 = __pyx_t_11;
    __pyx_L15_bool_binop_done:;
    __pyx_t_11 = ((!__pyx_t_10) != 0);
    __pyx_t_1 = __pyx_t_11;
    __pyx_L13_bool_binop_done:;
    if (__pyx_t_1) {

      /* "lark_cython/lark_cython.pyx":961
 *         nones_to_add += empty_indices[i]
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):
 *             to_include.append((i, _should_expand(sym), nones_to_add))             # <<<<<<<<<<<<<<
 *             nones_to_add = 0
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_should_expand); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 961, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_9 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_12, __pyx_v_sym) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_sym);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 961, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 961, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_i);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_9);
      __Pyx_INCREF(__pyx_v_nones_to_add);
      __Pyx_GIVEREF(__pyx_v_nones_to_add);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_nones_to_add);
      __pyx_t_9 = 0;
      __pyx_t_13 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_to_include, __pyx_t_3); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 961, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "lark_cython/lark_cython.pyx":962
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):
 *             to_include.append((i, _should_expand(sym), nones_to_add))
 *             nones_to_add = 0             # <<<<<<<<<<<<<<
 * 
 *     nones_to_add += empty_indices[len(expansion)]
 */
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_nones_to_add, __pyx_int_0);

      /* "lark_cython/lark_cython.pyx":960
 *     for i, sym in enumerate(expansion):
 *         nones_to_add += empty_indices[i]
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):             # <<<<<<<<<<<<<<
 *             to_include.append((i, _should_expand(sym), nones_to_add))
 *             nones_to_add = 0
 */
    }

    /* "lark_cython/lark_cython.pyx":958
 *     to_include = []
 *     nones_to_add = 0
 *     for i, sym in enumerate(expansion):             # <<<<<<<<<<<<<<
 *         nones_to_add += empty_indices[i]
 *         if keep_all_tokens or not (sym.is_term and sym.filter_out):
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":964
 *             nones_to_add = 0
 * 
 *     nones_to_add += empty_indices[len(expansion)]             # <<<<<<<<<<<<<<
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_expansion); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 964, __pyx_L1_error)
  __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_empty_indices, __pyx_t_6, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_nones_to_add, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_nones_to_add, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":966
 *     nones_to_add += empty_indices[len(expansion)]
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):             # <<<<<<<<<<<<<<
 *         if _empty_indices or ambiguous:
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)
 */
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v__empty_indices); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 966, __pyx_L1_error)
  if (!__pyx_t_11) {
  } else {
    __pyx_t_1 = __pyx_t_11;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_to_include;
  __Pyx_INCREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 966, __pyx_L1_error)
  }
  __pyx_t_6 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = PyObject_Length(__pyx_v_expansion); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 966, __pyx_L1_error)
  __pyx_t_11 = ((__pyx_t_6 < __pyx_t_5) != 0);
  if (!__pyx_t_11) {
  } else {
    __pyx_t_1 = __pyx_t_11;
    goto __pyx_L18_bool_binop_done;
  }
  __pyx_t_2 = __pyx_pf_11lark_cython_11lark_cython_25maybe_create_child_filter_3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_11;
  __pyx_L18_bool_binop_done:;
  if (__pyx_t_1) {

    /* "lark_cython/lark_cython.pyx":967
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):
 *         if _empty_indices or ambiguous:             # <<<<<<<<<<<<<<
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)
 *         else:
 */
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v__empty_indices); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 967, __pyx_L1_error)
    if (!__pyx_t_11) {
    } else {
      __pyx_t_1 = __pyx_t_11;
      goto __pyx_L22_bool_binop_done;
    }
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_ambiguous); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 967, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_11;
    __pyx_L22_bool_binop_done:;
    if (__pyx_t_1) {

      /* "lark_cython/lark_cython.pyx":968
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):
 *         if _empty_indices or ambiguous:
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)             # <<<<<<<<<<<<<<
 *         else:
 *             # LALR without placeholders
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_partial); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 968, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_ambiguous); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 968, __pyx_L1_error)
      if (__pyx_t_1) {
        __Pyx_INCREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilter));
        __pyx_t_3 = ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilter);
      } else {
        __Pyx_INCREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR));
        __pyx_t_3 = ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR);
      }
      __pyx_t_9 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_3, __pyx_cur_scope->__pyx_v_to_include, __pyx_v_nones_to_add};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 968, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_t_3, __pyx_cur_scope->__pyx_v_to_include, __pyx_v_nones_to_add};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 968, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 968, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_14, __pyx_t_3);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_to_include);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_to_include);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_14, __pyx_cur_scope->__pyx_v_to_include);
        __Pyx_INCREF(__pyx_v_nones_to_add);
        __Pyx_GIVEREF(__pyx_v_nones_to_add);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_14, __pyx_v_nones_to_add);
        __pyx_t_3 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 968, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "lark_cython/lark_cython.pyx":967
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):
 *         if _empty_indices or ambiguous:             # <<<<<<<<<<<<<<
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)
 *         else:
 */
    }

    /* "lark_cython/lark_cython.pyx":971
 *         else:
 *             # LALR without placeholders
 *             return partial(ChildFilterLALR_NoPlaceholders, [(i, x) for i,x,_ in to_include])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_partial); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 971, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      { /* enter inner scope */
        __pyx_t_12 = PyList_New(0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 971, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_3 = __pyx_cur_scope->__pyx_v_to_include; __Pyx_INCREF(__pyx_t_3); __pyx_t_5 = 0;
        for (;;) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_9 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_9); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 971, __pyx_L26_error)
          #else
          __pyx_t_9 = PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 971, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
          if ((likely(PyTuple_CheckExact(__pyx_t_9))) || (PyList_CheckExact(__pyx_t_9))) {
            PyObject* sequence = __pyx_t_9;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 3)) {
              if (size > 3) __Pyx_RaiseTooManyValuesError(3);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 971, __pyx_L26_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_15 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_16 = PyTuple_GET_ITEM(sequence, 1); 
              __pyx_t_17 = PyTuple_GET_ITEM(sequence, 2); 
            } else {
              __pyx_t_15 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_16 = PyList_GET_ITEM(sequence, 1); 
              __pyx_t_17 = PyList_GET_ITEM(sequence, 2); 
            }
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_17);
            #else
            __pyx_t_15 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 971, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_15);
            __pyx_t_16 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 971, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_17 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 971, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_18 = PyObject_GetIter(__pyx_t_9); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 971, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __pyx_t_19 = Py_TYPE(__pyx_t_18)->tp_iternext;
            index = 0; __pyx_t_15 = __pyx_t_19(__pyx_t_18); if (unlikely(!__pyx_t_15)) goto __pyx_L29_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_15);
            index = 1; __pyx_t_16 = __pyx_t_19(__pyx_t_18); if (unlikely(!__pyx_t_16)) goto __pyx_L29_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_16);
            index = 2; __pyx_t_17 = __pyx_t_19(__pyx_t_18); if (unlikely(!__pyx_t_17)) goto __pyx_L29_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_17);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_19(__pyx_t_18), 3) < 0) __PYX_ERR(0, 971, __pyx_L26_error)
            __pyx_t_19 = NULL;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L30_unpacking_done;
            __pyx_L29_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            __pyx_t_19 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 971, __pyx_L26_error)
            __pyx_L30_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_9genexpr13__pyx_v_i, __pyx_t_15);
          __pyx_t_15 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr13__pyx_v_x, __pyx_t_16);
          __pyx_t_16 = 0;
          __Pyx_XDECREF_SET(__pyx_9genexpr13__pyx_v__, __pyx_t_17);
          __pyx_t_17 = 0;
          __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 971, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_9genexpr13__pyx_v_i);
          __Pyx_GIVEREF(__pyx_9genexpr13__pyx_v_i);
          PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_9genexpr13__pyx_v_i);
          __Pyx_INCREF(__pyx_9genexpr13__pyx_v_x);
          __Pyx_GIVEREF(__pyx_9genexpr13__pyx_v_x);
          PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_9genexpr13__pyx_v_x);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_12, (PyObject*)__pyx_t_9))) __PYX_ERR(0, 971, __pyx_L26_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_9genexpr13__pyx_v__); __pyx_9genexpr13__pyx_v__ = 0;
        __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_i); __pyx_9genexpr13__pyx_v_i = 0;
        __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_x); __pyx_9genexpr13__pyx_v_x = 0;
        goto __pyx_L31_exit_scope;
        __pyx_L26_error:;
        __Pyx_XDECREF(__pyx_9genexpr13__pyx_v__); __pyx_9genexpr13__pyx_v__ = 0;
        __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_i); __pyx_9genexpr13__pyx_v_i = 0;
        __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_x); __pyx_9genexpr13__pyx_v_x = 0;
        goto __pyx_L1_error;
        __pyx_L31_exit_scope:;
      } /* exit inner scope */
      __pyx_t_3 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders), __pyx_t_12};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 971, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders), __pyx_t_12};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 971, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 971, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_3) {
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3); __pyx_t_3 = NULL;
        }
        __Pyx_INCREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders));
        __Pyx_GIVEREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders));
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_14, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders));
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_14, __pyx_t_12);
        __pyx_t_12 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 971, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;
    }

    /* "lark_cython/lark_cython.pyx":966
 *     nones_to_add += empty_indices[len(expansion)]
 * 
 *     if _empty_indices or len(to_include) < len(expansion) or any(to_expand for i, to_expand,_ in to_include):             # <<<<<<<<<<<<<<
 *         if _empty_indices or ambiguous:
 *             return partial(ChildFilter if ambiguous else ChildFilterLALR, to_include, nones_to_add)
 */
  }

  /* "lark_cython/lark_cython.pyx":946
 * 
 * 
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):             # <<<<<<<<<<<<<<
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("lark_cython.lark_cython.maybe_create_child_filter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_empty_indices);
  __Pyx_XDECREF(__pyx_v_nones_to_add);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_sym);
  __Pyx_XDECREF(__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_2generator6);
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_ones);
  __Pyx_XDECREF(__pyx_gb_11lark_cython_11lark_cython_25maybe_create_child_filter_5generator7);
  __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_i);
  __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_x);
  __Pyx_XDECREF(__pyx_9genexpr13__pyx_v__);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":976
 * class ParseTreeBuilder:
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):             # <<<<<<<<<<<<<<
 *         self.tree_class = Tree #tree_class
 *         self.propagate_positions = propagate_positions
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_1__init__ = {"__init__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_rules = 0;
  CYTHON_UNUSED PyObject *__pyx_v_tree_class = 0;
  PyObject *__pyx_v_propagate_positions = 0;
  PyObject *__pyx_v_ambiguous = 0;
  PyObject *__pyx_v_maybe_placeholders = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_rules,&__pyx_n_s_tree_class,&__pyx_n_s_propagate_positions,&__pyx_n_s_ambiguous,&__pyx_n_s_maybe_placeholders,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[3] = ((PyObject *)((PyObject *)Py_False));
    values[4] = ((PyObject *)((PyObject *)Py_False));
    values[5] = ((PyObject *)((PyObject *)Py_False));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_rules)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 6, 1); __PYX_ERR(0, 976, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tree_class)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 6, 2); __PYX_ERR(0, 976, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_propagate_positions);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ambiguous);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_maybe_placeholders);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 976, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_rules = values[1];
    __pyx_v_tree_class = values[2];
    __pyx_v_propagate_positions = values[3];
    __pyx_v_ambiguous = values[4];
    __pyx_v_maybe_placeholders = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 976, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder___init__(__pyx_self, __pyx_v_self, __pyx_v_rules, __pyx_v_tree_class, __pyx_v_propagate_positions, __pyx_v_ambiguous, __pyx_v_maybe_placeholders);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_rules, CYTHON_UNUSED PyObject *__pyx_v_tree_class, PyObject *__pyx_v_propagate_positions, PyObject *__pyx_v_ambiguous, PyObject *__pyx_v_maybe_placeholders) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "lark_cython/lark_cython.pyx":977
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):
 *         self.tree_class = Tree #tree_class             # <<<<<<<<<<<<<<
 *         self.propagate_positions = propagate_positions
 *         self.ambiguous = ambiguous
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_tree_class, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Tree)) < 0) __PYX_ERR(0, 977, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":978
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):
 *         self.tree_class = Tree #tree_class
 *         self.propagate_positions = propagate_positions             # <<<<<<<<<<<<<<
 *         self.ambiguous = ambiguous
 *         self.maybe_placeholders = maybe_placeholders
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_propagate_positions, __pyx_v_propagate_positions) < 0) __PYX_ERR(0, 978, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":979
 *         self.tree_class = Tree #tree_class
 *         self.propagate_positions = propagate_positions
 *         self.ambiguous = ambiguous             # <<<<<<<<<<<<<<
 *         self.maybe_placeholders = maybe_placeholders
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ambiguous, __pyx_v_ambiguous) < 0) __PYX_ERR(0, 979, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":980
 *         self.propagate_positions = propagate_positions
 *         self.ambiguous = ambiguous
 *         self.maybe_placeholders = maybe_placeholders             # <<<<<<<<<<<<<<
 * 
 *         self.rule_builders = list(self._init_builders(rules))
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_maybe_placeholders, __pyx_v_maybe_placeholders) < 0) __PYX_ERR(0, 980, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":982
 *         self.maybe_placeholders = maybe_placeholders
 * 
 *         self.rule_builders = list(self._init_builders(rules))             # <<<<<<<<<<<<<<
 * 
 *     def _init_builders(self, rules):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_init_builders); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_rules) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_rules);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PySequence_List(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_rule_builders, __pyx_t_2) < 0) __PYX_ERR(0, 982, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":976
 * class ParseTreeBuilder:
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):             # <<<<<<<<<<<<<<
 *         self.tree_class = Tree #tree_class
 *         self.propagate_positions = propagate_positions
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_11lark_cython_11lark_cython_16ParseTreeBuilder_4generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "lark_cython/lark_cython.pyx":984
 *         self.rule_builders = list(self._init_builders(rules))
 * 
 *     def _init_builders(self, rules):             # <<<<<<<<<<<<<<
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_3_init_builders(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_3_init_builders = {"_init_builders", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_3_init_builders, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_3_init_builders(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_rules = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init_builders (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_rules,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_rules)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_init_builders", 1, 2, 2, 1); __PYX_ERR(0, 984, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_init_builders") < 0)) __PYX_ERR(0, 984, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_rules = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_init_builders", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 984, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder._init_builders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_2_init_builders(__pyx_self, __pyx_v_self, __pyx_v_rules);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_2_init_builders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_rules) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_builders", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 984, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_rules = __pyx_v_rules;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rules);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_rules);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_11lark_cython_11lark_cython_16ParseTreeBuilder_4generator2, __pyx_codeobj__39, (PyObject *) __pyx_cur_scope, __pyx_n_s_init_builders, __pyx_n_s_ParseTreeBuilder__init_builders, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!gen)) __PYX_ERR(0, 984, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder._init_builders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_11lark_cython_11lark_cython_16ParseTreeBuilder_4generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *__pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init_builders", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L9_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 984, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":985
 * 
 *     def _init_builders(self, rules):
 *         propagate_positions = make_propagate_positions(self.propagate_positions)             # <<<<<<<<<<<<<<
 * 
 *         for rule in rules:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_propagate_positions); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_11lark_cython_11lark_cython_make_propagate_positions(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_propagate_positions = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":987
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 *         for rule in rules:             # <<<<<<<<<<<<<<
 *             options = rule.options
 *             keep_all_tokens = options.keep_all_tokens
 */
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_rules)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_rules)) {
    __pyx_t_2 = __pyx_cur_scope->__pyx_v_rules; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_rules); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 987, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 987, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 987, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_1); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 987, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 987, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 987, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_rule);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_rule, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":988
 * 
 *         for rule in rules:
 *             options = rule.options             # <<<<<<<<<<<<<<
 *             keep_all_tokens = options.keep_all_tokens
 *             expand_single_child = options.expand1
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rule, __pyx_n_s_options); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_options);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_options, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":989
 *         for rule in rules:
 *             options = rule.options
 *             keep_all_tokens = options.keep_all_tokens             # <<<<<<<<<<<<<<
 *             expand_single_child = options.expand1
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_options, __pyx_n_s_keep_all_tokens); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_keep_all_tokens);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_keep_all_tokens, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":990
 *             options = rule.options
 *             keep_all_tokens = options.keep_all_tokens
 *             expand_single_child = options.expand1             # <<<<<<<<<<<<<<
 * 
 *             wrapper_chain = list(filter(None, [
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_options, __pyx_n_s_expand1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_expand_single_child);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_expand_single_child, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":993
 * 
 *             wrapper_chain = list(filter(None, [
 *                 (expand_single_child and not rule.alias) and ExpandSingleChild,             # <<<<<<<<<<<<<<
 *                 maybe_create_child_filter(rule.expansion, keep_all_tokens, self.ambiguous, options.empty_indices if self.maybe_placeholders else None),
 *                 propagate_positions,
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_expand_single_child); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 993, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_expand_single_child);
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_expand_single_child;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rule, __pyx_n_s_alias); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 993, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = (!__pyx_t_5);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L6_bool_binop_done;
    }
    __Pyx_INCREF(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ExpandSingleChild));
    __pyx_t_1 = ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ExpandSingleChild);
    __pyx_L6_bool_binop_done:;

    /* "lark_cython/lark_cython.pyx":994
 *             wrapper_chain = list(filter(None, [
 *                 (expand_single_child and not rule.alias) and ExpandSingleChild,
 *                 maybe_create_child_filter(rule.expansion, keep_all_tokens, self.ambiguous, options.empty_indices if self.maybe_placeholders else None),             # <<<<<<<<<<<<<<
 *                 propagate_positions,
 *             ]))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_maybe_create_child_filter); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_rule, __pyx_n_s_expansion); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_ambiguous); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self, __pyx_n_s_maybe_placeholders); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 994, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (__pyx_t_7) {
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_options, __pyx_n_s_empty_indices_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 994, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_11 = __pyx_t_12;
      __pyx_t_12 = 0;
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_11 = Py_None;
    }
    __pyx_t_12 = NULL;
    __pyx_t_13 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_13 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[5] = {__pyx_t_12, __pyx_t_9, __pyx_cur_scope->__pyx_v_keep_all_tokens, __pyx_t_10, __pyx_t_11};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 994, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[5] = {__pyx_t_12, __pyx_t_9, __pyx_cur_scope->__pyx_v_keep_all_tokens, __pyx_t_10, __pyx_t_11};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_13, 4+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 994, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else
    #endif
    {
      __pyx_t_14 = PyTuple_New(4+__pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 994, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (__pyx_t_12) {
        __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_12); __pyx_t_12 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_13, __pyx_t_9);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_keep_all_tokens);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_keep_all_tokens);
      PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_13, __pyx_cur_scope->__pyx_v_keep_all_tokens);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_14, 2+__pyx_t_13, __pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_14, 3+__pyx_t_13, __pyx_t_11);
      __pyx_t_9 = 0;
      __pyx_t_10 = 0;
      __pyx_t_11 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_14, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 994, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "lark_cython/lark_cython.pyx":992
 *             expand_single_child = options.expand1
 * 
 *             wrapper_chain = list(filter(None, [             # <<<<<<<<<<<<<<
 *                 (expand_single_child and not rule.alias) and ExpandSingleChild,
 *                 maybe_create_child_filter(rule.expansion, keep_all_tokens, self.ambiguous, options.empty_indices if self.maybe_placeholders else None),
 */
    __pyx_t_8 = PyList_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_8, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_8, 1, __pyx_t_6);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_propagate_positions);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_propagate_positions);
    PyList_SET_ITEM(__pyx_t_8, 2, __pyx_cur_scope->__pyx_v_propagate_positions);
    __pyx_t_1 = 0;
    __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_6, 0, Py_None);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_filter, __pyx_t_6, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PySequence_List(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_wrapper_chain);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_wrapper_chain, ((PyObject*)__pyx_t_6));
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "lark_cython/lark_cython.pyx":998
 *             ]))
 * 
 *             yield rule, wrapper_chain             # <<<<<<<<<<<<<<
 * 
 *     def create_callback(self, transformer=None):
 */
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 998, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rule);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_rule);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_cur_scope->__pyx_v_rule);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_wrapper_chain);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_wrapper_chain);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_wrapper_chain);
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    __Pyx_XGIVEREF(__pyx_t_2);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_4;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L9_resume_from_yield:;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 998, __pyx_L1_error)

    /* "lark_cython/lark_cython.pyx":987
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 *         for rule in rules:             # <<<<<<<<<<<<<<
 *             options = rule.options
 *             keep_all_tokens = options.keep_all_tokens
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "lark_cython/lark_cython.pyx":984
 *         self.rule_builders = list(self._init_builders(rules))
 * 
 *     def _init_builders(self, rules):             # <<<<<<<<<<<<<<
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("_init_builders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":1000
 *             yield rule, wrapper_chain
 * 
 *     def create_callback(self, transformer=None):             # <<<<<<<<<<<<<<
 *         callbacks = {}
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_6create_callback(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_6create_callback = {"create_callback", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_6create_callback, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_6create_callback(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_transformer = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_callback (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_transformer,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transformer);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_callback") < 0)) __PYX_ERR(0, 1000, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_transformer = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_callback", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1000, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.create_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_5create_callback(__pyx_self, __pyx_v_self, __pyx_v_transformer);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":1005
 *         default_handler = getattr(transformer, '__default__', None)
 *         if default_handler:
 *             def default_callback(data, children):             # <<<<<<<<<<<<<<
 *                 return default_handler(data, children, None)
 *         else:
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_1default_callback(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_1default_callback = {"default_callback", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_1default_callback, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_1default_callback(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_v_children = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("default_callback (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,&__pyx_n_s_children,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_children)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("default_callback", 1, 2, 2, 1); __PYX_ERR(0, 1005, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "default_callback") < 0)) __PYX_ERR(0, 1005, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_data = values[0];
    __pyx_v_children = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("default_callback", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1005, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.create_callback.default_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_default_callback(__pyx_self, __pyx_v_data, __pyx_v_children);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_default_callback(PyObject *__pyx_self, PyObject *__pyx_v_data, PyObject *__pyx_v_children) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *__pyx_cur_scope;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("default_callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "lark_cython/lark_cython.pyx":1006
 *         if default_handler:
 *             def default_callback(data, children):
 *                 return default_handler(data, children, None)             # <<<<<<<<<<<<<<
 *         else:
 *             default_callback = self.tree_class
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_default_handler)) { __Pyx_RaiseClosureNameError("default_handler"); __PYX_ERR(0, 1006, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_default_handler);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_default_handler; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_data, __pyx_v_children, Py_None};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1006, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, __pyx_v_data, __pyx_v_children, Py_None};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1006, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_data);
    __Pyx_INCREF(__pyx_v_children);
    __Pyx_GIVEREF(__pyx_v_children);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_children);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, Py_None);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":1005
 *         default_handler = getattr(transformer, '__default__', None)
 *         if default_handler:
 *             def default_callback(data, children):             # <<<<<<<<<<<<<<
 *                 return default_handler(data, children, None)
 *         else:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.create_callback.default_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "lark_cython/lark_cython.pyx":1000
 *             yield rule, wrapper_chain
 * 
 *     def create_callback(self, transformer=None):             # <<<<<<<<<<<<<<
 *         callbacks = {}
 * 
 */

static PyObject *__pyx_pf_11lark_cython_11lark_cython_16ParseTreeBuilder_5create_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_transformer) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *__pyx_cur_scope;
  PyObject *__pyx_v_callbacks = NULL;
  PyObject *__pyx_v_default_callback = 0;
  PyObject *__pyx_v_rule = NULL;
  PyObject *__pyx_v_wrapper_chain = NULL;
  PyObject *__pyx_v_user_callback_name = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_wrapper = NULL;
  PyObject *__pyx_v_w = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  PyObject *(*__pyx_t_19)(PyObject *);
  Py_UCS4 __pyx_t_20;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_callback", 0);
  __pyx_cur_scope = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *)__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback(__pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1000, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "lark_cython/lark_cython.pyx":1001
 * 
 *     def create_callback(self, transformer=None):
 *         callbacks = {}             # <<<<<<<<<<<<<<
 * 
 *         default_handler = getattr(transformer, '__default__', None)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_callbacks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":1003
 *         callbacks = {}
 * 
 *         default_handler = getattr(transformer, '__default__', None)             # <<<<<<<<<<<<<<
 *         if default_handler:
 *             def default_callback(data, children):
 */
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_v_transformer, __pyx_n_u_default, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_default_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":1004
 * 
 *         default_handler = getattr(transformer, '__default__', None)
 *         if default_handler:             # <<<<<<<<<<<<<<
 *             def default_callback(data, children):
 *                 return default_handler(data, children, None)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_default_handler); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1004, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "lark_cython/lark_cython.pyx":1005
 *         default_handler = getattr(transformer, '__default__', None)
 *         if default_handler:
 *             def default_callback(data, children):             # <<<<<<<<<<<<<<
 *                 return default_handler(data, children, None)
 *         else:
 */
    __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_15create_callback_1default_callback, 0, __pyx_n_s_ParseTreeBuilder_create_callback, ((PyObject*)__pyx_cur_scope), __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_default_callback = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":1004
 * 
 *         default_handler = getattr(transformer, '__default__', None)
 *         if default_handler:             # <<<<<<<<<<<<<<
 *             def default_callback(data, children):
 *                 return default_handler(data, children, None)
 */
    goto __pyx_L3;
  }

  /* "lark_cython/lark_cython.pyx":1008
 *                 return default_handler(data, children, None)
 *         else:
 *             default_callback = self.tree_class             # <<<<<<<<<<<<<<
 * 
 *         for rule, wrapper_chain in self.rule_builders:
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_tree_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_default_callback = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "lark_cython/lark_cython.pyx":1010
 *             default_callback = self.tree_class
 * 
 *         for rule, wrapper_chain in self.rule_builders:             # <<<<<<<<<<<<<<
 * 
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_rule_builders); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1010, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1010, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1010, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1010, __pyx_L1_error)
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1010, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1010, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1010, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1010, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1010, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1010, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) __PYX_ERR(0, 1010, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1010, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_rule, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_wrapper_chain, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "lark_cython/lark_cython.pyx":1012
 *         for rule, wrapper_chain in self.rule_builders:
 * 
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name             # <<<<<<<<<<<<<<
 *             try:
 *                 if not isinstance(user_callback_name, str):
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rule, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1012, __pyx_L1_error)
    if (!__pyx_t_2) {
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_1 = __pyx_t_7;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_rule, __pyx_n_s_options); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_template_source); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1012, __pyx_L1_error)
    if (!__pyx_t_2) {
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_1 = __pyx_t_6;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_rule, __pyx_n_s_origin); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_1 = __pyx_t_7;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_L8_bool_binop_done:;
    __Pyx_XDECREF_SET(__pyx_v_user_callback_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "lark_cython/lark_cython.pyx":1013
 * 
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 *             try:             # <<<<<<<<<<<<<<
 *                 if not isinstance(user_callback_name, str):
 *                     user_callback_name = user_callback_name.value
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      /*try:*/ {

        /* "lark_cython/lark_cython.pyx":1014
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 *             try:
 *                 if not isinstance(user_callback_name, str):             # <<<<<<<<<<<<<<
 *                     user_callback_name = user_callback_name.value
 *                 f = getattr(transformer, user_callback_name)
 */
        __pyx_t_2 = PyUnicode_Check(__pyx_v_user_callback_name); 
        __pyx_t_13 = ((!(__pyx_t_2 != 0)) != 0);
        if (__pyx_t_13) {

          /* "lark_cython/lark_cython.pyx":1015
 *             try:
 *                 if not isinstance(user_callback_name, str):
 *                     user_callback_name = user_callback_name.value             # <<<<<<<<<<<<<<
 *                 f = getattr(transformer, user_callback_name)
 *                 wrapper = getattr(f, 'visit_wrapper', None)
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_user_callback_name, __pyx_n_s_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1015, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_user_callback_name, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "lark_cython/lark_cython.pyx":1014
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 *             try:
 *                 if not isinstance(user_callback_name, str):             # <<<<<<<<<<<<<<
 *                     user_callback_name = user_callback_name.value
 *                 f = getattr(transformer, user_callback_name)
 */
        }

        /* "lark_cython/lark_cython.pyx":1016
 *                 if not isinstance(user_callback_name, str):
 *                     user_callback_name = user_callback_name.value
 *                 f = getattr(transformer, user_callback_name)             # <<<<<<<<<<<<<<
 *                 wrapper = getattr(f, 'visit_wrapper', None)
 *                 if wrapper is not None:
 */
        __pyx_t_1 = __Pyx_GetAttr(__pyx_v_transformer, __pyx_v_user_callback_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1016, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_f, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "lark_cython/lark_cython.pyx":1017
 *                     user_callback_name = user_callback_name.value
 *                 f = getattr(transformer, user_callback_name)
 *                 wrapper = getattr(f, 'visit_wrapper', None)             # <<<<<<<<<<<<<<
 *                 if wrapper is not None:
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)
 */
        __pyx_t_1 = __Pyx_GetAttr3(__pyx_v_f, __pyx_n_u_visit_wrapper, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1017, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_wrapper, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "lark_cython/lark_cython.pyx":1018
 *                 f = getattr(transformer, user_callback_name)
 *                 wrapper = getattr(f, 'visit_wrapper', None)
 *                 if wrapper is not None:             # <<<<<<<<<<<<<<
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)
 *                 elif isinstance(transformer, Transformer_InPlace):
 */
        __pyx_t_13 = (__pyx_v_wrapper != Py_None);
        __pyx_t_2 = (__pyx_t_13 != 0);
        if (__pyx_t_2) {

          /* "lark_cython/lark_cython.pyx":1019
 *                 wrapper = getattr(f, 'visit_wrapper', None)
 *                 if wrapper is not None:
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)             # <<<<<<<<<<<<<<
 *                 elif isinstance(transformer, Transformer_InPlace):
 *                     f = inplace_transformer(f)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_apply_visit_wrapper); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1019, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = NULL;
          __pyx_t_14 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_14 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_f, __pyx_v_user_callback_name, __pyx_v_wrapper};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1019, __pyx_L11_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_v_f, __pyx_v_user_callback_name, __pyx_v_wrapper};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1019, __pyx_L11_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          {
            __pyx_t_8 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1019, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_8);
            if (__pyx_t_6) {
              __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
            }
            __Pyx_INCREF(__pyx_v_f);
            __Pyx_GIVEREF(__pyx_v_f);
            PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_14, __pyx_v_f);
            __Pyx_INCREF(__pyx_v_user_callback_name);
            __Pyx_GIVEREF(__pyx_v_user_callback_name);
            PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_14, __pyx_v_user_callback_name);
            __Pyx_INCREF(__pyx_v_wrapper);
            __Pyx_GIVEREF(__pyx_v_wrapper);
            PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_14, __pyx_v_wrapper);
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1019, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF_SET(__pyx_v_f, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "lark_cython/lark_cython.pyx":1018
 *                 f = getattr(transformer, user_callback_name)
 *                 wrapper = getattr(f, 'visit_wrapper', None)
 *                 if wrapper is not None:             # <<<<<<<<<<<<<<
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)
 *                 elif isinstance(transformer, Transformer_InPlace):
 */
          goto __pyx_L20;
        }

        /* "lark_cython/lark_cython.pyx":1020
 *                 if wrapper is not None:
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)
 *                 elif isinstance(transformer, Transformer_InPlace):             # <<<<<<<<<<<<<<
 *                     f = inplace_transformer(f)
 *             except AttributeError:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Transformer_InPlace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1020, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = PyObject_IsInstance(__pyx_v_transformer, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1020, __pyx_L11_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_13 = (__pyx_t_2 != 0);
        if (__pyx_t_13) {

          /* "lark_cython/lark_cython.pyx":1021
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)
 *                 elif isinstance(transformer, Transformer_InPlace):
 *                     f = inplace_transformer(f)             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 f = partial(default_callback, user_callback_name)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_inplace_transformer); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1021, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_f) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_f);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1021, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF_SET(__pyx_v_f, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "lark_cython/lark_cython.pyx":1020
 *                 if wrapper is not None:
 *                     f = apply_visit_wrapper(f, user_callback_name, wrapper)
 *                 elif isinstance(transformer, Transformer_InPlace):             # <<<<<<<<<<<<<<
 *                     f = inplace_transformer(f)
 *             except AttributeError:
 */
        }
        __pyx_L20:;

        /* "lark_cython/lark_cython.pyx":1013
 * 
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 *             try:             # <<<<<<<<<<<<<<
 *                 if not isinstance(user_callback_name, str):
 *                     user_callback_name = user_callback_name.value
 */
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      goto __pyx_L18_try_end;
      __pyx_L11_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "lark_cython/lark_cython.pyx":1022
 *                 elif isinstance(transformer, Transformer_InPlace):
 *                     f = inplace_transformer(f)
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 f = partial(default_callback, user_callback_name)
 * 
 */
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_14) {
        __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.create_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 1022, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_8);

        /* "lark_cython/lark_cython.pyx":1023
 *                     f = inplace_transformer(f)
 *             except AttributeError:
 *                 f = partial(default_callback, user_callback_name)             # <<<<<<<<<<<<<<
 * 
 *             for w in wrapper_chain:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_partial); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1023, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_16 = NULL;
        __pyx_t_14 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_16)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_16);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
            __pyx_t_14 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_15)) {
          PyObject *__pyx_temp[3] = {__pyx_t_16, __pyx_v_default_callback, __pyx_v_user_callback_name};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1023, __pyx_L13_except_error)
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
          PyObject *__pyx_temp[3] = {__pyx_t_16, __pyx_v_default_callback, __pyx_v_user_callback_name};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1023, __pyx_L13_except_error)
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else
        #endif
        {
          __pyx_t_17 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 1023, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          if (__pyx_t_16) {
            __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_16); __pyx_t_16 = NULL;
          }
          __Pyx_INCREF(__pyx_v_default_callback);
          __Pyx_GIVEREF(__pyx_v_default_callback);
          PyTuple_SET_ITEM(__pyx_t_17, 0+__pyx_t_14, __pyx_v_default_callback);
          __Pyx_INCREF(__pyx_v_user_callback_name);
          __Pyx_GIVEREF(__pyx_v_user_callback_name);
          PyTuple_SET_ITEM(__pyx_t_17, 1+__pyx_t_14, __pyx_v_user_callback_name);
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1023, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        }
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF_SET(__pyx_v_f, __pyx_t_6);
        __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L12_exception_handled;
      }
      goto __pyx_L13_except_error;
      __pyx_L13_except_error:;

      /* "lark_cython/lark_cython.pyx":1013
 * 
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 *             try:             # <<<<<<<<<<<<<<
 *                 if not isinstance(user_callback_name, str):
 *                     user_callback_name = user_callback_name.value
 */
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      goto __pyx_L1_error;
      __pyx_L12_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_L18_try_end:;
    }

    /* "lark_cython/lark_cython.pyx":1025
 *                 f = partial(default_callback, user_callback_name)
 * 
 *             for w in wrapper_chain:             # <<<<<<<<<<<<<<
 *                 f = w(f)
 * 
 */
    if (likely(PyList_CheckExact(__pyx_v_wrapper_chain)) || PyTuple_CheckExact(__pyx_v_wrapper_chain)) {
      __pyx_t_8 = __pyx_v_wrapper_chain; __Pyx_INCREF(__pyx_t_8); __pyx_t_18 = 0;
      __pyx_t_19 = NULL;
    } else {
      __pyx_t_18 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_v_wrapper_chain); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1025, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_19 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 1025, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_19)) {
        if (likely(PyList_CheckExact(__pyx_t_8))) {
          if (__pyx_t_18 >= PyList_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_18); __Pyx_INCREF(__pyx_t_7); __pyx_t_18++; if (unlikely(0 < 0)) __PYX_ERR(0, 1025, __pyx_L1_error)
          #else
          __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1025, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        } else {
          if (__pyx_t_18 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_18); __Pyx_INCREF(__pyx_t_7); __pyx_t_18++; if (unlikely(0 < 0)) __PYX_ERR(0, 1025, __pyx_L1_error)
          #else
          __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1025, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
        }
      } else {
        __pyx_t_7 = __pyx_t_19(__pyx_t_8);
        if (unlikely(!__pyx_t_7)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1025, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_7);
      }
      __Pyx_XDECREF_SET(__pyx_v_w, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":1026
 * 
 *             for w in wrapper_chain:
 *                 f = w(f)             # <<<<<<<<<<<<<<
 * 
 *             if rule in callbacks:
 */
      __Pyx_INCREF(__pyx_v_w);
      __pyx_t_1 = __pyx_v_w; __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, __pyx_v_f) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_f);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1026, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_f, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "lark_cython/lark_cython.pyx":1025
 *                 f = partial(default_callback, user_callback_name)
 * 
 *             for w in wrapper_chain:             # <<<<<<<<<<<<<<
 *                 f = w(f)
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "lark_cython/lark_cython.pyx":1028
 *                 f = w(f)
 * 
 *             if rule in callbacks:             # <<<<<<<<<<<<<<
 *                 raise GrammarError("Rule '%s' already exists" % (rule,))
 * 
 */
    __pyx_t_13 = (__Pyx_PyDict_ContainsTF(__pyx_v_rule, __pyx_v_callbacks, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 1028, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_13 != 0);
    if (unlikely(__pyx_t_2)) {

      /* "lark_cython/lark_cython.pyx":1029
 * 
 *             if rule in callbacks:
 *                 raise GrammarError("Rule '%s' already exists" % (rule,))             # <<<<<<<<<<<<<<
 * 
 *             callbacks[rule] = f
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_GrammarError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1029, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1029, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_18 = 0;
      __pyx_t_20 = 127;
      __Pyx_INCREF(__pyx_kp_u_Rule);
      __pyx_t_18 += 6;
      __Pyx_GIVEREF(__pyx_kp_u_Rule);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_Rule);
      __pyx_t_6 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_rule), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1029, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_20 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_20) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_20;
      __pyx_t_18 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u_already_exists);
      __pyx_t_18 += 16;
      __Pyx_GIVEREF(__pyx_kp_u_already_exists);
      PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_already_exists);
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_18, __pyx_t_20); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1029, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_8 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1029, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 1029, __pyx_L1_error)

      /* "lark_cython/lark_cython.pyx":1028
 *                 f = w(f)
 * 
 *             if rule in callbacks:             # <<<<<<<<<<<<<<
 *                 raise GrammarError("Rule '%s' already exists" % (rule,))
 * 
 */
    }

    /* "lark_cython/lark_cython.pyx":1031
 *                 raise GrammarError("Rule '%s' already exists" % (rule,))
 * 
 *             callbacks[rule] = f             # <<<<<<<<<<<<<<
 * 
 *         return callbacks
 */
    if (unlikely(PyDict_SetItem(__pyx_v_callbacks, __pyx_v_rule, __pyx_v_f) < 0)) __PYX_ERR(0, 1031, __pyx_L1_error)

    /* "lark_cython/lark_cython.pyx":1010
 *             default_callback = self.tree_class
 * 
 *         for rule, wrapper_chain in self.rule_builders:             # <<<<<<<<<<<<<<
 * 
 *             user_callback_name = rule.alias or rule.options.template_source or rule.origin.name
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "lark_cython/lark_cython.pyx":1033
 *             callbacks[rule] = f
 * 
 *         return callbacks             # <<<<<<<<<<<<<<
 * 
 * plugins = {
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_callbacks);
  __pyx_r = __pyx_v_callbacks;
  goto __pyx_L0;

  /* "lark_cython/lark_cython.pyx":1000
 *             yield rule, wrapper_chain
 * 
 *     def create_callback(self, transformer=None):             # <<<<<<<<<<<<<<
 *         callbacks = {}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("lark_cython.lark_cython.ParseTreeBuilder.create_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_callbacks);
  __Pyx_XDECREF(__pyx_v_default_callback);
  __Pyx_XDECREF(__pyx_v_rule);
  __Pyx_XDECREF(__pyx_v_wrapper_chain);
  __Pyx_XDECREF(__pyx_v_user_callback_name);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_wrapper);
  __Pyx_XDECREF(__pyx_v_w);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Lexer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_9__pyx_unpickle_Lexer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_9__pyx_unpickle_Lexer = {"__pyx_unpickle_Lexer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_9__pyx_unpickle_Lexer, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_9__pyx_unpickle_Lexer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Lexer (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Lexer", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Lexer", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_Lexer") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Lexer", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_Lexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_8__pyx_unpickle_Lexer(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_8__pyx_unpickle_Lexer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Lexer", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xd41d8cd) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = Lexer.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xd41d8cd:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = Lexer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xd41d8cd:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = Lexer.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Lexer), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = Lexer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = Lexer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Lexer__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xd41d8cd = ())" % __pyx_checksum)
 *     __pyx_result = Lexer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Lexer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_Lexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Lexer__set_state(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Lexer__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = ((__pyx_t_2 > 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_Lexer__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_BasicLexer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11__pyx_unpickle_BasicLexer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_11__pyx_unpickle_BasicLexer = {"__pyx_unpickle_BasicLexer", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11__pyx_unpickle_BasicLexer, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_11__pyx_unpickle_BasicLexer(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_BasicLexer (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BasicLexer", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BasicLexer", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_BasicLexer") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BasicLexer", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_BasicLexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_10__pyx_unpickle_BasicLexer(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_10__pyx_unpickle_BasicLexer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BasicLexer", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x6409ee0:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x6409ee0) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x6409ee0:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)
 *     __pyx_result = BasicLexer.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x6409ee0:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = BasicLexer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x64, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x6409ee0:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)
 *     __pyx_result = BasicLexer.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_BasicLexer), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)
 *     __pyx_result = BasicLexer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = BasicLexer.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_BasicLexer__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x6409ee0 = (_scanner, callback, g_regex_flags, ignore_types, newline_types, re, terminals, terminals_by_name, use_bytes, user_callbacks))" % __pyx_checksum)
 *     __pyx_result = BasicLexer.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_BasicLexer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_BasicLexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_BasicLexer__set_state(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BasicLexer__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_Scanner))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_scanner);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->_scanner));
  __pyx_v___pyx_result->_scanner = ((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->callback);
  __Pyx_DECREF(__pyx_v___pyx_result->callback);
  __pyx_v___pyx_result->callback = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->g_regex_flags = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyFrozenSet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "frozenset", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->ignore_types);
  __Pyx_DECREF(__pyx_v___pyx_result->ignore_types);
  __pyx_v___pyx_result->ignore_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyFrozenSet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "frozenset", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->newline_types);
  __Pyx_DECREF(__pyx_v___pyx_result->newline_types);
  __pyx_v___pyx_result->newline_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->re);
  __Pyx_DECREF(__pyx_v___pyx_result->re);
  __pyx_v___pyx_result->re = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->terminals);
  __Pyx_DECREF(__pyx_v___pyx_result->terminals);
  __pyx_v___pyx_result->terminals = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->terminals_by_name);
  __Pyx_DECREF(__pyx_v___pyx_result->terminals_by_name);
  __pyx_v___pyx_result->terminals_by_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->use_bytes = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->user_callbacks);
  __Pyx_DECREF(__pyx_v___pyx_result->user_callbacks);
  __pyx_v___pyx_result->user_callbacks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 10) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[10])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_BasicLexer__set_state(<BasicLexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BasicLexer__set_state(BasicLexer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._scanner = __pyx_state[0]; __pyx_result.callback = __pyx_state[1]; __pyx_result.g_regex_flags = __pyx_state[2]; __pyx_result.ignore_types = __pyx_state[3]; __pyx_result.newline_types = __pyx_state[4]; __pyx_result.re = __pyx_state[5]; __pyx_result.terminals = __pyx_state[6]; __pyx_result.terminals_by_name = __pyx_state[7]; __pyx_result.use_bytes = __pyx_state[8]; __pyx_result.user_callbacks = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_BasicLexer__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ParseConf(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_13__pyx_unpickle_ParseConf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_13__pyx_unpickle_ParseConf = {"__pyx_unpickle_ParseConf", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_13__pyx_unpickle_ParseConf, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_13__pyx_unpickle_ParseConf(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ParseConf (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ParseConf", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ParseConf", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ParseConf") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ParseConf", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ParseConf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_12__pyx_unpickle_ParseConf(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_12__pyx_unpickle_ParseConf(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ParseConf", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x87545ac:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x87545ac) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x87545ac:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)
 *     __pyx_result = ParseConf.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x87545ac:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ParseConf.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x87, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x87545ac:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)
 *     __pyx_result = ParseConf.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ParseConf), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)
 *     __pyx_result = ParseConf.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ParseConf.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParseConf__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x87545ac = (callbacks, end_state, parse_table, start, start_state, states))" % __pyx_checksum)
 *     __pyx_result = ParseConf.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ParseConf(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ParseConf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParseConf__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ParseConf__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->callbacks);
  __Pyx_DECREF(__pyx_v___pyx_result->callbacks);
  __pyx_v___pyx_result->callbacks = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->end_state = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->parse_table);
  __Pyx_DECREF(__pyx_v___pyx_result->parse_table);
  __pyx_v___pyx_result->parse_table = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->start);
  __Pyx_DECREF(__pyx_v___pyx_result->start);
  __pyx_v___pyx_result->start = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->start_state = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->states);
  __Pyx_DECREF(__pyx_v___pyx_result->states);
  __pyx_v___pyx_result->states = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 6) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ParseConf__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ParserState(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15__pyx_unpickle_ParserState(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_15__pyx_unpickle_ParserState = {"__pyx_unpickle_ParserState", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_15__pyx_unpickle_ParserState, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_15__pyx_unpickle_ParserState(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ParserState (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ParserState", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ParserState", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ParserState") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ParserState", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ParserState", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_14__pyx_unpickle_ParserState(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_14__pyx_unpickle_ParserState(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ParserState", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x0b3311e:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x0b3311e) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x0b3311e:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)
 *     __pyx_result = ParserState.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x0b3311e:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ParserState.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x0b, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x0b3311e:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)
 *     __pyx_result = ParserState.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ParserState), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)
 *     __pyx_result = ParserState.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ParserState.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParserState__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x0b3311e = (lexer, parse_conf, state_stack, value_stack))" % __pyx_checksum)
 *     __pyx_result = ParserState.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ParserState(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ParserState", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ParserState__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ParserState__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_LexerThread))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->lexer);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->lexer));
  __pyx_v___pyx_result->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_11lark_cython_11lark_cython_ParseConf))))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->parse_conf);
  __Pyx_DECREF(((PyObject *)__pyx_v___pyx_result->parse_conf));
  __pyx_v___pyx_result->parse_conf = ((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->state_stack);
  __Pyx_DECREF(__pyx_v___pyx_result->state_stack);
  __pyx_v___pyx_result->state_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->value_stack);
  __Pyx_DECREF(__pyx_v___pyx_result->value_stack);
  __pyx_v___pyx_result->value_stack = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 4) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[4])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[4])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ParserState__set_state(<ParserState> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ParserState__set_state(ParserState __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.lexer = __pyx_state[0]; __pyx_result.parse_conf = __pyx_state[1]; __pyx_result.state_stack = __pyx_state[2]; __pyx_result.value_stack = __pyx_state[3]
 *     if len(__pyx_state) > 4 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ParserState__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Meta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17__pyx_unpickle_Meta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_17__pyx_unpickle_Meta = {"__pyx_unpickle_Meta", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_17__pyx_unpickle_Meta, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_17__pyx_unpickle_Meta(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Meta (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Meta", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Meta", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_Meta") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Meta", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_Meta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_16__pyx_unpickle_Meta(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_16__pyx_unpickle_Meta(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Meta", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x68ad4c6:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x68ad4c6) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x68ad4c6:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)
 *     __pyx_result = Meta.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x68ad4c6:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = Meta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x68, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x68ad4c6:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)
 *     __pyx_result = Meta.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Meta), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)
 *     __pyx_result = Meta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = Meta.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Meta__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x68ad4c6 = (column, empty, end_column, end_line, end_pos, line, match_tree, orig_expansion, start_pos))" % __pyx_checksum)
 *     __pyx_result = Meta.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Meta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_Meta", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_Meta__set_state(struct __pyx_obj_11lark_cython_11lark_cython_Meta *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Meta__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[9])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->column = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->empty = __pyx_t_3;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->end_column = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->end_line = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->end_pos = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->line = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->match_tree = __pyx_t_3;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->orig_expansion);
  __Pyx_DECREF(__pyx_v___pyx_result->orig_expansion);
  __pyx_v___pyx_result->orig_expansion = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->start_pos = __pyx_t_2;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[9])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 9) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[9])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[9])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_Meta__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ExpandSingleChild(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_19__pyx_unpickle_ExpandSingleChild(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_19__pyx_unpickle_ExpandSingleChild = {"__pyx_unpickle_ExpandSingleChild", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_19__pyx_unpickle_ExpandSingleChild, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_19__pyx_unpickle_ExpandSingleChild(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ExpandSingleChild (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ExpandSingleChild", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ExpandSingleChild", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ExpandSingleChild") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ExpandSingleChild", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ExpandSingleChild", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_18__pyx_unpickle_ExpandSingleChild(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_18__pyx_unpickle_ExpandSingleChild(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ExpandSingleChild", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x8bfa35b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x8bfa35b) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x8bfa35b:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)
 *     __pyx_result = ExpandSingleChild.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x8bfa35b:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ExpandSingleChild.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x8b, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x8bfa35b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)
 *     __pyx_result = ExpandSingleChild.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ExpandSingleChild), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)
 *     __pyx_result = ExpandSingleChild.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ExpandSingleChild.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ExpandSingleChild__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x8bfa35b = (node_builder))" % __pyx_checksum)
 *     __pyx_result = ExpandSingleChild.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ExpandSingleChild(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ExpandSingleChild", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.node_builder = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ExpandSingleChild__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ExpandSingleChild__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->node_builder);
  __Pyx_DECREF(__pyx_v___pyx_result->node_builder);
  __pyx_v___pyx_result->node_builder = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 1) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.node_builder = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ExpandSingleChild__set_state(<ExpandSingleChild> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ExpandSingleChild__set_state(ExpandSingleChild __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.node_builder = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ExpandSingleChild__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_PropagatePositions(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_21__pyx_unpickle_PropagatePositions(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_21__pyx_unpickle_PropagatePositions = {"__pyx_unpickle_PropagatePositions", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_21__pyx_unpickle_PropagatePositions, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_21__pyx_unpickle_PropagatePositions(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_PropagatePositions (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_PropagatePositions", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_PropagatePositions", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_PropagatePositions") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_PropagatePositions", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_PropagatePositions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_20__pyx_unpickle_PropagatePositions(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_20__pyx_unpickle_PropagatePositions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_PropagatePositions", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xf88b1a2:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0xf88b1a2) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xf88b1a2:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)
 *     __pyx_result = PropagatePositions.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0xf88b1a2:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = PropagatePositions.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xf8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xf88b1a2:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)
 *     __pyx_result = PropagatePositions.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_PropagatePositions), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)
 *     __pyx_result = PropagatePositions.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = PropagatePositions.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_PropagatePositions__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xf88b1a2 = (node_builder, node_filter))" % __pyx_checksum)
 *     __pyx_result = PropagatePositions.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_PropagatePositions(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_PropagatePositions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_PropagatePositions__set_state(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_PropagatePositions__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->node_builder);
  __Pyx_DECREF(__pyx_v___pyx_result->node_builder);
  __pyx_v___pyx_result->node_builder = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->node_filter);
  __Pyx_DECREF(__pyx_v___pyx_result->node_filter);
  __pyx_v___pyx_result->node_filter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 2) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[2])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[2])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_PropagatePositions__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilter(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_23__pyx_unpickle_ChildFilter(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_23__pyx_unpickle_ChildFilter = {"__pyx_unpickle_ChildFilter", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_23__pyx_unpickle_ChildFilter, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_23__pyx_unpickle_ChildFilter(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilter (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilter", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilter", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ChildFilter") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilter", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_22__pyx_unpickle_ChildFilter(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_22__pyx_unpickle_ChildFilter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilter", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x443db17) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilter.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x443db17:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ChildFilter.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x44, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilter.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilter), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilter.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ChildFilter.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilter__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilter.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilter(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilter__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilter__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->append_none);
  __Pyx_DECREF(__pyx_v___pyx_result->append_none);
  __pyx_v___pyx_result->append_none = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->node_builder);
  __Pyx_DECREF(__pyx_v___pyx_result->node_builder);
  __pyx_v___pyx_result->node_builder = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->to_include);
  __Pyx_DECREF(__pyx_v___pyx_result->to_include);
  __pyx_v___pyx_result->to_include = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 3) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilter__set_state(<ChildFilter> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilter__set_state(ChildFilter __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilter__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilterLALR(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_25__pyx_unpickle_ChildFilterLALR(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_25__pyx_unpickle_ChildFilterLALR = {"__pyx_unpickle_ChildFilterLALR", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_25__pyx_unpickle_ChildFilterLALR, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_25__pyx_unpickle_ChildFilterLALR(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilterLALR (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilterLALR", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilterLALR", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ChildFilterLALR") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilterLALR", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilterLALR", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_24__pyx_unpickle_ChildFilterLALR(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_24__pyx_unpickle_ChildFilterLALR(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilterLALR", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x443db17) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x443db17:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ChildFilterLALR.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x44, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ChildFilterLALR.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilterLALR(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilterLALR", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilterLALR__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.append_none);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.append_none);
  __pyx_v___pyx_result->__pyx_base.append_none = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.node_builder);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.node_builder);
  __pyx_v___pyx_result->__pyx_base.node_builder = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.to_include);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.to_include);
  __pyx_v___pyx_result->__pyx_base.to_include = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 3) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilterLALR__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilterLALR_NoPlaceholders(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_11lark_cython_11lark_cython_27__pyx_unpickle_ChildFilterLALR_NoPlaceholders(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_11lark_cython_11lark_cython_27__pyx_unpickle_ChildFilterLALR_NoPlaceholders = {"__pyx_unpickle_ChildFilterLALR_NoPlaceholders", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_27__pyx_unpickle_ChildFilterLALR_NoPlaceholders, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_11lark_cython_11lark_cython_27__pyx_unpickle_ChildFilterLALR_NoPlaceholders(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilterLALR_NoPlaceholders (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilterLALR_NoPlaceholders", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilterLALR_NoPlaceholders", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_ChildFilterLALR_NoPlaceholders") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_ChildFilterLALR_NoPlaceholders", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilterLALR_NoPlaceholders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11lark_cython_11lark_cython_26__pyx_unpickle_ChildFilterLALR_NoPlaceholders(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11lark_cython_11lark_cython_26__pyx_unpickle_ChildFilterLALR_NoPlaceholders(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilterLALR_NoPlaceholders", 0);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x443db17) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR_NoPlaceholders.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum != 0x443db17:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = ChildFilterLALR_NoPlaceholders.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x44, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0x443db17:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR_NoPlaceholders.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR_NoPlaceholders.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "(tree fragment)":9
 *     __pyx_result = ChildFilterLALR_NoPlaceholders.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x443db17 = (append_none, node_builder, to_include))" % __pyx_checksum)
 *     __pyx_result = ChildFilterLALR_NoPlaceholders.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilterLALR_NoPlaceholders(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilterLALR_NoPlaceholders", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_11lark_cython_11lark_cython___pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state", 0);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.append_none);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.append_none);
  __pyx_v___pyx_result->__pyx_base.append_none = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.node_builder);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.node_builder);
  __pyx_v___pyx_result->__pyx_base.node_builder = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base.to_include);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base.to_include);
  __pyx_v___pyx_result->__pyx_base.to_include = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 3) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(<ChildFilterLALR_NoPlaceholders> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state(ChildFilterLALR_NoPlaceholders __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("lark_cython.lark_cython.__pyx_unpickle_ChildFilterLALR_NoPlaceholders__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_Token __pyx_vtable_11lark_cython_11lark_cython_Token;

static struct __pyx_obj_11lark_cython_11lark_cython_Token *__pyx_freelist_11lark_cython_11lark_cython_Token[10240];
static int __pyx_freecount_11lark_cython_11lark_cython_Token = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Token(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_Token *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython_Token > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Token)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython_Token[--__pyx_freecount_11lark_cython_11lark_cython_Token];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Token));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_Token;
  p->type = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->value = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->end_line = Py_None; Py_INCREF(Py_None);
  p->end_column = Py_None; Py_INCREF(Py_None);
  p->end_pos = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_5Token_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_Token(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_Token *p = (struct __pyx_obj_11lark_cython_11lark_cython_Token *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->type);
  Py_CLEAR(p->value);
  Py_CLEAR(p->end_line);
  Py_CLEAR(p->end_column);
  Py_CLEAR(p->end_pos);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython_Token < 10240) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Token)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_11lark_cython_11lark_cython_Token[__pyx_freecount_11lark_cython_11lark_cython_Token++] = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_Token(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *p = (struct __pyx_obj_11lark_cython_11lark_cython_Token *)o;
  if (p->end_line) {
    e = (*v)(p->end_line, a); if (e) return e;
  }
  if (p->end_column) {
    e = (*v)(p->end_column, a); if (e) return e;
  }
  if (p->end_pos) {
    e = (*v)(p->end_pos, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_Token(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_Token *p = (struct __pyx_obj_11lark_cython_11lark_cython_Token *)o;
  tmp = ((PyObject*)p->end_line);
  p->end_line = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->end_column);
  p->end_column = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->end_pos);
  p->end_pos = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_4type_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_type(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_4type_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_4type_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_start_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_9start_pos_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_start_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_9start_pos_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_value(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_5value_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_value(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_5value_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_5value_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_4line_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_line(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_4line_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_column(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_6column_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_column(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_6column_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_end_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_end_line(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_8end_line_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_end_column(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_end_column(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_10end_column_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_5Token_end_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_5Token_end_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_5Token_7end_pos_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_Token[] = {
  {"new_borrow_pos", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_5Token_3new_borrow_pos, METH_VARARGS|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_Token[] = {
  {(char *)"type", __pyx_getprop_11lark_cython_11lark_cython_5Token_type, __pyx_setprop_11lark_cython_11lark_cython_5Token_type, (char *)0, 0},
  {(char *)"start_pos", __pyx_getprop_11lark_cython_11lark_cython_5Token_start_pos, __pyx_setprop_11lark_cython_11lark_cython_5Token_start_pos, (char *)0, 0},
  {(char *)"value", __pyx_getprop_11lark_cython_11lark_cython_5Token_value, __pyx_setprop_11lark_cython_11lark_cython_5Token_value, (char *)0, 0},
  {(char *)"line", __pyx_getprop_11lark_cython_11lark_cython_5Token_line, __pyx_setprop_11lark_cython_11lark_cython_5Token_line, (char *)0, 0},
  {(char *)"column", __pyx_getprop_11lark_cython_11lark_cython_5Token_column, __pyx_setprop_11lark_cython_11lark_cython_5Token_column, (char *)0, 0},
  {(char *)"end_line", __pyx_getprop_11lark_cython_11lark_cython_5Token_end_line, __pyx_setprop_11lark_cython_11lark_cython_5Token_end_line, (char *)0, 0},
  {(char *)"end_column", __pyx_getprop_11lark_cython_11lark_cython_5Token_end_column, __pyx_setprop_11lark_cython_11lark_cython_5Token_end_column, (char *)0, 0},
  {(char *)"end_pos", __pyx_getprop_11lark_cython_11lark_cython_5Token_end_pos, __pyx_setprop_11lark_cython_11lark_cython_5Token_end_pos, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_Token = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.Token", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Token), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Token, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11lark_cython_11lark_cython_5Token_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_11lark_cython_11lark_cython_5Token_9__hash__, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_Token, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_Token, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_Token, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_Token, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_Token, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerState __pyx_vtable_11lark_cython_11lark_cython_LexerState;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_LexerState(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_LexerState *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_LexerState;
  p->text = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)Py_None); Py_INCREF(Py_None);
  p->last_token = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_10LexerState_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_LexerState(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_LexerState *p = (struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->text);
  Py_CLEAR(p->line_ctr);
  Py_CLEAR(p->last_token);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_LexerState(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_LexerState *p = (struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)o;
  if (p->line_ctr) {
    e = (*v)(((PyObject *)p->line_ctr), a); if (e) return e;
  }
  if (p->last_token) {
    e = (*v)(p->last_token, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_LexerState(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_LexerState *p = (struct __pyx_obj_11lark_cython_11lark_cython_LexerState *)o;
  tmp = ((PyObject*)p->line_ctr);
  p->line_ctr = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->last_token);
  p->last_token = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_richcompare_11lark_cython_11lark_cython_LexerState(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_11lark_cython_11lark_cython_10LexerState_3__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_11lark_cython_11lark_cython_10LexerState_3__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret); Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_10LexerState_text(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_10LexerState_text(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_10LexerState_4text_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_10LexerState_line_ctr(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_10LexerState_line_ctr(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_10LexerState_8line_ctr_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_10LexerState_last_token(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_10LexerState_last_token(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_10LexerState_10last_token_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_LexerState[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10LexerState_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10LexerState_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_LexerState[] = {
  {(char *)"text", __pyx_getprop_11lark_cython_11lark_cython_10LexerState_text, __pyx_setprop_11lark_cython_11lark_cython_10LexerState_text, (char *)0, 0},
  {(char *)"line_ctr", __pyx_getprop_11lark_cython_11lark_cython_10LexerState_line_ctr, __pyx_setprop_11lark_cython_11lark_cython_10LexerState_line_ctr, (char *)0, 0},
  {(char *)"last_token", __pyx_getprop_11lark_cython_11lark_cython_10LexerState_last_token, __pyx_setprop_11lark_cython_11lark_cython_10LexerState_last_token, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_LexerState = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.LexerState", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_LexerState), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_LexerState, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_LexerState, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_LexerState, /*tp_clear*/
  __pyx_tp_richcompare_11lark_cython_11lark_cython_LexerState, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_LexerState, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_LexerState, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_LexerState, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_LineCounter __pyx_vtable_11lark_cython_11lark_cython_LineCounter;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_LineCounter(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_LineCounter;
  p->newline_char = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_11LineCounter_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_LineCounter(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *p = (struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  Py_CLEAR(p->newline_char);
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_tp_richcompare_11lark_cython_11lark_cython_LineCounter(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_3__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_11lark_cython_11lark_cython_11LineCounter_3__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret); Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11LineCounter_newline_char(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_newline_char(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_12newline_char_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11LineCounter_char_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_8char_pos_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_char_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_8char_pos_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11LineCounter_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_4line_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_line(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_4line_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11LineCounter_column(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_6column_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_column(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_6column_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11LineCounter_line_start_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_line_start_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_11LineCounter_14line_start_pos_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_LineCounter[] = {
  {"feed", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_11LineCounter_5feed, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11lark_cython_11lark_cython_11LineCounter_4feed},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11LineCounter_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11LineCounter_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_LineCounter[] = {
  {(char *)"newline_char", __pyx_getprop_11lark_cython_11lark_cython_11LineCounter_newline_char, __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_newline_char, (char *)0, 0},
  {(char *)"char_pos", __pyx_getprop_11lark_cython_11lark_cython_11LineCounter_char_pos, __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_char_pos, (char *)0, 0},
  {(char *)"line", __pyx_getprop_11lark_cython_11lark_cython_11LineCounter_line, __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_line, (char *)0, 0},
  {(char *)"column", __pyx_getprop_11lark_cython_11lark_cython_11LineCounter_column, __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_column, (char *)0, 0},
  {(char *)"line_start_pos", __pyx_getprop_11lark_cython_11lark_cython_11LineCounter_line_start_pos, __pyx_setprop_11lark_cython_11lark_cython_11LineCounter_line_start_pos, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_LineCounter = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.LineCounter", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_LineCounter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  __pyx_tp_richcompare_11lark_cython_11lark_cython_LineCounter, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_LineCounter, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_LineCounter, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_LineCounter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_Scanner __pyx_vtable_11lark_cython_11lark_cython_Scanner;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Scanner(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_Scanner *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_Scanner;
  p->terminals = Py_None; Py_INCREF(Py_None);
  p->re_ = Py_None; Py_INCREF(Py_None);
  p->use_bytes = Py_None; Py_INCREF(Py_None);
  p->match_whole = Py_None; Py_INCREF(Py_None);
  p->allowed_types = Py_None; Py_INCREF(Py_None);
  p->_mres = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_7Scanner_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_Scanner(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_Scanner *p = (struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->terminals);
  Py_CLEAR(p->re_);
  Py_CLEAR(p->use_bytes);
  Py_CLEAR(p->match_whole);
  Py_CLEAR(p->allowed_types);
  Py_CLEAR(p->_mres);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_Scanner(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_Scanner *p = (struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)o;
  if (p->terminals) {
    e = (*v)(p->terminals, a); if (e) return e;
  }
  if (p->re_) {
    e = (*v)(p->re_, a); if (e) return e;
  }
  if (p->use_bytes) {
    e = (*v)(p->use_bytes, a); if (e) return e;
  }
  if (p->match_whole) {
    e = (*v)(p->match_whole, a); if (e) return e;
  }
  if (p->allowed_types) {
    e = (*v)(p->allowed_types, a); if (e) return e;
  }
  if (p->_mres) {
    e = (*v)(p->_mres, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_Scanner(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_Scanner *p = (struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)o;
  tmp = ((PyObject*)p->terminals);
  p->terminals = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->re_);
  p->re_ = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->use_bytes);
  p->use_bytes = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->match_whole);
  p->match_whole = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->allowed_types);
  p->allowed_types = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_mres);
  p->_mres = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_7Scanner_terminals(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_7Scanner_terminals(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_9terminals_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_7Scanner_g_regex_flags(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_7Scanner_g_regex_flags(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_13g_regex_flags_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_7Scanner_re_(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_7Scanner_re_(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_3re__5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_7Scanner_use_bytes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_7Scanner_use_bytes(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_9use_bytes_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_7Scanner_match_whole(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_7Scanner_match_whole(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_11match_whole_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_7Scanner_allowed_types(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_7Scanner_allowed_types(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_7Scanner_13allowed_types_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_Scanner[] = {
  {"_build_mres", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_7Scanner_3_build_mres, METH_VARARGS|METH_KEYWORDS, 0},
  {"match", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_7Scanner_5match, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_7Scanner_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_7Scanner_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_Scanner[] = {
  {(char *)"terminals", __pyx_getprop_11lark_cython_11lark_cython_7Scanner_terminals, __pyx_setprop_11lark_cython_11lark_cython_7Scanner_terminals, (char *)0, 0},
  {(char *)"g_regex_flags", __pyx_getprop_11lark_cython_11lark_cython_7Scanner_g_regex_flags, __pyx_setprop_11lark_cython_11lark_cython_7Scanner_g_regex_flags, (char *)0, 0},
  {(char *)"re_", __pyx_getprop_11lark_cython_11lark_cython_7Scanner_re_, __pyx_setprop_11lark_cython_11lark_cython_7Scanner_re_, (char *)0, 0},
  {(char *)"use_bytes", __pyx_getprop_11lark_cython_11lark_cython_7Scanner_use_bytes, __pyx_setprop_11lark_cython_11lark_cython_7Scanner_use_bytes, (char *)0, 0},
  {(char *)"match_whole", __pyx_getprop_11lark_cython_11lark_cython_7Scanner_match_whole, __pyx_setprop_11lark_cython_11lark_cython_7Scanner_match_whole, (char *)0, 0},
  {(char *)"allowed_types", __pyx_getprop_11lark_cython_11lark_cython_7Scanner_allowed_types, __pyx_setprop_11lark_cython_11lark_cython_7Scanner_allowed_types, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_Scanner = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.Scanner", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Scanner), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Scanner, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_Scanner, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_Scanner, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_Scanner, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_Scanner, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_Scanner, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer __pyx_vtable_11lark_cython_11lark_cython_Lexer;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Lexer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_Lexer *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_Lexer;
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_Lexer(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_Lexer[] = {
  {"make_lexer_thread", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_5Lexer_1make_lexer_thread, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_5Lexer_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_5Lexer_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_Lexer = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.Lexer", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Lexer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Lexer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "Lexer interface\n\n    Method Signatures:\n        lex(self, lexer_state, parser_state) -> Iterator[Token]\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_Lexer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_Lexer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_BasicLexer __pyx_vtable_11lark_cython_11lark_cython_BasicLexer;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_BasicLexer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *p;
  PyObject *o = __pyx_tp_new_11lark_cython_11lark_cython_Lexer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer*)__pyx_vtabptr_11lark_cython_11lark_cython_BasicLexer;
  p->terminals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->ignore_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->newline_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->user_callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->callback = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->re = Py_None; Py_INCREF(Py_None);
  p->terminals_by_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_scanner = ((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_BasicLexer(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *p = (struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->terminals);
  Py_CLEAR(p->ignore_types);
  Py_CLEAR(p->newline_types);
  Py_CLEAR(p->user_callbacks);
  Py_CLEAR(p->callback);
  Py_CLEAR(p->re);
  Py_CLEAR(p->terminals_by_name);
  Py_CLEAR(p->_scanner);
  #if CYTHON_USE_TYPE_SLOTS
  if (PyType_IS_GC(Py_TYPE(o)->tp_base))
  #endif
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Lexer(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_BasicLexer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *p = (struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)o;
  e = ((likely(__pyx_ptype_11lark_cython_11lark_cython_Lexer)) ? ((__pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_traverse) ? __pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_11lark_cython_11lark_cython_BasicLexer)); if (e) return e;
  if (p->terminals) {
    e = (*v)(p->terminals, a); if (e) return e;
  }
  if (p->ignore_types) {
    e = (*v)(p->ignore_types, a); if (e) return e;
  }
  if (p->newline_types) {
    e = (*v)(p->newline_types, a); if (e) return e;
  }
  if (p->user_callbacks) {
    e = (*v)(p->user_callbacks, a); if (e) return e;
  }
  if (p->callback) {
    e = (*v)(p->callback, a); if (e) return e;
  }
  if (p->re) {
    e = (*v)(p->re, a); if (e) return e;
  }
  if (p->terminals_by_name) {
    e = (*v)(p->terminals_by_name, a); if (e) return e;
  }
  if (p->_scanner) {
    e = (*v)(((PyObject *)p->_scanner), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_BasicLexer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *p = (struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)o;
  if (likely(__pyx_ptype_11lark_cython_11lark_cython_Lexer)) { if (__pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_clear) __pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_11lark_cython_11lark_cython_BasicLexer);
  tmp = ((PyObject*)p->terminals);
  p->terminals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->ignore_types);
  p->ignore_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->newline_types);
  p->newline_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->user_callbacks);
  p->user_callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->callback);
  p->callback = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->re);
  p->re = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->terminals_by_name);
  p->terminals_by_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_scanner);
  p->_scanner = ((struct __pyx_obj_11lark_cython_11lark_cython_Scanner *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_10BasicLexer_scanner(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_10BasicLexer_7scanner_1__get__(o);
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_BasicLexer[] = {
  {"_build_scanner", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_3_build_scanner, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_10BasicLexer_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_BasicLexer[] = {
  {(char *)"scanner", __pyx_getprop_11lark_cython_11lark_cython_10BasicLexer_scanner, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_BasicLexer = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.BasicLexer", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_BasicLexer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_BasicLexer, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_BasicLexer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_BasicLexer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_BasicLexer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_10BasicLexer_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_BasicLexer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_ContextualLexer __pyx_vtable_11lark_cython_11lark_cython_ContextualLexer;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ContextualLexer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *p;
  PyObject *o = __pyx_tp_new_11lark_cython_11lark_cython_Lexer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_11lark_cython_11lark_cython_Lexer*)__pyx_vtabptr_11lark_cython_11lark_cython_ContextualLexer;
  p->lexers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->root_lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_ContextualLexer(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *p = (struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->lexers);
  Py_CLEAR(p->root_lexer);
  #if CYTHON_USE_TYPE_SLOTS
  if (PyType_IS_GC(Py_TYPE(o)->tp_base))
  #endif
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Lexer(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_ContextualLexer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *p = (struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)o;
  e = ((likely(__pyx_ptype_11lark_cython_11lark_cython_Lexer)) ? ((__pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_traverse) ? __pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_11lark_cython_11lark_cython_ContextualLexer)); if (e) return e;
  if (p->lexers) {
    e = (*v)(p->lexers, a); if (e) return e;
  }
  if (p->root_lexer) {
    e = (*v)(((PyObject *)p->root_lexer), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_ContextualLexer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *p = (struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *)o;
  if (likely(__pyx_ptype_11lark_cython_11lark_cython_Lexer)) { if (__pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_clear) __pyx_ptype_11lark_cython_11lark_cython_Lexer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_11lark_cython_11lark_cython_ContextualLexer);
  tmp = ((PyObject*)p->lexers);
  p->lexers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->root_lexer);
  p->root_lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ContextualLexer[] = {
  {"make_lexer_state", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_3make_lexer_state, METH_O, 0},
  {"next_token", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_5next_token, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_15ContextualLexer_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ContextualLexer = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ContextualLexer", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ContextualLexer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ContextualLexer, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ContextualLexer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ContextualLexer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ContextualLexer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_LexerThread __pyx_vtable_11lark_cython_11lark_cython_LexerThread;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_LexerThread(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_LexerThread;
  p->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)Py_None); Py_INCREF(Py_None);
  p->state = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_11LexerThread_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_LexerThread(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *p = (struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->lexer);
  Py_CLEAR(p->state);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_LexerThread(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *p = (struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)o;
  if (p->lexer) {
    e = (*v)(((PyObject *)p->lexer), a); if (e) return e;
  }
  if (p->state) {
    e = (*v)(p->state, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_LexerThread(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *p = (struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)o;
  tmp = ((PyObject*)p->lexer);
  p->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_Lexer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->state);
  p->state = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_LexerThread[] = {
  {"__copy__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11LexerThread_3__copy__, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11LexerThread_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11LexerThread_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_LexerThread = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.LexerThread", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_LexerThread, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "A thread that ties a lexer instance and a lexer state, to be used by the parser", /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_LexerThread, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_LexerThread, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_LexerThread, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_LexerThread, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ParseConf(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)o);
  p->parse_table = Py_None; Py_INCREF(Py_None);
  p->states = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->start = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_ParseConf(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *p = (struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->parse_table);
  Py_CLEAR(p->states);
  Py_CLEAR(p->callbacks);
  Py_CLEAR(p->start);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_ParseConf(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *p = (struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)o;
  if (p->parse_table) {
    e = (*v)(p->parse_table, a); if (e) return e;
  }
  if (p->states) {
    e = (*v)(p->states, a); if (e) return e;
  }
  if (p->callbacks) {
    e = (*v)(p->callbacks, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_ParseConf(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *p = (struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)o;
  tmp = ((PyObject*)p->parse_table);
  p->parse_table = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->states);
  p->states = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->callbacks);
  p->callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ParseConf[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_9ParseConf_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_9ParseConf_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ParseConf = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ParseConf", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ParseConf), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ParseConf, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ParseConf, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ParseConf, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ParseConf, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_9ParseConf_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ParseConf, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_ParserState __pyx_vtable_11lark_cython_11lark_cython_ParserState;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ParserState(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_ParserState *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_ParserState;
  p->parse_conf = ((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)Py_None); Py_INCREF(Py_None);
  p->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)Py_None); Py_INCREF(Py_None);
  p->value_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->state_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_ParserState(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_ParserState *p = (struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->parse_conf);
  Py_CLEAR(p->lexer);
  Py_CLEAR(p->value_stack);
  Py_CLEAR(p->state_stack);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_ParserState(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_ParserState *p = (struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)o;
  if (p->parse_conf) {
    e = (*v)(((PyObject *)p->parse_conf), a); if (e) return e;
  }
  if (p->lexer) {
    e = (*v)(((PyObject *)p->lexer), a); if (e) return e;
  }
  if (p->value_stack) {
    e = (*v)(p->value_stack, a); if (e) return e;
  }
  if (p->state_stack) {
    e = (*v)(p->state_stack, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_ParserState(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_ParserState *p = (struct __pyx_obj_11lark_cython_11lark_cython_ParserState *)o;
  tmp = ((PyObject*)p->parse_conf);
  p->parse_conf = ((struct __pyx_obj_11lark_cython_11lark_cython_ParseConf *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->lexer);
  p->lexer = ((struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->value_stack);
  p->value_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->state_stack);
  p->state_stack = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_richcompare_11lark_cython_11lark_cython_ParserState(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_11lark_cython_11lark_cython_11ParserState_3__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_11lark_cython_11lark_cython_11ParserState_3__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret); Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11ParserState_position(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11ParserState_8position_1__get__(o);
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ParserState[] = {
  {"__copy__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11ParserState_5__copy__, METH_NOARGS, 0},
  {"copy", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11ParserState_7copy, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11ParserState_9__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11ParserState_11__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_ParserState[] = {
  {(char *)"position", __pyx_getprop_11lark_cython_11lark_cython_11ParserState_position, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ParserState = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ParserState", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ParserState), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ParserState, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ParserState, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ParserState, /*tp_clear*/
  __pyx_tp_richcompare_11lark_cython_11lark_cython_ParserState, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ParserState, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_ParserState, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_11ParserState_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ParserState, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython__Parser __pyx_vtable_11lark_cython_11lark_cython__Parser;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython__Parser(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython__Parser *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython__Parser *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython__Parser;
  p->parse_table = Py_None; Py_INCREF(Py_None);
  p->callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_7_Parser_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython__Parser(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython__Parser *p = (struct __pyx_obj_11lark_cython_11lark_cython__Parser *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->parse_table);
  Py_CLEAR(p->callbacks);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython__Parser(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython__Parser *p = (struct __pyx_obj_11lark_cython_11lark_cython__Parser *)o;
  if (p->parse_table) {
    e = (*v)(p->parse_table, a); if (e) return e;
  }
  if (p->callbacks) {
    e = (*v)(p->callbacks, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython__Parser(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython__Parser *p = (struct __pyx_obj_11lark_cython_11lark_cython__Parser *)o;
  tmp = ((PyObject*)p->parse_table);
  p->parse_table = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->callbacks);
  p->callbacks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython__Parser[] = {
  {"parse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_7_Parser_3parse, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_7_Parser_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_7_Parser_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython__Parser = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython._Parser", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython__Parser), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython__Parser, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython__Parser, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython__Parser, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython__Parser, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython__Parser, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Meta(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)o);
  p->orig_expansion = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_Meta(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *p = (struct __pyx_obj_11lark_cython_11lark_cython_Meta *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->orig_expansion);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_Meta(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *p = (struct __pyx_obj_11lark_cython_11lark_cython_Meta *)o;
  if (p->orig_expansion) {
    e = (*v)(p->orig_expansion, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_Meta(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_Meta *p = (struct __pyx_obj_11lark_cython_11lark_cython_Meta *)o;
  tmp = ((PyObject*)p->orig_expansion);
  p->orig_expansion = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_empty(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_5empty_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_empty(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_5empty_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_4line_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_line(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_4line_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_column(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_6column_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_column(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_6column_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_start_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_9start_pos_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_start_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_9start_pos_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_end_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_8end_line_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_end_line(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_8end_line_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_end_column(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_10end_column_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_end_column(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_10end_column_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_end_pos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_7end_pos_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_end_pos(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_7end_pos_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_orig_expansion(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_orig_expansion(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_14orig_expansion_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Meta_match_tree(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Meta_10match_tree_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Meta_match_tree(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Meta_10match_tree_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_Meta[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Meta_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Meta_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_Meta[] = {
  {(char *)"empty", __pyx_getprop_11lark_cython_11lark_cython_4Meta_empty, __pyx_setprop_11lark_cython_11lark_cython_4Meta_empty, (char *)0, 0},
  {(char *)"line", __pyx_getprop_11lark_cython_11lark_cython_4Meta_line, __pyx_setprop_11lark_cython_11lark_cython_4Meta_line, (char *)0, 0},
  {(char *)"column", __pyx_getprop_11lark_cython_11lark_cython_4Meta_column, __pyx_setprop_11lark_cython_11lark_cython_4Meta_column, (char *)0, 0},
  {(char *)"start_pos", __pyx_getprop_11lark_cython_11lark_cython_4Meta_start_pos, __pyx_setprop_11lark_cython_11lark_cython_4Meta_start_pos, (char *)0, 0},
  {(char *)"end_line", __pyx_getprop_11lark_cython_11lark_cython_4Meta_end_line, __pyx_setprop_11lark_cython_11lark_cython_4Meta_end_line, (char *)0, 0},
  {(char *)"end_column", __pyx_getprop_11lark_cython_11lark_cython_4Meta_end_column, __pyx_setprop_11lark_cython_11lark_cython_4Meta_end_column, (char *)0, 0},
  {(char *)"end_pos", __pyx_getprop_11lark_cython_11lark_cython_4Meta_end_pos, __pyx_setprop_11lark_cython_11lark_cython_4Meta_end_pos, (char *)0, 0},
  {(char *)"orig_expansion", __pyx_getprop_11lark_cython_11lark_cython_4Meta_orig_expansion, __pyx_setprop_11lark_cython_11lark_cython_4Meta_orig_expansion, (char *)0, 0},
  {(char *)"match_tree", __pyx_getprop_11lark_cython_11lark_cython_4Meta_match_tree, __pyx_setprop_11lark_cython_11lark_cython_4Meta_match_tree, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_Meta = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.Meta", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Meta), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Meta, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_Meta, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_Meta, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_Meta, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_Meta, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_4Meta_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_Meta, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_Tree(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_Tree *)o);
  p->data = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)Py_None); Py_INCREF(Py_None);
  p->children = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_11lark_cython_11lark_cython_4Tree_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_Tree(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *p = (struct __pyx_obj_11lark_cython_11lark_cython_Tree *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->data);
  Py_CLEAR(p->children);
  Py_CLEAR(p->_meta);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_Tree(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *p = (struct __pyx_obj_11lark_cython_11lark_cython_Tree *)o;
  if (p->data) {
    e = (*v)(((PyObject *)p->data), a); if (e) return e;
  }
  if (p->children) {
    e = (*v)(p->children, a); if (e) return e;
  }
  if (p->_meta) {
    e = (*v)(((PyObject *)p->_meta), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_Tree(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_Tree *p = (struct __pyx_obj_11lark_cython_11lark_cython_Tree *)o;
  tmp = ((PyObject*)p->data);
  p->data = ((struct __pyx_obj_11lark_cython_11lark_cython_Token *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->children);
  p->children = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_meta);
  p->_meta = ((struct __pyx_obj_11lark_cython_11lark_cython_Meta *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_richcompare_11lark_cython_11lark_cython_Tree(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_11lark_cython_11lark_cython_4Tree_11__eq__(o1, o2);
    }
    case Py_NE: {
      return __pyx_pw_11lark_cython_11lark_cython_4Tree_13__ne__(o1, o2);
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Tree_meta(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Tree_4meta_1__get__(o);
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Tree_data(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Tree_data(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_4Tree_4data_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Tree_children(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Tree_children(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_4Tree_8children_5__del__(o);
  }
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_4Tree__meta(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_1__get__(o);
}

static int __pyx_setprop_11lark_cython_11lark_cython_4Tree__meta(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_3__set__(o, v);
  }
  else {
    return __pyx_pw_11lark_cython_11lark_cython_4Tree_5_meta_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_Tree[] = {
  {"_pretty_label", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_5_pretty_label, METH_NOARGS, 0},
  {"_pretty", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_4Tree_7_pretty, METH_VARARGS|METH_KEYWORDS, 0},
  {"pretty", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_4Tree_9pretty, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11lark_cython_11lark_cython_4Tree_8pretty},
  {"iter_subtrees", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_17iter_subtrees, METH_NOARGS, __pyx_doc_11lark_cython_11lark_cython_4Tree_16iter_subtrees},
  {"find_pred", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_19find_pred, METH_O, __pyx_doc_11lark_cython_11lark_cython_4Tree_18find_pred},
  {"find_data", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_21find_data, METH_O, __pyx_doc_11lark_cython_11lark_cython_4Tree_20find_data},
  {"expand_kids_by_data", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_4Tree_23expand_kids_by_data, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11lark_cython_11lark_cython_4Tree_22expand_kids_by_data},
  {"scan_values", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_25scan_values, METH_O, __pyx_doc_11lark_cython_11lark_cython_4Tree_24scan_values},
  {"iter_subtrees_topdown", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_28iter_subtrees_topdown, METH_NOARGS, __pyx_doc_11lark_cython_11lark_cython_4Tree_27iter_subtrees_topdown},
  {"__deepcopy__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_31__deepcopy__, METH_O, 0},
  {"copy", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_33copy, METH_NOARGS, 0},
  {"set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_11lark_cython_11lark_cython_4Tree_35set, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_37__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_4Tree_39__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_Tree[] = {
  {(char *)"meta", __pyx_getprop_11lark_cython_11lark_cython_4Tree_meta, 0, (char *)0, 0},
  {(char *)"data", __pyx_getprop_11lark_cython_11lark_cython_4Tree_data, __pyx_setprop_11lark_cython_11lark_cython_4Tree_data, (char *)0, 0},
  {(char *)"children", __pyx_getprop_11lark_cython_11lark_cython_4Tree_children, __pyx_setprop_11lark_cython_11lark_cython_4Tree_children, (char *)0, 0},
  {(char *)"_meta", __pyx_getprop_11lark_cython_11lark_cython_4Tree__meta, __pyx_setprop_11lark_cython_11lark_cython_4Tree__meta, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_Tree = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.Tree", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_Tree), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_Tree, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_11lark_cython_11lark_cython_4Tree_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_11lark_cython_11lark_cython_4Tree_15__hash__, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_Tree, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_Tree, /*tp_clear*/
  __pyx_tp_richcompare_11lark_cython_11lark_cython_Tree, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_Tree, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_Tree, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_Tree, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ExpandSingleChild(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)o);
  p->node_builder = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_ExpandSingleChild(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *p = (struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->node_builder);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_ExpandSingleChild(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *p = (struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)o;
  if (p->node_builder) {
    e = (*v)(p->node_builder, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_ExpandSingleChild(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *p = (struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild *)o;
  tmp = ((PyObject*)p->node_builder);
  p->node_builder = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ExpandSingleChild[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ExpandSingleChild = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ExpandSingleChild", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ExpandSingleChild), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ExpandSingleChild, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ExpandSingleChild, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ExpandSingleChild, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ExpandSingleChild, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_17ExpandSingleChild_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ExpandSingleChild, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};
static struct __pyx_vtabstruct_11lark_cython_11lark_cython_PropagatePositions __pyx_vtable_11lark_cython_11lark_cython_PropagatePositions;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_PropagatePositions(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)o);
  p->__pyx_vtab = __pyx_vtabptr_11lark_cython_11lark_cython_PropagatePositions;
  p->node_builder = Py_None; Py_INCREF(Py_None);
  p->node_filter = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_PropagatePositions(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *p = (struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->node_builder);
  Py_CLEAR(p->node_filter);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_PropagatePositions(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *p = (struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)o;
  if (p->node_builder) {
    e = (*v)(p->node_builder, a); if (e) return e;
  }
  if (p->node_filter) {
    e = (*v)(p->node_filter, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_PropagatePositions(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *p = (struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *)o;
  tmp = ((PyObject*)p->node_builder);
  p->node_builder = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->node_filter);
  p->node_filter = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_PropagatePositions[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_PropagatePositions = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.PropagatePositions", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_PropagatePositions, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_PropagatePositions, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_PropagatePositions, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_PropagatePositions, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_18PropagatePositions_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_PropagatePositions, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ChildFilter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)o);
  p->node_builder = Py_None; Py_INCREF(Py_None);
  p->to_include = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->append_none = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython_ChildFilter(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *p = (struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->node_builder);
  Py_CLEAR(p->to_include);
  Py_CLEAR(p->append_none);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython_ChildFilter(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *p = (struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)o;
  if (p->node_builder) {
    e = (*v)(p->node_builder, a); if (e) return e;
  }
  if (p->to_include) {
    e = (*v)(p->to_include, a); if (e) return e;
  }
  if (p->append_none) {
    e = (*v)(p->append_none, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython_ChildFilter(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *p = (struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter *)o;
  tmp = ((PyObject*)p->node_builder);
  p->node_builder = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->to_include);
  p->to_include = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->append_none);
  p->append_none = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11ChildFilter_node_builder(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_12node_builder_1__get__(o);
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11ChildFilter_to_include(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_10to_include_1__get__(o);
}

static PyObject *__pyx_getprop_11lark_cython_11lark_cython_11ChildFilter_append_none(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_11append_none_1__get__(o);
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ChildFilter[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_11ChildFilter_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_11lark_cython_11lark_cython_ChildFilter[] = {
  {(char *)"node_builder", __pyx_getprop_11lark_cython_11lark_cython_11ChildFilter_node_builder, 0, (char *)0, 0},
  {(char *)"to_include", __pyx_getprop_11lark_cython_11lark_cython_11ChildFilter_to_include, 0, (char *)0, 0},
  {(char *)"append_none", __pyx_getprop_11lark_cython_11lark_cython_11ChildFilter_append_none, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ChildFilter = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ChildFilter", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ChildFilter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ChildFilter, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ChildFilter, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ChildFilter, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_11lark_cython_11lark_cython_ChildFilter, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ChildFilter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ChildFilterLALR(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = __pyx_tp_new_11lark_cython_11lark_cython_ChildFilter(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ChildFilterLALR[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ChildFilterLALR", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ChildFilter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_11lark_cython_11lark_cython_15ChildFilterLALR_1__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)", /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ChildFilter, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ChildFilter, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ChildFilterLALR, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_11lark_cython_11lark_cython_11ChildFilter_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ChildFilterLALR, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o = __pyx_tp_new_11lark_cython_11lark_cython_ChildFilter(t, a, k);
  if (unlikely(!o)) return 0;
  return o;
}

static PyMethodDef __pyx_methods_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.ChildFilterLALR_NoPlaceholders", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython_ChildFilter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_3__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Optimized childfilter for LALR (assumes no duplication in parse tree, so it's safe to change it)", /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython_ChildFilter, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython_ChildFilter, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_11lark_cython_11lark_cython_30ChildFilterLALR_NoPlaceholders_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct___build_mres[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct___build_mres = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct___build_mres(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct___build_mres > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct___build_mres[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct___build_mres];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct___build_mres(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_max_size);
  Py_CLEAR(p->__pyx_v_postfix);
  Py_CLEAR(p->__pyx_v_terminals);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct___build_mres < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct___build_mres[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct___build_mres++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct___build_mres(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *)o;
  if (p->__pyx_v_max_size) {
    e = (*v)(p->__pyx_v_max_size, a); if (e) return e;
  }
  if (p->__pyx_v_terminals) {
    e = (*v)(p->__pyx_v_terminals, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct___build_mres(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres *)o;
  tmp = ((PyObject*)p->__pyx_v_max_size);
  p->__pyx_v_max_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_terminals);
  p->__pyx_v_terminals = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct___build_mres", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct___build_mres), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct___build_mres, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct___build_mres, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct___build_mres, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct___build_mres, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_t);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_2___init__[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_2___init__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_2___init__[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_2___init__];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_2___init__(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_terminals);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_2___init__[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_2___init__++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_2___init__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *)o;
  if (p->__pyx_v_terminals) {
    e = (*v)(p->__pyx_v_terminals, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_2___init__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ *)o;
  tmp = ((PyObject*)p->__pyx_v_terminals);
  p->__pyx_v_terminals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_2___init__", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_2___init__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_2___init__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_2___init__, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_2___init__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_2___init__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_t);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_3_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_4_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_type_);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *)o;
  if (p->__pyx_v_type_) {
    e = (*v)(p->__pyx_v_type_, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner *)o;
  tmp = ((PyObject*)p->__pyx_v_type_);
  p->__pyx_v_type_ = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_5__build_scanner", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *)o;
  Py_CLEAR(p->__pyx_v_data);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_6_find_data", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_c);
  Py_CLEAR(p->__pyx_v_pred);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_t);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values *)o;
  if (p->__pyx_v_c) {
    e = (*v)(p->__pyx_v_c, a); if (e) return e;
  }
  if (p->__pyx_v_pred) {
    e = (*v)(p->__pyx_v_pred, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_t) {
    e = (*v)(p->__pyx_v_t, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_7_scan_values", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_n);
  Py_CLEAR(p->__pyx_v_node);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_stack);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown *)o;
  if (p->__pyx_v_n) {
    e = (*v)(p->__pyx_v_n, a); if (e) return e;
  }
  if (p->__pyx_v_node) {
    e = (*v)(p->__pyx_v_node, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_stack) {
    e = (*v)(p->__pyx_v_stack, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_8_iter_subtrees_topdown", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_func);
  Py_CLEAR(p->__pyx_v_name);
  Py_CLEAR(p->__pyx_v_wrapper);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *)o;
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  if (p->__pyx_v_name) {
    e = (*v)(p->__pyx_v_name, a); if (e) return e;
  }
  if (p->__pyx_v_wrapper) {
    e = (*v)(p->__pyx_v_wrapper, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper *)o;
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_name);
  p->__pyx_v_name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_wrapper);
  p->__pyx_v_wrapper = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_9_apply_visit_wrapper", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_func);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *)o;
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer *)o;
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_10_inplace_transformer", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__empty_indices);
  Py_CLEAR(p->__pyx_v_to_include);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *)o;
  if (p->__pyx_v__empty_indices) {
    e = (*v)(p->__pyx_v__empty_indices, a); if (e) return e;
  }
  if (p->__pyx_v_to_include) {
    e = (*v)(p->__pyx_v_to_include, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter *)o;
  tmp = ((PyObject*)p->__pyx_v__empty_indices);
  p->__pyx_v__empty_indices = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_to_include);
  p->__pyx_v_to_include = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_11_maybe_create_child_filter", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_b);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_b) {
    e = (*v)(p->__pyx_v_b, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_12_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v__);
  Py_CLEAR(p->__pyx_v_i);
  Py_CLEAR(p->__pyx_v_to_expand);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v__) {
    e = (*v)(p->__pyx_v__, a); if (e) return e;
  }
  if (p->__pyx_v_i) {
    e = (*v)(p->__pyx_v_i, a); if (e) return e;
  }
  if (p->__pyx_v_to_expand) {
    e = (*v)(p->__pyx_v_to_expand, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_13_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_expand_single_child);
  Py_CLEAR(p->__pyx_v_keep_all_tokens);
  Py_CLEAR(p->__pyx_v_options);
  Py_CLEAR(p->__pyx_v_propagate_positions);
  Py_CLEAR(p->__pyx_v_rule);
  Py_CLEAR(p->__pyx_v_rules);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_wrapper_chain);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders *)o;
  if (p->__pyx_v_expand_single_child) {
    e = (*v)(p->__pyx_v_expand_single_child, a); if (e) return e;
  }
  if (p->__pyx_v_keep_all_tokens) {
    e = (*v)(p->__pyx_v_keep_all_tokens, a); if (e) return e;
  }
  if (p->__pyx_v_options) {
    e = (*v)(p->__pyx_v_options, a); if (e) return e;
  }
  if (p->__pyx_v_propagate_positions) {
    e = (*v)(p->__pyx_v_propagate_positions, a); if (e) return e;
  }
  if (p->__pyx_v_rule) {
    e = (*v)(p->__pyx_v_rule, a); if (e) return e;
  }
  if (p->__pyx_v_rules) {
    e = (*v)(p->__pyx_v_rules, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(p->__pyx_v_self, a); if (e) return e;
  }
  if (p->__pyx_v_wrapper_chain) {
    e = (*v)(p->__pyx_v_wrapper_chain, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_14__init_builders", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback[8];
static int __pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback = 0;

static PyObject *__pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback)))) {
    o = (PyObject*)__pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback[--__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback];
    memset(o, 0, sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback(PyObject *o) {
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_default_handler);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback)))) {
    __pyx_freelist_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback[__pyx_freecount_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback++] = ((struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *)o;
  if (p->__pyx_v_default_handler) {
    e = (*v)(p->__pyx_v_default_handler, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *p = (struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback *)o;
  tmp = ((PyObject*)p->__pyx_v_default_handler);
  p->__pyx_v_default_handler = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback = {
  PyVarObject_HEAD_INIT(0, 0)
  "lark_cython.lark_cython.__pyx_scope_struct_15_create_callback", /*tp_name*/
  sizeof(struct __pyx_obj_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback, /*tp_traverse*/
  __pyx_tp_clear_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
  0, /*tp_pypy_flags*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_lark_cython(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_lark_cython},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "lark_cython",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_kp_u_0, __pyx_k_0, sizeof(__pyx_k_0), 0, 1, 0, 0},
  {&__pyx_n_s_Any, __pyx_k_Any, sizeof(__pyx_k_Any), 0, 0, 1, 1},
  {&__pyx_n_s_AssertionError, __pyx_k_AssertionError, sizeof(__pyx_k_AssertionError), 0, 0, 1, 1},
  {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
  {&__pyx_n_s_BasicLexer, __pyx_k_BasicLexer, sizeof(__pyx_k_BasicLexer), 0, 0, 1, 1},
  {&__pyx_n_u_BasicLexer, __pyx_k_BasicLexer, sizeof(__pyx_k_BasicLexer), 0, 1, 0, 1},
  {&__pyx_n_s_CallChain, __pyx_k_CallChain, sizeof(__pyx_k_CallChain), 0, 0, 1, 1},
  {&__pyx_kp_u_Callbacks_must_return_a_token_re, __pyx_k_Callbacks_must_return_a_token_re, sizeof(__pyx_k_Callbacks_must_return_a_token_re), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_compile_token, __pyx_k_Cannot_compile_token, sizeof(__pyx_k_Cannot_compile_token), 0, 1, 0, 0},
  {&__pyx_n_s_ChildFilter, __pyx_k_ChildFilter, sizeof(__pyx_k_ChildFilter), 0, 0, 1, 1},
  {&__pyx_n_s_ChildFilterLALR, __pyx_k_ChildFilterLALR, sizeof(__pyx_k_ChildFilterLALR), 0, 0, 1, 1},
  {&__pyx_n_s_ChildFilterLALR_NoPlaceholders, __pyx_k_ChildFilterLALR_NoPlaceholders, sizeof(__pyx_k_ChildFilterLALR_NoPlaceholders), 0, 0, 1, 1},
  {&__pyx_n_s_Collection, __pyx_k_Collection, sizeof(__pyx_k_Collection), 0, 0, 1, 1},
  {&__pyx_n_s_ConfigurationError, __pyx_k_ConfigurationError, sizeof(__pyx_k_ConfigurationError), 0, 0, 1, 1},
  {&__pyx_n_s_ContextualLexer, __pyx_k_ContextualLexer, sizeof(__pyx_k_ContextualLexer), 0, 0, 1, 1},
  {&__pyx_n_u_ContextualLexer, __pyx_k_ContextualLexer, sizeof(__pyx_k_ContextualLexer), 0, 1, 0, 1},
  {&__pyx_n_s_Dict, __pyx_k_Dict, sizeof(__pyx_k_Dict), 0, 0, 1, 1},
  {&__pyx_kp_u_END, __pyx_k_END, sizeof(__pyx_k_END), 0, 1, 0, 0},
  {&__pyx_kp_u_END_OF_FILE, __pyx_k_END_OF_FILE, sizeof(__pyx_k_END_OF_FILE), 0, 1, 0, 0},
  {&__pyx_n_s_EOFError, __pyx_k_EOFError, sizeof(__pyx_k_EOFError), 0, 0, 1, 1},
  {&__pyx_n_s_ExpandSingleChild, __pyx_k_ExpandSingleChild, sizeof(__pyx_k_ExpandSingleChild), 0, 0, 1, 1},
  {&__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_k_Expected_at_least_d_argument_s_g, sizeof(__pyx_k_Expected_at_least_d_argument_s_g), 0, 0, 1, 0},
  {&__pyx_kp_s_Function_call_with_ambiguous_arg, __pyx_k_Function_call_with_ambiguous_arg, sizeof(__pyx_k_Function_call_with_ambiguous_arg), 0, 0, 1, 0},
  {&__pyx_n_s_GrammarError, __pyx_k_GrammarError, sizeof(__pyx_k_GrammarError), 0, 0, 1, 1},
  {&__pyx_kp_u_Ignore_terminals_are_not_defined, __pyx_k_Ignore_terminals_are_not_defined, sizeof(__pyx_k_Ignore_terminals_are_not_defined), 0, 1, 0, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x0b, __pyx_k_Incompatible_checksums_s_vs_0x0b, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x0b), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x44, __pyx_k_Incompatible_checksums_s_vs_0x44, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x44), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x64, __pyx_k_Incompatible_checksums_s_vs_0x64, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x64), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x68, __pyx_k_Incompatible_checksums_s_vs_0x68, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x68), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x87, __pyx_k_Incompatible_checksums_s_vs_0x87, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x87), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x8b, __pyx_k_Incompatible_checksums_s_vs_0x8b, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x8b), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xd4, __pyx_k_Incompatible_checksums_s_vs_0xd4, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xd4), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xf8, __pyx_k_Incompatible_checksums_s_vs_0xf8, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xf8), 0, 0, 1, 0},
  {&__pyx_n_s_IntParseTable, __pyx_k_IntParseTable, sizeof(__pyx_k_IntParseTable), 0, 0, 1, 1},
  {&__pyx_n_s_InteractiveParser, __pyx_k_InteractiveParser, sizeof(__pyx_k_InteractiveParser), 0, 0, 1, 1},
  {&__pyx_kp_u_Invalid_option_for_propagate_pos, __pyx_k_Invalid_option_for_propagate_pos, sizeof(__pyx_k_Invalid_option_for_propagate_pos), 0, 1, 0, 0},
  {&__pyx_n_s_Iterator, __pyx_k_Iterator, sizeof(__pyx_k_Iterator), 0, 0, 1, 1},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_n_s_LALR_Analyzer, __pyx_k_LALR_Analyzer, sizeof(__pyx_k_LALR_Analyzer), 0, 0, 1, 1},
  {&__pyx_n_s_LALR_Parser, __pyx_k_LALR_Parser, sizeof(__pyx_k_LALR_Parser), 0, 0, 1, 1},
  {&__pyx_n_u_LALR_Parser, __pyx_k_LALR_Parser, sizeof(__pyx_k_LALR_Parser), 0, 1, 0, 1},
  {&__pyx_n_s_LALR_Parser___init, __pyx_k_LALR_Parser___init, sizeof(__pyx_k_LALR_Parser___init), 0, 0, 1, 1},
  {&__pyx_n_s_LALR_Parser_deserialize, __pyx_k_LALR_Parser_deserialize, sizeof(__pyx_k_LALR_Parser_deserialize), 0, 0, 1, 1},
  {&__pyx_n_s_LALR_Parser_parse, __pyx_k_LALR_Parser_parse, sizeof(__pyx_k_LALR_Parser_parse), 0, 0, 1, 1},
  {&__pyx_n_s_LALR_Parser_parse_interactive, __pyx_k_LALR_Parser_parse_interactive, sizeof(__pyx_k_LALR_Parser_parse_interactive), 0, 0, 1, 1},
  {&__pyx_n_s_LALR_Parser_serialize, __pyx_k_LALR_Parser_serialize, sizeof(__pyx_k_LALR_Parser_serialize), 0, 0, 1, 1},
  {&__pyx_n_s_LexError, __pyx_k_LexError, sizeof(__pyx_k_LexError), 0, 0, 1, 1},
  {&__pyx_n_s_Lexer, __pyx_k_Lexer, sizeof(__pyx_k_Lexer), 0, 0, 1, 1},
  {&__pyx_n_s_LexerState, __pyx_k_LexerState, sizeof(__pyx_k_LexerState), 0, 0, 1, 1},
  {&__pyx_n_s_LexerThread, __pyx_k_LexerThread, sizeof(__pyx_k_LexerThread), 0, 0, 1, 1},
  {&__pyx_n_u_LexerThread, __pyx_k_LexerThread, sizeof(__pyx_k_LexerThread), 0, 1, 0, 1},
  {&__pyx_kp_u_Lexer_does_not_allow_zero_width, __pyx_k_Lexer_does_not_allow_zero_width, sizeof(__pyx_k_Lexer_does_not_allow_zero_width), 0, 1, 0, 0},
  {&__pyx_n_s_LineCounter, __pyx_k_LineCounter, sizeof(__pyx_k_LineCounter), 0, 0, 1, 1},
  {&__pyx_n_s_Meta, __pyx_k_Meta, sizeof(__pyx_k_Meta), 0, 0, 1, 1},
  {&__pyx_kp_u_Meta_args_not_supported_for_inte, __pyx_k_Meta_args_not_supported_for_inte, sizeof(__pyx_k_Meta_args_not_supported_for_inte), 0, 1, 0, 0},
  {&__pyx_n_s_NameError, __pyx_k_NameError, sizeof(__pyx_k_NameError), 0, 0, 1, 1},
  {&__pyx_kp_s_No_matching_signature_found, __pyx_k_No_matching_signature_found, sizeof(__pyx_k_No_matching_signature_found), 0, 0, 1, 0},
  {&__pyx_n_s_NotImplemented, __pyx_k_NotImplemented, sizeof(__pyx_k_NotImplemented), 0, 0, 1, 1},
  {&__pyx_n_s_NotImplementedError, __pyx_k_NotImplementedError, sizeof(__pyx_k_NotImplementedError), 0, 0, 1, 1},
  {&__pyx_n_s_Optional, __pyx_k_Optional, sizeof(__pyx_k_Optional), 0, 0, 1, 1},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_kp_u_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 1, 0, 0},
  {&__pyx_n_s_ParseConf, __pyx_k_ParseConf, sizeof(__pyx_k_ParseConf), 0, 0, 1, 1},
  {&__pyx_n_s_ParseTreeBuilder, __pyx_k_ParseTreeBuilder, sizeof(__pyx_k_ParseTreeBuilder), 0, 0, 1, 1},
  {&__pyx_n_s_ParseTreeBuilder___init, __pyx_k_ParseTreeBuilder___init, sizeof(__pyx_k_ParseTreeBuilder___init), 0, 0, 1, 1},
  {&__pyx_n_s_ParseTreeBuilder__init_builders, __pyx_k_ParseTreeBuilder__init_builders, sizeof(__pyx_k_ParseTreeBuilder__init_builders), 0, 0, 1, 1},
  {&__pyx_n_s_ParseTreeBuilder_create_callback, __pyx_k_ParseTreeBuilder_create_callback, sizeof(__pyx_k_ParseTreeBuilder_create_callback), 0, 0, 1, 1},
  {&__pyx_n_s_ParseTreeBuilder_create_callback_2, __pyx_k_ParseTreeBuilder_create_callback_2, sizeof(__pyx_k_ParseTreeBuilder_create_callback_2), 0, 0, 1, 1},
  {&__pyx_n_s_Parser, __pyx_k_Parser, sizeof(__pyx_k_Parser), 0, 0, 1, 1},
  {&__pyx_n_u_Parser, __pyx_k_Parser, sizeof(__pyx_k_Parser), 0, 1, 0, 1},
  {&__pyx_n_s_ParserState, __pyx_k_ParserState, sizeof(__pyx_k_ParserState), 0, 0, 1, 1},
  {&__pyx_n_s_Pattern, __pyx_k_Pattern, sizeof(__pyx_k_Pattern), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_PropagatePositions, __pyx_k_PropagatePositions, sizeof(__pyx_k_PropagatePositions), 0, 0, 1, 1},
  {&__pyx_n_s_Reduce, __pyx_k_Reduce, sizeof(__pyx_k_Reduce), 0, 0, 1, 1},
  {&__pyx_kp_u_Return_all_values_in_the_tree_th, __pyx_k_Return_all_values_in_the_tree_th, sizeof(__pyx_k_Return_all_values_in_the_tree_th), 0, 1, 0, 0},
  {&__pyx_kp_u_Rule, __pyx_k_Rule, sizeof(__pyx_k_Rule), 0, 1, 0, 0},
  {&__pyx_kp_u_STATE_STACK_DUMP, __pyx_k_STATE_STACK_DUMP, sizeof(__pyx_k_STATE_STACK_DUMP), 0, 1, 0, 0},
  {&__pyx_n_s_Scanner, __pyx_k_Scanner, sizeof(__pyx_k_Scanner), 0, 0, 1, 1},
  {&__pyx_n_s_Serialize, __pyx_k_Serialize, sizeof(__pyx_k_Serialize), 0, 0, 1, 1},
  {&__pyx_n_s_Shift, __pyx_k_Shift, sizeof(__pyx_k_Shift), 0, 0, 1, 1},
  {&__pyx_n_s_TOKEN_DEFAULT_PRIORITY, __pyx_k_TOKEN_DEFAULT_PRIORITY, sizeof(__pyx_k_TOKEN_DEFAULT_PRIORITY), 0, 0, 1, 1},
  {&__pyx_n_s_TerminalDef, __pyx_k_TerminalDef, sizeof(__pyx_k_TerminalDef), 0, 0, 1, 1},
  {&__pyx_kp_u_Token, __pyx_k_Token, sizeof(__pyx_k_Token), 0, 1, 0, 0},
  {&__pyx_n_s_Token_2, __pyx_k_Token_2, sizeof(__pyx_k_Token_2), 0, 0, 1, 1},
  {&__pyx_n_s_Token___eq, __pyx_k_Token___eq, sizeof(__pyx_k_Token___eq), 0, 0, 1, 1},
  {&__pyx_n_s_Transformer_InPlace, __pyx_k_Transformer_InPlace, sizeof(__pyx_k_Transformer_InPlace), 0, 0, 1, 1},
  {&__pyx_kp_u_Tree, __pyx_k_Tree, sizeof(__pyx_k_Tree), 0, 1, 0, 0},
  {&__pyx_n_s_Tree_2, __pyx_k_Tree_2, sizeof(__pyx_k_Tree_2), 0, 0, 1, 1},
  {&__pyx_n_s_Tree_iter_subtrees_topdown, __pyx_k_Tree_iter_subtrees_topdown, sizeof(__pyx_k_Tree_iter_subtrees_topdown), 0, 0, 1, 1},
  {&__pyx_n_s_Tree_scan_values, __pyx_k_Tree_scan_values, sizeof(__pyx_k_Tree_scan_values), 0, 0, 1, 1},
  {&__pyx_kp_u_Tree_scan_values_line_712, __pyx_k_Tree_scan_values_line_712, sizeof(__pyx_k_Tree_scan_values_line_712), 0, 1, 0, 0},
  {&__pyx_n_s_Type, __pyx_k_Type, sizeof(__pyx_k_Type), 0, 0, 1, 1},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_s_UnexpectedCharacters, __pyx_k_UnexpectedCharacters, sizeof(__pyx_k_UnexpectedCharacters), 0, 0, 1, 1},
  {&__pyx_n_s_UnexpectedInput, __pyx_k_UnexpectedInput, sizeof(__pyx_k_UnexpectedInput), 0, 0, 1, 1},
  {&__pyx_n_s_UnexpectedToken, __pyx_k_UnexpectedToken, sizeof(__pyx_k_UnexpectedToken), 0, 0, 1, 1},
  {&__pyx_kp_u__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 1, 0, 0},
  {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
  {&__pyx_kp_b__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 0, 0, 0},
  {&__pyx_kp_u__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 1, 0, 0},
  {&__pyx_kp_u__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 1, 0, 0},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_u__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 1, 0, 0},
  {&__pyx_kp_u__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 1, 0, 0},
  {&__pyx_kp_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 0},
  {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
  {&__pyx_kp_u__30, __pyx_k__30, sizeof(__pyx_k__30), 0, 1, 0, 0},
  {&__pyx_n_s__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 0, 1, 1},
  {&__pyx_n_u__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 1, 0, 1},
  {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
  {&__pyx_kp_s__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 0, 1, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_n_s_alias, __pyx_k_alias, sizeof(__pyx_k_alias), 0, 0, 1, 1},
  {&__pyx_n_s_all, __pyx_k_all, sizeof(__pyx_k_all), 0, 0, 1, 1},
  {&__pyx_n_s_allowed, __pyx_k_allowed, sizeof(__pyx_k_allowed), 0, 0, 1, 1},
  {&__pyx_n_s_allowed_types, __pyx_k_allowed_types, sizeof(__pyx_k_allowed_types), 0, 0, 1, 1},
  {&__pyx_kp_u_already_exists, __pyx_k_already_exists, sizeof(__pyx_k_already_exists), 0, 1, 0, 0},
  {&__pyx_n_s_always_accept, __pyx_k_always_accept, sizeof(__pyx_k_always_accept), 0, 0, 1, 1},
  {&__pyx_n_s_ambiguous, __pyx_k_ambiguous, sizeof(__pyx_k_ambiguous), 0, 0, 1, 1},
  {&__pyx_n_s_analysis, __pyx_k_analysis, sizeof(__pyx_k_analysis), 0, 0, 1, 1},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_append_none, __pyx_k_append_none, sizeof(__pyx_k_append_none), 0, 0, 1, 1},
  {&__pyx_n_s_apply_visit_wrapper, __pyx_k_apply_visit_wrapper, sizeof(__pyx_k_apply_visit_wrapper), 0, 0, 1, 1},
  {&__pyx_n_s_apply_visit_wrapper_locals_f, __pyx_k_apply_visit_wrapper_locals_f, sizeof(__pyx_k_apply_visit_wrapper_locals_f), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_borrow_t, __pyx_k_borrow_t, sizeof(__pyx_k_borrow_t), 0, 0, 1, 1},
  {&__pyx_n_s_build_mres, __pyx_k_build_mres, sizeof(__pyx_k_build_mres), 0, 0, 1, 1},
  {&__pyx_n_s_build_mres_locals_genexpr, __pyx_k_build_mres_locals_genexpr, sizeof(__pyx_k_build_mres_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_build_scanner, __pyx_k_build_scanner, sizeof(__pyx_k_build_scanner), 0, 0, 1, 1},
  {&__pyx_n_s_build_scanner_locals_lambda, __pyx_k_build_scanner_locals_lambda, sizeof(__pyx_k_build_scanner_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_callbacks, __pyx_k_callbacks, sizeof(__pyx_k_callbacks), 0, 0, 1, 1},
  {&__pyx_n_u_callbacks, __pyx_k_callbacks, sizeof(__pyx_k_callbacks), 0, 1, 0, 1},
  {&__pyx_n_s_char_pos, __pyx_k_char_pos, sizeof(__pyx_k_char_pos), 0, 0, 1, 1},
  {&__pyx_n_u_char_pos, __pyx_k_char_pos, sizeof(__pyx_k_char_pos), 0, 1, 0, 1},
  {&__pyx_n_s_children, __pyx_k_children, sizeof(__pyx_k_children), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 0, 1, 1},
  {&__pyx_n_u_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 1, 0, 1},
  {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
  {&__pyx_n_s_compute_lalr, __pyx_k_compute_lalr, sizeof(__pyx_k_compute_lalr), 0, 0, 1, 1},
  {&__pyx_n_s_conf, __pyx_k_conf, sizeof(__pyx_k_conf), 0, 0, 1, 1},
  {&__pyx_n_s_container_column, __pyx_k_container_column, sizeof(__pyx_k_container_column), 0, 0, 1, 1},
  {&__pyx_n_u_container_column, __pyx_k_container_column, sizeof(__pyx_k_container_column), 0, 1, 0, 1},
  {&__pyx_n_s_container_end_column, __pyx_k_container_end_column, sizeof(__pyx_k_container_end_column), 0, 0, 1, 1},
  {&__pyx_n_u_container_end_column, __pyx_k_container_end_column, sizeof(__pyx_k_container_end_column), 0, 1, 0, 1},
  {&__pyx_n_s_container_end_line, __pyx_k_container_end_line, sizeof(__pyx_k_container_end_line), 0, 0, 1, 1},
  {&__pyx_n_u_container_end_line, __pyx_k_container_end_line, sizeof(__pyx_k_container_end_line), 0, 1, 0, 1},
  {&__pyx_n_u_container_end_pos, __pyx_k_container_end_pos, sizeof(__pyx_k_container_end_pos), 0, 1, 0, 1},
  {&__pyx_n_s_container_line, __pyx_k_container_line, sizeof(__pyx_k_container_line), 0, 0, 1, 1},
  {&__pyx_n_u_container_line, __pyx_k_container_line, sizeof(__pyx_k_container_line), 0, 1, 0, 1},
  {&__pyx_n_u_container_start_pos, __pyx_k_container_start_pos, sizeof(__pyx_k_container_start_pos), 0, 1, 0, 1},
  {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
  {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
  {&__pyx_n_s_create_callback, __pyx_k_create_callback, sizeof(__pyx_k_create_callback), 0, 0, 1, 1},
  {&__pyx_n_s_create_unless, __pyx_k_create_unless, sizeof(__pyx_k_create_unless), 0, 0, 1, 1},
  {&__pyx_kp_u_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 1, 0, 0},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_s_deepcopy, __pyx_k_deepcopy, sizeof(__pyx_k_deepcopy), 0, 0, 1, 1},
  {&__pyx_n_u_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 1, 0, 1},
  {&__pyx_n_s_default_callback, __pyx_k_default_callback, sizeof(__pyx_k_default_callback), 0, 0, 1, 1},
  {&__pyx_n_s_default_handler, __pyx_k_default_handler, sizeof(__pyx_k_default_handler), 0, 0, 1, 1},
  {&__pyx_n_s_defaults, __pyx_k_defaults, sizeof(__pyx_k_defaults), 0, 0, 1, 1},
  {&__pyx_n_s_deserialize, __pyx_k_deserialize, sizeof(__pyx_k_deserialize), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
  {&__pyx_n_s_e2, __pyx_k_e2, sizeof(__pyx_k_e2), 0, 0, 1, 1},
  {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
  {&__pyx_n_s_empty_indices, __pyx_k_empty_indices, sizeof(__pyx_k_empty_indices), 0, 0, 1, 1},
  {&__pyx_n_s_empty_indices_2, __pyx_k_empty_indices_2, sizeof(__pyx_k_empty_indices_2), 0, 0, 1, 1},
  {&__pyx_n_s_end_column, __pyx_k_end_column, sizeof(__pyx_k_end_column), 0, 0, 1, 1},
  {&__pyx_n_s_end_line, __pyx_k_end_line, sizeof(__pyx_k_end_line), 0, 0, 1, 1},
  {&__pyx_n_u_end_line, __pyx_k_end_line, sizeof(__pyx_k_end_line), 0, 1, 0, 1},
  {&__pyx_n_s_end_pos, __pyx_k_end_pos, sizeof(__pyx_k_end_pos), 0, 0, 1, 1},
  {&__pyx_n_u_end_state, __pyx_k_end_state, sizeof(__pyx_k_end_state), 0, 1, 0, 1},
  {&__pyx_n_s_end_states, __pyx_k_end_states, sizeof(__pyx_k_end_states), 0, 0, 1, 1},
  {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
  {&__pyx_n_s_eq, __pyx_k_eq, sizeof(__pyx_k_eq), 0, 0, 1, 1},
  {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
  {&__pyx_n_s_expand1, __pyx_k_expand1, sizeof(__pyx_k_expand1), 0, 0, 1, 1},
  {&__pyx_n_s_expand_single_child, __pyx_k_expand_single_child, sizeof(__pyx_k_expand_single_child), 0, 0, 1, 1},
  {&__pyx_n_s_expansion, __pyx_k_expansion, sizeof(__pyx_k_expansion), 0, 0, 1, 1},
  {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
  {&__pyx_n_s_feed, __pyx_k_feed, sizeof(__pyx_k_feed), 0, 0, 1, 1},
  {&__pyx_n_s_filter, __pyx_k_filter, sizeof(__pyx_k_filter), 0, 0, 1, 1},
  {&__pyx_n_s_filter_out, __pyx_k_filter_out, sizeof(__pyx_k_filter_out), 0, 0, 1, 1},
  {&__pyx_n_s_find_data_locals_lambda, __pyx_k_find_data_locals_lambda, sizeof(__pyx_k_find_data_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_find_pred, __pyx_k_find_pred, sizeof(__pyx_k_find_pred), 0, 0, 1, 1},
  {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
  {&__pyx_n_s_functools, __pyx_k_functools, sizeof(__pyx_k_functools), 0, 0, 1, 1},
  {&__pyx_n_s_g_regex_flags, __pyx_k_g_regex_flags, sizeof(__pyx_k_g_regex_flags), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
  {&__pyx_n_s_groupindex, __pyx_k_groupindex, sizeof(__pyx_k_groupindex), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_indent_str, __pyx_k_indent_str, sizeof(__pyx_k_indent_str), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_init___locals_genexpr, __pyx_k_init___locals_genexpr, sizeof(__pyx_k_init___locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_init___locals_lambda, __pyx_k_init___locals_lambda, sizeof(__pyx_k_init___locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_init_builders, __pyx_k_init_builders, sizeof(__pyx_k_init_builders), 0, 0, 1, 1},
  {&__pyx_n_s_inplace_transformer, __pyx_k_inplace_transformer, sizeof(__pyx_k_inplace_transformer), 0, 0, 1, 1},
  {&__pyx_n_s_inplace_transformer_locals_f, __pyx_k_inplace_transformer_locals_f, sizeof(__pyx_k_inplace_transformer_locals_f), 0, 0, 1, 1},
  {&__pyx_n_s_inst, __pyx_k_inst, sizeof(__pyx_k_inst), 0, 0, 1, 1},
  {&__pyx_n_s_interactive_parser, __pyx_k_interactive_parser, sizeof(__pyx_k_interactive_parser), 0, 0, 1, 1},
  {&__pyx_n_s_is_term, __pyx_k_is_term, sizeof(__pyx_k_is_term), 0, 0, 1, 1},
  {&__pyx_n_s_isupper, __pyx_k_isupper, sizeof(__pyx_k_isupper), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_iter_subtrees, __pyx_k_iter_subtrees, sizeof(__pyx_k_iter_subtrees), 0, 0, 1, 1},
  {&__pyx_n_s_iter_subtrees_topdown, __pyx_k_iter_subtrees_topdown, sizeof(__pyx_k_iter_subtrees_topdown), 0, 0, 1, 1},
  {&__pyx_n_s_itertools, __pyx_k_itertools, sizeof(__pyx_k_itertools), 0, 0, 1, 1},
  {&__pyx_n_s_keep_all_tokens, __pyx_k_keep_all_tokens, sizeof(__pyx_k_keep_all_tokens), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
  {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
  {&__pyx_kp_s_lark_cython_lark_cython, __pyx_k_lark_cython_lark_cython, sizeof(__pyx_k_lark_cython_lark_cython), 0, 0, 1, 0},
  {&__pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_k_lark_cython_lark_cython_pyx, sizeof(__pyx_k_lark_cython_lark_cython_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_lark_exceptions, __pyx_k_lark_exceptions, sizeof(__pyx_k_lark_exceptions), 0, 0, 1, 1},
  {&__pyx_n_s_lark_lexer, __pyx_k_lark_lexer, sizeof(__pyx_k_lark_lexer), 0, 0, 1, 1},
  {&__pyx_n_s_lark_parsers_lalr_analysis, __pyx_k_lark_parsers_lalr_analysis, sizeof(__pyx_k_lark_parsers_lalr_analysis), 0, 0, 1, 1},
  {&__pyx_n_s_lark_parsers_lalr_interactive_pa, __pyx_k_lark_parsers_lalr_interactive_pa, sizeof(__pyx_k_lark_parsers_lalr_interactive_pa), 0, 0, 1, 1},
  {&__pyx_n_s_lark_utils, __pyx_k_lark_utils, sizeof(__pyx_k_lark_utils), 0, 0, 1, 1},
  {&__pyx_n_s_lark_visitors, __pyx_k_lark_visitors, sizeof(__pyx_k_lark_visitors), 0, 0, 1, 1},
  {&__pyx_n_s_last_token, __pyx_k_last_token, sizeof(__pyx_k_last_token), 0, 0, 1, 1},
  {&__pyx_n_u_last_token, __pyx_k_last_token, sizeof(__pyx_k_last_token), 0, 1, 0, 1},
  {&__pyx_n_s_lastindex, __pyx_k_lastindex, sizeof(__pyx_k_lastindex), 0, 0, 1, 1},
  {&__pyx_n_s_level, __pyx_k_level, sizeof(__pyx_k_level), 0, 0, 1, 1},
  {&__pyx_n_s_lexer, __pyx_k_lexer, sizeof(__pyx_k_lexer), 0, 0, 1, 1},
  {&__pyx_n_u_lexer, __pyx_k_lexer, sizeof(__pyx_k_lexer), 0, 1, 0, 1},
  {&__pyx_n_s_lexer_state, __pyx_k_lexer_state, sizeof(__pyx_k_lexer_state), 0, 0, 1, 1},
  {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
  {&__pyx_n_u_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 1, 0, 1},
  {&__pyx_n_s_line_ctr, __pyx_k_line_ctr, sizeof(__pyx_k_line_ctr), 0, 0, 1, 1},
  {&__pyx_n_u_line_ctr, __pyx_k_line_ctr, sizeof(__pyx_k_line_ctr), 0, 1, 0, 1},
  {&__pyx_n_u_line_start_pos, __pyx_k_line_start_pos, sizeof(__pyx_k_line_start_pos), 0, 1, 0, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_make_lexer_state, __pyx_k_make_lexer_state, sizeof(__pyx_k_make_lexer_state), 0, 0, 1, 1},
  {&__pyx_n_s_make_lexer_thread, __pyx_k_make_lexer_thread, sizeof(__pyx_k_make_lexer_thread), 0, 0, 1, 1},
  {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
  {&__pyx_n_s_match_whole, __pyx_k_match_whole, sizeof(__pyx_k_match_whole), 0, 0, 1, 1},
  {&__pyx_n_s_max_size, __pyx_k_max_size, sizeof(__pyx_k_max_size), 0, 0, 1, 1},
  {&__pyx_n_s_max_width, __pyx_k_max_width, sizeof(__pyx_k_max_width), 0, 0, 1, 1},
  {&__pyx_n_s_maybe_create_child_filter, __pyx_k_maybe_create_child_filter, sizeof(__pyx_k_maybe_create_child_filter), 0, 0, 1, 1},
  {&__pyx_n_s_maybe_create_child_filter_locals, __pyx_k_maybe_create_child_filter_locals, sizeof(__pyx_k_maybe_create_child_filter_locals), 0, 0, 1, 1},
  {&__pyx_n_s_maybe_placeholders, __pyx_k_maybe_placeholders, sizeof(__pyx_k_maybe_placeholders), 0, 0, 1, 1},
  {&__pyx_n_s_memo, __pyx_k_memo, sizeof(__pyx_k_memo), 0, 0, 1, 1},
  {&__pyx_n_s_meta, __pyx_k_meta, sizeof(__pyx_k_meta), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_min_width, __pyx_k_min_width, sizeof(__pyx_k_min_width), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_n_s_new_borrow_pos, __pyx_k_new_borrow_pos, sizeof(__pyx_k_new_borrow_pos), 0, 0, 1, 1},
  {&__pyx_n_s_newline_char, __pyx_k_newline_char, sizeof(__pyx_k_newline_char), 0, 0, 1, 1},
  {&__pyx_n_u_newline_char, __pyx_k_newline_char, sizeof(__pyx_k_newline_char), 0, 1, 0, 1},
  {&__pyx_n_s_next_token, __pyx_k_next_token, sizeof(__pyx_k_next_token), 0, 0, 1, 1},
  {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
  {&__pyx_n_s_node_builder, __pyx_k_node_builder, sizeof(__pyx_k_node_builder), 0, 0, 1, 1},
  {&__pyx_n_s_node_filter, __pyx_k_node_filter, sizeof(__pyx_k_node_filter), 0, 0, 1, 1},
  {&__pyx_n_s_nones_to_add, __pyx_k_nones_to_add, sizeof(__pyx_k_nones_to_add), 0, 0, 1, 1},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {&__pyx_n_s_on_error, __pyx_k_on_error, sizeof(__pyx_k_on_error), 0, 0, 1, 1},
  {&__pyx_n_s_ones, __pyx_k_ones, sizeof(__pyx_k_ones), 0, 0, 1, 1},
  {&__pyx_n_s_options, __pyx_k_options, sizeof(__pyx_k_options), 0, 0, 1, 1},
  {&__pyx_n_s_origin, __pyx_k_origin, sizeof(__pyx_k_origin), 0, 0, 1, 1},
  {&__pyx_n_s_other, __pyx_k_other, sizeof(__pyx_k_other), 0, 0, 1, 1},
  {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
  {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
  {&__pyx_n_s_parse_conf, __pyx_k_parse_conf, sizeof(__pyx_k_parse_conf), 0, 0, 1, 1},
  {&__pyx_n_u_parse_conf, __pyx_k_parse_conf, sizeof(__pyx_k_parse_conf), 0, 1, 0, 1},
  {&__pyx_n_s_parse_interactive, __pyx_k_parse_interactive, sizeof(__pyx_k_parse_interactive), 0, 0, 1, 1},
  {&__pyx_n_s_parse_table, __pyx_k_parse_table, sizeof(__pyx_k_parse_table), 0, 0, 1, 1},
  {&__pyx_n_u_parse_table, __pyx_k_parse_table, sizeof(__pyx_k_parse_table), 0, 1, 0, 1},
  {&__pyx_n_s_parse_table_2, __pyx_k_parse_table_2, sizeof(__pyx_k_parse_table_2), 0, 0, 1, 1},
  {&__pyx_n_s_parser, __pyx_k_parser, sizeof(__pyx_k_parser), 0, 0, 1, 1},
  {&__pyx_n_s_parser_conf, __pyx_k_parser_conf, sizeof(__pyx_k_parser_conf), 0, 0, 1, 1},
  {&__pyx_n_s_parser_state, __pyx_k_parser_state, sizeof(__pyx_k_parser_state), 0, 0, 1, 1},
  {&__pyx_n_s_partial, __pyx_k_partial, sizeof(__pyx_k_partial), 0, 0, 1, 1},
  {&__pyx_n_s_pattern, __pyx_k_pattern, sizeof(__pyx_k_pattern), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_plugins, __pyx_k_plugins, sizeof(__pyx_k_plugins), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_pos, __pyx_k_pos, sizeof(__pyx_k_pos), 0, 0, 1, 1},
  {&__pyx_n_s_position, __pyx_k_position, sizeof(__pyx_k_position), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_pretty, __pyx_k_pretty, sizeof(__pyx_k_pretty), 0, 0, 1, 1},
  {&__pyx_n_s_pretty_label, __pyx_k_pretty_label, sizeof(__pyx_k_pretty_label), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_priority, __pyx_k_priority, sizeof(__pyx_k_priority), 0, 0, 1, 1},
  {&__pyx_n_s_product, __pyx_k_product, sizeof(__pyx_k_product), 0, 0, 1, 1},
  {&__pyx_n_s_propagate_positions, __pyx_k_propagate_positions, sizeof(__pyx_k_propagate_positions), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_BasicLexer, __pyx_k_pyx_unpickle_BasicLexer, sizeof(__pyx_k_pyx_unpickle_BasicLexer), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ChildFilter, __pyx_k_pyx_unpickle_ChildFilter, sizeof(__pyx_k_pyx_unpickle_ChildFilter), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ChildFilterLALR, __pyx_k_pyx_unpickle_ChildFilterLALR, sizeof(__pyx_k_pyx_unpickle_ChildFilterLALR), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ChildFilterLALR_N, __pyx_k_pyx_unpickle_ChildFilterLALR_N, sizeof(__pyx_k_pyx_unpickle_ChildFilterLALR_N), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ExpandSingleChild, __pyx_k_pyx_unpickle_ExpandSingleChild, sizeof(__pyx_k_pyx_unpickle_ExpandSingleChild), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_Lexer, __pyx_k_pyx_unpickle_Lexer, sizeof(__pyx_k_pyx_unpickle_Lexer), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_Meta, __pyx_k_pyx_unpickle_Meta, sizeof(__pyx_k_pyx_unpickle_Meta), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ParseConf, __pyx_k_pyx_unpickle_ParseConf, sizeof(__pyx_k_pyx_unpickle_ParseConf), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_ParserState, __pyx_k_pyx_unpickle_ParserState, sizeof(__pyx_k_pyx_unpickle_ParserState), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_PropagatePosition, __pyx_k_pyx_unpickle_PropagatePosition, sizeof(__pyx_k_pyx_unpickle_PropagatePosition), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_re_module, __pyx_k_re_module, sizeof(__pyx_k_re_module), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_regexp_has_newline, __pyx_k_regexp_has_newline, sizeof(__pyx_k_regexp_has_newline), 0, 0, 1, 1},
  {&__pyx_n_s_repeat, __pyx_k_repeat, sizeof(__pyx_k_repeat), 0, 0, 1, 1},
  {&__pyx_n_s_resume_parse, __pyx_k_resume_parse, sizeof(__pyx_k_resume_parse), 0, 0, 1, 1},
  {&__pyx_n_s_reversed, __pyx_k_reversed, sizeof(__pyx_k_reversed), 0, 0, 1, 1},
  {&__pyx_n_s_rindex, __pyx_k_rindex, sizeof(__pyx_k_rindex), 0, 0, 1, 1},
  {&__pyx_n_s_rule, __pyx_k_rule, sizeof(__pyx_k_rule), 0, 0, 1, 1},
  {&__pyx_n_s_rule_builders, __pyx_k_rule_builders, sizeof(__pyx_k_rule_builders), 0, 0, 1, 1},
  {&__pyx_n_s_rules, __pyx_k_rules, sizeof(__pyx_k_rules), 0, 0, 1, 1},
  {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
  {&__pyx_n_s_scan_values, __pyx_k_scan_values, sizeof(__pyx_k_scan_values), 0, 0, 1, 1},
  {&__pyx_n_s_scanner, __pyx_k_scanner, sizeof(__pyx_k_scanner), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_serialize, __pyx_k_serialize, sizeof(__pyx_k_serialize), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_should_expand, __pyx_k_should_expand, sizeof(__pyx_k_should_expand), 0, 0, 1, 1},
  {&__pyx_n_s_skip_validation, __pyx_k_skip_validation, sizeof(__pyx_k_skip_validation), 0, 0, 1, 1},
  {&__pyx_n_s_slots, __pyx_k_slots, sizeof(__pyx_k_slots), 0, 0, 1, 1},
  {&__pyx_n_s_sort, __pyx_k_sort, sizeof(__pyx_k_sort), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
  {&__pyx_n_u_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 1, 0, 1},
  {&__pyx_n_s_start_interactive, __pyx_k_start_interactive, sizeof(__pyx_k_start_interactive), 0, 0, 1, 1},
  {&__pyx_n_s_start_pos, __pyx_k_start_pos, sizeof(__pyx_k_start_pos), 0, 0, 1, 1},
  {&__pyx_n_u_start_state, __pyx_k_start_state, sizeof(__pyx_k_start_state), 0, 1, 0, 1},
  {&__pyx_n_s_start_states, __pyx_k_start_states, sizeof(__pyx_k_start_states), 0, 0, 1, 1},
  {&__pyx_n_s_startswith, __pyx_k_startswith, sizeof(__pyx_k_startswith), 0, 0, 1, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_n_s_state_stack, __pyx_k_state_stack, sizeof(__pyx_k_state_stack), 0, 0, 1, 1},
  {&__pyx_n_u_state_stack, __pyx_k_state_stack, sizeof(__pyx_k_state_stack), 0, 1, 0, 1},
  {&__pyx_n_s_states, __pyx_k_states, sizeof(__pyx_k_states), 0, 0, 1, 1},
  {&__pyx_n_u_states, __pyx_k_states, sizeof(__pyx_k_states), 0, 1, 0, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
  {&__pyx_n_s_sym, __pyx_k_sym, sizeof(__pyx_k_sym), 0, 0, 1, 1},
  {&__pyx_n_s_template_source, __pyx_k_template_source, sizeof(__pyx_k_template_source), 0, 0, 1, 1},
  {&__pyx_n_s_terminals, __pyx_k_terminals, sizeof(__pyx_k_terminals), 0, 0, 1, 1},
  {&__pyx_n_s_terminals_by_name, __pyx_k_terminals_by_name, sizeof(__pyx_k_terminals_by_name), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_test_newline, __pyx_k_test_newline, sizeof(__pyx_k_test_newline), 0, 0, 1, 1},
  {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
  {&__pyx_n_u_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 1, 0, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_to_include, __pyx_k_to_include, sizeof(__pyx_k_to_include), 0, 0, 1, 1},
  {&__pyx_n_s_to_regexp, __pyx_k_to_regexp, sizeof(__pyx_k_to_regexp), 0, 0, 1, 1},
  {&__pyx_n_s_token, __pyx_k_token, sizeof(__pyx_k_token), 0, 0, 1, 1},
  {&__pyx_n_s_token_history, __pyx_k_token_history, sizeof(__pyx_k_token_history), 0, 0, 1, 1},
  {&__pyx_n_s_transformer, __pyx_k_transformer, sizeof(__pyx_k_transformer), 0, 0, 1, 1},
  {&__pyx_n_s_tree, __pyx_k_tree, sizeof(__pyx_k_tree), 0, 0, 1, 1},
  {&__pyx_n_s_tree_class, __pyx_k_tree_class, sizeof(__pyx_k_tree_class), 0, 0, 1, 1},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_s_type_2, __pyx_k_type_2, sizeof(__pyx_k_type_2), 0, 0, 1, 1},
  {&__pyx_n_s_typing, __pyx_k_typing, sizeof(__pyx_k_typing), 0, 0, 1, 1},
  {&__pyx_n_s_unicode, __pyx_k_unicode, sizeof(__pyx_k_unicode), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_use_bytes, __pyx_k_use_bytes, sizeof(__pyx_k_use_bytes), 0, 0, 1, 1},
  {&__pyx_n_s_user_callback_name, __pyx_k_user_callback_name, sizeof(__pyx_k_user_callback_name), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_value_stack, __pyx_k_value_stack, sizeof(__pyx_k_value_stack), 0, 0, 1, 1},
  {&__pyx_n_u_value_stack, __pyx_k_value_stack, sizeof(__pyx_k_value_stack), 0, 1, 0, 1},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_n_s_vargs_meta, __pyx_k_vargs_meta, sizeof(__pyx_k_vargs_meta), 0, 0, 1, 1},
  {&__pyx_n_s_vargs_meta_inline, __pyx_k_vargs_meta_inline, sizeof(__pyx_k_vargs_meta_inline), 0, 0, 1, 1},
  {&__pyx_n_u_visit_wrapper, __pyx_k_visit_wrapper, sizeof(__pyx_k_visit_wrapper), 0, 1, 0, 1},
  {&__pyx_n_s_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 0, 1, 1},
  {&__pyx_n_s_wrapper, __pyx_k_wrapper, sizeof(__pyx_k_wrapper), 0, 0, 1, 1},
  {&__pyx_n_s_wrapper_chain, __pyx_k_wrapper_chain, sizeof(__pyx_k_wrapper_chain), 0, 0, 1, 1},
  {&__pyx_n_s_wraps, __pyx_k_wraps, sizeof(__pyx_k_wraps), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_n_s_import); if (!__pyx_builtin___import__) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 56, __pyx_L1_error)
  __pyx_builtin_NotImplemented = __Pyx_GetBuiltinName(__pyx_n_s_NotImplemented); if (!__pyx_builtin_NotImplemented) __PYX_ERR(0, 79, __pyx_L1_error)
  __pyx_builtin_AssertionError = __Pyx_GetBuiltinName(__pyx_n_s_AssertionError); if (!__pyx_builtin_AssertionError) __PYX_ERR(0, 157, __pyx_L1_error)
  __pyx_builtin_all = __Pyx_GetBuiltinName(__pyx_n_s_all); if (!__pyx_builtin_all) __PYX_ERR(0, 236, __pyx_L1_error)
  __pyx_builtin_EOFError = __Pyx_GetBuiltinName(__pyx_n_s_EOFError); if (!__pyx_builtin_EOFError) __PYX_ERR(0, 299, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 320, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 367, __pyx_L1_error)
  __pyx_builtin_NameError = __Pyx_GetBuiltinName(__pyx_n_s_NameError); if (!__pyx_builtin_NameError) __PYX_ERR(0, 528, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 533, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 536, __pyx_L1_error)
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 667, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(0, 684, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_n_s_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 689, __pyx_L1_error)
  __pyx_builtin_filter = __Pyx_GetBuiltinName(__pyx_n_s_filter); if (!__pyx_builtin_filter) __PYX_ERR(0, 693, __pyx_L1_error)
  __pyx_builtin_NotImplementedError = __Pyx_GetBuiltinName(__pyx_n_s_NotImplementedError); if (!__pyx_builtin_NotImplementedError) __PYX_ERR(0, 763, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "lark_cython/lark_cython.pyx":56
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 *     def __eq__(self, Token_or_str other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_s_No_matching_signature_found); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_Function_call_with_ambiguous_arg); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "lark_cython/lark_cython.pyx":523
 *                 pass
 * 
 *             end_token = Token.new_borrow_pos('$END', '', token) if token else Token('$END', '', 0, 1, 1)             # <<<<<<<<<<<<<<
 *             return state.feed_token(end_token, True)
 *         except UnexpectedInput as e:
 */
  __pyx_tuple__22 = PyTuple_Pack(5, __pyx_kp_u_END, __pyx_kp_u__3, __pyx_int_0, __pyx_int_1, __pyx_int_1); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "lark_cython/lark_cython.pyx":533
 *         except Exception as e:
 *             if self.debug:
 *                 print("")             # <<<<<<<<<<<<<<
 *                 print("STATE STACK DUMP")
 *                 print("----------------")
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_u__3); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "lark_cython/lark_cython.pyx":534
 *             if self.debug:
 *                 print("")
 *                 print("STATE STACK DUMP")             # <<<<<<<<<<<<<<
 *                 print("----------------")
 *                 for i, s in enumerate(state.state_stack):
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_u_STATE_STACK_DUMP); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "lark_cython/lark_cython.pyx":535
 *                 print("")
 *                 print("STATE STACK DUMP")
 *                 print("----------------")             # <<<<<<<<<<<<<<
 *                 for i, s in enumerate(state.state_stack):
 *                     print('%d)' % i , s)
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_u__25); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "lark_cython/lark_cython.pyx":763
 * def apply_visit_wrapper(func, name, wrapper):
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")             # <<<<<<<<<<<<<<
 * 
 *     @wraps(func)
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_kp_u_Meta_args_not_supported_for_inte); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "lark_cython/lark_cython.pyx":766
 * 
 *     @wraps(func)
 *     def f(children):             # <<<<<<<<<<<<<<
 *         return wrapper(func, name, children, None)
 *     return f
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_n_s_children); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_f, 766, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(0, 766, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":772
 * def inplace_transformer(func):
 *     @wraps(func)
 *     def f(list children):             # <<<<<<<<<<<<<<
 *         # function name in a Transformer is a rule name.
 *         cdef Tree tree
 */
  __pyx_tuple__36 = PyTuple_Pack(2, __pyx_n_s_children, __pyx_n_s_tree); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__36, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_f, 772, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(0, 772, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":1005
 *         default_handler = getattr(transformer, '__default__', None)
 *         if default_handler:
 *             def default_callback(data, children):             # <<<<<<<<<<<<<<
 *                 return default_handler(data, children, None)
 *         else:
 */
  __pyx_tuple__40 = PyTuple_Pack(2, __pyx_n_s_data, __pyx_n_s_children); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 1005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_default_callback, 1005, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(0, 1005, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":56
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 *     def __eq__(self, Token_or_str other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False
 */
  __pyx_tuple__42 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_codeobj__43 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__42, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_eq, 56, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__43)) __PYX_ERR(0, 56, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":66
 * 
 * cdef class LexerState:
 *     __slots__ = 'text', 'line_ctr', 'last_token'             # <<<<<<<<<<<<<<
 * 
 *     cdef public str text
 */
  __pyx_tuple__44 = PyTuple_Pack(3, __pyx_n_u_text, __pyx_n_u_line_ctr, __pyx_n_u_last_token); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "lark_cython/lark_cython.pyx":87
 * 
 * cdef class LineCounter:
 *     __slots__ = 'char_pos', 'line', 'column', 'line_start_pos', 'newline_char'             # <<<<<<<<<<<<<<
 * 
 *     cdef public str newline_char
 */
  __pyx_tuple__45 = PyTuple_Pack(5, __pyx_n_u_char_pos, __pyx_n_u_line, __pyx_n_u_column, __pyx_n_u_line_start_pos, __pyx_n_u_newline_char); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "lark_cython/lark_cython.pyx":384
 * 
 * cdef class ParseConf:
 *     __slots__ = 'parse_table', 'callbacks', 'start', 'start_state', 'end_state', 'states'             # <<<<<<<<<<<<<<
 * 
 *     cdef parse_table
 */
  __pyx_tuple__46 = PyTuple_Pack(6, __pyx_n_u_parse_table, __pyx_n_u_callbacks, __pyx_n_u_start, __pyx_n_u_start_state, __pyx_n_u_end_state, __pyx_n_u_states); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "lark_cython/lark_cython.pyx":403
 * 
 * cdef class ParserState:
 *     __slots__ = 'parse_conf', 'lexer', 'state_stack', 'value_stack'             # <<<<<<<<<<<<<<
 * 
 *     cdef ParseConf parse_conf
 */
  __pyx_tuple__47 = PyTuple_Pack(4, __pyx_n_u_parse_conf, __pyx_n_u_lexer, __pyx_n_u_state_stack, __pyx_n_u_value_stack); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "lark_cython/lark_cython.pyx":544
 * 
 * class LALR_Parser(Serialize):
 *     def __init__(self, parser_conf, debug=False):             # <<<<<<<<<<<<<<
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 *         analysis.compute_lalr()
 */
  __pyx_tuple__48 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_parser_conf, __pyx_n_s_debug, __pyx_n_s_analysis, __pyx_n_s_callbacks); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_init, 544, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 544, __pyx_L1_error)
  __pyx_tuple__50 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "lark_cython/lark_cython.pyx":554
 * 
 *     @classmethod
 *     def deserialize(cls, data, memo, callbacks, debug=False):             # <<<<<<<<<<<<<<
 *         inst = cls.__new__(cls)
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 */
  __pyx_tuple__51 = PyTuple_Pack(6, __pyx_n_s_cls, __pyx_n_s_data, __pyx_n_s_memo, __pyx_n_s_callbacks, __pyx_n_s_debug, __pyx_n_s_inst); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);
  __pyx_codeobj__52 = (PyObject*)__Pyx_PyCode_New(5, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__51, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_deserialize, 554, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__52)) __PYX_ERR(0, 554, __pyx_L1_error)
  __pyx_tuple__53 = PyTuple_Pack(1, ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "lark_cython/lark_cython.pyx":560
 *         return inst
 * 
 *     def serialize(self, memo):             # <<<<<<<<<<<<<<
 *         return self._parse_table.serialize(memo)
 * 
 */
  __pyx_tuple__54 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_memo); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__54, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_serialize, 560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(0, 560, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":563
 *         return self._parse_table.serialize(memo)
 * 
 *     def parse_interactive(self, lexer, start):             # <<<<<<<<<<<<<<
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 */
  __pyx_tuple__56 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_lexer, __pyx_n_s_start); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__56, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_parse_interactive, 563, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(0, 563, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":566
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 *     def parse(self, lexer, start, on_error=None):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.parser.parse(lexer, start)
 */
  __pyx_tuple__58 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_lexer, __pyx_n_s_start, __pyx_n_s_on_error, __pyx_n_s_e, __pyx_n_s_s, __pyx_n_s_p, __pyx_n_s_e2); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(4, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__58, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_parse, 566, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(0, 566, __pyx_L1_error)
  __pyx_tuple__60 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "lark_cython/lark_cython.pyx":761
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 * def apply_visit_wrapper(func, name, wrapper):             # <<<<<<<<<<<<<<
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 */
  __pyx_tuple__61 = PyTuple_Pack(5, __pyx_n_s_func, __pyx_n_s_name, __pyx_n_s_wrapper, __pyx_n_s_f, __pyx_n_s_f); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);
  __pyx_codeobj__62 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__61, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_apply_visit_wrapper, 761, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__62)) __PYX_ERR(0, 761, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":770
 *     return f
 * 
 * def inplace_transformer(func):             # <<<<<<<<<<<<<<
 *     @wraps(func)
 *     def f(list children):
 */
  __pyx_tuple__63 = PyTuple_Pack(3, __pyx_n_s_func, __pyx_n_s_f, __pyx_n_s_f); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);
  __pyx_codeobj__64 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__63, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_inplace_transformer, 770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__64)) __PYX_ERR(0, 770, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":939
 * 
 * 
 * def _should_expand(sym):             # <<<<<<<<<<<<<<
 *     name = sym.name
 *     if not isinstance(name, str):
 */
  __pyx_tuple__65 = PyTuple_Pack(2, __pyx_n_s_sym, __pyx_n_s_name); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__65, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_should_expand, 939, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(0, 939, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":946
 * 
 * 
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):             # <<<<<<<<<<<<<<
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 */
  __pyx_tuple__67 = PyTuple_Pack(17, __pyx_n_s_expansion, __pyx_n_s_keep_all_tokens, __pyx_n_s_ambiguous, __pyx_n_s_empty_indices, __pyx_n_s_s, __pyx_n_s_empty_indices_2, __pyx_n_s_to_include, __pyx_n_s_nones_to_add, __pyx_n_s_i, __pyx_n_s_sym, __pyx_n_s_genexpr, __pyx_n_s_genexpr, __pyx_n_s_ones, __pyx_n_s_genexpr, __pyx_n_s_i, __pyx_n_s_x, __pyx_n_s__38); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(4, 0, 17, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_maybe_create_child_filter, 946, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 946, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":976
 * class ParseTreeBuilder:
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):             # <<<<<<<<<<<<<<
 *         self.tree_class = Tree #tree_class
 *         self.propagate_positions = propagate_positions
 */
  __pyx_tuple__69 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_rules, __pyx_n_s_tree_class, __pyx_n_s_propagate_positions, __pyx_n_s_ambiguous, __pyx_n_s_maybe_placeholders); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(6, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_init, 976, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 976, __pyx_L1_error)
  __pyx_tuple__71 = PyTuple_Pack(3, ((PyObject *)Py_False), ((PyObject *)Py_False), ((PyObject *)Py_False)); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "lark_cython/lark_cython.pyx":984
 *         self.rule_builders = list(self._init_builders(rules))
 * 
 *     def _init_builders(self, rules):             # <<<<<<<<<<<<<<
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 */
  __pyx_tuple__72 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_rules, __pyx_n_s_propagate_positions, __pyx_n_s_rule, __pyx_n_s_options, __pyx_n_s_keep_all_tokens, __pyx_n_s_expand_single_child, __pyx_n_s_wrapper_chain); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__72, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_init_builders, 984, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 984, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":1000
 *             yield rule, wrapper_chain
 * 
 *     def create_callback(self, transformer=None):             # <<<<<<<<<<<<<<
 *         callbacks = {}
 * 
 */
  __pyx_tuple__73 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_transformer, __pyx_n_s_callbacks, __pyx_n_s_default_handler, __pyx_n_s_default_callback, __pyx_n_s_default_callback, __pyx_n_s_rule, __pyx_n_s_wrapper_chain, __pyx_n_s_user_callback_name, __pyx_n_s_f, __pyx_n_s_wrapper, __pyx_n_s_w); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(2, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__73, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_lark_cython_lark_cython_pyx, __pyx_n_s_create_callback, 1000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __pyx_tuple__75 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Lexer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__76 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);
  __pyx_codeobj__77 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__76, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Lexer, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__77)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__78 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_BasicLexer, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__80 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__80, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ParseConf, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__82 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__82, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ParserState, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__84 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Meta, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__86 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__86, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ExpandSingleChild, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__88 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_PropagatePosition, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__90 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);
  __pyx_codeobj__91 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__90, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ChildFilter, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__91)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__92 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);
  __pyx_codeobj__93 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__92, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ChildFilterLALR, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__93)) __PYX_ERR(1, 1, __pyx_L1_error)
  __pyx_tuple__94 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);
  __pyx_codeobj__95 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__94, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_ChildFilterLALR_N, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__95)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyList_Type_isupper.type = (PyObject*)&PyList_Type;
  __pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  __pyx_umethod_PyUnicode_Type_rindex.type = (PyObject*)&PyUnicode_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_11743518 = PyInt_FromLong(11743518L); if (unlikely(!__pyx_int_11743518)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_71555863 = PyInt_FromLong(71555863L); if (unlikely(!__pyx_int_71555863)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_104898272 = PyInt_FromLong(104898272L); if (unlikely(!__pyx_int_104898272)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_109761734 = PyInt_FromLong(109761734L); if (unlikely(!__pyx_int_109761734)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_141903276 = PyInt_FromLong(141903276L); if (unlikely(!__pyx_int_141903276)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_146776923 = PyInt_FromLong(146776923L); if (unlikely(!__pyx_int_146776923)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_260616610 = PyInt_FromLong(260616610L); if (unlikely(!__pyx_int_260616610)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_11lark_cython_11lark_cython_Token = &__pyx_vtable_11lark_cython_11lark_cython_Token;
  __pyx_vtable_11lark_cython_11lark_cython_Token.update = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Token *, struct __pyx_opt_args_11lark_cython_11lark_cython_5Token_update *__pyx_optional_args))__pyx_f_11lark_cython_11lark_cython_5Token_update;
  __pyx_vtable_11lark_cython_11lark_cython_Token.__pyx___reduce__ = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Token *))__pyx_f_11lark_cython_11lark_cython_5Token___reduce__;
  __pyx_vtable_11lark_cython_11lark_cython_Token.__pyx___deepcopy__ = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Token *, PyObject *))__pyx_f_11lark_cython_11lark_cython_5Token___deepcopy__;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_Token) < 0) __PYX_ERR(0, 16, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_Token.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_Token.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_Token.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_Token.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_Token.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_Token) < 0) __PYX_ERR(0, 16, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Token_2, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_Token) < 0) __PYX_ERR(0, 16, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_Token = &__pyx_type_11lark_cython_11lark_cython_Token;
  __pyx_vtabptr_11lark_cython_11lark_cython_LexerState = &__pyx_vtable_11lark_cython_11lark_cython_LexerState;
  __pyx_vtable_11lark_cython_11lark_cython_LexerState.__pyx___copy__ = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_LexerState *))__pyx_f_11lark_cython_11lark_cython_10LexerState___copy__;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_LexerState) < 0) __PYX_ERR(0, 65, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_LexerState.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_LexerState.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_LexerState.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_LexerState.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_LexerState.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_LexerState) < 0) __PYX_ERR(0, 65, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_LexerState, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_LexerState) < 0) __PYX_ERR(0, 65, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_LexerState) < 0) __PYX_ERR(0, 65, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_LexerState = &__pyx_type_11lark_cython_11lark_cython_LexerState;
  __pyx_vtabptr_11lark_cython_11lark_cython_LineCounter = &__pyx_vtable_11lark_cython_11lark_cython_LineCounter;
  __pyx_vtable_11lark_cython_11lark_cython_LineCounter.feed = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_LineCounter *, PyObject *, int, int __pyx_skip_dispatch))__pyx_f_11lark_cython_11lark_cython_11LineCounter_feed;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_LineCounter) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_LineCounter.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_LineCounter.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_LineCounter.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_LineCounter.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_LineCounter.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_LineCounter) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_LineCounter, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_LineCounter) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_LineCounter) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_LineCounter = &__pyx_type_11lark_cython_11lark_cython_LineCounter;
  __pyx_vtabptr_11lark_cython_11lark_cython_Scanner = &__pyx_vtable_11lark_cython_11lark_cython_Scanner;
  __pyx_vtable_11lark_cython_11lark_cython_Scanner.match = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Scanner *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11lark_cython_11lark_cython_7Scanner_match;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_Scanner) < 0) __PYX_ERR(0, 125, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_Scanner.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_Scanner.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_Scanner.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_Scanner.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_Scanner.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_Scanner) < 0) __PYX_ERR(0, 125, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Scanner, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_Scanner) < 0) __PYX_ERR(0, 125, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_Scanner) < 0) __PYX_ERR(0, 125, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_Scanner = &__pyx_type_11lark_cython_11lark_cython_Scanner;
  __pyx_vtabptr_11lark_cython_11lark_cython_Lexer = &__pyx_vtable_11lark_cython_11lark_cython_Lexer;
  __pyx_vtable_11lark_cython_11lark_cython_Lexer.make_lexer_state = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *, PyObject *))__pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_state;
  __pyx_vtable_11lark_cython_11lark_cython_Lexer.make_lexer_thread = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11lark_cython_11lark_cython_5Lexer_make_lexer_thread;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_Lexer) < 0) __PYX_ERR(0, 171, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_Lexer.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_Lexer.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_Lexer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_Lexer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_Lexer.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_Lexer) < 0) __PYX_ERR(0, 171, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Lexer, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_Lexer) < 0) __PYX_ERR(0, 171, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_Lexer) < 0) __PYX_ERR(0, 171, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_Lexer = &__pyx_type_11lark_cython_11lark_cython_Lexer;
  __pyx_vtabptr_11lark_cython_11lark_cython_BasicLexer = &__pyx_vtable_11lark_cython_11lark_cython_BasicLexer;
  __pyx_vtable_11lark_cython_11lark_cython_BasicLexer.__pyx_base = *__pyx_vtabptr_11lark_cython_11lark_cython_Lexer;
  __pyx_vtable_11lark_cython_11lark_cython_BasicLexer.match = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *, PyObject *, PyObject *))__pyx_f_11lark_cython_11lark_cython_10BasicLexer_match;
  __pyx_vtable_11lark_cython_11lark_cython_BasicLexer.next_token = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_BasicLexer *, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *))__pyx_f_11lark_cython_11lark_cython_10BasicLexer_next_token;
  __pyx_type_11lark_cython_11lark_cython_BasicLexer.tp_base = __pyx_ptype_11lark_cython_11lark_cython_Lexer;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_BasicLexer) < 0) __PYX_ERR(0, 187, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_BasicLexer.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_BasicLexer.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_BasicLexer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_BasicLexer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_BasicLexer.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_BasicLexer) < 0) __PYX_ERR(0, 187, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BasicLexer, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_BasicLexer) < 0) __PYX_ERR(0, 187, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_BasicLexer) < 0) __PYX_ERR(0, 187, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_BasicLexer = &__pyx_type_11lark_cython_11lark_cython_BasicLexer;
  __pyx_vtabptr_11lark_cython_11lark_cython_ContextualLexer = &__pyx_vtable_11lark_cython_11lark_cython_ContextualLexer;
  __pyx_vtable_11lark_cython_11lark_cython_ContextualLexer.__pyx_base = *__pyx_vtabptr_11lark_cython_11lark_cython_Lexer;
  __pyx_vtable_11lark_cython_11lark_cython_ContextualLexer.__pyx_base.make_lexer_state = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_Lexer *, PyObject *))__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state__pyx_wrap_1;
  __pyx_vtable_11lark_cython_11lark_cython_ContextualLexer.make_lexer_state = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_make_lexer_state;
  __pyx_vtable_11lark_cython_11lark_cython_ContextualLexer.next_token = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_ContextualLexer *, struct __pyx_obj_11lark_cython_11lark_cython_LexerState *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *, int __pyx_skip_dispatch))__pyx_f_11lark_cython_11lark_cython_15ContextualLexer_next_token;
  __pyx_type_11lark_cython_11lark_cython_ContextualLexer.tp_base = __pyx_ptype_11lark_cython_11lark_cython_Lexer;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ContextualLexer) < 0) __PYX_ERR(0, 301, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ContextualLexer.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ContextualLexer.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ContextualLexer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ContextualLexer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_ContextualLexer.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_ContextualLexer) < 0) __PYX_ERR(0, 301, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ContextualLexer, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ContextualLexer) < 0) __PYX_ERR(0, 301, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ContextualLexer) < 0) __PYX_ERR(0, 301, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ContextualLexer = &__pyx_type_11lark_cython_11lark_cython_ContextualLexer;
  __pyx_vtabptr_11lark_cython_11lark_cython_LexerThread = &__pyx_vtable_11lark_cython_11lark_cython_LexerThread;
  __pyx_vtable_11lark_cython_11lark_cython_LexerThread.next_token = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_LexerThread *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *))__pyx_f_11lark_cython_11lark_cython_11LexerThread_next_token;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_LexerThread) < 0) __PYX_ERR(0, 353, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_LexerThread.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_LexerThread.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_LexerThread.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_LexerThread.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_LexerThread.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_LexerThread) < 0) __PYX_ERR(0, 353, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_LexerThread, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_LexerThread) < 0) __PYX_ERR(0, 353, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_LexerThread) < 0) __PYX_ERR(0, 353, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_LexerThread = &__pyx_type_11lark_cython_11lark_cython_LexerThread;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ParseConf) < 0) __PYX_ERR(0, 383, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ParseConf.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ParseConf.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ParseConf.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ParseConf.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ParseConf, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ParseConf) < 0) __PYX_ERR(0, 383, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ParseConf) < 0) __PYX_ERR(0, 383, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ParseConf = &__pyx_type_11lark_cython_11lark_cython_ParseConf;
  __pyx_vtabptr_11lark_cython_11lark_cython_ParserState = &__pyx_vtable_11lark_cython_11lark_cython_ParserState;
  __pyx_vtable_11lark_cython_11lark_cython_ParserState.feed_token = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_ParserState *, struct __pyx_obj_11lark_cython_11lark_cython_Token *, struct __pyx_opt_args_11lark_cython_11lark_cython_11ParserState_feed_token *__pyx_optional_args))__pyx_f_11lark_cython_11lark_cython_11ParserState_feed_token;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ParserState) < 0) __PYX_ERR(0, 402, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ParserState.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ParserState.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ParserState.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ParserState.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_ParserState.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_ParserState) < 0) __PYX_ERR(0, 402, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ParserState, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ParserState) < 0) __PYX_ERR(0, 402, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ParserState) < 0) __PYX_ERR(0, 402, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ParserState = &__pyx_type_11lark_cython_11lark_cython_ParserState;
  __pyx_vtabptr_11lark_cython_11lark_cython__Parser = &__pyx_vtable_11lark_cython_11lark_cython__Parser;
  __pyx_vtable_11lark_cython_11lark_cython__Parser.parse_from_state = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython__Parser *, struct __pyx_obj_11lark_cython_11lark_cython_ParserState *))__pyx_f_11lark_cython_11lark_cython_7_Parser_parse_from_state;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython__Parser) < 0) __PYX_ERR(0, 490, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython__Parser.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython__Parser.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython__Parser.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython__Parser.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython__Parser.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython__Parser) < 0) __PYX_ERR(0, 490, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Parser, (PyObject *)&__pyx_type_11lark_cython_11lark_cython__Parser) < 0) __PYX_ERR(0, 490, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython__Parser) < 0) __PYX_ERR(0, 490, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython__Parser = &__pyx_type_11lark_cython_11lark_cython__Parser;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_Meta) < 0) __PYX_ERR(0, 602, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_Meta.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_Meta.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_Meta.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_Meta.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Meta, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_Meta) < 0) __PYX_ERR(0, 602, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_Meta) < 0) __PYX_ERR(0, 602, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_Meta = &__pyx_type_11lark_cython_11lark_cython_Meta;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_Tree) < 0) __PYX_ERR(0, 622, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_Tree.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_Tree.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_Tree.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_Tree.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Tree_2, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_Tree) < 0) __PYX_ERR(0, 622, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_Tree) < 0) __PYX_ERR(0, 622, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_Tree = &__pyx_type_11lark_cython_11lark_cython_Tree;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ExpandSingleChild) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ExpandSingleChild.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ExpandSingleChild.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ExpandSingleChild.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ExpandSingleChild.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ExpandSingleChild, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ExpandSingleChild) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ExpandSingleChild) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ExpandSingleChild = &__pyx_type_11lark_cython_11lark_cython_ExpandSingleChild;
  __pyx_vtabptr_11lark_cython_11lark_cython_PropagatePositions = &__pyx_vtable_11lark_cython_11lark_cython_PropagatePositions;
  __pyx_vtable_11lark_cython_11lark_cython_PropagatePositions._pp_get_meta = (PyObject *(*)(struct __pyx_obj_11lark_cython_11lark_cython_PropagatePositions *, PyObject *))__pyx_f_11lark_cython_11lark_cython_18PropagatePositions__pp_get_meta;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_PropagatePositions) < 0) __PYX_ERR(0, 792, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_PropagatePositions.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_PropagatePositions.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_PropagatePositions.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_PropagatePositions.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_11lark_cython_11lark_cython_PropagatePositions.tp_dict, __pyx_vtabptr_11lark_cython_11lark_cython_PropagatePositions) < 0) __PYX_ERR(0, 792, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_PropagatePositions, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_PropagatePositions) < 0) __PYX_ERR(0, 792, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_PropagatePositions) < 0) __PYX_ERR(0, 792, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_PropagatePositions = &__pyx_type_11lark_cython_11lark_cython_PropagatePositions;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ChildFilter) < 0) __PYX_ERR(0, 859, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ChildFilter.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ChildFilter.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ChildFilter.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ChildFilter.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ChildFilter, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ChildFilter) < 0) __PYX_ERR(0, 859, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ChildFilter) < 0) __PYX_ERR(0, 859, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ChildFilter = &__pyx_type_11lark_cython_11lark_cython_ChildFilter;
  __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR.tp_base = __pyx_ptype_11lark_cython_11lark_cython_ChildFilter;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ChildFilterLALR, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR = &__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR;
  __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders.tp_base = __pyx_ptype_11lark_cython_11lark_cython_ChildFilter;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders) < 0) __PYX_ERR(0, 914, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ChildFilterLALR_NoPlaceholders, (PyObject *)&__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders) < 0) __PYX_ERR(0, 914, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders) < 0) __PYX_ERR(0, 914, __pyx_L1_error)
  __pyx_ptype_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders = &__pyx_type_11lark_cython_11lark_cython_ChildFilterLALR_NoPlaceholders;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres) < 0) __PYX_ERR(0, 145, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct___build_mres = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct___build_mres;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 152, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_1_genexpr;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__) < 0) __PYX_ERR(0, 201, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_2___init__ = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_2___init__;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr) < 0) __PYX_ERR(0, 203, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_3_genexpr;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_4_genexpr;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner) < 0) __PYX_ERR(0, 234, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_5__build_scanner;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data) < 0) __PYX_ERR(0, 695, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_6_find_data;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values) < 0) __PYX_ERR(0, 712, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_7_scan_values;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown) < 0) __PYX_ERR(0, 728, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_8_iter_subtrees_topdown;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper) < 0) __PYX_ERR(0, 761, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_9_apply_visit_wrapper;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer) < 0) __PYX_ERR(0, 770, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_10_inplace_transformer;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter) < 0) __PYX_ERR(0, 946, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_11_maybe_create_child_filter;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr) < 0) __PYX_ERR(0, 950, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_12_genexpr;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr) < 0) __PYX_ERR(0, 966, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_13_genexpr;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders) < 0) __PYX_ERR(0, 984, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_14__init_builders;
  if (PyType_Ready(&__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback) < 0) __PYX_ERR(0, 1000, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback.tp_dictoffset && __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback = &__pyx_type_11lark_cython_11lark_cython___pyx_scope_struct_15_create_callback;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initlark_cython(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initlark_cython(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_lark_cython(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_lark_cython(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_lark_cython(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'lark_cython' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_lark_cython(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("lark_cython", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_lark_cython__lark_cython) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "lark_cython.lark_cython")) {
      if (unlikely(PyDict_SetItemString(modules, "lark_cython.lark_cython", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "lark_cython/lark_cython.pyx":4
 * import cython
 * 
 * from copy import copy             # <<<<<<<<<<<<<<
 * from typing import Any, Iterator, Type, Optional, Collection, Dict
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_copy);
  __Pyx_GIVEREF(__pyx_n_s_copy);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_copy);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_copy, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_copy, __pyx_t_1) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":5
 * 
 * from copy import copy
 * from typing import Any, Iterator, Type, Optional, Collection, Dict             # <<<<<<<<<<<<<<
 * 
 * from lark.exceptions import UnexpectedCharacters, UnexpectedToken, LexError
 */
  __pyx_t_2 = PyList_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Any);
  __Pyx_GIVEREF(__pyx_n_s_Any);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Any);
  __Pyx_INCREF(__pyx_n_s_Iterator);
  __Pyx_GIVEREF(__pyx_n_s_Iterator);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_Iterator);
  __Pyx_INCREF(__pyx_n_s_Type);
  __Pyx_GIVEREF(__pyx_n_s_Type);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_Type);
  __Pyx_INCREF(__pyx_n_s_Optional);
  __Pyx_GIVEREF(__pyx_n_s_Optional);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_Optional);
  __Pyx_INCREF(__pyx_n_s_Collection);
  __Pyx_GIVEREF(__pyx_n_s_Collection);
  PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_Collection);
  __Pyx_INCREF(__pyx_n_s_Dict);
  __Pyx_GIVEREF(__pyx_n_s_Dict);
  PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_Dict);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_typing, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Any); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Any, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Iterator); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Iterator, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Type, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Optional); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Optional, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Collection); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Collection, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Dict, __pyx_t_2) < 0) __PYX_ERR(0, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":7
 * from typing import Any, Iterator, Type, Optional, Collection, Dict
 * 
 * from lark.exceptions import UnexpectedCharacters, UnexpectedToken, LexError             # <<<<<<<<<<<<<<
 * from lark.lexer import CallChain, _create_unless, TerminalDef, _regexp_has_newline, TOKEN_DEFAULT_PRIORITY, Pattern
 * 
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_UnexpectedCharacters);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedCharacters);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_UnexpectedCharacters);
  __Pyx_INCREF(__pyx_n_s_UnexpectedToken);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedToken);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_UnexpectedToken);
  __Pyx_INCREF(__pyx_n_s_LexError);
  __Pyx_GIVEREF(__pyx_n_s_LexError);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_s_LexError);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_lark_exceptions, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedCharacters, __pyx_t_1) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedToken, __pyx_t_1) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_LexError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LexError, __pyx_t_1) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":8
 * 
 * from lark.exceptions import UnexpectedCharacters, UnexpectedToken, LexError
 * from lark.lexer import CallChain, _create_unless, TerminalDef, _regexp_has_newline, TOKEN_DEFAULT_PRIORITY, Pattern             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyList_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_CallChain);
  __Pyx_GIVEREF(__pyx_n_s_CallChain);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_CallChain);
  __Pyx_INCREF(__pyx_n_s_create_unless);
  __Pyx_GIVEREF(__pyx_n_s_create_unless);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_create_unless);
  __Pyx_INCREF(__pyx_n_s_TerminalDef);
  __Pyx_GIVEREF(__pyx_n_s_TerminalDef);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_TerminalDef);
  __Pyx_INCREF(__pyx_n_s_regexp_has_newline);
  __Pyx_GIVEREF(__pyx_n_s_regexp_has_newline);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_regexp_has_newline);
  __Pyx_INCREF(__pyx_n_s_TOKEN_DEFAULT_PRIORITY);
  __Pyx_GIVEREF(__pyx_n_s_TOKEN_DEFAULT_PRIORITY);
  PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_TOKEN_DEFAULT_PRIORITY);
  __Pyx_INCREF(__pyx_n_s_Pattern);
  __Pyx_GIVEREF(__pyx_n_s_Pattern);
  PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_Pattern);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_lark_lexer, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_CallChain); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CallChain, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_create_unless); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_create_unless, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_TerminalDef); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TerminalDef, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_regexp_has_newline); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_regexp_has_newline, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_TOKEN_DEFAULT_PRIORITY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TOKEN_DEFAULT_PRIORITY, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Pattern); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Pattern, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":44
 * 
 *     @classmethod
 *     def new_borrow_pos(cls, type_: str, value: Any, borrow_t: 'Token'):             # <<<<<<<<<<<<<<
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)
 * 
 */
  __Pyx_GetNameInClass(__pyx_t_1, (PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token, __pyx_n_s_new_borrow_pos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "lark_cython/lark_cython.pyx":43
 *         )
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def new_borrow_pos(cls, type_: str, value: Any, borrow_t: 'Token'):
 *         return cls(type_, value, borrow_t.start_pos, borrow_t.line, borrow_t.column, borrow_t.end_line, borrow_t.end_column, borrow_t.end_pos)
 */
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token->tp_dict, __pyx_n_s_new_borrow_pos, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_11lark_cython_11lark_cython_Token);

  /* "lark_cython/lark_cython.pyx":56
 *         return Token(self.type, self.value, self.start_pos, self.line, self.column)
 * 
 *     def __eq__(self, Token_or_str other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, Token) and self.type != other.type:
 *             return False
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __pyx_FusedFunction_New(&__pyx_fuse_0__pyx_mdef_11lark_cython_11lark_cython_5Token_11__eq__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Token___eq, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_Token_2, __pyx_t_1) < 0) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_FusedFunction_New(&__pyx_fuse_1__pyx_mdef_11lark_cython_11lark_cython_5Token_13__eq__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Token___eq, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_unicode, __pyx_t_1) < 0) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __pyx_FusedFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_5Token_7__eq__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Token___eq, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__43)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_empty_tuple);
  ((__pyx_FusedFunctionObject *) __pyx_t_1)->__signatures__ = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_Token->tp_dict, __pyx_n_s_eq, __pyx_t_1) < 0) __PYX_ERR(0, 56, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_11lark_cython_11lark_cython_Token);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":66
 * 
 * cdef class LexerState:
 *     __slots__ = 'text', 'line_ctr', 'last_token'             # <<<<<<<<<<<<<<
 * 
 *     cdef public str text
 */
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LexerState->tp_dict, __pyx_n_s_slots, __pyx_tuple__44) < 0) __PYX_ERR(0, 66, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_11lark_cython_11lark_cython_LexerState);

  /* "lark_cython/lark_cython.pyx":87
 * 
 * cdef class LineCounter:
 *     __slots__ = 'char_pos', 'line', 'column', 'line_start_pos', 'newline_char'             # <<<<<<<<<<<<<<
 * 
 *     cdef public str newline_char
 */
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LineCounter->tp_dict, __pyx_n_s_slots, __pyx_tuple__45) < 0) __PYX_ERR(0, 87, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_11lark_cython_11lark_cython_LineCounter);

  /* "lark_cython/lark_cython.pyx":374
 * ####
 * 
 * from copy import deepcopy, copy             # <<<<<<<<<<<<<<
 * from lark.exceptions import UnexpectedInput, UnexpectedToken
 * from lark.utils import Serialize
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_deepcopy);
  __Pyx_GIVEREF(__pyx_n_s_deepcopy);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_deepcopy);
  __Pyx_INCREF(__pyx_n_s_copy);
  __Pyx_GIVEREF(__pyx_n_s_copy);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_copy);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_copy, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_deepcopy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_deepcopy, __pyx_t_1) < 0) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_copy, __pyx_t_1) < 0) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":375
 * 
 * from copy import deepcopy, copy
 * from lark.exceptions import UnexpectedInput, UnexpectedToken             # <<<<<<<<<<<<<<
 * from lark.utils import Serialize
 * 
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_UnexpectedInput);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedInput);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_UnexpectedInput);
  __Pyx_INCREF(__pyx_n_s_UnexpectedToken);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedToken);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_UnexpectedToken);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_lark_exceptions, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_UnexpectedInput); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedInput, __pyx_t_2) < 0) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedToken, __pyx_t_2) < 0) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":376
 * from copy import deepcopy, copy
 * from lark.exceptions import UnexpectedInput, UnexpectedToken
 * from lark.utils import Serialize             # <<<<<<<<<<<<<<
 * 
 * from lark.parsers.lalr_analysis import LALR_Analyzer, Shift, Reduce, IntParseTable
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_Serialize);
  __Pyx_GIVEREF(__pyx_n_s_Serialize);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_Serialize);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_lark_utils, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Serialize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Serialize, __pyx_t_1) < 0) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":378
 * from lark.utils import Serialize
 * 
 * from lark.parsers.lalr_analysis import LALR_Analyzer, Shift, Reduce, IntParseTable             # <<<<<<<<<<<<<<
 * from lark.parsers.lalr_interactive_parser import InteractiveParser
 * from lark.exceptions import UnexpectedCharacters, UnexpectedInput, UnexpectedToken
 */
  __pyx_t_2 = PyList_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_LALR_Analyzer);
  __Pyx_GIVEREF(__pyx_n_s_LALR_Analyzer);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_LALR_Analyzer);
  __Pyx_INCREF(__pyx_n_s_Shift);
  __Pyx_GIVEREF(__pyx_n_s_Shift);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_Shift);
  __Pyx_INCREF(__pyx_n_s_Reduce);
  __Pyx_GIVEREF(__pyx_n_s_Reduce);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_Reduce);
  __Pyx_INCREF(__pyx_n_s_IntParseTable);
  __Pyx_GIVEREF(__pyx_n_s_IntParseTable);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_IntParseTable);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_lark_parsers_lalr_analysis, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_LALR_Analyzer); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LALR_Analyzer, __pyx_t_2) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Shift); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Shift, __pyx_t_2) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Reduce); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Reduce, __pyx_t_2) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_IntParseTable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IntParseTable, __pyx_t_2) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":379
 * 
 * from lark.parsers.lalr_analysis import LALR_Analyzer, Shift, Reduce, IntParseTable
 * from lark.parsers.lalr_interactive_parser import InteractiveParser             # <<<<<<<<<<<<<<
 * from lark.exceptions import UnexpectedCharacters, UnexpectedInput, UnexpectedToken
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_InteractiveParser);
  __Pyx_GIVEREF(__pyx_n_s_InteractiveParser);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_InteractiveParser);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_lark_parsers_lalr_interactive_pa, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_InteractiveParser); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_InteractiveParser, __pyx_t_1) < 0) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":380
 * from lark.parsers.lalr_analysis import LALR_Analyzer, Shift, Reduce, IntParseTable
 * from lark.parsers.lalr_interactive_parser import InteractiveParser
 * from lark.exceptions import UnexpectedCharacters, UnexpectedInput, UnexpectedToken             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_UnexpectedCharacters);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedCharacters);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_UnexpectedCharacters);
  __Pyx_INCREF(__pyx_n_s_UnexpectedInput);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedInput);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_UnexpectedInput);
  __Pyx_INCREF(__pyx_n_s_UnexpectedToken);
  __Pyx_GIVEREF(__pyx_n_s_UnexpectedToken);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_UnexpectedToken);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_lark_exceptions, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_UnexpectedCharacters); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedCharacters, __pyx_t_2) < 0) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_UnexpectedInput); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedInput, __pyx_t_2) < 0) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_UnexpectedToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_UnexpectedToken, __pyx_t_2) < 0) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":384
 * 
 * cdef class ParseConf:
 *     __slots__ = 'parse_table', 'callbacks', 'start', 'start_state', 'end_state', 'states'             # <<<<<<<<<<<<<<
 * 
 *     cdef parse_table
 */
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ParseConf->tp_dict, __pyx_n_s_slots, __pyx_tuple__46) < 0) __PYX_ERR(0, 384, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_11lark_cython_11lark_cython_ParseConf);

  /* "lark_cython/lark_cython.pyx":403
 * 
 * cdef class ParserState:
 *     __slots__ = 'parse_conf', 'lexer', 'state_stack', 'value_stack'             # <<<<<<<<<<<<<<
 * 
 *     cdef ParseConf parse_conf
 */
  if (PyDict_SetItem((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ParserState->tp_dict, __pyx_n_s_slots, __pyx_tuple__47) < 0) __PYX_ERR(0, 403, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_11lark_cython_11lark_cython_ParserState);

  /* "lark_cython/lark_cython.pyx":543
 * 
 * 
 * class LALR_Parser(Serialize):             # <<<<<<<<<<<<<<
 *     def __init__(self, parser_conf, debug=False):
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Serialize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_2, __pyx_n_s_LALR_Parser, __pyx_n_s_LALR_Parser, (PyObject *) NULL, __pyx_kp_s_lark_cython_lark_cython, (PyObject *) NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "lark_cython/lark_cython.pyx":544
 * 
 * class LALR_Parser(Serialize):
 *     def __init__(self, parser_conf, debug=False):             # <<<<<<<<<<<<<<
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 *         analysis.compute_lalr()
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_1__init__, 0, __pyx_n_s_LALR_Parser___init, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__50);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_init, __pyx_t_4) < 0) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "lark_cython/lark_cython.pyx":554
 * 
 *     @classmethod
 *     def deserialize(cls, data, memo, callbacks, debug=False):             # <<<<<<<<<<<<<<
 *         inst = cls.__new__(cls)
 *         inst._parse_table = IntParseTable.deserialize(data, memo)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_3deserialize, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_LALR_Parser_deserialize, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__52)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__53);

  /* "lark_cython/lark_cython.pyx":553
 *         self.parser = _Parser(analysis.parse_table, callbacks, debug)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def deserialize(cls, data, memo, callbacks, debug=False):
 *         inst = cls.__new__(cls)
 */
  __pyx_t_5 = __Pyx_Method_ClassMethod(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_deserialize, __pyx_t_5) < 0) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "lark_cython/lark_cython.pyx":560
 *         return inst
 * 
 *     def serialize(self, memo):             # <<<<<<<<<<<<<<
 *         return self._parse_table.serialize(memo)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_5serialize, 0, __pyx_n_s_LALR_Parser_serialize, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_serialize, __pyx_t_5) < 0) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "lark_cython/lark_cython.pyx":563
 *         return self._parse_table.serialize(memo)
 * 
 *     def parse_interactive(self, lexer, start):             # <<<<<<<<<<<<<<
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_7parse_interactive, 0, __pyx_n_s_LALR_Parser_parse_interactive, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_parse_interactive, __pyx_t_5) < 0) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "lark_cython/lark_cython.pyx":566
 *         return self.parser.parse(lexer, start, start_interactive=True)
 * 
 *     def parse(self, lexer, start, on_error=None):             # <<<<<<<<<<<<<<
 *         try:
 *             return self.parser.parse(lexer, start)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_11LALR_Parser_9parse, 0, __pyx_n_s_LALR_Parser_parse, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__60);
  if (__Pyx_SetNameInClass(__pyx_t_3, __pyx_n_s_parse, __pyx_t_5) < 0) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "lark_cython/lark_cython.pyx":543
 * 
 * 
 * class LALR_Parser(Serialize):             # <<<<<<<<<<<<<<
 *     def __init__(self, parser_conf, debug=False):
 *         analysis = LALR_Analyzer(parser_conf, debug=debug)
 */
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_LALR_Parser, __pyx_t_2, __pyx_t_3, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_LALR_Parser, __pyx_t_5) < 0) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":600
 * ###}
 * 
 * from collections import OrderedDict             # <<<<<<<<<<<<<<
 * 
 * cdef class Meta:
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_OrderedDict);
  __Pyx_GIVEREF(__pyx_n_s_OrderedDict);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_OrderedDict);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, __pyx_t_2) < 0) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":754
 * 
 * #####
 * from lark.exceptions import GrammarError, ConfigurationError             # <<<<<<<<<<<<<<
 * 
 * from functools import partial, wraps
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_GrammarError);
  __Pyx_GIVEREF(__pyx_n_s_GrammarError);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_GrammarError);
  __Pyx_INCREF(__pyx_n_s_ConfigurationError);
  __Pyx_GIVEREF(__pyx_n_s_ConfigurationError);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_ConfigurationError);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_lark_exceptions, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_GrammarError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GrammarError, __pyx_t_1) < 0) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_ConfigurationError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ConfigurationError, __pyx_t_1) < 0) __PYX_ERR(0, 754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":756
 * from lark.exceptions import GrammarError, ConfigurationError
 * 
 * from functools import partial, wraps             # <<<<<<<<<<<<<<
 * from itertools import repeat, product
 * from lark.visitors import Transformer_InPlace
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_partial);
  __Pyx_GIVEREF(__pyx_n_s_partial);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_partial);
  __Pyx_INCREF(__pyx_n_s_wraps);
  __Pyx_GIVEREF(__pyx_n_s_wraps);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_wraps);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_functools, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_partial); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_partial, __pyx_t_2) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_wraps, __pyx_t_2) < 0) __PYX_ERR(0, 756, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":757
 * 
 * from functools import partial, wraps
 * from itertools import repeat, product             # <<<<<<<<<<<<<<
 * from lark.visitors import Transformer_InPlace
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_repeat);
  __Pyx_GIVEREF(__pyx_n_s_repeat);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_repeat);
  __Pyx_INCREF(__pyx_n_s_product);
  __Pyx_GIVEREF(__pyx_n_s_product);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_product);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_itertools, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_repeat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_repeat, __pyx_t_1) < 0) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_product); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_product, __pyx_t_1) < 0) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":758
 * from functools import partial, wraps
 * from itertools import repeat, product
 * from lark.visitors import Transformer_InPlace             # <<<<<<<<<<<<<<
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Transformer_InPlace);
  __Pyx_GIVEREF(__pyx_n_s_Transformer_InPlace);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Transformer_InPlace);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_lark_visitors, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Transformer_InPlace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Transformer_InPlace, __pyx_t_2) < 0) __PYX_ERR(0, 758, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":759
 * from itertools import repeat, product
 * from lark.visitors import Transformer_InPlace
 * from lark.visitors import _vargs_meta, _vargs_meta_inline             # <<<<<<<<<<<<<<
 * 
 * def apply_visit_wrapper(func, name, wrapper):
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_vargs_meta);
  __Pyx_GIVEREF(__pyx_n_s_vargs_meta);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_vargs_meta);
  __Pyx_INCREF(__pyx_n_s_vargs_meta_inline);
  __Pyx_GIVEREF(__pyx_n_s_vargs_meta_inline);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_vargs_meta_inline);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_lark_visitors, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_vargs_meta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_vargs_meta, __pyx_t_1) < 0) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_vargs_meta_inline); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_vargs_meta_inline, __pyx_t_1) < 0) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":761
 * from lark.visitors import _vargs_meta, _vargs_meta_inline
 * 
 * def apply_visit_wrapper(func, name, wrapper):             # <<<<<<<<<<<<<<
 *     if wrapper is _vargs_meta or wrapper is _vargs_meta_inline:
 *         raise NotImplementedError("Meta args not supported for internal transformer")
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_1apply_visit_wrapper, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_apply_visit_wrapper, __pyx_t_2) < 0) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":770
 *     return f
 * 
 * def inplace_transformer(func):             # <<<<<<<<<<<<<<
 *     @wraps(func)
 *     def f(list children):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_3inplace_transformer, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_inplace_transformer, __pyx_t_2) < 0) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":939
 * 
 * 
 * def _should_expand(sym):             # <<<<<<<<<<<<<<
 *     name = sym.name
 *     if not isinstance(name, str):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_5_should_expand, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_should_expand, __pyx_t_2) < 0) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":946
 * 
 * 
 * def maybe_create_child_filter(expansion, keep_all_tokens, ambiguous, _empty_indices):             # <<<<<<<<<<<<<<
 *     # Prepare empty_indices as: How many Nones to insert at each index?
 *     if _empty_indices:
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_7maybe_create_child_filter, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_maybe_create_child_filter, __pyx_t_2) < 0) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":974
 * 
 * 
 * class ParseTreeBuilder:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):
 */
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_ParseTreeBuilder, __pyx_n_s_ParseTreeBuilder, (PyObject *) NULL, __pyx_kp_s_lark_cython_lark_cython, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "lark_cython/lark_cython.pyx":976
 * class ParseTreeBuilder:
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):             # <<<<<<<<<<<<<<
 *         self.tree_class = Tree #tree_class
 *         self.propagate_positions = propagate_positions
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_1__init__, 0, __pyx_n_s_ParseTreeBuilder___init, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__71);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_1) < 0) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":984
 *         self.rule_builders = list(self._init_builders(rules))
 * 
 *     def _init_builders(self, rules):             # <<<<<<<<<<<<<<
 *         propagate_positions = make_propagate_positions(self.propagate_positions)
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_3_init_builders, 0, __pyx_n_s_ParseTreeBuilder__init_builders, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init_builders, __pyx_t_1) < 0) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":1000
 *             yield rule, wrapper_chain
 * 
 *     def create_callback(self, transformer=None):             # <<<<<<<<<<<<<<
 *         callbacks = {}
 * 
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_11lark_cython_11lark_cython_16ParseTreeBuilder_6create_callback, 0, __pyx_n_s_ParseTreeBuilder_create_callback_2, NULL, __pyx_kp_s_lark_cython_lark_cython, __pyx_d, ((PyObject *)__pyx_codeobj__74)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_1, __pyx_tuple__75);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_create_callback, __pyx_t_1) < 0) __PYX_ERR(0, 1000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":974
 * 
 * 
 * class ParseTreeBuilder:             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, rules, tree_class, propagate_positions=False, ambiguous=False, maybe_placeholders=False):
 */
  __pyx_t_1 = __Pyx_Py3ClassCreate(((PyObject*)&__Pyx_DefaultClassType), __pyx_n_s_ParseTreeBuilder, __pyx_empty_tuple, __pyx_t_2, NULL, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParseTreeBuilder, __pyx_t_1) < 0) __PYX_ERR(0, 974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":1036
 * 
 * plugins = {
 *     'BasicLexer': BasicLexer,             # <<<<<<<<<<<<<<
 *     'ContextualLexer': ContextualLexer,
 *     'LexerThread': LexerThread,
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_BasicLexer, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_BasicLexer)) < 0) __PYX_ERR(0, 1036, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":1037
 * plugins = {
 *     'BasicLexer': BasicLexer,
 *     'ContextualLexer': ContextualLexer,             # <<<<<<<<<<<<<<
 *     'LexerThread': LexerThread,
 *     'LALR_Parser': LALR_Parser,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ContextualLexer, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_ContextualLexer)) < 0) __PYX_ERR(0, 1036, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":1038
 *     'BasicLexer': BasicLexer,
 *     'ContextualLexer': ContextualLexer,
 *     'LexerThread': LexerThread,             # <<<<<<<<<<<<<<
 *     'LALR_Parser': LALR_Parser,
 *     '_Parser': _Parser,     # XXX Ugly
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_LexerThread, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython_LexerThread)) < 0) __PYX_ERR(0, 1036, __pyx_L1_error)

  /* "lark_cython/lark_cython.pyx":1039
 *     'ContextualLexer': ContextualLexer,
 *     'LexerThread': LexerThread,
 *     'LALR_Parser': LALR_Parser,             # <<<<<<<<<<<<<<
 *     '_Parser': _Parser,     # XXX Ugly
 * }
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_LALR_Parser); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_LALR_Parser, __pyx_t_1) < 0) __PYX_ERR(0, 1036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "lark_cython/lark_cython.pyx":1040
 *     'LexerThread': LexerThread,
 *     'LALR_Parser': LALR_Parser,
 *     '_Parser': _Parser,     # XXX Ugly             # <<<<<<<<<<<<<<
 * }
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_Parser, ((PyObject *)__pyx_ptype_11lark_cython_11lark_cython__Parser)) < 0) __PYX_ERR(0, 1036, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_plugins, __pyx_t_2) < 0) __PYX_ERR(0, 1035, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Lexer(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_9__pyx_unpickle_Lexer, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Lexer, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_Lexer__set_state(<Lexer> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Lexer__set_state(Lexer __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_11__pyx_unpickle_BasicLexer, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_BasicLexer, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ParseConf(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_13__pyx_unpickle_ParseConf, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ParseConf, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_ParseConf__set_state(<ParseConf> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ParseConf__set_state(ParseConf __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.callbacks = __pyx_state[0]; __pyx_result.end_state = __pyx_state[1]; __pyx_result.parse_table = __pyx_state[2]; __pyx_result.start = __pyx_state[3]; __pyx_result.start_state = __pyx_state[4]; __pyx_result.states = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_15__pyx_unpickle_ParserState, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ParserState, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Meta(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_17__pyx_unpickle_Meta, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Meta, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_Meta__set_state(<Meta> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Meta__set_state(Meta __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.column = __pyx_state[0]; __pyx_result.empty = __pyx_state[1]; __pyx_result.end_column = __pyx_state[2]; __pyx_result.end_line = __pyx_state[3]; __pyx_result.end_pos = __pyx_state[4]; __pyx_result.line = __pyx_state[5]; __pyx_result.match_tree = __pyx_state[6]; __pyx_result.orig_expansion = __pyx_state[7]; __pyx_result.start_pos = __pyx_state[8]
 *     if len(__pyx_state) > 9 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_19__pyx_unpickle_ExpandSingleChild, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ExpandSingleChild, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_PropagatePositions(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_21__pyx_unpickle_PropagatePositions, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_PropagatePosition, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_PropagatePositions__set_state(<PropagatePositions> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_PropagatePositions__set_state(PropagatePositions __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.node_builder = __pyx_state[0]; __pyx_result.node_filter = __pyx_state[1]
 *     if len(__pyx_state) > 2 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_23__pyx_unpickle_ChildFilter, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ChildFilter, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_ChildFilterLALR(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_25__pyx_unpickle_ChildFilterLALR, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ChildFilterLALR, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_ChildFilterLALR__set_state(<ChildFilterLALR> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_ChildFilterLALR__set_state(ChildFilterLALR __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.append_none = __pyx_state[0]; __pyx_result.node_builder = __pyx_state[1]; __pyx_result.to_include = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_11lark_cython_11lark_cython_27__pyx_unpickle_ChildFilterLALR_NoPlaceholders, NULL, __pyx_kp_s_lark_cython_lark_cython); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_ChildFilterLALR_N, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "lark_cython/lark_cython.pyx":1
 * #cython: language_level=3             # <<<<<<<<<<<<<<
 * import cython
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_kp_u_Tree_scan_values_line_712, __pyx_kp_u_Return_all_values_in_the_tree_th) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init lark_cython.lark_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init lark_cython.lark_cython");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyString_CheckExact(s))) {
        PyObject *result = PyUnicode_FromEncodedObject(s, NULL, "strict");
        Py_DECREF(s);
        return result;
    }
    #endif
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (__Pyx_PyFastCFunction_Check(func)) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = Py_TYPE(iter)->tp_iternext;
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* UnpackUnboundCMethod */
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    }
#endif
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if (PY_VERSION_HEX >= 0x030600B1 && flag == METH_FASTCALL) {
            if (PY_VERSION_HEX >= 0x030700A0) {
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            } else {
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            }
        } else if (PY_VERSION_HEX >= 0x030700A0 && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* None */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
#if PY_MAJOR_VERSION < 3 || CYTHON_USE_PYLONG_INTERNALS
#define __Pyx_PyInt_FloorDivideObjC_ZeroDivisionError(operand)\
    if (unlikely(zerodivision_check && ((operand) == 0))) {\
        PyErr_SetString(PyExc_ZeroDivisionError, "integer division by zero");\
        return NULL;\
    }
#endif
static PyObject* __Pyx_PyInt_FloorDivideObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            __Pyx_PyInt_FloorDivideObjC_ZeroDivisionError(b)
            if (unlikely(b == -1 && ((unsigned long)a) == 0-(unsigned long)a))
                return PyInt_Type.tp_as_number->nb_floor_divide(op1, op2);
            else {
                long q, r;
                q = a / b;
                r = a - q*b;
                q -= ((r != 0) & ((r ^ b) < 0));
                x = q;
            }
            return PyInt_FromLong(x);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_floor_divide(op1, op2);
            }
        }
                __Pyx_PyInt_FloorDivideObjC_ZeroDivisionError(b)
                {
                    long q, r;
                    q = a / b;
                    r = a - q*b;
                    q -= ((r != 0) & ((r ^ b) < 0));
                    x = q;
                }
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                {
                    PY_LONG_LONG q, r;
                    q = lla / llb;
                    r = lla - q*llb;
                    q -= ((r != 0) & ((r ^ llb) < 0));
                    llx = q;
                }
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceFloorDivide : PyNumber_FloorDivide)(op1, op2);
}
#endif

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* pyfrozenset_new */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((PY_VERSION_HEX >= 0x031000A1) || likely(PySet_GET_SIZE(result)))
            return result;
        Py_DECREF(result);
#endif
    }
#if CYTHON_USE_TYPE_SLOTS
    return PyFrozenSet_Type.tp_new(&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#else
    return PyObject_Call((PyObject*)&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#endif
}

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_values */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_values, d);
    else
        return PyDict_Values(d);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject** CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyList_New(0);
    dest = PyList_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyListObject*)src)->ob_item + start,
        ((PyListObject*)dest)->ob_item,
        length);
    return dest;
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    PyObject* dest;
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (unlikely(length <= 0))
        return PyTuple_New(0);
    dest = PyTuple_New(length);
    if (unlikely(!dest))
        return NULL;
    __Pyx_copy_object_array(
        ((PyTupleObject*)src)->ob_item + start,
        ((PyTupleObject*)dest)->ob_item,
        length);
    return dest;
}
#endif

/* SliceObject */
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(PyObject* obj, PyObject* value,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_ass_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_ass_slice(obj, cstart, cstop, value);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_ass_subscript))
#endif
    {
        int result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_ass_subscript(obj, py_slice, value);
#else
        result = value ? PyObject_SetItem(obj, py_slice, value) : PyObject_DelItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object does not support slice %.10s",
        Py_TYPE(obj)->tp_name, value ? "assignment" : "deletion");
bad:
    return -1;
}

/* None */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (Py_TYPE(L) == &PySet_Type) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_n_s_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CallNextTpTraverse */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_traverse != current_tp_traverse)
        type = type->tp_base;
    while (type && type->tp_traverse == current_tp_traverse)
        type = type->tp_base;
    if (type && type->tp_traverse)
        return type->tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    while (type && type->tp_clear != current_tp_clear)
        type = type->tp_base;
    while (type && type->tp_clear == current_tp_clear)
        type = type->tp_base;
    if (type && type->tp_clear)
        type->tp_clear(obj);
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYSTON || CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (methoddescr_type == NULL) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (!meth) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* GetNameInClass */
static PyObject *__Pyx_GetGlobalNameAfterAttributeLookup(PyObject *name) {
    PyObject *result;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    result = __Pyx_PyObject_GetAttrStr(nmspace, name);
    if (!result) {
        result = __Pyx_GetGlobalNameAfterAttributeLookup(name);
    }
    return result;
}

/* FusedFunction */
static PyObject *
__pyx_FusedFunction_New(PyMethodDef *ml, int flags,
                        PyObject *qualname, PyObject *closure,
                        PyObject *module, PyObject *globals,
                        PyObject *code)
{
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_FusedFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        __pyx_FusedFunctionObject *fusedfunc = (__pyx_FusedFunctionObject *) op;
        fusedfunc->__signatures__ = NULL;
        fusedfunc->type = NULL;
        fusedfunc->self = NULL;
        PyObject_GC_Track(op);
    }
    return op;
}
static void
__pyx_FusedFunction_dealloc(__pyx_FusedFunctionObject *self)
{
    PyObject_GC_UnTrack(self);
    Py_CLEAR(self->self);
    Py_CLEAR(self->type);
    Py_CLEAR(self->__signatures__);
    __Pyx__CyFunction_dealloc((__pyx_CyFunctionObject *) self);
}
static int
__pyx_FusedFunction_traverse(__pyx_FusedFunctionObject *self,
                             visitproc visit,
                             void *arg)
{
    Py_VISIT(self->self);
    Py_VISIT(self->type);
    Py_VISIT(self->__signatures__);
    return __Pyx_CyFunction_traverse((__pyx_CyFunctionObject *) self, visit, arg);
}
static int
__pyx_FusedFunction_clear(__pyx_FusedFunctionObject *self)
{
    Py_CLEAR(self->self);
    Py_CLEAR(self->type);
    Py_CLEAR(self->__signatures__);
    return __Pyx_CyFunction_clear((__pyx_CyFunctionObject *) self);
}
static PyObject *
__pyx_FusedFunction_descr_get(PyObject *self, PyObject *obj, PyObject *type)
{
    __pyx_FusedFunctionObject *func, *meth;
    func = (__pyx_FusedFunctionObject *) self;
    if (func->self || func->func.flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(self);
        return self;
    }
    if (obj == Py_None)
        obj = NULL;
    meth = (__pyx_FusedFunctionObject *) __pyx_FusedFunction_New(
                    ((PyCFunctionObject *) func)->m_ml,
                    ((__pyx_CyFunctionObject *) func)->flags,
                    ((__pyx_CyFunctionObject *) func)->func_qualname,
                    ((__pyx_CyFunctionObject *) func)->func_closure,
                    ((PyCFunctionObject *) func)->m_module,
                    ((__pyx_CyFunctionObject *) func)->func_globals,
                    ((__pyx_CyFunctionObject *) func)->func_code);
    if (!meth)
        return NULL;
    if (func->func.defaults) {
        PyObject **pydefaults;
        int i;
        if (!__Pyx_CyFunction_InitDefaults((PyObject*)meth,
                                      func->func.defaults_size,
                                      func->func.defaults_pyobjects)) {
            Py_XDECREF((PyObject*)meth);
            return NULL;
        }
        memcpy(meth->func.defaults, func->func.defaults, func->func.defaults_size);
        pydefaults = __Pyx_CyFunction_Defaults(PyObject *, meth);
        for (i = 0; i < meth->func.defaults_pyobjects; i++)
            Py_XINCREF(pydefaults[i]);
    }
    Py_XINCREF(func->func.func_classobj);
    meth->func.func_classobj = func->func.func_classobj;
    Py_XINCREF(func->__signatures__);
    meth->__signatures__ = func->__signatures__;
    Py_XINCREF(type);
    meth->type = type;
    Py_XINCREF(func->func.defaults_tuple);
    meth->func.defaults_tuple = func->func.defaults_tuple;
    if (func->func.flags & __Pyx_CYFUNCTION_CLASSMETHOD)
        obj = type;
    Py_XINCREF(obj);
    meth->self = obj;
    return (PyObject *) meth;
}
static PyObject *
_obj_to_str(PyObject *obj)
{
    if (PyType_Check(obj))
        return PyObject_GetAttr(obj, __pyx_n_s_name_2);
    else
        return PyObject_Str(obj);
}
static PyObject *
__pyx_FusedFunction_getitem(__pyx_FusedFunctionObject *self, PyObject *idx)
{
    PyObject *signature = NULL;
    PyObject *unbound_result_func;
    PyObject *result_func = NULL;
    if (self->__signatures__ == NULL) {
        PyErr_SetString(PyExc_TypeError, "Function is not fused");
        return NULL;
    }
    if (PyTuple_Check(idx)) {
        PyObject *list = PyList_New(0);
        Py_ssize_t n = PyTuple_GET_SIZE(idx);
        PyObject *sep = NULL;
        int i;
        if (unlikely(!list))
            return NULL;
        for (i = 0; i < n; i++) {
            int ret;
            PyObject *string;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            PyObject *item = PyTuple_GET_ITEM(idx, i);
#else
            PyObject *item = PySequence_ITEM(idx, i);  if (unlikely(!item)) goto __pyx_err;
#endif
            string = _obj_to_str(item);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
            Py_DECREF(item);
#endif
            if (unlikely(!string)) goto __pyx_err;
            ret = PyList_Append(list, string);
            Py_DECREF(string);
            if (unlikely(ret < 0)) goto __pyx_err;
        }
        sep = PyUnicode_FromString("|");
        if (likely(sep))
            signature = PyUnicode_Join(sep, list);
__pyx_err:
;
        Py_DECREF(list);
        Py_XDECREF(sep);
    } else {
        signature = _obj_to_str(idx);
    }
    if (!signature)
        return NULL;
    unbound_result_func = PyObject_GetItem(self->__signatures__, signature);
    if (unbound_result_func) {
        if (self->self || self->type) {
            __pyx_FusedFunctionObject *unbound = (__pyx_FusedFunctionObject *) unbound_result_func;
            Py_CLEAR(unbound->func.func_classobj);
            Py_XINCREF(self->func.func_classobj);
            unbound->func.func_classobj = self->func.func_classobj;
            result_func = __pyx_FusedFunction_descr_get(unbound_result_func,
                                                        self->self, self->type);
        } else {
            result_func = unbound_result_func;
            Py_INCREF(result_func);
        }
    }
    Py_DECREF(signature);
    Py_XDECREF(unbound_result_func);
    return result_func;
}
static PyObject *
__pyx_FusedFunction_callfunction(PyObject *func, PyObject *args, PyObject *kw)
{
     __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    int static_specialized = (cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD &&
                              !((__pyx_FusedFunctionObject *) func)->__signatures__);
    if (cyfunc->flags & __Pyx_CYFUNCTION_CCLASS && !static_specialized) {
        return __Pyx_CyFunction_CallAsMethod(func, args, kw);
    } else {
        return __Pyx_CyFunction_Call(func, args, kw);
    }
}
static PyObject *
__pyx_FusedFunction_call(PyObject *func, PyObject *args, PyObject *kw)
{
    __pyx_FusedFunctionObject *binding_func = (__pyx_FusedFunctionObject *) func;
    Py_ssize_t argc = PyTuple_GET_SIZE(args);
    PyObject *new_args = NULL;
    __pyx_FusedFunctionObject *new_func = NULL;
    PyObject *result = NULL;
    PyObject *self = NULL;
    int is_staticmethod = binding_func->func.flags & __Pyx_CYFUNCTION_STATICMETHOD;
    int is_classmethod = binding_func->func.flags & __Pyx_CYFUNCTION_CLASSMETHOD;
    if (binding_func->self) {
        Py_ssize_t i;
        new_args = PyTuple_New(argc + 1);
        if (!new_args)
            return NULL;
        self = binding_func->self;
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_INCREF(self);
#endif
        Py_INCREF(self);
        PyTuple_SET_ITEM(new_args, 0, self);
        for (i = 0; i < argc; i++) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            PyObject *item = PyTuple_GET_ITEM(args, i);
            Py_INCREF(item);
#else
            PyObject *item = PySequence_ITEM(args, i);  if (unlikely(!item)) goto bad;
#endif
            PyTuple_SET_ITEM(new_args, i + 1, item);
        }
        args = new_args;
    } else if (binding_func->type) {
        if (argc < 1) {
            PyErr_SetString(PyExc_TypeError, "Need at least one argument, 0 given.");
            return NULL;
        }
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        self = PyTuple_GET_ITEM(args, 0);
#else
        self = PySequence_ITEM(args, 0);  if (unlikely(!self)) return NULL;
#endif
    }
    if (self && !is_classmethod && !is_staticmethod) {
        int is_instance = PyObject_IsInstance(self, binding_func->type);
        if (unlikely(!is_instance)) {
            PyErr_Format(PyExc_TypeError,
                         "First argument should be of type %.200s, got %.200s.",
                         ((PyTypeObject *) binding_func->type)->tp_name,
                         Py_TYPE(self)->tp_name);
            goto bad;
        } else if (unlikely(is_instance == -1)) {
            goto bad;
        }
    }
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
    Py_XDECREF(self);
    self = NULL;
#endif
    if (binding_func->__signatures__) {
        PyObject *tup;
        if (is_staticmethod && binding_func->func.flags & __Pyx_CYFUNCTION_CCLASS) {
            tup = PyTuple_Pack(3, args,
                               kw == NULL ? Py_None : kw,
                               binding_func->func.defaults_tuple);
            if (unlikely(!tup)) goto bad;
            new_func = (__pyx_FusedFunctionObject *) __Pyx_CyFunction_CallMethod(
                func, binding_func->__signatures__, tup, NULL);
        } else {
            tup = PyTuple_Pack(4, binding_func->__signatures__, args,
                               kw == NULL ? Py_None : kw,
                               binding_func->func.defaults_tuple);
            if (unlikely(!tup)) goto bad;
            new_func = (__pyx_FusedFunctionObject *) __pyx_FusedFunction_callfunction(func, tup, NULL);
        }
        Py_DECREF(tup);
        if (unlikely(!new_func))
            goto bad;
        Py_XINCREF(binding_func->func.func_classobj);
        Py_CLEAR(new_func->func.func_classobj);
        new_func->func.func_classobj = binding_func->func.func_classobj;
        func = (PyObject *) new_func;
    }
    result = __pyx_FusedFunction_callfunction(func, args, kw);
bad:
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
    Py_XDECREF(self);
#endif
    Py_XDECREF(new_args);
    Py_XDECREF((PyObject *) new_func);
    return result;
}
static PyMemberDef __pyx_FusedFunction_members[] = {
    {(char *) "__signatures__",
     T_OBJECT,
     offsetof(__pyx_FusedFunctionObject, __signatures__),
     READONLY,
     0},
    {0, 0, 0, 0, 0},
};
static PyMappingMethods __pyx_FusedFunction_mapping_methods = {
    0,
    (binaryfunc) __pyx_FusedFunction_getitem,
    0,
};
static PyTypeObject __pyx_FusedFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "fused_cython_function",
    sizeof(__pyx_FusedFunctionObject),
    0,
    (destructor) __pyx_FusedFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    0,
    0,
    0,
    &__pyx_FusedFunction_mapping_methods,
    0,
    (ternaryfunc) __pyx_FusedFunction_call,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __pyx_FusedFunction_traverse,
    (inquiry) __pyx_FusedFunction_clear,
    0,
    0,
    0,
    0,
    0,
    __pyx_FusedFunction_members,
    __pyx_CyFunction_getsets,
    &__pyx_CyFunctionType_type,
    0,
    __pyx_FusedFunction_descr_get,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
    0,
#endif
};
static int __pyx_FusedFunction_init(void) {
    __pyx_FusedFunctionType_type.tp_base = __pyx_CyFunctionType;
    __pyx_FusedFunctionType = __Pyx_FetchCommonType(&__pyx_FusedFunctionType_type);
    if (__pyx_FusedFunctionType == NULL) {
        return -1;
    }
    return 0;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* ImportNumPyArray */
static PyObject* __Pyx__ImportNumPyArray(void) {
    PyObject *numpy_module, *ndarray_object = NULL;
    numpy_module = __Pyx_Import(__pyx_n_s_numpy, NULL, 0);
    if (likely(numpy_module)) {
        ndarray_object = PyObject_GetAttrString(numpy_module, "ndarray");
        Py_DECREF(numpy_module);
    }
    if (unlikely(!ndarray_object)) {
        PyErr_Clear();
    }
    if (unlikely(!ndarray_object || !PyObject_TypeCheck(ndarray_object, &PyType_Type))) {
        Py_XDECREF(ndarray_object);
        Py_INCREF(Py_None);
        ndarray_object = Py_None;
    }
    return ndarray_object;
}
static CYTHON_INLINE PyObject* __Pyx_ImportNumPyArrayTypeIfAvailable(void) {
    if (unlikely(!__pyx_numpy_ndarray)) {
        __pyx_numpy_ndarray = __Pyx__ImportNumPyArray();
    }
    Py_INCREF(__pyx_numpy_ndarray);
    return __pyx_numpy_ndarray;
}

/* CoroutineBase */
#include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
            _PyGen_SetStopIterationValue(result);
        }
        Py_CLEAR(result);
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (Py_REFCNT(self) > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM+0 >= 0x06000000
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
